/*****************************************************************
 *
 *	tapio
 *
 *	 function to replace Fortran subroutine TAPIO in 
 *	FBIDR_EXTRACTOR program.
 *
 *	Before using this function, be sure to 
 *
 *	   setenv TAPE /dev/rst0
 *
 *	Replace "rst0" with the appropriate device.
 *
 *	4/22/94 Lynne Norikane, Vexcel Corporation.
 *
 ****************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <sys/types.h>
#include <sys/mtio.h>
#include <sys/ioctl.h>

int tapio_ (icode, ibuf, isize, num)
int	*icode;
char	*ibuf;
int	*isize;
int	*num;
{
   static int	fd;
   
   struct mtop  op;
   char	  *device;
   int    n;

   switch (*icode) {
      /* ---- initialization ---- */
      case 1:  device = getenv ("TAPE");
               if (device == NULL) {
                  fprintf (stderr, "**** ERROR: Environment variable TAPE not set ****\n");
                  exit(0);
               } else {
                  fd = open (device, 0);
                  if (fd == -1) {
                     fprintf (stderr, "**** ERROR: Unable to open %s ****\n", device);
                     exit(0);
                  }
               }
               break;
      /* ---- write ---- */
      case 2:  n = write (fd, ibuf, *isize);
               if (n != *isize) {
                  fprintf (stderr, "**** ERROR: Wrote %d of %d bytes ****\n", n, *isize);
                  exit(0);
               }
               break;
      /* ---- read ---- */
      case 3:  n = read (fd, ibuf, *isize);
               if (n != *isize) {
                  fprintf (stderr, "**** ERROR: Read %d of %d bytes ****\n", n, *isize);
                  exit(0);
               }
               break;
      /* ---- skip file(s) ---- */
      case 4:  if (*num > 0) {
                  op.mt_op = MTFSF;
                  op.mt_count = *num;
               } else {
                  op.mt_op = MTBSF;
                  op.mt_count = -(*num);
               }
               if (ioctl(fd, MTIOCTOP, &op) == -1) {
                  fprintf (stderr, "**** ERROR: Unable to skip %d files ****\n", *num);
                  exit(0);
               }
               break;
      /* ---- skip record(s) ---- */
      case 5:  if (*num > 0) {
                  op.mt_op = MTFSR;
                  op.mt_count = *num;
               } else {
                  op.mt_op = MTBSR;
                  op.mt_count = -(*num);
               }
               if (ioctl(fd, MTIOCTOP, &op) == -1) {
                  fprintf (stderr, "**** ERROR: Unable to skip %d records ****\n", *num);
                  exit(0);
               }
               break;
      /* ---- rewind ---- */
      case 6:  op.mt_op = MTREW;
               if (ioctl(fd, MTIOCTOP, &op) == -1) {
                  fprintf (stderr, "**** ERROR: Unable to rewind ****\n");
                  exit(0);
               }
               break;
      /* ---- write EOF ---- */
      case 7:  op.mt_op = MTWEOF;
               if (ioctl(fd, MTIOCTOP, &op) == -1) {
                  fprintf (stderr, "**** ERROR: Unable to write EOF ****\n");
                  exit(0);
               }
               break;
      /* ---- rewind offline ---- */
      case 8:  op.mt_op = MTOFFL;
               if (ioctl(fd, MTIOCTOP, &op) == -1) {
                  fprintf (stderr, "**** ERROR: Unable to rewind and go offline ****\n");
                  exit(0);
               }
               break;
   }

   return (0);

}
