C========================================================================
C c_sab_hdr.f
C	contains subroutines c_sab_hdr and c_extract_sab
C------------------------------------------------------------------------
      subroutine c_sab_hdr ( error, filename )
C
C Abstract:
C	Top-level routine which calls C_EXTRACT_SAB to extract sab header 
C	information
C
	implicit none

C Declarations:
C	Passing Parameters: 

      integer*4 error                  ! error
      character*(*) filename

      integer*4 burst_count                   ! burst counter
      common /burst_counter/ burst_count

      integer*4 n_reject                      ! number of missing burst
      common /n_reject/ n_reject

      integer*4 sfdu_len                      ! length of sfdu of EDR file
      common /sfdu_len/ sfdu_len

      integer*4 total_golay_error /0/, golay_burst /0/
      common /golay/ total_golay_error, golay_burst

C	Constant Parameters: 

      integer*4 maxrec                 
      parameter (maxrec=8600)

C	Include files: 

      include '../../../inc/b_head'                 ! bidr header record file
      include '../../../inc/po'                     ! per-orbit
      include '../../../inc/sdmr'                   ! sar data monitor report

C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	error		O		error checking flag
C	filename	I		name of SAB header file
C
C Constant Parameters:
C	maxrec	- maximum number of bursts
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	see include file listing
C	burst_counter	I		returns from c_extract_sab
C	n_reject	I		returns from c_extract_sab
C	sfdu_len	I		returns from c_get_sfdu_len
C	golay		I		returns from c_extract_sab
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	Reads SAB header file
C
C Author and Institution:
C	Cynthia L. Wong (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C	K. Maurice for PDS subnode - changed ../inc to ../../inc for Makefiles
C
C========================================================================
C Local Variables:

      integer*4 i                             ! scratch index
      integer*4 initdk
      integer*4 channel                       ! channel linked to file
      integer*4 lun                           ! logical unit of file
      integer*4 reclng /338/                  ! sab record length
      integer*4 rec_os /0/                    ! records to skip
      integer*4 d1,d20,d0	      ! datax = x ; L. Chen
      external c_extract_sab
      external c_get_sfdu_len

      integer*4 burst_proc       ! number of burst to be processed
      integer*4 percent_good     ! percent of good data * 10

      write (*,*) 'C_SAB_HDR:'

c    set constant  Lawrence Chen 1/7/94

      d1 = 1
      d20 = 20
      d0 = 0

C>>  Open SAB header file

      error = 0
      burst_count = 0
      n_reject = 0

      call get_lun ( lun )
      WRITE (*,*) 'Reading (EZIO) ', filename
      CHANNEL = INITDK( LUN, filename ) 
      if ( channel.le.0 ) then
         write (*,*) 'OPENQIO error'
         error = 1
         return
      endif
      call bufhandler (d1,d20,channel,d0,d0,d0,c_get_sfdu_len,error)
	CALL BUFHANDLER ( PO_DATA_GEN_N_EDR_BURSTS, RECLNG, CHANNEL, d0,
     .                  sfdu_len, rec_os, c_extract_sab, error )

      if ( error.eq.1 ) then
         write (*,*) 'BUFHANDLER error'
         return
      endif
	IF ( BURST_COUNT .LT. PO_DATA_GEN_N_EDR_BURSTS ) THEN
         write (*,*) '# sab burst is less than # edr bursts'
         write (*,*) ' burst_count=', burst_count
	PO_DATA_GEN_N_EDR_BURSTS = BURST_COUNT
         error = 1
      endif

      burst_proc = burst_count - n_reject
      write (*,*) 'burst processed=',burst_proc
      percent_good = ( burst_proc / float( burst_count ) ) * 1000
      write (*,*) 'percent good data=',percent_good

	WRITE (SDMR_SEC2_MISDAT,'(I4)') N_REJECT
	WRITE (SDMR_SEC2_NUM_PROC,'(I4)') BURST_PROC
	WRITE (SDMR_SEC2_DD2,'(I3)') INT( PERCENT_GOOD / 10.)
	WRITE (SDMR_SEC2_F2,'(I1.1)') MOD( PERCENT_GOOD,10 )

      call closedk ( lun, channel )

      write (*,*)
      write (*,*) 'GOLAY_ERROR_COUNT=', total_golay_error,
     .            ' GOLAY_BURST=', golay_burst
      write(*,*)  'GOLAY_ERROR_RATE=',
     .             total_golay_error/ float( golay_burst * 54 * 8 )
      write (*,*)

      write (*,*) 'End of C_SAB_HDR.'

      return
      end

C=============================================================================
C>>  C_EXTRACT_SAB - CONTROL subroutine to extract SAB header information
C>>                  This routine is called from BUFHANDLER
C>>
C>>  ** /clw/11-07-89/ **
C>>  ** /clw/07-26-90/ check for number of bursts > 8600
C=============================================================================
C>>
      subroutine c_extract_sab ( buf, nrec )

      implicit none

C>>  Passing parameters

      byte buf (*)            ! data buffer
      integer*4 nrec            ! number of records

C>>  Addition to Physical/Math Constants file

      integer*4 maxrec          ! maximun records per orbit
      real*8 res_clk         !MGN fine resolution clock interval
      real*8 stalo           !stalo frequency in Hz

      parameter (maxrec=8600)
      parameter (stalo = 72.272727D6)
      parameter (res_clk=32./stalo)

C>>  Include files

      include '../../../inc/sar_stat'          ! sar status
      include '../../../inc/radiom'            ! radiometer related
      include '../../../inc/radiom2'

C>>  Variables

      byte threshold (24,maxrec)

      integer*4 i, j, k       ! scratch index
      integer*4 ptr           ! buffer byte pointer
      integer*4 bptr          ! burst pointer
      integer*4 n_reject      ! number of missing burst
      integer*2 mem_check     ! memory check

      integer*4 rcd_ptr       ! rcd byte pointer
      integer*4 first_good_burst /0/

      integer*2 PRF, NP, RGL, SCR, FR, BP, GS, GR, RS, ACR
      character*12 sfdu_label

      integer*4 rcd_count, rcd_missing, rcd_total
      byte rcd_percent( maxrec )
      real rcd_lat( maxrec )
      common / rcd_rpt / rcd_percent, rcd_lat

      integer*4 max_rcd_percent, rbad_size
      parameter ( max_rcd_percent = 50 )
      parameter ( rbad_size = nint(max_rcd_percent/100. * 111) )
      integer*2 rcd_bad(rbad_size)
      integer*4 rbad_ptr

      integer*4 golay_error_count, golay_decode
      integer*4 total_golay_error, golay_burst
      common /golay/ total_golay_error, golay_burst

c ------------------------------------------
c
c Lawrence Chen 12/21/93
c Since the arguments for iishft are integer*2
c and the arguments for jishft are integer*4
c The explicit type of arguments will cause problem when
c compiling the subroutine in Sun workstation
c Therefore, one way to solve the problem is
c compiling the subroutine with -i2 flags, so all of the
c explicit type arguments are defined as integer*2
c modify the subroutine by adding a integer*4 variable
c use it instead of explicit argument in jishft instrinsic
c function

      integer*4 i4b
      integer*2 datac0,datai2

c -----------------------------------------

Cccccccccccccc  JG  09/14/90:

	BYTE	ALT_freq
	BYTE	ALT_present

Cccccccccccccc End of change.


C>>  Common Blocks

      common /threshold/ threshold
      common /burst_counter/ bptr
      common /n_reject/ n_reject

	INTEGER*4	ii


D     write (*,*) 'C_EXTRACT_SAB: # records=',nrec
D     write (*,*) '               burst count=',bptr
D     write (*,*) '               num reject=',n_reject

      ptr = 0
      do i = 1, nrec

         decode (12,'(a12)',buf(ptr+1)) sfdu_label
D         write (*,*) bptr+1, sfdu_label,
D    .               index( sfdu_label, 'NJPL1I00C111' )
         if ( index( sfdu_label, 'NJPL1I00C111' ) .ne. 1 ) then
D            write (*,*) 'Total number of SAB: ', bptr
             return
         endif

         bptr = bptr + 1
         if ( bptr .gt. maxrec ) then
            write (*,*) '** ERROR ** number of burst > 8600 '
            return
         endif

D        write (*,*) 'Processing SAB burst # ', bptr

C>>  Extract thresholds (byte 289-312)

         sar_stat_error( bptr ) = 0
         do j = 1, 24
            threshold (j,bptr) = buf (ptr+288+j)
            if ( izext( threshold (j,bptr) ) .ge. 127 ) then
               write (*,*) 'Sensor Saturation in threshold'
	       threshold (j,bptr) = '7f'x
            endif
         enddo

C>>  Extract radiometer (byte 315-316)

         radiom_rad_raw(bptr) = iishft ( izext (buf(ptr+315)), 8 ) .or.
     .                                   izext (buf(ptr+316))


C>>  Extract time tag (byte 317-324)

         sar_stat_time_tag_mod210( bptr ) =
     .             iishft ( izext(buf(ptr+318)), 8 ) .or.
     .	                    izext(buf(ptr+319))
         sar_stat_time_tag_rim(1,bptr) = buf(ptr+320)
         sar_stat_time_tag_rim(2,bptr) = buf(ptr+321)
         sar_stat_time_tag_rim(3,bptr) = buf(ptr+322)
         sar_stat_time_tag_mod91( bptr ) = buf(ptr+323)
         sar_stat_time_tag_mod10( bptr ) = buf(ptr+324)

C>>  Extract SAR status information (byte 327-336)

         FR  = iishft( iibits( izext( buf(ptr+327) ),0,7 ), 1 ) .or.
     .                 iibits( izext( buf(ptr+328) ),7,1 )
         PRF = iibits( izext( buf(ptr+328) ),0,7 )
         SCR = izext ( buf(ptr+329) )
         RGL = izext ( buf(ptr+330) )
         NP  = iishft ( izext ( buf(ptr+331) ), 3 ) .or.
     .         iibits ( izext ( buf(ptr+332) ),5,3 )
         ACR = iishft( iibits( izext( buf(ptr+332) ),0,5 ), 4 ) .or.
     .                 iibits( izext( buf(ptr+333) ),4,4 )
         BP  = iishft( iibits( izext( buf(ptr+333) ),0,4 ), 11 ) .or.
     .         iishft(         izext( buf(ptr+334) ),       3  ) .or.
     .                 iibits( izext( buf(ptr+335) ),5,3 )
         GS  = iishft( iibits( izext( buf(ptr+335) ),0,2 ), 1 ) .or.
     .                 iibits( izext( buf(ptr+336) ),7,1 )
         GR  = ( buf(ptr+336).and.'70'x ) / 16


Ccccccccccccccc  JG  09/14/90:

	 ALT_freq = 4 - ( buf(ptr+336) .AND. '0C'x ) / 4

Ccccccccccccccc End of change.


         RS  = ( buf(ptr+336).and.'02'x ) / 2


Ccccccccccccccc  JG  09/14/90:

         ALT_present  = ( buf(ptr+336) .and. '01'x )

Ccccccccccccccc End of change.


D	WRITE(*,100) (buf(ptr+ii), ii=327,336)
D100	FORMAT ( 1x, 10( z2.2, 3x ) )
D        write (*,'(12i8)') FR, PRF, SCR, RGL, NP, ACR, BP, GS, GR,
D	2			ALT_freq, RS, ALT_present

         sar_stat_PRF_code(bptr) = 512 - PRF
         sar_stat_n_echos(bptr) = 2048 - NP
         sar_stat_range_gate(bptr) = 256 - RGL
         sar_stat_coarse_res(bptr) = 256 - SCR
         sar_stat_fine_res(bptr) = 2 * ( 256 - FR )
         sar_stat_burst_period(bptr) = ( 32768 - BP ) * 151
         sar_stat_SAR_gain(bptr) = GS
         sar_stat_alt_coarse_res(bptr) = 512 - ACR

         radiom_rad_gain(bptr) = GR
         radiom_rad_source(bptr) = RS


Ccccccccccccc  JG  09/14/90:

	radiom2_ACR( bptr ) = 512 - ACR
	radiom2_ALT_freq( bptr ) = ALT_freq
	radiom2_ALT_present( bptr )= ALT_present

Ccccccccccccc End of change.


C>>  Extract memory check

         mem_check = iishft ( izext( buf(ptr+337) ), 8 ) .or.
     .                        izext( buf(ptr+338) )

         if ( mem_check.eq.0 ) then
            sar_stat_test( bptr ) = 0
         else
            sar_stat_test( bptr ) = 1
         endif

         sar_stat_anomaly( bptr ) = 0

C>>  Extract golay_error count

c	L. Chen 6/28/94
c         golay_decode = izext( buf(ptr+278) .and. 'C0'x )
	datac0 = 'C0'x
	datai2 = buf(ptr+278) .and. datac0
	golay_decode = izext(datai2)


	 i4b = 8  ! L. Chen 
         if ( golay_decode .eq. 0 ) then
            golay_error_count = jishft( jzext( buf(ptr+271) ), i4b) .or.
     .                                  jzext( buf(ptr+272) )
            golay_burst = golay_burst + 1
            total_golay_error = total_golay_error + golay_error_count
         else
            golay_error_count = 0
         endif
         if ( golay_decode .ne. 0 ) then
            sar_stat_anomaly( bptr ) = 1
            write (*,'(1x,a,i5,5x,z8)')
     .             'Golay decode not done at burst ',
     .             bptr, golay_decode
         elseif ( golay_error_count .gt. 0 ) then
            write (*,*) 'Golay error bits =', golay_error_count,
     .                  ' at burst ', bptr
         endif

C>>  Extract rcd_count & rcd_missing

         rcd_count = izext ( buf(ptr+273) )
         rcd_missing = izext ( buf(ptr+274) )

         rcd_total = rcd_count + rcd_missing
         rcd_percent( bptr )= nint(
     .                   ( rcd_missing / float( rcd_total ) ) * 100. )

         rcd_ptr = 147
         if ( rcd_percent( bptr ) .eq. 0 .or.
     .        rcd_percent( bptr ) .gt. max_rcd_percent ) then

C>>  Determine if there are any missing rcd frames; check bytes 147-257
C>>                                                 total 111 rcd frames
            do j = 1, rcd_total
               if ( buf( ptr + rcd_ptr ) .eq. 0 ) then
                  sar_stat_anomaly( bptr ) = 1
               endif
               rcd_ptr = rcd_ptr + 1
            enddo

         else

            rbad_ptr = 1
            do j = 1, rcd_total
               if ( buf( ptr + rcd_ptr ) .eq. 0 ) then
                  rcd_bad( rbad_ptr ) = j
                  rbad_ptr = rbad_ptr + 1
               endif
               rcd_ptr = rcd_ptr + 1
            enddo
C            write (*,'(1x,3(a,i5),a)') 'C_SAB_HDR: @burst ', bptr,
C     .                   ' missing rcd ',rcd_missing,
C     .                   ' out of ', rcd_total, ' RCD:'
C    	    write (*,*) (rcd_bad(j),j=1,rcd_missing)

         endif

C>>  Check for first good burst

         if ( first_good_burst .eq. 0 .and.
     .        sar_stat_anomaly( bptr ) .eq. 0 .and.
     .        sar_stat_test( bptr ) .eq. 0 .and.
     .        sar_stat_error( bptr ) .eq. 0 ) then
            first_good_burst = 1
            sar_stat_test( bptr ) = 1
         endif

         if ( sar_stat_anomaly( bptr ) .eq. 1 .or.
     .        sar_stat_test( bptr ) .eq. 1 .or.
     .        sar_stat_error( bptr ) .eq. 1 ) then
               n_reject = n_reject + 1
         endif

         ptr = ptr + 338

D        write (*,*) 'buffer byte pointer=',ptr

      enddo

D     write (*,*) 'End of C_EXTRACT_SAB.'

      return
      end
