/*  SPAWN_COPY_EDR  routine to create sub process to run COPY_EDR  */
#include <stdio.h>
char copy_edr_char[256];
FILE *copy_edr_fd;

int spawn_copy_edr_( edr_sar, edr_ancillary, tape1, tape2, orbit )
char *edr_sar, *edr_ancillary, *tape1, *tape2, *orbit;

/*  Inputs:

	EDR_SAR:  A string containing the directory into which the
		EDR header, data, and trailer files will be recorded.

	EDR_ANCILLARY:  A string contiaining the directory into which
		the EDR ancillary files will be recorded.

	TAPE1, TAPE2:  Strings containing the names of the input tape
			drive(s).  If only one drive is used, set TAPE2
			to zero (0).

	ORBIT:  A dual-function argument;  if zero, the routine will
		return immediately without waiting for the subprocess
		to complete.  if non-zero, this is assumed to point to
		a string which will be used to store the orbit ID of the 
		EDR that was read, and the routine will return only after
		the process is complete.

		If the routine returns asynchronously (before the 
		subprocess completes), a call to WAIT_COPY_EDR 
		must be issued later to wait for the subprocess to 
		complete, and extract the orbit ID.

	The orbit ID returned has the form T_NNNNN_VV where T is the
	data type, NNNNN is the decimal orbit number with leading zeros,
	and VV is the version number with leading zeros.

	The routine will return a 1 if the subprocess was spawned
	successfully (asynchronous) or if the subprocess completed
	and the returned orbit number was extracted successfully
	(synchronous).  A -1 will be returned on any error.
*/
{
FILE *popen();

/*  Build the command string  */

strcpy( copy_edr_char, "copy_edr " );
strcat( copy_edr_char, edr_ancillary );
strcat( copy_edr_char, " ");
strcat( copy_edr_char, edr_sar );
strcat( copy_edr_char, " ");
strcat( copy_edr_char, tape1 );
strcat( copy_edr_char, " ");
strcat( copy_edr_char, tape2 );
printf("SPAWN_COPY_EDR command to popen:\n %s]\n", copy_edr_char );
copy_edr_fd = popen( copy_edr_char, "r" );
if( copy_edr_fd != NULL ){
    printf("SPAWN_COPT_EDR error in POPEN: %d\n", copy_edr_fd );
    return( (int) copy_edr_fd );
}

if( orbit==0 ) return( 1 );

return( wait_copy_edr_( orbit ) );

}

/*  WAIT_COPY_EDR - routine to wait for a subprocess spawned to read an
EDR tape into disk and extract the orbit ID from the volume label  */

#include <stdio.h>

char copy_edr_char[256];
FILE *copy_edr_fd;

int wait_copy_edr_( orbit )
char *orbit;

/*  Outputs:

    ORBIT:  A pointer to a string which will receive the orbit ID
		obtained from the tape volume label.

    The routine will return a 1 if all is well.  Otherwise, a -1 is returned.
*/
{
char *lchar;

lchar = copy_edr_char + 128;
while( fgets( copy_edr_char, 120, copy_edr_fd ) != NULL ){
    printf(">>%s", copy_edr_char );
    strcpy( lchar, copy_edr_char );
}
if( strncmp( "COPY_EDR orbit: ", lchar, 16 ) == 0 ){
    strncpy( orbit, lchar+16, 10 );
    return( 1 );
} else printf("WAIT_COPY_EDR message from COPY_EDR: \n**%s**\n", lchar );
return( -1 );
}
