c******************************************************************
c	Jet Propulsion Laboratory
c	Section:	334, Radar Science and Engineering
c	Project: 	Magellan
c	Task:		Correlator, Alliant Fortran Version.
c------------------------------------------------------------------
c	Module Name: mosaic
c	
c-------------------------------------------------------------------
c	11/3/93  Lawrence Chen porting from Alliant to Sun
c	11/2/92  Anhua Chu Convert p1/p2 to ingeter*2 for display
c	5/1/92   Anhua Chu Initial code
c*******************************************************************
	program mosaic
     
	implicit none	

c	include 'keyvar.inc'
	include '../../../inc/pp.inc'
	include '../../../inc/po.inc'
	include '../../../inc/constant.inc'
c	include 'corr_buffer.inc'
c	include 'overlay.inc'

c	PASSING OUT PARAMETERS

		byte		im_sfdu( 92 )

c	IMAGE F-BIDR SFDU HEADER

c	Primary label:
		
		character*12	prime_label
		character*8	prime_length

c	Secondary label:

		integer*2	second_label / 2 /
		integer*2	second_length / 68 /
		integer*2	orbit_num

c	Data annotation block:

		byte		data_class
		byte		data_ann_length / 64 /

c	Image data-specific fields:

		integer*2	line_cnt
		integer*2	line_length
		real*4		proj_lat
		real*4		proj_lon
		real*4		ref_pt_lat
		real*4		ref_pt_lon
		integer*4	ref_pt_line_off
		integer*4	ref_pt_pix_off
		integer*4	burst_cnt/ 0 /
		character*32	nav_fit_ID
	        integer*2       i_lat(2),i_lon(2)

	equivalence(im_sfdu(1),prime_label)
	equivalence(im_sfdu(13),prime_length)
	equivalence(im_sfdu(21),second_label)
	equivalence(im_sfdu(23),second_length)
	equivalence(im_sfdu(25),orbit_num)
	equivalence(im_sfdu(27),data_class)
	equivalence(im_sfdu(28),data_ann_length)
	equivalence(im_sfdu(29),line_cnt)
	equivalence(im_sfdu(31),line_length)
	equivalence(im_sfdu(33),proj_lat)
	equivalence(im_sfdu(37),proj_lon)
	equivalence(im_sfdu(41),ref_pt_lat)
	equivalence(im_sfdu(45),ref_pt_lon)
	equivalence(im_sfdu(49),ref_pt_line_off) !c1
	equivalence(im_sfdu(53),ref_pt_pix_off)  !c2
	equivalence(im_sfdu(57),burst_cnt)
	equivalence(im_sfdu(61),nav_fit_id)
c
c	LOCAL VARIABLES

	integer*4     	length,i,projection,j,k,num_image,n

	real*4		lat
	real*4		lon
c	real*4		vax_alliant_sf	! Modified by LC
c	functions called
	real*4		vax2sunr4	
	integer*2	vax2suni2
	integer*4	vax2suni4

	integer*4     	o_burst,pre_burst
	common /o_burst/ o_burst,pre_burst

	integer		copen,cread,cwrite,ccreate,ichan_i,ichan_o
	character*(50)  file_name_i,file_name_o
	integer		disk_address,image_num,bytes,image_size
	integer		c1_start,c2_start
	byte		mosaic_buff(1024,1280)
c	byte		mosaic_buff(1024,1024)
	byte		image_buff(512*2048)
	integer		image_hdr_len,start_burst
	integer		pix_off_pre,line_off_pre
	integer		pix_off_1st,line_off_1st,c2_1st
	integer		proj
	integer*2	p1_i,p2_i
	byte		p1_b(2),p2_b(2)
	equivalence(p1_i,p1_b)
	equivalence(p2_i,p2_b)

	
	type *,' Enter image file name file_13/file15'
	accept '(a)',file_name_i
	type '(a)',file_name_i
	
	type *,' Enter image file projection '
	accept *,proj
	type *,proj

	type *,' Enter the start image num in FILE_15/13' 
	accept *,start_burst
	type *,start_burst

	type *,' Enter the desired multi-look number' 
	accept *,image_num
	type *,image_num

	type *,' Enter the number of images in FILE_15/13' 
	accept *,num_image
	type *,num_image

	type *,' Enter o/p single multi-look file name'
	accept '(a)',file_name_o
	type '(a)',file_name_o

	ichan_i=copen(file_name_i)
	ichan_o=ccreate(file_name_o)

	image_hdr_len=92
	disk_address = 0
	

	do i=start_burst,image_num

	      bytes=cread(ichan_i,im_sfdu,image_hdr_len,disk_address)
	      line_cnt = vax2suni2(line_cnt) !LC: convert to Sun format
	      image_size=line_cnt*516
	      disk_address= disk_address+image_hdr_len+image_size

	enddo

c	*** convert the header data from VAX to Sun format

	burst_cnt = vax2suni4(burst_cnt) 
	ref_pt_line_off = vax2suni4(ref_pt_line_off) 
	ref_pt_pix_off = vax2suni4(ref_pt_pix_off) 
	burst_cnt = vax2suni4(burst_cnt)
	line_length = vax2suni2(line_length)

c	convert the data which are used in the program
c	this converstion must be executed everytime we read 
c	header data from disk


        type *,'image(burst) disk_addr=',burst_cnt,disk_address

	c1_start = 1 
	c2_start =41
	c2_1st=c2_start
	line_off_1st=ref_pt_line_off
	pix_off_1st=ref_pt_pix_off

	disk_address= disk_address-image_size

	do n=1,num_image
	   type *,' disk_address:',disk_address
	   bytes=cread(ichan_i,image_buff,image_size,disk_address)
	   if (bytes .ne. image_size) type *,' DISK READ ERROR',bytes

           type *,'overlay o/p image(burst) num=',burst_cnt
	   type *,' c1_start c2_start:',c1_start,c2_start
	   type *,'c1_in=',ref_pt_line_off
	   type *,'c2_in=',ref_pt_pix_off
	   type *,'line_cnt=',         line_cnt 
	   type *,'line_len=',         line_length 

c           lon=vax_alliant_sf(ref_pt_lon)	! Modified by LC
c	   lat=vax_alliant_sf(ref_pt_lat)	! Modified by LC
	   lon = vax2sunr4(ref_pt_lon)		! Modified by LC
	   lat = vax2sunr4(ref_pt_lat)		! Modified by LC

	   type *,'c2_lon=',lon
	   type *,'c1_lat=',lat

	  if ((c1_start+line_cnt) .gt. 1280 ) then
c	  if ((c1_start+line_cnt) .gt. 1024 ) then
	     type *,' ***image data size too big***'
	     type *,' c1 length:',c1_start-1 
	     goto 1000
	  endif
	      
	   k=0
	  do i=1,line_cnt
	   p1_b(1)=image_buff(k+1)
	   p1_b(2)=image_buff(k+2)
	   p2_b(1)=image_buff(k+3)
	   p2_b(2)=image_buff(k+4)
c L. Chen
	   p1_i = vax2suni2(p1_i)
	   p2_i = vax2suni2(p2_i)
	   type *,' p1 p2:',p1_i,p2_i
	     do j=1,516
	        k=k+1
		mosaic_buff(j+c2_start,c1_start)=image_buff(k)
  	     enddo	
	     c1_start = c1_start+1
          enddo		 

	  pix_off_pre=ref_pt_pix_off
		
	  disk_address= disk_address+image_size
	  if (n .ne. num_image) then
	     bytes=cread(ichan_i,im_sfdu,image_hdr_len,disk_address)

	     line_cnt = vax2suni2(line_cnt) ! convert integer format
	     line_length = vax2suni2(line_length)
	     burst_cnt = vax2suni4(burst_cnt)
	     ref_pt_line_off = vax2suni4(ref_pt_line_off)
	     ref_pt_pix_off = vax2suni4(ref_pt_pix_off)

	     image_size=line_cnt*516
	     disk_address= disk_address+image_hdr_len
	  endif
        
	  c2_start = c2_1st+(ref_pt_pix_off-pix_off_1st)+1

	  if ( proj .eq. 1) then
	    c1_start = (line_off_1st - ref_pt_line_off )+1
	  else
	    c1_start = (ref_pt_line_off - line_off_1st )+1
	  endif
	      
	enddo

1000      if ((c1_start+line_cnt) .gt. 1024 ) then
                 image_size=1024*(c1_start)		
	  type *,' image_size:',image_size,c1_start
	  else
	         image_size=1024*(c1_start+line_cnt)		
	  type *,' image_size:',image_size,c1_start+line_cnt
	  endif

          bytes=cwrite(ichan_o,mosaic_buff,image_size,0)
	  if (bytes .ne. image_size) type *,'DISK WRITE ERROR',bytes

 	  type *,' o/p size(1024,c1_len):',image_size/1024


	  type *,'prime image label=',prime_label
	  type *,'prime image length=',prime_length

c	  lon=vax_alliant_sf(proj_lon)	! Modified by LC
c	  lat=vax_alliant_sf(proj_lat)	! Modified by LC
	  lon = vax2sunr4(proj_lon)	! Modified by LC
	  lat = vax2sunr4(proj_lat)	! Modified by LC

	  type *,'ref_pt_lon=',lon
	  type *,'ref_pt_lat=',lat

	end
c---------------------------------------
