/*  Routine to open an ANSI formatted tape volume and extract its label
    or to create a volume label on a new tape.

  Functional Description:

  Flag = 0:

  Rewind the tape and read the first 80 byte record and check the
  header and label fields.  Return a status of 1 on success and
  copy the label into the name buffer.

  Flag = 1:

  Rewind the tape and write the first 80 byte record.  Compose this record
  using the components stored in the global buffers.

*/

#include <sys/types.h>
#include <sys/ioctl.h>
#include <sys/mtio.h>
extern int errno;

#include "tape_buff.h"

int open_tape_volume(tape_chan, flag)
	int tape_chan, flag;
{
	struct mtop mt_com;
	int status, j, byte_count;

	/*
	printf("OPEN_TAPE_VOLUME...read(0)/write(1) flag=%d\n", flag);
	*/

	/*  Rewind the tape  */

	mt_com.mt_op = MTREW;
	mt_com.mt_count = 1;
	status = ioctl(tape_chan, MTIOCTOP, &mt_com);
	if(status == -1)
	{
    	status = errno;
    	printf("OPEN_TAPE_VOLUME error rewinding tape: %d\n", status );
    	perror("OPEN_TAPE_VOLUME error:");
		/* exit( status ); */
	}

	byte_count = 80;
	if(flag == 0)
	{
		/*  reading a tape  */
    	if((status = read(tape_chan, buffer, byte_count)) != byte_count)
		{
			printf("OPEN_TAPE_VOLUME error reading tape: %d\n", errno);
			perror("OPEN_TAPE_VOLUME error:");
			return(errno);
    	}

    	for(j = 0; j < 4; j = j+1)
		{
			/*  copy token  */
			tv_id[j] = buffer[j];
		}

   		tv_id[4] = 0;

    	if(strcmp(tv_id, "VOL1") != 0)
		{
			printf("OPEN_TAPE_VOLUME error: invalid tape volume header %s\n",
				tv_id);
			return(0);
    	}

		printf("OPEN_TAPE_VOLUME read tape volume header %s\n", tv_id);

    	for(j = 0; j < 6; j++)
		{
			tv_id[j] = buffer[j+4];
		}

		/*  save tape volume label  */
    	tv_id[j] = 0;

    	for(j = 0; j < 14; j++)
		{
			owner_id[j] = buffer[j+37];
		}

		/*  save tape owner ID  */
    	owner_id[14] = 0;

		printf("OPEN_TAPE_VOLUME read tape volume label: %s, owner=%s\n", 
			tv_id, owner_id );

	}
	else
	{
		/*  writing a tape  */

    	strcpy( buffer, "VOL1" );			/*  start with VOL1 marker  */
    	strcat( buffer, tv_id );			/*  append volime label  */

    	for( j=10; j<79; j++ )
		{
			/*  blank the buffer  */
			buffer[j] = 0x20;
		}

		/*  ASCII 3  */
    	buffer[79] = 0x33;

    	for(j = 0; j < 14; j++)
		{
			/*  Owner ID  */
			buffer[j+37] = owner_id[j];
		}

    	if((status = write(tape_chan, buffer, byte_count)) != byte_count)
		{
			printf("OPEN_TAPE_VOLUME error writing tape: %d\n", errno );
			perror("OPEN_TAPE_VOLUME error:");
			return( errno );
    	}
	}

	/* printf("OPEN_TAPE_VOLUME completed\n");*/
	return(1);
}
