/*  COPY_RECORDS  routine to copy a number of records from the input FD
    to the output FD.

  Inputs:

    IN:  input file descriptor
    OUT:  Output file descriptor
    BUF:  Pointer to buffer to use
    LEN:  Maximum record size
    RECS:  The number of records to copy (-1=copy until EOF)

  Outputs:

    I_STAT:  Set to last read status on input FD
    O_STAT:  Set to last write status on output FD

  Returns number of records copied, 0 or less indicate error
*/

#include <sys/ioctl.h>
#include <errno.h>
extern int errno;

int copy_records( in, out, buf, len, recs, i_stat, o_stat )
int in, out, len, recs, *i_stat, *o_stat;
char *buf;

{
int count;

/*  read and write for as long as no error occurs  */

for( count=0; recs<0 || (recs>0 && count<recs); count ++ ){

    *i_stat = read( in, buf, len );
    if( *i_stat==len ){				/* read something, write it */
	*o_stat = write( out, buf, *i_stat );
    } else if( *i_stat == 0 ){			/* got EOF on input, return */
	*i_stat = 1;
	*o_stat = 1;
	return( count );
    } else if( *i_stat < 0 ){			/* read error, return */
	*i_stat = -1;
	*o_stat = -1;
	perror( "COPY_RECORDS read error:");
	return( count );
    } else {
printf("COPY_RECORDS read short, %d bytes requested, %d bytes read\n",
		len, *i_stat );
printf("COPY_RECORDS filling remainder...\n");
	while( *i_stat < len ) buf[ *i_stat++ ] = 94;	/*  filler  */
	*o_stat = write( out, buf, *i_stat );
    }	/*  end read error check  */

    if( *o_stat == 0 ){		/* EOF error on write, return */
	*i_stat = 0;
	*o_stat = -1;
	perror( "COPY_RECORDS EOF on file write error:");
	return( count );
    } else if( *o_stat < 0 ){		/* write exception, return */
	*i_stat = -1;
	*o_stat = -1;
	perror( "COPY_RECORDS write error:");
	return( count );
    } else if( *o_stat < *i_stat ){
printf("COPY_RECORDS wrote short, %d bytes requested, %d bytes written\n",
		len, *o_stat );
	*i_stat = *o_stat;
	*o_stat = -1;
	return( count );
    }	/*  end write error check  */

}	/*  end copy loop  */
}	/*  end of routine  */
