/*  MODIFY_EDR

  Program for examining a Magellan EDR file set to look for data areas
  that were zero'd by MHR, and fill them with random data.

  Functional Description:

  Checks SAB header for each burst of data to determine amount of missing
  data.  If above a certain threshold, replace the zeros with random data.

  Inputs:

	EDR_SAR:  path to the location of the SAR_DATA file
	EDR_ANC:  path to the location of the EDR ancillary files

 Outputs:

	The program will replace the zero data in the SAR_DATA file with
	the random data values.

  Summary:

	The program calls the routine NOISE_FILL to analyze the EDR files
	in the given paths to locate and replace the missing RCDs in each]
	burst with psuedo-noise data.

*/

#include <stdio.h>
#include <fcntl.h>
#include <errno.h>
extern int errno;

#define o_SABQ 156
#define o_SAB 316
#define o_BDAT 370

#include "tape_buff.h"

main( argc, argv )
int argc;
char *argv[];
{
int seed, j;
int s0, s1, us0, us1;
unsigned char *fn;

float time;

printf("UNIX version of the MODIFY_EDR program.  Inputs=%d\n", argc);

if( argc<2 ){		/*  verify inputs  */
    printf("Usage:  modify_edr EDR_SAR [EDR_ANC] [seed]\n");
    exit(-1);
}

/*  copy inputs to local variables  */

strcpy( edr_dir, argv[1] );
j = strlen( edr_dir );
if( edr_dir[j-1]=='/' ) edr_dir[j-1] = 0;	/* truncate last back slash */
if( argc>2 ) strcpy( edr_anc, argv[2] );	/*  ancillary directory  */
else strcpy( edr_anc, edr_dir );
j = strlen( edr_anc );
if( edr_anc[j-1]=='/' ) edr_anc[j-1] = 0;	/* truncate last back slash */

if( argc>3 ) sscanf( argv[3], "%d", &seed );
else seed = 1234567;
printf("Seed value for random number generator: %d\n", seed );

fn = &file_names[11] [0];
strcpy( fn, edr_dir );	
strcat( fn, "/SAR_DATA" );			/* construct SAR file name */
printf("EDR_SAR file: %s\n", fn );
fn = &file_names[1] [0];
strcpy( fn, edr_anc );
strcat( fn, "/FILE_02" );			/* Orbit Header file name */
printf("Orbit Header file: %s\n", fn );
gettime_( &s0, &us0 );
noise_fill( seed );
gettime_( &s1, &us1 );

time = (float) ( s1-s0 ) + (float) ( us1-us0 )/1000000.;
printf("Time taken for noise fill=%f\n", time );

exit( 1 );
}
