/*  Routine to open a file on an ANSI formatted tape and extract its ID
    or write ANSI file headers on the tape, followed by a tape mark.

  Functional Description:

  Flag = 0:

  Look for the 80 byte ANSI file headers on the current tape file.
  Copy tape file ID from HDR1 into name buffer and return HDR level
  if successful, 0 if EOV encountered while attempting to open file,
  and a negative number for all other errors.

  Flag = 1:

  Generate ANSI file headers of various levels up to 4 and write to tape.
  File names and other contents in the labels will be taken from information
  stored in the global buffers in TAPE_BUFF.H.

*/

#include <sys/types.h>
#include <sys/mtio.h>
#include <sys/ioctl.h>
#include <errno.h>
extern int errno;

#include "tape_buff.h"

int open_tape_file( tape_chan, level, flag )
int tape_chan, *level, flag;
{
unsigned char *hdr;
int status, byte_count, j, l;
struct mtop mt_com;

/*  printf("OPEN_TAPE_FILE...read(0)/write(1) flag=%d\n", flag);  */

byte_count = 80;
hdr = buffer + 80;

if( flag==0 ){		/*  reading tape  */

/*  read and check tape file header level  */

    *level = 0;
    while( (status=read( tape_chan, buffer, byte_count)) == byte_count ){

	for( j=0; j<3; j++ ) hdr[j] = buffer[j];	/*  copy token  */
	hdr[3] = 0;
	fmt[0] = buffer[3];
	fmt[1] = 0;
	if( strcmp( hdr, "HDR")==0 ){		/*  found a HDR  */
	    j = atoi( fmt );
	    (*level)++;
	    if( j!=*level ){
		printf("OPEN_TAPE_FILE error: invalid header level:%s%s %d\n",
			hdr, fmt, *level );
		return( -1 );
	    }
/*  printf("OPEN_TAPE_FILE got tape file header %s%d\n", hdr, *level );  */

	    if( *level==1 ){		/*  get tape file HDR1 info  */

		for( j=0; j<17; j++ ) tf_id[j] = buffer[j+4];
		tf_id[j] = 0;			/*  save tape file name  */
		for( j=0; j<6; j++ ) tf_set_id[j] = buffer[j+21];
		tf_set_id[j] = 0;		/*  save tape volume name  */
		for( j=0; j<2; j++ ) ver[j] = buffer[j+39];
		ver[j] = 0;			/*  save generation version  */
		for( j=0; j<6; j++ ) date[j] = buffer[j+41];
		date[j] = 0;			/*  save generation version  */
		for( j=0; j<2; j++ ) hdr[j] = buffer[j+54];
		hdr[j] = 0;			/*  tape blocks  */
		blocks = atoi( hdr );
/*  printf("OPEN_TAPE_FILE got tape file label1: %s\n", tf_id );  */

	    } else if( *level==2 ) {	/*  process HDR 2  */

		fmt[0] = buffer[4];
		fmt[1] = 0;			/*  save tape record format  */
		for( j=0; j<5; j++ ) hdr[j] = buffer[j+5];
		hdr[j] = 0;
		blen = atoi( hdr );		/*  save tape block length  */
		for( j=0; j<5; j++ ) hdr[j] = buffer[j+10];
		hdr[j] = 0;
		rlen = atoi( hdr );		/*  save tape record length  */

	    }	/*  end getting tape file label  */

	} else if( strcmp( hdr, "EOV" )==0 ){	/*  read EOV record  */

	    printf("OPEN_TAPE_FILE reached EOV on tape\n");
	    return( 0 );

	} else {	/*  read garbage from tape  */

	printf("OPEN_TAPE_FILE error: invalid file header: %s\n", hdr );
	return( -1 );
	}		/*  End verifying HDRs  */

    }
    if( status==0 ) return( 1 );	/*  allow only EOF  */
    printf("OPEN_TAPE_FILE error reading tape: %d\n", errno );
    perror("OPEN_TAPE_FILE error:");
    return( -errno );

} else {		/*  writing a tape  */

    if( *level>2 ){
	printf( "OPEN_TAPE_FILE currently does not support writing\n" );
	printf( "tape files with HDR levels greater than 2.\n" );
	*level = 2;
    }
    for( l=1; l<=(*level); l++ ){

	strcpy( buffer, "HDR" );
	if( l==1 ){
	    strcat( buffer, "1" );		/*  header level  */
	    strcat( buffer, tf_id );		/*  File ID  */
	    strcat( buffer, tv_id );		/*  File set ID  */
	    strcat( buffer, "0001" );		/*  File section number  */
	    strcat( buffer, fseq );		/*  File sequence number  */
	    strcat( buffer, "0001" );		/*  Generation number  */
	    strcat( buffer, ver );		/*  Generation version  */
	    strcat( buffer, date );		/*  year, GMT of creation  */
	    strcat( buffer, " 00000 " );	/*  expiration date  */
	    strcat( buffer, "000000" );		/*  Block/record count  */
	    for( j=60; j<80; j++ ) buffer[ j ] = 0x20;
	} else if( l==2 ){
	    strcat( buffer, "2" );		/*  header level  */
	    strcat( buffer, fmt );		/*  record format  */
	    sprintf( hdr, "%05d%05d\0", blen, rlen );
	    strcat( buffer, hdr );		/*  block, record length  */
	    for( j=15; j<35; j++ ) buffer[j] = 0x20;
	    buffer[35] = 0;
	    strcat( buffer, "Mr. Mustang GT 00" );
	    for( j=52; j<80; j++ ) buffer[j] = 0x20;
	}
	status = write( tape_chan, buffer, byte_count );
	if( status==0 ) return ( 0 );
	else if( status!=byte_count ){
	    printf("OPEN_TAPE_FILE error writing tape HDR %d\n", l );
	    perror("OPEN_TAPE_FILE error:");
	    return( -errno );
	}
    }		/*  end looping through HDR levels  */
    mt_com.mt_op = MTWEOF;      /*  write a tape mark  */
    mt_com.mt_count = 1;
    status = ioctl( tape_chan, MTIOCTOP, &mt_com );
    if( status==-1 ){
        printf("OPEN_TAPE_FILE error writing EOF: %d\n", errno );
	perror("OPEN_TAPE_FILE error:");
	return( -errno );
    }
    return( 1 );
}		/*  end read/write decision  */
}
