/*  Program for copying files from a set of MGN SAR BIDR disk files to tape(s).

  Functional Description:

  A MGN SAR BIDR tape contains the 20 processed BIDR files in the ANSI
  level II format.  The organization of the files on tape is:

	First Record:	Volume Header (80 bytes)
	Second Record:	Data File Header 1 (80 bytes)
	Third Record:	Data File Header 2 (80 bytes)
	Tape Mark (End of file)
	Fourth Record:	First data record
	Fifth Record:	Second data record
				.
				.
				.
	N+4th Record:	Nth data record
	Tape Mark (End of file)
	N+5th Record:	Data File Trailer 1 (80 bytes)
	N+6th Record:	Data File Trailer 2 (End of first data file)
	Tape Mark (End of file)
	N+7th Record:	Data File Header 1 (Start of second data file)
	N+8th Record:	Data File Header 2 (80 bytes)
				.
				.
				.
	Tape Mark (Last data record on volume)
	End of Volume Record (80 bytes)
	Tape Mark
	Tape Mark (Logical EOT)

  Records 2 through N+4+2 constitute one complete data file.
  The data records of each file will be fixed at 32500 bytes.

  This program will copy each disk file onto one or two tapes, depending
  on the number of copies requested in the inputs.

 Inputs:

	DIR:  The directory where the BIDR files reside
	TAPE1:  The name of the tape drive containing the first reel of tape
	TAPE2:  The name of the tape drive containing the second reel of tape

 Outputs:

	The program will output either a success if all went well
	or an error code.
*/

#include <sys/ioctl.h>
#include <stdio.h>
#include <sys/time.h>
#include <fcntl.h>
#include <errno.h>
extern int errno;

#include "tape_buff.h"

main( argc, argv )
int argc;
char *argv[];
{
unsigned char *fn, junk[80];
int same_drive, in, out, out0, switch_vol, tf_opened, tv_opened, i;
int *rec_count, status, level_h, vol, j, v, rev;

struct tm *tp;
struct timeval tv;

/*  printf("This is the UNIX version of the Magellan BIDR save program.\n"); */

rec_count = recs;
for( i=0; i<20; i++ ) rec_count[i] = 0;

if( argc<3 ){		/*  verify inputs  */
    printf("Usage:  save_bidr /bidr_dir/ tape1 [tape2]\n");
    exit(-1);
}

/*  copy inputs to local variables  */

strcpy( edr_anc, argv[1] );
strcpy( tape1, argv[2] );
if( argc>3 && strcmp( argv[2], argv[3] ) != 0 ) strcpy( tape2, argv[3] );
else tape2[0] = 0;

/*  printf("SAVE_BIDR received tape names: %s %s\n", tape1, tape2 ); */

tv_opened = 0;			/*  opened tape volume flag  */
tf_opened = 0;			/*  opened tape file flag  */
switch_vol = 0;			/*  switching volume flag  */
level_h = 2;			/*  header level  */
in = 0;				/*  initialize disk file descriptor  */
out = 0;			/*  initialize tape file descriptor  */
out0 = 0;			/*  initialize tape file descriptor  */
rlen = 32500;			/*  logical record length  */
blen = 32500;			/*  physical record length  */
vol = 0;			/*  tape volume number  */

/*  build tape volume label  */

j = strlen( edr_anc );
/* printf("SAVE_BIDR using directory: %s, (len=%d)\n", edr_anc, j ); */
if( edr_anc[j-1]=='/' ){	/*  trim off the trailing slash if present  */
    j--;
    edr_anc[j] = 0;
}
junk[0] = edr_anc[j-2];
junk[1] = edr_anc[j-1];
junk[2] = 0;
v = atoi( junk );			/*  BIDR version number  */
for( i=0; i<5; i++ ) junk[i] = edr_anc[j-8+i];
rev = atoi( junk );			/*  BIDR rev number  */
junk[0] = edr_anc[j-10];
junk[1] = 0;				/*  BIDR type (F,U,T...)  */
/*  printf("SAVE_BIDR retrieved data type:%s, Rev=%d, Ver=%d\n",
	junk, rev, v );  */
sprintf( tv_id, "%s%04x%01x\0", junk, rev, v );
/*  printf("SAVE_BIDR tape volume ID:%s\n", tv_id );  */
for( fn=tv_id; *fn!=0; fn++ ) if( *fn>='a' && *fn<='z' ) *fn = *fn - ' ';
strcpy( owner_id, "SDPS;0001,0001" );	/*  owner ID  */
fn = &file_names[0][0];		/*  point to first disk file name  */

/*  build stuff for file headers  */

sprintf( ver, "%02d\0", v );		/*  file version=BIDR version  */
strcpy( fmt, "F" );			/*  fixed record format  */
gettimeofday( &tv, (char *)0L );		/*  get time  */
tp = localtime( &tv.tv_sec );			/*  separate it  */
sprintf( date, " %02d%3d\0", tp->tm_year, tp->tm_yday );

for( i=1; i<=20; ){

/******/
/*  Open tape volume if necessary  */
/******/

    if( tv_opened <= 0 ){
/*
	if( switch_vol && same_drive ){
	    printf("Please load next volume of tape on %s\n", tape );
	    printf("Type carriage return when ready:  ");
	    junk[0] = getchar();
	    if( junk[0] == 'z' ) exit( -1 );
	}
*/
	if( (out=open(tape1,O_RDWR))==-1 ){
	    printf("SAVE_BIDR error openning TAPE1: %d\n", errno);
	    perror("SAVE_BIDR error:" );
	    exit(errno);
	}
/*	printf("SAVE_BIDR openning tape drive 1...%s\n", tape1 ); */
	tv_opened = open_tape_volume( out, 1 );
	if( tv_opened != 1 )
	    printf("SAVE_BIDR error openning tape1 volume: %d\n", tv_opened );

      if( tape2[0] > 0 ){
/*	printf("SAVE_BIDR openning tape drive 2...%s\n", tape2 ); */
	if( (out0=open(tape2,O_RDWR))==-1 ){
	    printf("SAVE_BIDR error openning TAPE2: %d\n", errno);
	    perror("SAVE_BIDR error:" );
	    exit(errno);
	}
	tv_opened = open_tape_volume( out0, 1 );
	if( tv_opened != 1 )
	    printf("SAVE_BIDR error openning tape2 volume: %d\n", tv_opened );
      }
	set_dir( tv_id, edr_anc, edr_anc, fn, 20, 0 );
    }

/******/
/*  Open the file on tape  */
/******/

    if( tf_opened <=0 ){	/*  open tape file  */
	sprintf( tf_id, "FILE_%02d.         \0", i );	/*  File ID  */
	sprintf( fseq, "%04d\0", i );			/*  File Sequence  */
	tf_opened = open_tape_file( out, &level_h, 1 );	/*  write HDRs  */
	if( tf_opened !=1 ){
	    printf("SAVE_BIDR error writing tape1 header:%s, %d\n",
		tf_id, tf_opened );
	    exit( -1 );
	}
	if( tape2[0]>0 ){
	    tf_opened = open_tape_file( out0, &level_h, 1 );
	    if( tf_opened !=1 ){
		printf("SAVE_BIDR error writing tape2 header:%s, %d\n",
		    tf_id, tf_opened );
		exit( -1 );
	    }
	}
    }

/******/
/*  open disk file as necessary  */
/******/

    if( in<=0 && tf_opened==1 ){
	if( ( in=open( fn, O_RDONLY ) ) == -1 ){
	    printf("SAVE_BIDR error openning file %d, name=%s\n", i, fn );
	    perror("SAVE_BIDR error:" );
	    exit( errno );
	}
    }			/*  end openning disk file  */

/******/
/*  Copy data from disk file into tape file(s)  */
/******/

    if( in>0 && tf_opened==1 && tv_opened==1 ){
	status = copy_records( in, out, buffer, blen, -1, &i_stat, &o_stat );
	blocks = status;		/*  save record count  */
	if( status<=0 || i_stat!=1 || o_stat!=1 ){
	    printf("SAVE_BIDR error copying file %d i=%d, o=%d, status=%d\n",
		i, i_stat, o_stat, status );
	    if( i_stat<0 ){	/*  input error  */
		printf("SAVE_BIDR error reading from input file \n" );
		exit( -1 );
	    }
	    if( o_stat<0 ){	/*  output error  */
		printf("SAVE_BIDR error writing file %d i_stat=%d, status=%d\n",
		i, i_stat, status );
		exit( -1 );
	    }
	}
      if( out0>0 ){			/*  copy to second tape  */
	lseek( in, 0L, 0 );		/*  rewind disk file  */
	status = copy_records( in, out0, buffer, blen, -1, &i_stat, &o_stat );
	if( status<=0 &&( i_stat!=1 || o_stat!=1 ) ){
	    printf("SAVE_BIDR error copying tape2 %d i_stat=%d, o_stat=%d\n",
		i, i_stat, o_stat );
	    exit( -1 );
	}
	if( i_stat!=1 ){
	    printf("SAVE_BIDR error reading file2 %d i_stat=%d, status=%d\n",
		i, i_stat, status );
	    exit( -1 );
	}
	if( o_stat!=1 ){
	    printf("SAVE_BIDR error writing tape2 %d o_stat=%d, status=%d\n",
		i, o_stat, status );
	    exit( -1 );
	}
      }
	*rec_count += blocks;	/*	increment record count  */
    }

/******/
/*  Close disk file  */
/******/

    if( o_stat==1 ){
/*	printf("SAVE_BIDR closeing disk file %s, records=%d\n", fn, blocks );*/
	close( in );
	in = 0;
	fn += 64;
	i++;
    }

/******/
/*  Close tape file and check trailer level  */
/******/

    if( tf_opened ){
/*	printf("SAVE_BIDR closeing tape file, blocks=%d...\n", blocks );*/
	close_tape_file( out, &level_h, 1 );
	if( out0>0 ) close_tape_file( out0, &level_h, 1 );
	rec_count++;
	tf_opened = 0;
    }

}
close_tape_volume( out, 1 );
close( out );		/*  close tape unit FD  */
if( out0>0 ){
    close_tape_volume( out0, 1 );
    close( out0 );
}

/*  write REC_ROUNT file  */
/*
junk[0] = 0;
strcpy( junk, edr_anc );
strcat( junk, "/REC_COUNT" );
out=creat( junk, 0666 );
write( out, recs, 52 );
close( out );
*/
printf("SAVE_BIDR Normal exit\n");
exit( 1 );
}
