c******************************************************************
c	Jet Propulsion Laboratory
c	Section:	334, Radar Science and Engineering
c	Project: 	Magellan
c	Task:		Correlator, Alliant Fortran Version.
c------------------------------------------------------------------
c	Module Name: bidr_maker.f
c	
c		Generate multi-look image bidr format. 
c
c	           - Write image BIDR header.
c	           - Normalize each pixel by the number of looks.
c	           - Convert multi-look pixel values in unit of 
c	             normalized radar backscatter coefficient given 
c	             in DN.
c
c	Reference: F-BIDR SIS 
c-------------------------------------------------------------------
c
c	11/22/93 Lawrence Chen convert p1p2 to vax format
c		 convert byte to real before arithmetic operation
c	12/1/92  Anhua Chu Right look revised
c	11/6/92  Anhua Chu Speed up the codes
c	8/26/92  Anhua Chu Take care overlay buffer extra images
c	5/1/92   Anhua Chu Initial code.
c*******************************************************************
	subroutine bidr_maker(buff_out)
c-----------------------------------------------------------------
	implicit none	

	include '../../../inc/pp.inc'
	include '../../../inc/keyvar.inc'
	include '../../../inc/constant.inc'
	include '../../../inc/corr_buffer.inc'
	include '../../../inc/overlay.inc'

c	passing in/out parameters

	byte	buff_out(*)	!output byte image buffer
	byte	im_sfdu(92)     !move to overlay.inc

c	Local variables

	integer*4 out_c1,out_c2
	integer*4 c1,c2,c1c,c2c,k,l,i,j
	integer*4 inc,num_offset
	integer*4 reset_c1_flag,left_out_ptr_do,c1_size_len
	real*4	db
	integer*4 min_c2_left_value,left_in_ptr_2,c2_reserve_min
	logical p2_flag,pixel_cnt_flag
	integer*4 p1p2_count,c2_size_rem
	integer*2 pixel_offset,pixel_num
	byte	byte_pixel_offset(2),byte_pixel_num(2)
	equivalence (pixel_offset,byte_pixel_offset(1))
	equivalence (byte_pixel_num(1),pixel_num)
	integer*4 c2_total,c2_c_offset,c2_c_start,c2_c_end
	integer*4 c1_total,c1_c_offset,c1_c_start,c1_c_end
	integer*4 test_burst_no
	real*4    scale
	common /test_burst_no/ scale,test_burst_no

c	------------
c	Image Header
c	------------

	call image_header(im_sfdu) 

	do i=1,92
	   byte_count = byte_count + 1	!byte_count=0 in process_corr.f 
	   buff_out(byte_count)=im_sfdu(i)
	enddo	

c	------------
c	Image & Look summation 
c	------------

	if (projection .eq. sine) then    
	   inc = -1 
 	else 
	   inc = 1
	endif

	c1=c1_start_out

cvd$l nodepchk
	do out_c1 = 1,c1_size_out	

	   p1p2_count = byte_count+1
	   pixel_offset = 0
	   pixel_num =0
	   byte_count = byte_count + 4

	   c1c=mod(mod(c1,memo_c1_len)+memo_c1_len,memo_c1_len)

	   c2=c2_start_out

           p2_flag = .false.

cvd$l nodepchk
	   do out_c2 = 1,c2_size_out

	      byte_count = byte_count + 1

	      c2c=mod(mod(c2,memo_c2_len)+memo_c2_len,memo_c2_len)

c	      -------------
c	      CONVERT PIXELS dB VALUE TO 8-BIT DN
c	      -------------

	      if (buff_vlook(c2c,c1c) .eq. 0) then
	          buff_out(byte_count) = 0
	      else 
		  if (buff_v(c2c,c1c) .eq. 0 ) then
	              buff_out(byte_count)=1
	   	  else
	              buff_v(c2c,c1c)
     *                =buff_v(c2c,c1c)/real(buff_vlook(c2c,c1c))
	              db = 10*log10(buff_v(c2c,c1c))
cd	      type *,'--db',db,buff_v(c2c,c1c),real(buff_vlook(c2c,c1c))
		      buff_out(byte_count)
     *	              = 1 +nint((min(max(db,-20.),30.)+20.1) /.2)
cd	           type *,'buff_out()',byte_count,buff_out(byte_count)	 
	          endif
		
	      endif
	
c	      -------------
c	      CALCULATE P1 & P2 VALUE
c	      -------------

	      if ( buff_vlook(c2c,c1c) .ge. 4 ) then
	         pixel_num = pixel_num+1
     	 	 p2_flag = .true.
	      endif

	      if (p2_flag .eq. .false.) then  
	         pixel_offset = pixel_offset+1
	      endif

	      c2=c2 + 1

	      buff_v(c2c,c1c)=0.0	!reset to zero
	      buff_vlook(c2c,c1c)=0   !reset to zero

	   enddo	!out_c2

	   c1 = c1 + inc

c	   -----------
c	   p1p2 header of image line
c	   -----------
	   pixel_num = pixel_num+pixel_offset

cd	if (test_burst_no .eq. burst_no ) then
cd	   type *,' burst_no:',burst_no
cd	   type *,' pixel offset, num:',pixel_offset,pixel_num 
cd	endif

c	L. Chen 11/22/93
c		p1 and p2 are integer
c		therefore, we have to convert them from sun to vax format
c		b(L) = b(H), b(H) = b(L)


c	   buff_out(p1p2_count) = byte_pixel_offset(1)
	   buff_out(p1p2_count) = byte_pixel_offset(2) ! L. Chen
	   p1p2_count = p1p2_count + 1
c	   buff_out(p1p2_count) = byte_pixel_offset(2)
	   buff_out(p1p2_count) = byte_pixel_offset(1) ! L. Chen
	   p1p2_count = p1p2_count + 1
c	   buff_out(p1p2_count) = byte_pixel_num(1)
	   buff_out(p1p2_count) = byte_pixel_num(2) ! L. Chen
	   p1p2_count = p1p2_count + 1 
c	   buff_out(p1p2_count) = byte_pixel_num(2) 
	   buff_out(p1p2_count) = byte_pixel_num(1) ! L. Chen

	enddo		!out_c1

d	           type *,'buff_out()',byte_count,buff_out(byte_count)	 
c	------------
c	EREASE EXTRA BYTES in C2-Direction 
c	------------
c	Base on Far Range
d	type *,'OVER C2 checking burst_no-1 :',burst_no-1
d	type *,' OVLY START COOR(c2/c1):',c2_start_out,c1_start_out
d	type *,'c2_min_left()&out/inptr ',c2_min_left(left_out_ptr), 
d    *                               left_out_ptr,left_in_ptr-1 

	if (c2_start_out .ge. c2_min_left(left_out_ptr)) then

	   c2_reserve_min = c2_min_left(left_out_ptr)
	   left_out_ptr_do = left_out_ptr 
	   left_in_ptr_2 = left_in_ptr - 2 	!-1!?
	   reset_c1_flag = 0  

	   if (projection .eq. sine) then

	   do while (left_out_ptr_do .le. left_in_ptr_2)
             if (c1_down_left(left_out_ptr_do) .le. c1_start_out) then 
	     if (c2_min_left(left_out_ptr_do) .le. c2_reserve_min) then  
	        c2_reserve_min=c2_min_left(left_out_ptr_do)
	        left_out_ptr = left_out_ptr_do
	        if (c2_start_out .gt. c2_min_left(left_out_ptr_do)) then
	           reset_c1_flag = 1  
d	        type *,' c2_reserve_min',c2_reserve_min,left_out_ptr_do
	        endif
	     endif
	     else
	        c2_reserve_min = c2_min_left(left_out_ptr_do+1)
d	        type *,'c2_min change',c2_reserve_min,left_out_ptr_do+1
	     endif
	     left_out_ptr_do = left_out_ptr_do + 1 
	   enddo

	   else !if (projection .ne. sine) then !Oblique 

	   do while (left_out_ptr_do .le. left_in_ptr_2)
             if (c1_down_left(left_out_ptr_do) .ge. c1_start_out) then
	     if (c2_min_left(left_out_ptr_do) .le. c2_reserve_min) then  
	        c2_reserve_min=c2_min_left(left_out_ptr_do)
	        left_out_ptr = left_out_ptr_do
	        if (c2_start_out .gt. c2_min_left(left_out_ptr_do)) then
	           reset_c1_flag = 1  
d	        type *,' c2_reserve_min',c2_reserve_min,left_out_ptr_do
	        endif
	     endif
	     else
	        c2_reserve_min = c2_min_left(left_out_ptr_do+1)
d	        type *,'c2_min change',c2_reserve_min,left_out_ptr_do+1
	     endif
	     left_out_ptr_do = left_out_ptr_do + 1 
	   enddo
                  
	   endif	

	   if ( reset_c1_flag .eq. 1 ) then

	      reset_c1_flag = 0
	      c2_c_end = c2_start_out - 1
	      if (c2_min_left(left_out_ptr) .lt. c2_c_end ) then
	         c2_c_start = c2_min_left(left_out_ptr)
	      else
	     	 c2_c_start = c2_c_end
	      endif 

	      if (projection .eq. sine) then    
	          c1=c1_start_out 
	          c1_size_len=c1_size_out
c	          c1=c1_start_out +1 
c	          c1_size_len=c1_size_out+1
	          inc = -1 
 	      else 
	          c1=c1_start_out 
	          c1_size_len=c1_size_out
c	          c1=c1_start_out - 1  
c	          c1_size_len=c1_size_out+1
	          inc = 1
	      endif

	      do j=1,c1_size_out
	        c1c=mod(mod(c1,memo_c1_len)+memo_c1_len,memo_c1_len)
	      do i=c2_c_start, c2_c_end
	         c2c=mod(mod(i,memo_c2_len)+memo_c2_len,memo_c2_len)
	         buff_v(c2c,c1c)=0.0	!reset to zero
	         buff_vlook(c2c,c1c)=0     !reset to zero
 	      enddo
	         c1=c1+inc
 	      enddo
d	type *,'***OVER C2 512 burst_no-1*** :',burst_no-1

	   endif 

d	type *,'OVER C2 checking burst_no-1 :',burst_no-1
c	type *,' c2_min_2,c2_max_2',c2_min_2,c2_max_2
d	type *,'c2_min/max_1,_0',c2_min_1,c2_max_1,c2_min_0,c2_max_0
c	type *,' c1_min_2,c1_max_2',c1_min_2,c1_max_2
d	type *,'c1_m/x_1 c1_m/x_0',c1_min_1,c1_max_1,c1_min_0,c1_max_0
d	type *,' OVLY START COOR(c2/c1):',c2_start_out,c1_start_out
d	type *,'c2_min_left()&out/inptr ',c2_min_left(left_out_ptr), 
d    *                               left_out_ptr,left_in_ptr-1 
d	type *,' C2_c_start/end:',c2_c_start,c2_c_end
d	type *,' C1_start_out/size:',c1_start_out,c1_size_out

        endif 

	return

	end
c********************* end of bidr_maker.f *********************
