c************  DECODE_BAQ  *************************************************

      subroutine decode_baq( c0, c1, thresh, in, out, pulses, sam, olen)

c  Decodes BAQ data array IN into OUT using C0, C1 table and THRESH array

c  Inputs:

c	C0, C1:  Look-up tables generated by INIT_BAQ_TABLE, range (-128:127)
c	THRESH:  Threshold table for this burst, range (0:31)
c	IN:  Inputbytes array containing 2I/2Q data
c	OUT:  Output complex array to store decoded data
c	PULSES:  Number of pulses to process
c	SAM:  Number of samples in each pulse
c  Note: each input pulse must be contiguous with the next
c	OLEN:  Length of output record.  If this is used to FFT padding,
c		the output array should first be zeroed before calling.

      integer pulses, sam, olen
      complex c0( -128:127 ), c1( -128:127 ), out( 0:pulses*olen-1 )
      real thresh( 0:31 )
      byte in( 0:pulses*sam/2-1 )

	integer i, j, l

cvd$ nodepchk
cvd$ select (concurrent)
cvd$ cncall
cvd$ novector
d	type *, 'Entering DECODE_BAQ:', pulses, sam, olen
	do i = 0, pulses-1
	    j = i*sam/2
	    l = i*olen
d	    type '('' BAQ data:'', i6, ''='', z2.2 )', j, in(j)
	    call decode_lut( c0, c1, thresh, in( j ), out( l ), sam/2 )
	    do j = l+sam, l+olen-1	!  zero remaining output elements
		out( j ) = 0
	    end do
d	    type *, 'Output data:', l, '=', out(l)
	end do
d	type *, 'Leaving DECODE BAQ'
	return
      end

c************  DECODE_LUT  ********************************************
      subroutine decode_lut( c0, c1, thresh, in, out, n )

      integer n
      complex c0( -128:127 ), c1( -128:127 ), out( 0:n*2-1 )
      real thresh( 0:31 )
      byte in( 0:n-1 )

	integer k, l, m, t

cvd$ select (vector)
	do k = 0, n-1
	    m = in( k )
	    l = k*2
	    t = ishft( k, -3 )	!8=16/2 samples
c	    t = ishft( k, -4 )
	    out( l ) = c0( m ) * ( thresh( t )+1 )	!start from 0
	    out( l+1 ) = c1( m ) * ( thresh( t )+1 )
	end do
	return
      end
