c******************************************************************
c	Jet Propulsion Laboratory
c	Section:	334, Radar Science and Engineering
c	Project: 	Magellan
c	Task:		Correlator, Alliant Fortran Version.
c*******************************************************************
c	frame_case.f:	(Alliant Fortran Version)
c	
c		Determine overlay cases from c1 & c2 dimension. 
c
c	Input:	1). Processing Paramers:
c		    frame_c1_fdmin.
c		    frame_c1_fdmax.
c		    frame_c2_min.
c		    frmae_c2_max.
c	Ouput: 	Four overlay cases indexes:
c		1).Nominal.
c		2).Go backward.
c		3).No overlay in cross track.
c		4).No overlay in along track.
c
c	Requested by: overlay_process.f module.
c
c	Called by: Overlay_main.f module.
c	
c	Function:
c		Base on the frame corner coordinates to determine the cases.
c					
c---------------------------------------------------------------------------
c
c	12/6/92  Anhua Chu  Take care jumping around case.
c	9/16/92  Anhua Chu  Output from Far-range. 
c	5/5/92  Anhua Chu Initial code.
c***************************************************************************
	subroutine frame_case(case_id)

	implicit none	

	include '../../../inc/pp.inc'
	include '../../../inc/keyvar.inc'
	include '../../../inc/constant.inc'
	include '../../../inc/corr_buffer.inc'
	include '../../../inc/overlay.inc'

c	passing out parameter

	integer	case_id

c	COMMON BLOCK FOR IMAGE HEADER

	integer o_burst,pre_burst
	common /o_burst/o_burst,pre_burst

	integer right_out_ptr_do,reset_c2_flag
	integer delta_c1,reserve_c2

c       ------------
c	FRAME CORNER 
c	-----------

	if (projection .eq. sine) then
	   c1_min_2 = pp_data_frame_c1_fdmax 
	   c1_max_2 = pp_data_frame_c1_fdmin
	else
	   c1_min_2 = pp_data_frame_c1_fdmin  !nint(c1min/75.)
	   c1_max_2 = pp_data_frame_c1_fdmax  !nint(c1max/75.)
	endif

	c2_min_2 = pp_data_frame_c2_min   !c2_min/75.
	c2_max_2 = pp_data_frame_c2_max   !c2max/75.
	
d	type *,' FRAME_CASE c2_min_2 c2_max_2:',c2_min_2,c2_max_2
cd	type *,' c1_min_2 c1_max_2:',c1_min_2,c1_max_2

c	------------
c	FRAME OUTPUT SIZE & DIMENSION
c	-----------

	if (projection .eq. sine) then
	   c1_start_out = c1_max_1
	   c1_down_left(left_in_ptr)=c1_min_1
	   c1_down_right(right_in_ptr)=c1_min_0
	   if (hop_request .eq. .false.) then
	      c1_size_out = abs(c1_offset)	!setup in pp
	   else
	      c1_size_out = abs(c1_max_1 - c1_max_2)
c	      	!for after no overlay in cross-track burst. 
	   endif
	else
	   c1_start_out = c1_min_1
	   c1_down_left(left_in_ptr)=c1_max_1
	   c1_down_right(right_in_ptr)=c1_max_0
	   if (hop_request .eq. .false.) then
	      c1_size_out = abs(c1_offset)	!setup in pp
	   else
	      c1_size_out = abs(c1_min_2 - c1_min_1)
c	      c1_size_out = 0	!for after no overlay in cross-track burst. 
	   endif
	endif

cd	type *,' c1:start_out/offset',c1_start_out,c1_size_out
	
	reset_c2_flag = 0 
	c2_min_left(left_in_ptr)=c2_min_1
	c2_max_right(right_in_ptr)=c2_max_0

d	type *,'c2_max_right(ptr)0',c2_max_right(right_out_ptr)
d	type *,'right_in/out_ptr',right_in_ptr,right_out_ptr

        if (c2_max_1 .ge. c2_max_right(right_out_ptr)) then
   	   
	  right_out_ptr = right_in_ptr + 1
	  c2_start_out = c2_max_1 - 511 
d	  type *,'**C2_START 1:',c2_start_out,c2_max_1,right_out_ptr

	else !if (c2_max_1 .lt. c2_max_right(right_out_ptr)) then

	  if (projection .eq. sine) then


	  if (c1_max_1 .ge. c1_down_right(right_out_ptr)) then

	    c2_start_out = c2_max_right(right_out_ptr) - 511 
d	    type *,'**C2_START 2:',c2_max_right(right_out_ptr),
d    *	                          right_out_ptr

	  else

	    right_out_ptr = right_out_ptr + 1
	    right_out_ptr_do = right_out_ptr
      	    reserve_c2 = c2_max_1

	    do while(right_out_ptr_do .le. right_in_ptr)

               if (c1_max_1 .ge. 
     *                c1_down_right(right_out_ptr_do)) then

	         if (c2_max_1 .ge. 
     *                c2_max_right(right_out_ptr_do)) then

     	 	   if (c2_max_1 .ge. reserve_c2) then
	              c2_start_out = c2_max_1 - 511
	              right_out_ptr = right_in_ptr + 1
	              reserve_c2 = c2_max_1
	              reset_c2_flag = 1
d	              type *,'**C2_START 3:',c2_start_out,c2_max_1,
d    *	                                  right_out_ptr_do
	           endif  

	         else

	         if (reset_c2_flag .ne. 1) then
      	            reserve_c2 = c2_max_right(right_out_ptr_do)
                    c2_start_out = reserve_c2 - 511
                    right_out_ptr = right_out_ptr_do
	            reset_c2_flag = 1
d	            type *,'**C2_START40',reserve_c2, right_out_ptr
	         endif

	         if (reserve_c2 .lt. 
     *                      c2_max_right(right_out_ptr_do)) then
    	            reserve_c2 = c2_max_right(right_out_ptr_do)
                    c2_start_out = reserve_c2 - 511
                    right_out_ptr = right_out_ptr_do
	            reset_c2_flag = 1
d	            type *,'**C2_START41',reserve_c2, right_out_ptr
	         endif

d	            type *,'4 bypass',c2_max_right(right_out_ptr),
d    *	                            reserve_c2, right_out_ptr
	
	         endif 		!c2_max_1 .ge. c2_max_right

               endif		!c1_max_1 .ge. c1_down_right

               right_out_ptr_do = right_out_ptr_do + 1

            enddo
	    
	    if (((right_out_ptr_do-1) .eq. right_in_ptr) .and.
     *	         (reset_c2_flag .eq. 0)) then
	       c2_start_out = c2_max_1 - 511
d	       type *,'**C2_START 5:',c2_start_out,c2_max_1
	       right_out_ptr = right_in_ptr + 1
	    endif
	
	  endif

	  else		!Oblique Sin

	  if (c1_min_1 .le. c1_down_right(right_out_ptr)) then
	    c2_start_out = c2_max_right(right_out_ptr) - 511 
	  else
	    right_out_ptr = right_out_ptr + 1
	    right_out_ptr_do = right_out_ptr
	    do while(right_out_ptr_do .le. right_in_ptr)
               if (c1_min_1 .le. 
     *                c1_down_right(right_out_ptr_do)) then
	          if (c2_max_1 .ge. 
     *                c2_max_right(right_out_ptr_do)) then
     	 	     if (c2_max_1 .ge. reserve_c2) then
	                c2_start_out = c2_max_1 - 511
	                right_out_ptr = right_in_ptr + 1
	                reserve_c2 = c2_max_1
	                reset_c2_flag = 1
d	                type *,'**C2_START 31:',c2_start_out,c2_max_1,
d    *	                                  right_out_ptr_do
	             endif  
	          else
	            if (reset_c2_flag .ne. 1) then
      	             reserve_c2 = c2_max_right(right_out_ptr_do)
                     c2_start_out = reserve_c2 - 511
                     right_out_ptr = right_out_ptr_do
	             reset_c2_flag = 1
d	             type *,'c2_st_out41',reserve_c2, right_out_ptr
	            endif
	            if (reserve_c2 .lt. 
     *                      c2_max_right(right_out_ptr_do)) then
    	              reserve_c2 = c2_max_right(right_out_ptr_do)
                      c2_start_out = reserve_c2 - 511
                      right_out_ptr = right_out_ptr_do
	              reset_c2_flag = 1
d	              type *,'c2_st_out4',reserve_c2, right_out_ptr
	            endif
	           endif	!c2_max_1 .ge. c2_max_right
               endif		!c1_max_1 .ge. c1_down_right
               right_out_ptr_do = right_out_ptr_do + 1
            enddo
	    if (((right_out_ptr_do-1) .eq. right_in_ptr) .and.
     *	         (reset_c2_flag .eq. 0)) then
	       c2_start_out = c2_max_1 - 511
	       right_out_ptr = right_in_ptr + 1
	    endif
	  endif		!end of oblique

	endif		!end of projection check

	endif		!end of c2_start_out

	c2_size_out = 512

cd	type *,' *** FRAME CASE ***'
cd	type *,' c2_start_out c2_offset:',c2_start_out,c2_offset
cd	type *,'right_out_ptr_do',right_out_ptr_do,right_out_ptr
d	type *,' c2_min_1 c2_max_1:',c2_min_1,c2_max_1
d	type *,' c1_min_1 c1_max_1:',c1_min_1,c1_max_1
cd	type *,' c2_min_0 c2_max_0:',c2_min_0,c2_max_0
d	type *,'S c2minL:',c2_min_left(left_in_ptr),left_in_ptr,
d    *	       'S c2maxR',c2_max_right(right_in_ptr),right_in_ptr
d	type *,'S c1down_R',c1_down_right(right_in_ptr),right_in_ptr,
d    *	       'S c1down_L',c1_down_left(left_in_ptr),left_in_ptr

	left_in_ptr = left_in_ptr + 1 
	right_in_ptr = right_in_ptr + 1
c	-------------
c	First Image Case
c	-------------	
        
	if ( first_burst .eq. 1) then

	    case_id = go_backward 	!same as 1st image 

	     c1_min_1 = c1_min_2
	     c1_max_1 = c1_max_2
	     if (projection .eq. sine) then
	       c1_edge_left = c1_min_2
	       c1_down_left(1)=c1_min_2
	       c1_down_right(1)=c1_min_2
	     else
	       c1_edge_left = c1_max_2
	       c1_down_left(1)=c1_max_2
	       c1_down_right(1)=c1_max_2
	     endif
	     c2_min_left(1)=c2_min_2
	     c2_max_right(1)=c2_max_2
	     c2_min_1 = c2_min_2
	     c2_max_1 = c2_max_2
	    first_burst = 0
	    pre_burst = burst_no

	    return

	endif

c	-------------
c	Nominal Case
c	-------------	

	if (((projection .eq. sine )    .and.
     *       (c1_max_2 .lt. c1_max_1)  .and. 
     *	     (c1_max_2 .gt. c1_min_1)) .or.
     *      ((projection .ne. sine )    .and.
     *       (c1_min_2 .gt. c1_min_1)  .and. 
     *	     (c1_min_2 .lt. c1_max_1))) then 

	    case_id = nominal
	    o_burst = pre_burst
	    pre_burst = burst_no
	    hop_request = .false.
d	    type *,' nominal case'

c	-------------
c	Go-backward Case
c	-------------	

	else if (((projection .eq. sine )    .and.
     *            (c1_min_2 .lt. c1_max_1)  .and. 
     *	          (c1_max_2 .ge. c1_max_1)) .or.
     *           ((projection .ne. sine )    .and.
     *            (c1_max_2 .gt. c1_min_1)  .and. 
     *	          (c1_min_2 .le. c1_min_1))) then 
	
	    case_id = go_backward
	    hop_request = .false.

	    type *,' gobackward  case'
c	-------------
c	No-overlay in Cross Track Case
c	-------------	

	else if ((c2_min_2 .ge. c2_max_1) .or. 
     *           (c2_min_1 .ge. c2_max_2)) then 

	    case_id = cross_no_overlay
	    o_burst = pre_burst
	    pre_burst = burst_no
	
	  if (hop_request .eq. .false. ) then

            type *,'**BURST FLYING **SKIP Burst_num:',burst_no	   
	    type *,'c1_max_1 c1_min_1:SIN',c1_max_1,c1_min_1 
	    type *,'c1_min_2 c1_max_2',c1_min_2,c1_max_2 
	    type *,' c2_max_1 c2_min_1:',c2_max_1,c2_min_1 
	    type *,' c2_max_2 c2_min_2:',c2_max_2,c2_min_2 

     	    if ( projection .eq. sine )   then 
	      delta_c1 = c1_min_1 - c1_max_2
     	    else ! if ( (projection .eq. oblique  ) then   
	      delta_c1 = c1_min_2 - c1_max_1
	    endif
	       type *,'*C2 NO-OVERLAY*',c2_max_2 - c2_max_1    	
	    if (delta_c1 .gt. 1 ) then
	       type *,'*C1 NO-OVERLAY*',delta_c1
	    endif

	    hop_request = .true.
	    left_in_ptr = left_in_ptr -1 
	    right_in_ptr = right_in_ptr - 1
	    right_out_ptr = right_out_ptr - 1

	 else 

	    hop_request = .false.

	 endif

	    type *,' no overlay in cross-track  case'
c	-------------
c	No-overlay in Along Track Case
c	-------------	

	else if (((projection .eq. sine )    .and.
     *            (c1_max_2 .le. c1_min_1)) .or. 
     *           ((projection .ne. sine )    .and.
     *	          (c1_min_2 .ge. c1_max_1))) then 

	    case_id = along_no_overlay
	    o_burst = pre_burst
	    pre_burst = burst_no
	    hop_request = .false.

	    type *,' no overlay in along  case'
	endif

	return
	end
c***************************** end of frame_cases.f *******************
