c*******************************************************************
c	Jet Propulsion Laboratory
c	Section:	334, Radar Sience and Engineering
c	Project:	Magellan
c	Task:		Correlator, Alliant Fortran Version
c-------------------------------------------------------------------
c	geo_rect.f:	(Alliant Fortran Version)
c	
c		Perform a geometric rectification function resampling 
c		a range doppler image into c1/c2 projection domain.
c
c	Input:	1). A burst range-doppler image data 
c		2). A associated processing parameters file.
c
c	Ouput: 	A single look image in the orthnormal C1/C2 projection.
c
c	Function:
c		Pixels in the raw image framelet are indexed by quantized
c		slant range distant and Doppler frequency. In order to get
c		orthonormal projection image, three functions, framelet
c		truncation, range resampling, and azimuth resampling, are 
c		required to perform.
c		1). Framelet truncation:
c	            The framelet truncation shall retain all pixels whose
c		    centers lie on or within the perimeter defined by this 
c		    framelet and set pixels value to be zero for pixels 
c		    outside the perimeter.
c		2).Range Resampling:
c		   Perform a 1-D four-point range interpolation to obtain 
c		   pixels along quasi-logitude or c2 lines.  
c		3).Azimuth Resampling:
c		   Perform a 1-D four-point azimuth interpolation to obtain 
c		   pixels along quasi-latitude or c1 lines.  
c
c	Algorithms and original coded by Mike Jin.
c-------------------------------------------------------------------
c
c	7/7/94 A.Chu for MIPL'SUN alps machine of edge gap  
c	6/20/92 A. Chu Make byte-o/p for testing single-look(byte_geo)
c	5/10/92 A. Chu Make a real power output(power_geo).
c	4/13/92 Anhua Chu Reconstructed S/W to fit the Alliant.
c*******************************************************************
	subroutine geo_rect(buff_az,power_geo,buff_look,byte_geo)

	implicit none	

	include '../../../inc/pp.inc'
	include '../../../inc/keyvar.inc'
	include '../../../inc/constant.inc'
	include '../../../inc/corr_buffer.inc'
	include '../../../inc/overlay.inc'
	
c	PASSING IN PARAMETERS	

	complex	buff_az(*)	!input data buffer
	REAL W1(16), W2(16), W3(16), W4(16)
	common/s_weight/w1,w2,w3,w4

c	PASSING OUT PARAMTERS

	real    power_geo(*)	!output data buffer
	byte	buff_look(*)
	byte    byte_geo(*)	!testing  buffer	

c	LOCAL VARIABLES

	COMPLEX DATA(2048)
	COMPLEX d1, d2, d3, d4
	REAL E_COEF_R(3), E_COEF_FD(3)

	complex x_value
	integer	nr_center,nf_center
	integer k,i,ii,ifd,ip,idp,c1_index_start,c1_index_end,j,jj
	integer ic1min,ic1max,ic2min,ic2max
	integer count,c2_count
d	integer test_burst_no
d	real    scale
d	common /test_burst_no/scale,test_burst_no

	real    dc1,dc2,r_indx,fd_indx
	real    r_indx_mi,r_indx_mx,fd_indx_mi,fd_indx_mx
	real	dfd,drestm,dfdestm
	real 	dlta_r,dlta_fd
	real	db

cd	type *,' Enter Geo_rectification module'	

	c2_count = 0

	nr_center = nfft_rg / 2
	nf_center = nfft_az / 2

	dlta_r=dr		!dr=300./(2*2.26)
	dlta_fd=prf/nfft_az

d	if ( test_burst_no .eq. burst_no) then
d	type *, 'c1_g(2,2) c2_g(2,2)', c1_g(2,2),c2_g(2,2)
d	type *,' fd_g(2,2) r_g(2,2)',fd_g(2,2),r_g(2,2)
d	type *,' prf dlta_fd,,r_m',prf,dlta_fd,fd_m
d	type *,'rhi rlo r_m',r_hi,r_lo,r_m
d	endif


c---------------------------------------------------------------------
c	CORNER OF FRAMELET & FRAME IMAGE
c---------------------------------------------------------------------
c	GROUND PROJECTION C1/C2: FRAME DIMENSION

	IC1MIN=NINT((C1MIN-C1_G(2,2))/75.)
	IC1MAX=NINT((C1MAX-C1_G(2,2))/75.)

	IC2MIN=NINT((C2MIN-C2_G(2,2))/75.)
	IC2MAX=NINT((C2MAX-C2_G(2,2))/75.)

	if ( projection .eq. sine) then
	   c1_index_start = ic1max
	   c1_index_end= ic1min
  	else
	   c1_index_start = ic1min
	   c1_index_end= ic1max
	endif

	c1_len = c1_index_end - c1_index_start + 1

	c2_len = ic2max - ic2min + 1

d	if ( test_burst_no .eq. burst_no) then
d	type *,' geo c1_len c2_len:',c1_len,c2_len
d	type *, 'Frame IC1minmax', IC1MIN, IC1MAX
d	type *, 'Frame IC2minmax', IC2MIN, IC2MAX
d	endif

c	RANGE-DOPPLER DOMAIN: FRAMELET DIMENSION

	R_INDX_MI=(R_lo-R_G(2,2))/DLTA_R+ nr_center-4
	R_INDX_MX=(R_hi-R_G(2,2))/DLTA_R+ nr_center+4
	
	FD_INDX_MI=(PRF-pbw)/(2*DLTA_FD)
	FD_INDX_MX=(PRF+pbw)/(2*DLTA_FD)

c	do i = 1, nfft_rg
c	   do j = 1, nfft_az
c	      if (j .lt. fd_indx_mi .or. j .gt. fd_indx_mx)
c     *        buff_az((i-1)*nfft_az + j) = cmplx(0.,0.)
c	   enddo
c        enddo

d	if ( test_burst_no .eq. burst_no) then
d	type *, 'rminmax', r_indx_mi, r_indx_mx
d	type *, 'fdminmax', fd_indx_mi, fd_indx_mx
d	endif
c-----------------------------------------------------------------
c	INTERPOLATION PROCESSING
c------------------------------------------------------------------
	do i= ic2min, ic2max

c	  ----------------
C	  RANGE RESAMPLING 
c	  ----------------

	  c2_count = c2_count + 1

          dc2=i*75.

	  do k=1,3
             e_coef_r(k)=mu_g(3,k)*dc2**2+mu_g(2,k)*dc2+mu_g(1,k)
	  enddo

	  do ifd=1,nfft_az

	     dfd=(ifd - nf_center) * dlta_fd

	     drestm=e_coef_r(3)*dfd**2+e_coef_r(2)*dfd+e_coef_r(1)

	     r_indx=(drestm +r_g(2,2) - r_m)/dlta_r + nr_center

cc	     IF(R_INDX.GE.R_INDX_MI .AND. R_INDX.LE.R_INDX_MX) THEN

	     ip=int(r_indx)
	     idp=int((r_indx-ip)*16)+1
	     if (idp .lt. 1) idp=1
	     if (ip .le. 1) ip=2
	     data(ifd) = buff_az( ifd  +nfft_az*(ip-1))*w1(idp)
     *	               + buff_az( ifd  +nfft_az*(ip  ))*w2(idp)
     *  	       + buff_az( ifd  +nfft_az*(ip+1))*w3(idp)
     *	               + buff_az( ifd  +nfft_az*(ip+2))*w4(idp)

cc	     ELSE

cc	     data(ifd) = cmplx(0.,0.)

cc	     END IF

	 end do 

c	  ----------------
C	  AZIMUTH RESAMPLING 
c	  ----------------

	  do k=1,3
             e_coef_fd(k)=mu_a(3,k)*dc2**2+mu_a(2,k)*dc2+mu_a(1,k)
	  enddo

	  count = 0

	  do J=c1_index_start,c1_index_end

	     count = count + 1 

	     dc1=j*75

	     dfdestm=e_coef_fd(3)*dc1**2+e_coef_fd(2)*dc1+e_coef_fd(1)

	     fd_indx=(dfdestm+fd_g(2,2)-fd_m)/dlta_fd+ nf_center
	     
	     IF(FD_INDX.GE.FD_INDX_MI.AND.FD_INDX.LE.FD_INDX_MX) THEN

	     ip=int(fd_indx)
	     idp=int((fd_indx-ip)*16)+1
	     if (idp .lt. 1) idp=1
	     if (ip .le. 1) ip=2
             x_value = data(ip-1)*w1(idp) + data(ip)*w2(idp)
     *               + data(ip+1)*w3(idp) + data(ip+2)*w4(idp)

c	     PIXELS DETECTION IN POWER

	     power_geo(c2_count+c2_len*(count-1))=x_value*conjg(x_value)

c	     PIXEL VALID LOOK 

	     buff_look( c2_count + c2_len*( count-1 )) = 1

c	     ------------
c	     TESTING GEO ONLY
c	     ------------
d	if ( test_burst_no .eq. burst_no) then
d	     db = 10*log10(power_geo(c2_count+c2_len*(count-1)))
d	     byte_geo( c2_count + c2_len*( count-1 )) = 
d    *           1+nint((min(max(db,-20.),30.)+20.1)/.2)
d	endif

             ELSE

	     power_geo(c2_count + c2_len*( count-1)) = 0.0 
             buff_look(c2_count + c2_len*( count-1 )) = 0

d	if ( test_burst_no .eq. burst_no) then
d	     byte_geo(c2_count + c2_len*( count-1)) =0 
c	     byte_geo(c2_count + c2_len*( c1_len-count)) =0 
d	endif
	     END IF

	   end do	! end of az resampling

	end do		! end of interpolation

	return
	end
c************************* end of geo_rect.f *****************
