c******************************************************************
c	Jet Propulsion Laboratory
c	Section:	334, Radar Science and Engineering
c	Project: 	Magellan
c	Task:		Correlator, Alliant Fortran Version.
c------------------------------------------------------------------
c	Module Name: process_overlay.f
c	
c		Generate multi-look image. 
c
c	Input:	1). Each single look image.
c		2). Processing Paramers:
c		    c1_fdmax: Length of Along track fd max direction. 
c		    c1_fdmin: Length of along track fd min direction.
c                   c2_max:   Length of cross track max frame dir.
c	            c2_min:   Length of cross track min frame dir.
c
c	Ouput: 	Multi-look image
c
c	Common Block Usage:
c
c	        overlay.inc
c
c	Calling modules:
c
c	 	overlay_sum.f
c	 	bidr_maker.f
c		bidr_out.f
c
c	Called by: multi_look.f module.
c	
c	Function:
c		1).Image frame and overlay memory size determined.
c		2).Overlay Calculation:
c		   - Summation the power of overlay pixels.
c		   - Accumulate the number of looks corresponding to 
c                    each pixel location.					
c	           - Perform the offset to first valid pixle and the
c	             pointer to the last valid pixel info for each 
c	             image line.
c	        3).BIDR maker:
c	           - Write image BIDR header.
c	           - Normalize each pixel by the number of looks.
c	           - Convert multi-look pixel values in unit of 
c	             normalized radar backscatter coefficient given 
c	             in DN.
c
c	Reference: F-BIDR SIS 
c-------------------------------------------------------------------
c
c	5/16/92  Anhua Chu Modified to Mike's scrolling memory method.
c	5/01/92  Anhua Chu Initial code, three buffer method.
c*******************************************************************
	subroutine process_overlay(case_id,
     *				buff_geo,
     *                          buff_look,
     *				buff_out,
     *                          image_ch )
     
	implicit none	

	include '../../../inc/pp.inc'
	include '../../../inc/keyvar.inc'
	include '../../../inc/constant.inc'
	include '../../../inc/corr_buffer.inc'
	include '../../../inc/overlay.inc'

c	passing in parameter

	integer	case_id		!overlay case
	real	buff_geo(*)	!power image from geometric rectification
	byte	buff_look(*)	!valid pixel is one look, otherwise is 0
	byte	buff_out(*)	!output byte image buffer
	integer	image_ch	!multi-look image disk file descriptor
				!or channel number

c	-------------
c	Norminal Case
c	-------------
	
	if ( case_id .eq. nominal ) then

	   call overlay_sum(buff_geo, buff_look)
	   call bidr_maker(buff_out)
	   call bidr_out(buff_out,image_ch)

c	-------------
c	Image Go-backward Case
c	-------------
	else if ( case_id .eq. go_backward ) then
	
	   call overlay_sum(buff_geo, buff_look)

c	-------------
c	No-overlay in Along-track Case
c	-------------
	else if (case_id .eq. along_no_overlay) then

	   call bidr_maker(buff_out)
	   call bidr_out(buff_out,image_ch)
	   call overlay_sum(buff_geo, buff_look)

c	-------------
c	No-overlay in Cross-track Case
c	-------------
	else if (case_id .eq. cross_no_overlay) then

	   call bidr_maker(buff_out)
	   call bidr_out(buff_out,image_ch)

	endif
	
	return
	end

c********************************************************************
c	Subroutines
c--------------------------------------------------------------------
	subroutine overlay_sum(buff_geo,buff_look)

	implicit none	

	include '../../../inc/pp.inc'
	include '../../../inc/keyvar.inc'
	include '../../../inc/constant.inc'
	include '../../../inc/corr_buffer.inc'
	include '../../../inc/overlay.inc'

c	passing in parameter

	real	buff_geo(*)	!power image from geometric rectification
	byte	buff_look(*)	!valid pixel is one look, otherwise is 0

c	Local variables

	integer c1,c2,c1c,c2c,k,j


	k=0

	do c1 = c1_min_2,c1_max_2
	   k = k + 1
	   j = 0
           c1c=mod(mod(c1,memo_c1_len)+memo_c1_len,memo_c1_len)
	   do c2 = c2_min_2,c2_max_2
		j = j + 1
                c2c=mod(mod(c2,memo_c2_len)+memo_c2_len,memo_c2_len)
		buff_v(c2c,c1c) = buff_v(c2c,c1c) 
     *                       + buff_geo( j + c2_len*(k-1))
		buff_vlook(c2c,c1c)=buff_vlook(c2c,c1c) 
     *                       + buff_look( j + c2_len*(k-1))

	   enddo
	enddo

	return
	end
c********************* end of overlay_process.f *********************
