c***************************************************************
c	JET PROPULSION LABORATORY
C	SECTION:	334 RADAR SCIENCE & ENGINEERING
C	PROJECT:	MAGELLAN
C	TASK:		CORRELATOR; FORTRAN-77 VERSION
c--------------------------------------------------------------
c	process_corr.f: ( Fortran Version)
c
c		Perform the Magellan SAR Correlator Processing, 
c               to produce the Full-Resolution Basic Image Record
c	        (F-BIDR) in Multi-Look Image.
c
c	Input:	1).Magellan SAR 32I/32Q BAQ.
c		2).Processing parameters for each burst of an one
c		   orbit.
c	Output:	Multi-look image in F-BIDR format.	
c
c	Referance: F-BIDR SIS Document.
c--------------------------------------------------------------
c
c	03/10/94 AC Delete single image input file.
c	11/11/92 A.Chu move get_sar_address.f to main_corr.f
c	9/18/92	A.Chu move sar_location.f to mgnsar.f
c	8/19/92	A.Chu Changed for mgnsar.f
c	5/19/92	A.Chu BAQ integration
c	5/4/92	A.Chu Initial code
c***************************************************************
	subroutine process_corr(image_ch,pp_ch,sar_channel)
	
	implicit none
	include '../../../inc/keyvar.inc'
	include '../../../inc/pp.inc'
	include '../../../inc/po_a.inc'
	include '../../../inc/constant.inc'
	include '../../../inc/corr_buffer.inc'
	include '../../../inc/overlay.inc'

c	PASSING IN PARAMETERS

	integer image_ch	!Image BIDR File Descriptor (channel)
	integer pp_ch		!PP File Descriptor (channel)
	integer sar_channel     !sar data File Descriptor (channel)

        integer	burst_address(8600)
	common /burst_address/burst_address

c	LOCAL VARIABLES

	integer ccreate		!function name  for cio
	integer cread		!function name  for cio
	integer cwrite		!function name  for cio
	complex	sample_1_tbl(256)
	complex sample_2_tbl(256)
	integer sar_address,proj_flag
	integer nbytes,r_nbytes
	integer row,col
	integer ic2min,ic2max
	integer i,j,k,ipnt,mode_flag,last_remainder_flag
	byte    byte_geo(512*2048)
	real    scale
	integer test_burst_no
	common/test_burst_no/scale,test_burst_no

	real 	t1_sar(2),t2_sar(2),etime_t1,etime_t2,run_time
	real 	t1_range(2),t2_range(2),t1_pp(2),t2_pp(2)
	real 	t1_az(2),t2_az(2),t1_radio(2),t2_radio(2)
	real 	t1_geo(2),t2_geo(2),t1_ov(2),t2_ov(2),etime


ccc	type *,' Enter Process Mode: 0=prep 1=stand_alone'
ccc	accept *, mode_flag  
ccc	type *,' Mode Flag:',mode_flag
ccc	type *,' Enter the test burst # for geo:'
ccc	accept *, test_burst_no
ccc	type *,' test_burst_no',test_burst_no
ccc	type *,' Enter the test burst SCALE  for RAD:'
ccc	accept *,scale
ccc	type *,' SCALE I/P:',scale
c	---------------
c	Initialization
c	---------------
	mode_flag = 0  
	test_burst_no=0


	byte_count = 0
	disk_address = 0 	!disk byte address starting at 0	
	num_image = 0
	image_total_size = 0
	first_burst = 1
	c2_min_0 = 0
	c2_max_0 = 0
	c2_min_1 = 0
	c2_max_1 = 0 
	left_in_ptr = 1
	left_out_ptr = 1
	right_in_ptr = 1
	right_out_ptr = 1

	call init_baq_table(sample_1_tbl,sample_2_tbl)
	
	call cube_weight

c	call sar_location !move to mgnsar.f or main_corr.f

	if (projection .eq. sine ) then
            proj_flag = 1
	else
	    proj_flag = 0 	! follow pre-processor
	endif
c------------------------------------------------------------------
c	MAIN LOOP FOR EACH BURST
c------------------------------------------------------------------

	do while (current_burst .le. end_burst_num )

d	type *,' current burst,end:',current_burst,end_burst_num
c	------------
c	READ & DECODE EACH BURST PP
c	------------

d	etime_t1 = etime(t1_pp)

ccc	if (mode_flag .eq. 0) then  
c          For MGNSAR EXE (Integrating with Prep-Processing)

	   call corr_pp(current_burst,proj_flag) 

ccc	else
c	   For Stand Alone Process: MAIN_CORR EXE
ccc	call read_pp(pp_file_name,	!PP file name
ccc   *               start_burst_num,	!Start Burst Number
ccc   *               current_burst,	!Current Burst Number
ccc   *               pp_ch)		!PP channel fd
ccc	endif

c	--------------
c	CHECK FOR A VALID BURST
c	--------------

	if (( pp_data_gen_anomaly .eq. 1 ) .or.
     *      (pp_data_gen_error .eq. 1 )    .or.
     *      (pp_data_gen_test  .eq. 1))    then

	    type *,' bad burst:',pp_data_gen_burst_num
	    if (pp_data_gen_burst_num .eq. end_burst_num) then
	       last_remainder_flag = 1
	       go to 999
	    else
	       go to 888
	    endif

        endif

	call pp_keyvar	!assigned all the correlator's pp

d	etime_t2 = etime(t2_pp)
d	run_time=etime_t2-etime_t1
d	type *,' read_pp time:',run_time

c	--------------
C	DETERMINE THE FFT SIZE OF RANGE & AZIMUTH 
c	----------------

	nfft_rg =128 
	do while (nsamples .gt. nfft_rg )
	   nfft_rg = nfft_rg *2
	enddo

	nfft_az = 128
	do while (npulses .gt. nfft_az )
	   nfft_az = nfft_az *2
	enddo

c	Calibration Factor calculated by AC
c	matching SUN and DCS
c	scale = scale * .09462 !LC 8/18/94

	scale = .0001542366573 * nfft_rg * nfft_az

c	FFT Scale factor elimilation FOR SUN & CFT.f 02/07/94 AC
c	scale = .000163*nfft_rg*nfft_az

c	scale = .000163 !9/1/92
d	type *,' nfft_rg:',nfft_rg,nsamples
d	type *,' nfft_az:',nfft_az,npulses

c	----------------
C	GENERATE FULL RESOLUTION CHECKER-BOARD
c	----------------
ccc	if (current_burst .le. (end_burst_num -5)) then 
ccc	call ck_board_sa(current_burst,buff1_rg)
ccc	type *,' ck_board burst_num:',current_burst
ccc	go to 777	
ccc	else
ccc	endif

c	----------------
C	READ & DECODE SAR 2I/2Q FROM DISK 
c	----------------
d	etime_t1 = etime(t1_sar)

	sar_address = burst_address(current_burst)

	nbytes = (npulses*nsamples)/2

d	type *,' SAR Address sar size:',sar_address,nbytes

	r_nbytes = cread(sar_ch,
     *	                 data_2iq(1),
     *                   nbytes,
     *                   sar_address)


d	type *,'SARd1/17/33:',data_2iq(1),data_2iq(17),data_2iq(33)
	
        if (r_nbytes .ne. nbytes) then
         type *,' >>>READ-SAR ERROR<<<',nbytes,r_nbytes
         stop
        endif	

	call decode_sar(sample_1_tbl,
     *	                sample_2_tbl,
     *                  sar_threshold,
     *                  data_2iq,
     *                  buff1_rg,
     *	                npulses,
     *                  nsamples,
     *                  nfft_rg)


d	type *,'SAR32 100 150 200',buff1_rg(100),buff1_rg(150)
d    *                            ,buff1_rg(200)
	
d	etime_t2 = etime(t2_sar)
d	run_time=etime_t2-etime_t1
d	type *,' sar read/decode  time:',run_time
	
c	----------------
c	RANGE COMPRESSION
c	----------------
	 
d	etime_t1 = etime(t1_range)

777	call range_comp(buff1_rg)

d	etime_t2 = etime(t2_range)
d	run_time=etime_t2-etime_t1
d	type *,' range time:',run_time
c	----------------
c	CORNER TURN
c	----------------

	call corner_turn(buff1_rg,buff1_az,nfft_rg,nfft_az)

c	----------------
c	AZIMUTH COMPRESSION
c	----------------

d	etime_t1 = etime(t1_az)

   	call az_comp(buff1_az,buff1_shift)

d	etime_t2 = etime(t2_az)
d	run_time=etime_t2-etime_t1
d	type *,' az time:',run_time

cccd	nbytes=nfft_az*nfft_rg*8
cccd	type *,'  az comp size',nfft_rg,nfft_az*8
cccd	ipnt = 0 
cccd	if (burst_no .eq. test_burst_no) then
cccd	type *,' burst az comp size',nfft_rg,nfft_az*8,burst_no
cccd	r_nbytes=cwrite(ichan2,buff1_az,nbytes,ipnt)
cccd	endif
c	----------------
c	RADIOMETRIC COMPENSATION
c	----------------

d	etime_t1 = etime(t1_radio)

	call radio_comp(buff1_shift,buff1_az)

d	etime_t2 = etime(t2_radio)
d	run_time=etime_t2-etime_t1
d	type *,' radio time:',run_time
c	----------------
c	GEOMETRIC RECTIFICATION
c	----------------

d	etime_t1 = etime(t1_geo)

	call geo_rect(buff1_az,power1_geo,buff1_look,byte_geo)

d	etime_t2 = etime(t2_geo)
d	run_time=etime_t2-etime_t1
d	type *,' geo time:',run_time

cccd	nbytes = c1_len*c2_len 
cccd	type *,' c1_len c2_len:', c1_len,c2_len
cccd	ipnt = 0 
cccd	if (burst_no .eq. (test_burst_no)) then
cccd	type *,'GEOburst  c1_len c2_len:', c1_len,c2_len,burst_no
cccd	   r_nbytes=cwrite(ichan3,byte_geo,nbytes,ipnt)
cccd          if (r_nbytes .ne. nbytes) then
cccd             type *,' >>>WRITE-GEO ERROR<<<1',nbytes,r_nbytes
cccd          endif	
cccd	   call cclose(ichan3)
cccd	else if (burst_no .eq. test_burst_no+1) then
cccd	type *,'GEOburst c1_len c2_len:', c1_len,c2_len,burst_no
cccd	   r_nbytes=cwrite(ichan4,byte_geo,nbytes,ipnt)
cccd          if (r_nbytes .ne. nbytes) then
cccd             type *,' >>>WRITE-GEO ERROR<<<2',nbytes,r_nbytes
cccd          endif	
cccd	   call cclose(ichan4)
cccd	endif

c	----------------
c	MULTI-LOOK OVERLAY
c	----------------
d	etime_t1 = etime(t1_ov)

	call multi_look(power1_geo,
     *                   buff1_look,
     *                   buff1_out,
     *                   image_ch)

d	etime_t2 = etime(t2_ov)
d	run_time=etime_t2-etime_t1
d	type *,' overlay time:',run_time
	
888	current_burst = current_burst + 1

	enddo	!end of orbit

999     if ( last_remainder_flag .eq.  1) then
	   call last_remainder(buff1_out,image_ch)
	endif

	type *,' End of process-corr orbit:',po_orbit_2_num

	return

	end

