c******************************************************************
c	Jet Propulsion Laboratory
c	Section:	334, Radar Science and Engineering
c	Projection: 	Magellan
c	Task:		Correlator, Sun Fortran Version.
c------------------------------------------------------------------
c	Module Name: read_pp
c	
c		Read Processing  paramters F-BIDR-14 &16 file from disk 
c		and convert floating point data to Alliant format.
c
c	Input:	1). File Name.
c
c	Ouput: 	1). Decoded processing parameters.
c
c	Called by: main_corr.f module.
c	
c	Function calls: 1).vax2sunr4(r4): single percision
c			   floating point conversion.
c			2).vax2suni4(i4): long integer conversion
c		        3).cio: Disk I/O in C(copen,cread&cclose)
c					
c-------------------------------------------------------------------
c	10/27/93 Lawrence Chen modify for VAX to Sun data format
c		 conversion
c	8/18/92  Anhua Chu For radiometric compensation
c	8/17/92  Anhua Chu For radiometric compensation
c	8/14/92  Anhua Chu For range antenna weights
c	5/1/92  Anhua Chu Initial code.
c*******************************************************************
	subroutine read_pp(file_pp_name,start_burst,burst_num,
     *                     channel_fd)
c	integer function read_pp(file_pp_name)
          
	implicit none	

	include '../../../inc/pp.inc'

c	PASSING IN PARAMETERS

	character*(*) file_pp_name
	integer start_burst 
	integer burst_num
	
c	PASSING OUT PARAMETER

	integer channel_fd !File Descriptor (Channel #) for closing!

c	FUNCTION CALLS

	integer*4 vax2suni4	!long integer conversion
	real	vax2sunr4	!single percision floating point conv.
	integer copen		!open a file 
	integer cread		!read data from a disk file
	
c	LOCAL VARIABLES

	integer		i,j
	integer		nbytes,bytes
	integer		start_address
c	character*35	c_hdr
c	character*1280	c_data
	byte		b_hdr(35)
	byte		b_data(1280)
c	equivalence 	(b_hdr,c_hdr)
c	equivalence 	(b_data,c_data)

c	-----------
c	SAR Threshold Byte Data 
c	-----------
	
	byte	threshold(24)

c	-----------
c	Integer Data 
c	-----------
	integer i_gen_burst_num
	integer i_gen_test
	integer i_gen_anomaly
	integer i_gen_error
	integer i_gen_projection

	integer i_brcomp_n_pulses
	integer i_brcomp_az_f

	integer i_dcs_rg_ref_ndx

	integer i_geo_c1_11 
	integer i_geo_c1_21
	integer i_geo_c1_31 
	integer i_geo_c1_12 
	integer i_geo_c1_22 
	integer i_geo_c1_32 
	integer i_geo_c1_13 
	integer i_geo_c1_23 
	integer i_geo_c1_33 

	integer i_geo_c2_11 
	integer i_geo_c2_21 
	integer i_geo_c2_31 
	integer i_geo_c2_12 
	integer i_geo_c2_22 
	integer i_geo_c2_32 
	integer i_geo_c2_13 
	integer i_geo_c2_23 
	integer i_geo_c2_33 

	integer i_bs_nsamples

	integer i_frame_c1_fdmax
	integer i_frame_c2_min
	integer i_frame_c2_start
	integer i_frame_c1_fdmin
	integer i_frame_c2_max
	integer i_frame_c1_offset
	integer i_frame_c2_offset
	integer i_frame_set_no
	integer i_frame_r_offset

	equivalence(i_gen_burst_num,b_data(1))
	equivalence(i_gen_test,b_data(33))
	equivalence(i_gen_anomaly,b_data(37))
	equivalence(i_gen_error,b_data(41))
	equivalence(i_gen_projection,b_data(45))

	equivalence(i_brcomp_az_f,b_data(277))	!9/16/92 radio_comp
	equivalence(i_brcomp_n_pulses,b_data(281))

	equivalence(i_dcs_rg_ref_ndx,b_data(309))

	equivalence(i_geo_c1_11,b_data(745))
	equivalence(i_geo_c1_21,b_data(749))
	equivalence(i_geo_c1_31,b_data(753))
	equivalence(i_geo_c1_12,b_data(757))
	equivalence(i_geo_c1_22,b_data(761))
	equivalence(i_geo_c1_32,b_data(765))
	equivalence(i_geo_c1_13,b_data(769))
	equivalence(i_geo_c1_23,b_data(773))
	equivalence(i_geo_c1_33,b_data(777))

	equivalence(i_geo_c2_11,b_data(781))
	equivalence(i_geo_c2_21,b_data(785))
	equivalence(i_geo_c2_31,b_data(789))
	equivalence(i_geo_c2_12,b_data(793))
	equivalence(i_geo_c2_22,b_data(797))
	equivalence(i_geo_c2_32,b_data(801))
	equivalence(i_geo_c2_13,b_data(805))
	equivalence(i_geo_c2_23,b_data(809))
	equivalence(i_geo_c2_33,b_data(813))

	equivalence(i_bs_nsamples,b_data(1069))

	equivalence(i_frame_c1_fdmax,b_data(1109))
	equivalence(i_frame_c2_min,b_data(1113))
	equivalence(i_frame_c2_start,b_data(1117))
	equivalence(i_frame_c1_fdmin,b_data(1121))
	equivalence(i_frame_c2_max,b_data(1125))
	equivalence(i_frame_c1_offset,b_data(1133))
	equivalence(i_frame_c2_offset,b_data(1137))
	equivalence(i_frame_set_no,b_data(1141))
	equivalence(i_frame_r_offset,b_data(1145))
 

c	-----------
c	Real*4  Data 
c	-----------
	integer*2	r_bip_app_rg(2)	!real 4 data
	integer*2	r_mrp_incang(2)
	integer*2	r_mrp_app_rg(2)
	integer*2	r_mrp_fd(2)
	integer*2	r_mrp_fr(2)
	integer*2	r_dcs_abs_rgwalk(2)
	integer*2	r_rcomp_rel_rg(18)
	integer*2	r_rcomp_rel_fd(18)
	integer*2	r_rcomp_c1(18)
	integer*2	r_rcomp_c2(18)
	integer*2	r_rcomp_c_in_fd(18)
	integer*2	r_rcomp_ant_gain(18)	!8/17/92
	integer*2	r_rcomp_rcomp(18)	!8/17/92
	integer*2	r_geo_c1(18)
	integer*2	r_geo_c2(18)
	integer*2	r_geo_rel_rg(18)
	integer*2	r_geo_rel_fd(18)
	integer*2	r_geo_c_in_c1(18)
	integer*2	r_geo_c_in_c2(18)
	integer*2	r_framelet_rg(8)
	integer*2	r_framelet_fd(8)
	integer*2	r_bs_prf(2)
	integer*2	r_bs_pbw(2)
	integer*2	r_sc_x		!8/14/92
	integer*2	r_sc_y
	integer*2	r_sc_z
	integer*2	r_look_ang
	integer*2	r_bip_elev	!8/14/92

	equivalence(r_sc_x,b_data(61))	!8/14/92
	equivalence(r_sc_y,b_data(65))
	equivalence(r_sc_z,b_data(69))
	equivalence(r_look_ang,b_data(177))
	equivalence(r_bip_elev,b_data(201))	!8/14/92

	equivalence(r_bip_app_rg(1),b_data(209))
	equivalence(r_mrp_incang(1),b_data(221))
	equivalence(r_mrp_app_rg(1),b_data(245))
	equivalence(r_mrp_fd(1),b_data(249))
	equivalence(r_mrp_fr(1),b_data(253))
	equivalence(r_dcs_abs_rgwalk(1),b_data(313))

	equivalence(r_rcomp_rel_rg(1),b_data(381))
	equivalence(r_rcomp_rel_rg(3),b_data(385))
	equivalence(r_rcomp_rel_rg(5),b_data(389))
	equivalence(r_rcomp_rel_rg(7),b_data(393))
	equivalence(r_rcomp_rel_rg(9),b_data(397))
	equivalence(r_rcomp_rel_rg(11),b_data(401))
	equivalence(r_rcomp_rel_rg(13),b_data(405))
	equivalence(r_rcomp_rel_rg(15),b_data(409))
	equivalence(r_rcomp_rel_rg(17),b_data(413))

	equivalence(r_rcomp_rel_fd(1),b_data(417))
	equivalence(r_rcomp_rel_fd(3),b_data(421))
	equivalence(r_rcomp_rel_fd(5),b_data(425))
	equivalence(r_rcomp_rel_fd(7),b_data(429))
	equivalence(r_rcomp_rel_fd(9),b_data(433))
	equivalence(r_rcomp_rel_fd(11),b_data(437))
	equivalence(r_rcomp_rel_fd(13),b_data(441))
	equivalence(r_rcomp_rel_fd(15),b_data(445))
	equivalence(r_rcomp_rel_fd(17),b_data(449))

	equivalence(r_rcomp_c1(1),b_data(453))
	equivalence(r_rcomp_c1(3),b_data(457))
	equivalence(r_rcomp_c1(5),b_data(461))
	equivalence(r_rcomp_c1(7),b_data(465))
	equivalence(r_rcomp_c1(9),b_data(469))
	equivalence(r_rcomp_c1(11),b_data(473))
	equivalence(r_rcomp_c1(13),b_data(477))
	equivalence(r_rcomp_c1(15),b_data(481))
	equivalence(r_rcomp_c1(17),b_data(485))
	equivalence(r_rcomp_c2(1),b_data(489))
	equivalence(r_rcomp_c2(3),b_data(493))
	equivalence(r_rcomp_c2(5),b_data(497))
	equivalence(r_rcomp_c2(7),b_data(501))
	equivalence(r_rcomp_c2(9),b_data(505))
	equivalence(r_rcomp_c2(11),b_data(509))
	equivalence(r_rcomp_c2(13),b_data(513))
	equivalence(r_rcomp_c2(15),b_data(517))
	equivalence(r_rcomp_c2(17),b_data(521))

	equivalence(r_rcomp_ant_gain(1),b_data(633))	!8/17/92
	equivalence(r_rcomp_ant_gain(3),b_data(637))
	equivalence(r_rcomp_ant_gain(5),b_data(641))
	equivalence(r_rcomp_ant_gain(7),b_data(645))	
	equivalence(r_rcomp_ant_gain(9),b_data(649))
	equivalence(r_rcomp_ant_gain(11),b_data(653))	!(range,az)
	equivalence(r_rcomp_ant_gain(13),b_data(657))
	equivalence(r_rcomp_ant_gain(15),b_data(661))
	equivalence(r_rcomp_ant_gain(17),b_data(665))

	equivalence(r_rcomp_rcomp(1),b_data(673))	!8/18/92
	equivalence(r_rcomp_rcomp(3),b_data(677))
	equivalence(r_rcomp_rcomp(5),b_data(681))
	equivalence(r_rcomp_rcomp(7),b_data(685))	
	equivalence(r_rcomp_rcomp(9),b_data(689))
	equivalence(r_rcomp_rcomp(11),b_data(693))	
	equivalence(r_rcomp_rcomp(13),b_data(697))
	equivalence(r_rcomp_rcomp(15),b_data(701))
	equivalence(r_rcomp_rcomp(17),b_data(705))

	equivalence(r_rcomp_c_in_fd(1),b_data(709))
	equivalence(r_rcomp_c_in_fd(3),b_data(713))
	equivalence(r_rcomp_c_in_fd(5),b_data(717))
	equivalence(r_rcomp_c_in_fd(7),b_data(721))
	equivalence(r_rcomp_c_in_fd(9),b_data(725))
	equivalence(r_rcomp_c_in_fd(11),b_data(729))
	equivalence(r_rcomp_c_in_fd(13),b_data(733))
	equivalence(r_rcomp_c_in_fd(15),b_data(737))
	equivalence(r_rcomp_c_in_fd(17),b_data(741))

	equivalence(r_geo_rel_rg(1),b_data(853))
	equivalence(r_geo_rel_rg(3),b_data(857))
	equivalence(r_geo_rel_rg(5),b_data(861))
	equivalence(r_geo_rel_rg(7),b_data(865))
	equivalence(r_geo_rel_rg(9),b_data(869))
	equivalence(r_geo_rel_rg(11),b_data(873))
	equivalence(r_geo_rel_rg(13),b_data(877))
	equivalence(r_geo_rel_rg(15),b_data(881))
	equivalence(r_geo_rel_rg(17),b_data(885))

	equivalence(r_geo_rel_fd(1),b_data(889))
	equivalence(r_geo_rel_fd(3),b_data(893))
	equivalence(r_geo_rel_fd(5),b_data(897))
	equivalence(r_geo_rel_fd(7),b_data(901))
	equivalence(r_geo_rel_fd(9),b_data(905))
	equivalence(r_geo_rel_fd(11),b_data(909))
	equivalence(r_geo_rel_fd(13),b_data(913))
	equivalence(r_geo_rel_fd(15),b_data(917))
	equivalence(r_geo_rel_fd(17),b_data(921))

	equivalence(r_geo_c_in_c2(1),b_data(925))
 	equivalence(r_geo_c_in_c2(3),b_data(929))
	equivalence(r_geo_c_in_c2(5),b_data(933))
	equivalence(r_geo_c_in_c2(7),b_data(937))
	equivalence(r_geo_c_in_c2(9),b_data(941))
	equivalence(r_geo_c_in_c2(11),b_data(945))
	equivalence(r_geo_c_in_c2(13),b_data(949))
	equivalence(r_geo_c_in_c2(15),b_data(953))
	equivalence(r_geo_c_in_c2(17),b_data(957))

	equivalence(r_geo_c_in_c1(1),b_data(961))
	equivalence(r_geo_c_in_c1(3),b_data(965))
	equivalence(r_geo_c_in_c1(5),b_data(969))
	equivalence(r_geo_c_in_c1(7),b_data(973))
	equivalence(r_geo_c_in_c1(9),b_data(977))
	equivalence(r_geo_c_in_c1(11),b_data(981))
	equivalence(r_geo_c_in_c1(13),b_data(985))
	equivalence(r_geo_c_in_c1(15),b_data(989))
	equivalence(r_geo_c_in_c1(17),b_data(993))

	equivalence(r_framelet_rg(1),b_data(997))
	equivalence(r_framelet_rg(3),b_data(1001))
	equivalence(r_framelet_rg(5),b_data(1005))
	equivalence(r_framelet_rg(7),b_data(1009))

	equivalence(r_framelet_fd(1),b_data(1013))
	equivalence(r_framelet_fd(3),b_data(1017))
	equivalence(r_framelet_fd(5),b_data(1021))
	equivalence(r_framelet_fd(7),b_data(1025))

	equivalence(r_bs_prf,b_data(1061))

	equivalence(r_bs_pbw,b_data(1073))

	equivalence(threshold(1),b_data(1085))
c	------------
c	DISK ACCESS
c	------------
	if (channel_fd .le. 0 ) stop ' READ_PP File Open ERROR'

	start_address = (burst_num - start_burst )*1315 

c	nbytes=35
c	bytes = cread(channel_fd, b_hdr, nbytes, start_address)

	nbytes=1280
	start_address=start_address+35

	bytes = cread(channel_fd, b_data, nbytes, start_address)
	  
	if (bytes .ne. nbytes) then
           type *,' READ-PP Reading ERROR',file_pp_name,bytes
	   stop
	endif

c	call cclose(channel_fd)
	
c	--------------
c	INTEGER ASSIGNMENT
c	--------------
c
c	------------------
c	since the integer*4(long integer) data formats are 
c	different in VAX and Sun, we need to convert it in proper
c	way.  10/27/93 L. Chen
c	------------------

	pp_data_gen_burst_num=vax2suni4(i_gen_burst_num)
	pp_data_gen_test=vax2suni4(i_gen_test)
	pp_data_gen_anomaly=vax2suni4(i_gen_anomaly)
	pp_data_gen_error=vax2suni4(i_gen_error)
	pp_data_gen_projection=vax2suni4(i_gen_projection)

	pp_data_brcomp_az_f=vax2suni4(i_brcomp_az_f)	!9/16/92 dcs fft_az
	pp_data_brcomp_n_pulses=vax2suni4(i_brcomp_n_pulses)

	pp_data_dcs_rg_ref_ndx=vax2suni4(i_dcs_rg_ref_ndx)

	pp_data_geo_c1(1,1)=vax2suni4(i_geo_c1_11) 
	pp_data_geo_c1(2,1)=vax2suni4(i_geo_c1_21) 
	pp_data_geo_c1(3,1)=vax2suni4(i_geo_c1_31)
	pp_data_geo_c1(1,2)=vax2suni4(i_geo_c1_12) 
	pp_data_geo_c1(2,2)=vax2suni4(i_geo_c1_22) 
	pp_data_geo_c1(3,2)=vax2suni4(i_geo_c1_32) 
	pp_data_geo_c1(1,3)=vax2suni4(i_geo_c1_13) 
	pp_data_geo_c1(2,3)=vax2suni4(i_geo_c1_23) 
	pp_data_geo_c1(3,3)=vax2suni4(i_geo_c1_33) 

	pp_data_geo_c2(1,1)=vax2suni4(i_geo_c2_11) 
	pp_data_geo_c2(2,1)=vax2suni4(i_geo_c2_21) 
	pp_data_geo_c2(3,1)=vax2suni4(i_geo_c2_31) 
	pp_data_geo_c2(1,2)=vax2suni4(i_geo_c2_12) 
	pp_data_geo_c2(2,2)=vax2suni4(i_geo_c2_22) 
	pp_data_geo_c2(3,2)=vax2suni4(i_geo_c2_32) 
	pp_data_geo_c2(1,3)=vax2suni4(i_geo_c2_13) 
	pp_data_geo_c2(2,3)=vax2suni4(i_geo_c2_23) 
	pp_data_geo_c2(3,3)=vax2suni4(i_geo_c2_33) 

	pp_data_bs_nsamples=vax2suni4(i_bs_nsamples)

	pp_data_frame_c1_fdmax=vax2suni4(i_frame_c1_fdmax)
	pp_data_frame_c2_min=vax2suni4(i_frame_c2_min)
	pp_data_frame_c2_start=vax2suni4(i_frame_c2_start)
	pp_data_frame_c1_fdmin=vax2suni4(i_frame_c1_fdmin)
	pp_data_frame_c2_max=vax2suni4(i_frame_c2_max)
	pp_data_frame_c1_offset=vax2suni4(i_frame_c1_offset)
	pp_data_frame_c2_offset=vax2suni4(i_frame_c2_offset)
	pp_data_frame_set_no=vax2suni4(i_frame_set_no)
	pp_data_frame_r_offset=vax2suni4(i_frame_r_offset)

c	------------
c	REAL*4 CONVERSION
c	------------
	pp_data_rcomp_ant_gain(1,1)=vax2sunr4(r_rcomp_ant_gain(1))
	pp_data_rcomp_ant_gain(2,1)=vax2sunr4(r_rcomp_ant_gain(3))
	pp_data_rcomp_ant_gain(3,1)=vax2sunr4(r_rcomp_ant_gain(5))
	pp_data_rcomp_ant_gain(1,2)=vax2sunr4(r_rcomp_ant_gain(7))
	pp_data_rcomp_ant_gain(2,2)=vax2sunr4(r_rcomp_ant_gain(9))
	pp_data_rcomp_ant_gain(3,2)=vax2sunr4(r_rcomp_ant_gain(11))
	pp_data_rcomp_ant_gain(1,3)=vax2sunr4(r_rcomp_ant_gain(13))
	pp_data_rcomp_ant_gain(2,3)=vax2sunr4(r_rcomp_ant_gain(15))
	pp_data_rcomp_ant_gain(3,3)=vax2sunr4(r_rcomp_ant_gain(17))

	pp_data_rcomp_rcomp(1,1)=vax2sunr4(r_rcomp_rcomp(1))
	pp_data_rcomp_rcomp(2,1)=vax2sunr4(r_rcomp_rcomp(3))
	pp_data_rcomp_rcomp(3,1)=vax2sunr4(r_rcomp_rcomp(5))
	pp_data_rcomp_rcomp(1,2)=vax2sunr4(r_rcomp_rcomp(7))
	pp_data_rcomp_rcomp(2,2)=vax2sunr4(r_rcomp_rcomp(9))
	pp_data_rcomp_rcomp(3,2)=vax2sunr4(r_rcomp_rcomp(11))
	pp_data_rcomp_rcomp(1,3)=vax2sunr4(r_rcomp_rcomp(13))
	pp_data_rcomp_rcomp(2,3)=vax2sunr4(r_rcomp_rcomp(15))
	pp_data_rcomp_rcomp(3,3)=vax2sunr4(r_rcomp_rcomp(17))

	pp_data_ssp_sc_x_vbf=vax2sunr4(r_sc_x)	!8/14/92
	pp_data_ssp_sc_y_vbf=vax2sunr4(r_sc_y)	!8/14/92
	pp_data_ssp_sc_z_vbf=vax2sunr4(r_sc_z)	!8/14/92
	pp_data_ssp_look_ang=vax2sunr4(r_look_ang)	!8/14/92
	pp_data_bip_bip_elev=vax2sunr4(r_bip_elev)	!8/14/92

	pp_data_bip_bip_app_rg=vax2sunr4(r_bip_app_rg)
	pp_data_mrp_mrp_incang=vax2sunr4(r_mrp_incang)
	pp_data_mrp_mrp_app_rg=vax2sunr4(r_mrp_app_rg)
	pp_data_mrp_mrp_fd=vax2sunr4(r_mrp_fd)
	pp_data_mrp_mrp_fr=vax2sunr4(r_mrp_fr)
	pp_data_dcs_abs_rgwalk=vax2sunr4(r_dcs_abs_rgwalk)

	pp_data_rcomp_rel_rg(1,1)=vax2sunr4(r_rcomp_rel_rg(1))
	pp_data_rcomp_rel_rg(2,1)=vax2sunr4(r_rcomp_rel_rg(3))
	pp_data_rcomp_rel_rg(3,1)=vax2sunr4(r_rcomp_rel_rg(5))
	pp_data_rcomp_rel_rg(1,2)=vax2sunr4(r_rcomp_rel_rg(7))
	pp_data_rcomp_rel_rg(2,2)=vax2sunr4(r_rcomp_rel_rg(9))
	pp_data_rcomp_rel_rg(3,2)=vax2sunr4(r_rcomp_rel_rg(11))
	pp_data_rcomp_rel_rg(1,3)=vax2sunr4(r_rcomp_rel_rg(13))
	pp_data_rcomp_rel_rg(2,3)=vax2sunr4(r_rcomp_rel_rg(15))
	pp_data_rcomp_rel_rg(3,3)=vax2sunr4(r_rcomp_rel_rg(17))

	pp_data_rcomp_rel_fd(1,1)=vax2sunr4(r_rcomp_rel_fd(1))
	pp_data_rcomp_rel_fd(2,1)=vax2sunr4(r_rcomp_rel_fd(3))
	pp_data_rcomp_rel_fd(3,1)=vax2sunr4(r_rcomp_rel_fd(5))
	pp_data_rcomp_rel_fd(1,2)=vax2sunr4(r_rcomp_rel_fd(7))
	pp_data_rcomp_rel_fd(2,2)=vax2sunr4(r_rcomp_rel_fd(9))
	pp_data_rcomp_rel_fd(3,2)=vax2sunr4(r_rcomp_rel_fd(11))
	pp_data_rcomp_rel_fd(1,3)=vax2sunr4(r_rcomp_rel_fd(13))
	pp_data_rcomp_rel_fd(2,3)=vax2sunr4(r_rcomp_rel_fd(15))
	pp_data_rcomp_rel_fd(3,3)=vax2sunr4(r_rcomp_rel_fd(17))

	pp_data_rcomp_c1(1,1)=vax2sunr4(r_rcomp_c1(1))
	pp_data_rcomp_c1(2,1)=vax2sunr4(r_rcomp_c1(3))
	pp_data_rcomp_c1(3,1)=vax2sunr4(r_rcomp_c1(5))
	pp_data_rcomp_c1(1,2)=vax2sunr4(r_rcomp_c1(7))
	pp_data_rcomp_c1(2,2)=vax2sunr4(r_rcomp_c1(9))
	pp_data_rcomp_c1(3,2)=vax2sunr4(r_rcomp_c1(11))
	pp_data_rcomp_c1(1,3)=vax2sunr4(r_rcomp_c1(13))
	pp_data_rcomp_c1(2,3)=vax2sunr4(r_rcomp_c1(15))
	pp_data_rcomp_c1(3,3)=vax2sunr4(r_rcomp_c1(17))


	pp_data_rcomp_c2(1,1)=vax2sunr4(r_rcomp_c2(1))
	pp_data_rcomp_c2(2,1)=vax2sunr4(r_rcomp_c2(3))
	pp_data_rcomp_c2(3,1)=vax2sunr4(r_rcomp_c2(5))
	pp_data_rcomp_c2(1,2)=vax2sunr4(r_rcomp_c2(7))
	pp_data_rcomp_c2(2,2)=vax2sunr4(r_rcomp_c2(9))
	pp_data_rcomp_c2(3,2)=vax2sunr4(r_rcomp_c2(11))
	pp_data_rcomp_c2(1,3)=vax2sunr4(r_rcomp_c2(13))
	pp_data_rcomp_c2(2,3)=vax2sunr4(r_rcomp_c2(15))
	pp_data_rcomp_c2(3,3)=vax2sunr4(r_rcomp_c2(17))

	pp_data_rcomp_c_in_fd(1,1)=vax2sunr4(r_rcomp_c_in_fd(1))
	pp_data_rcomp_c_in_fd(2,1)=vax2sunr4(r_rcomp_c_in_fd(3))
	pp_data_rcomp_c_in_fd(3,1)=vax2sunr4(r_rcomp_c_in_fd(5))
	pp_data_rcomp_c_in_fd(1,2)=vax2sunr4(r_rcomp_c_in_fd(7))
	pp_data_rcomp_c_in_fd(2,2)=vax2sunr4(r_rcomp_c_in_fd(9))
	pp_data_rcomp_c_in_fd(3,2)=vax2sunr4(r_rcomp_c_in_fd(11))
	pp_data_rcomp_c_in_fd(1,3)=vax2sunr4(r_rcomp_c_in_fd(13))
	pp_data_rcomp_c_in_fd(2,3)=vax2sunr4(r_rcomp_c_in_fd(15))
	pp_data_rcomp_c_in_fd(3,3)=vax2sunr4(r_rcomp_c_in_fd(17))

	pp_data_geo_rel_rg(1,1)=vax2sunr4(r_geo_rel_rg(1))
	pp_data_geo_rel_rg(2,1)=vax2sunr4(r_geo_rel_rg(3))
	pp_data_geo_rel_rg(3,1)=vax2sunr4(r_geo_rel_rg(5))
	pp_data_geo_rel_rg(1,2)=vax2sunr4(r_geo_rel_rg(7))
	pp_data_geo_rel_rg(2,2)=vax2sunr4(r_geo_rel_rg(9))
	pp_data_geo_rel_rg(3,2)=vax2sunr4(r_geo_rel_rg(11))
	pp_data_geo_rel_rg(1,3)=vax2sunr4(r_geo_rel_rg(13))
	pp_data_geo_rel_rg(2,3)=vax2sunr4(r_geo_rel_rg(15))
	pp_data_geo_rel_rg(3,3)=vax2sunr4(r_geo_rel_rg(17))

	pp_data_geo_rel_fd(1,1)=vax2sunr4(r_geo_rel_fd(1))
	pp_data_geo_rel_fd(2,1)=vax2sunr4(r_geo_rel_fd(3))
	pp_data_geo_rel_fd(3,1)=vax2sunr4(r_geo_rel_fd(5))
	pp_data_geo_rel_fd(1,2)=vax2sunr4(r_geo_rel_fd(7))
	pp_data_geo_rel_fd(2,2)=vax2sunr4(r_geo_rel_fd(9))
	pp_data_geo_rel_fd(3,2)=vax2sunr4(r_geo_rel_fd(11))
	pp_data_geo_rel_fd(1,3)=vax2sunr4(r_geo_rel_fd(13))
	pp_data_geo_rel_fd(2,3)=vax2sunr4(r_geo_rel_fd(15))
	pp_data_geo_rel_fd(3,3)=vax2sunr4(r_geo_rel_fd(17))

	pp_data_geo_c_in_c2(1,1)=vax2sunr4(r_geo_c_in_c2(1))
	pp_data_geo_c_in_c2(2,1)=vax2sunr4(r_geo_c_in_c2(3))
	pp_data_geo_c_in_c2(3,1)=vax2sunr4(r_geo_c_in_c2(5))
	pp_data_geo_c_in_c2(1,2)=vax2sunr4(r_geo_c_in_c2(7))
	pp_data_geo_c_in_c2(2,2)=vax2sunr4(r_geo_c_in_c2(9))
	pp_data_geo_c_in_c2(3,2)=vax2sunr4(r_geo_c_in_c2(11))
	pp_data_geo_c_in_c2(1,3)=vax2sunr4(r_geo_c_in_c2(13))
	pp_data_geo_c_in_c2(2,3)=vax2sunr4(r_geo_c_in_c2(15))
	pp_data_geo_c_in_c2(3,3)=vax2sunr4(r_geo_c_in_c2(17))

	pp_data_geo_c_in_c1(1,1)=vax2sunr4(r_geo_c_in_c1(1))
	pp_data_geo_c_in_c1(2,1)=vax2sunr4(r_geo_c_in_c1(3))
	pp_data_geo_c_in_c1(3,1)=vax2sunr4(r_geo_c_in_c1(5))
	pp_data_geo_c_in_c1(1,2)=vax2sunr4(r_geo_c_in_c1(7))
	pp_data_geo_c_in_c1(2,2)=vax2sunr4(r_geo_c_in_c1(9))
	pp_data_geo_c_in_c1(3,2)=vax2sunr4(r_geo_c_in_c1(11))
	pp_data_geo_c_in_c1(1,3)=vax2sunr4(r_geo_c_in_c1(13))
	pp_data_geo_c_in_c1(2,3)=vax2sunr4(r_geo_c_in_c1(15))
	pp_data_geo_c_in_c1(3,3)=vax2sunr4(r_geo_c_in_c1(17))

	pp_data_framelet_rg(1,1)=vax2sunr4(r_framelet_rg(1))
	pp_data_framelet_rg(2,1)=vax2sunr4(r_framelet_rg(3))
	pp_data_framelet_rg(1,2)=vax2sunr4(r_framelet_rg(5))
	pp_data_framelet_rg(2,2)=vax2sunr4(r_framelet_rg(7))
		
	pp_data_framelet_fd(1,1)=vax2sunr4(r_framelet_fd(1))
	pp_data_framelet_fd(2,1)=vax2sunr4(r_framelet_fd(3))
	pp_data_framelet_fd(1,2)=vax2sunr4(r_framelet_fd(5))
	pp_data_framelet_fd(2,2)=vax2sunr4(r_framelet_fd(7))

	pp_data_bs_prf=vax2sunr4(r_bs_prf)

	pp_data_bs_pbw=vax2sunr4(r_bs_pbw)

	do i=1,24
	   pp_data_pm_thresh(i)=threshold(i)
 	enddo
c	------------
c	DUMP PP TO MONITOR
c	------------

	type *,'gen_burst_num=', pp_data_gen_burst_num
c        type *,'gen_burst_start=', pp_data_gen_burst_start 
c        type *,'gen_burst_ref=', pp_data_gen_burst_ref 
d	type *,'gen_test=', pp_data_gen_test
d        type *,'gen_anomaly=', pp_data_gen_anomaly 
d        type *,'gen_error=', pp_data_gen_error 
d        type *,'gen_projection=', pp_data_gen_projection

d      type *,'ssp_sc_x_vbf=', pp_data_ssp_sc_x_vbf 
d      type *,'ssp_sc_y_vbf=', pp_data_ssp_sc_y_vbf 
d      type *,'ssp_sc_z_vbf=', pp_data_ssp_sc_z_vbf 

d      type *,'ssp_look_ang=', pp_data_ssp_look_ang 
	
d      type *,'bip_bip_elev=', pp_data_bip_bip_elev 

c      type *,'bip_bip_inc_ang=',pp_data_bip_bip_inc_ang 
d      type *,'bip_bip_app_rg=',pp_data_bip_bip_app_rg 

c      type *,'bip_bip_fd=', pp_data_bip_bip_fd 
c      type *,'bip_bip_fd_drift=',pp_data_bip_bip_fd_drift 
		
ctype *,'brcomp_sensor_proc_gain=',pp_data_brcomp_sensor_proc_gain 
c      type *,'brcomp_rg_f=', pp_data_brcomp_rg_f 

d      type *,'brcomp_az_f=', pp_data_brcomp_az_f 
d        type *,'brcomp_n_pulses=',pp_data_brcomp_n_pulses 

		
d        type *,'mrp_mrp_incang=', pp_data_mrp_mrp_incang
c        type *,'mrp_mrp_bs_coef=', pp_data_mrp_mrp_bs_coef 
c        type *,'mrp_mrp_lat=', pp_data_mrp_mrp_lat
c        type *,'mrp_mrp_lon=', pp_data_mrp_mrp_lon
 
c        type *,'mrp_mrp_elev=', pp_data_mrp_mrp_elev

c      type *,'mrp_sample1_app_rg=',pp_data_mrp_sample1_app_rg 
d        type *,'mrp_mrp_app_rg=', pp_data_mrp_mrp_app_rg
	
d        type *,'mrp_mrp_fd=', pp_data_mrp_mrp_fd 
d        type *,'mrp_mrp_fr=', pp_data_mrp_mrp_fr

d        type *,'dcs_rg_ref_ndx=', pp_data_dcs_rg_ref_ndx 
d        type *,'dcs_abs_rgwalk=', pp_data_dcs_abs_rgwalk 
c      type *,'dcs_rgwalk_0=', pp_data_dcs_rgwalk_0 
c      type *,'dcs_rgwalk_1=', pp_data_dcs_rgwalk_1 

d	do j=1, 3
d	do i=1, 3

d 	type *,'(i,j):',i,j
d        type *,'rcomp_rel_rg( i, j )=', pp_data_rcomp_rel_rg(i,j)
d        type *,'rcomp_rel_fd( i, j )=',pp_data_rcomp_rel_fd(i,j)
d        type *,'rcomp_C1( i, j )=',pp_data_rcomp_C1(i,j)
d        type *,'rcomp_C2( i, j )=',pp_data_rcomp_C2(i,j)

c        type *,'rcomp_sc_d( i, j )=',pp_data_rcomp_sc_d(i,j)
c        type *,'rcomp_bor_elang(i,j)=',pp_data_rcomp_bor_elang(i,j) 
c        type *,'rcomp_bor_hang(i,j)=',pp_data_rcomp_bor_hang(i,j) 
d        type *,'rcomp_ant_gain(i,j)=',pp_data_rcomp_ant_gain(i,j) 
d        type *,'rcomp_rcomp( i, j )=',pp_data_rcomp_rcomp(i,j)
d        type *,'rcomp_c_in_fd(i,j)=',pp_data_rcomp_c_in_fd(i,j)
d
d	end do
d	end do

d        type *,'rcomp_rel_rg(2,2)=',pp_data_rcomp_rel_rg(2,2)
d        type *,'rcomp_rel_fd(2, 2)=',pp_data_rcomp_rel_fd(2,2) 
c       type *,'rcomp_sigma22=',pp_data_rcomp_sigma22 

d	do j=1, 3
d	do i=1, 3
d	type *,'(i,j):',i,j
d        type *,'geo_C1(i,j)=',pp_data_geo_C1(i,j) 
d        type *,'geo_C2(i,j)=',pp_data_geo_C2(i,j) 
c        type *,'geo_elev(i,j)=',pp_data_geo_elev(i,j)
d        type *,'geo_rel_rg(i,j)=',pp_data_geo_rel_rg(i,j)
d        type *,'geo_rel_fd(i,j)=',pp_data_geo_rel_fd(i,j)
d        type *,'geo_c_in_C2(i,j)=',pp_data_geo_c_in_C2(i,j) 
d        type *,'geo_c_in_C1(i,j)=',pp_data_geo_c_in_C1(i,j)
d	end do
d	end do

d        type *,'geo_rel_rg(2,2)=', pp_data_geo_rel_rg(2,2)
d        type *,'geo_rel_fd(2,2)=',pp_data_geo_rel_fd(2,2) 
		
d        type *,'framelet_rg(1,1)=',pp_data_framelet_rg(1,1) 
d        type *,'framelet_rg(1,2)=',pp_data_framelet_rg(1,2) 
d        type *,'framelet_rg(2,1)=',pp_data_framelet_rg(2,1) 
d        type *,'framelet_rg(2,2)=',pp_data_framelet_rg(2,2) 
d        type *,'framelet_fd(1,1)=',pp_data_framelet_fd(1,1) 
d        type *,'framelet_fd(1,2)=',pp_data_framelet_fd(1,2) 
d        type *,'framelet_fd(2,1)=',pp_data_framelet_fd(2,1) 
d        type *,'framelet_fd(2,2)=',pp_data_framelet_fd(2,2) 

d        type *,'bs_prf=', pp_data_bs_prf 
c        type *,'bs_npulses=', pp_data_bs_npulses 
d        type *,'bs_nsamples=', pp_data_bs_nsamples
d        type *,'bs_pbw=', pp_data_bs_pbw
c        type *,'bs_prs=', pp_data_bs_prs
c        type *,'pm_min_looks=', pp_data_pm_min_looks 
      
d	do i=1, 24
d          type *,'pm_thresh(i )=',  pp_data_pm_thresh(i ) 
d	end do
 
d        type *,'frame_C1_FDmax=', pp_data_frame_C1_FDmax 
d        type *,'frame_C2_min=', pp_data_frame_C2_min 
d        type *,'frame_C2_start=', pp_data_frame_C2_start
d        type *,'frame_C1_FDmin=', pp_data_frame_C1_FDmin 
d        type *,'frame_C2_max=', pp_data_frame_C2_max 
c        type *,'frame_C2_end=', pp_data_frame_C2_end 
d
d        type *,'frame_C1_offset=', pp_data_frame_C1_offset 
d        type *,'frame_C2_offset=', pp_data_frame_C2_offset 

d        type *,'frame_set_no=', pp_data_frame_set_no
d        type *,'frame_r_offset=',pp_data_frame_r_offset


	return
	end
c********************* end of read_pp_f *********************
