/*
 *   vax2sunr4.c function to convert VAX real*4 to Sun IEEE real*4
 *               based on Anhua Chu's vax_alliant_sf.f
 *
 *   Changes:  Initial code David Swantek  9 / 25 / 93
 *   Changes:  Lawrence Chen 10/18/93 --> passed by value
 *   Changes:  Lawrence Chen 3/16/94  --> deal with -0.0
 *
 */

/***   Includes   ***/

#include<stdio.h>

/***   defines   ***/

#define EXP_BIAS -894;

/***   Structure and union definitions   ***/

struct vaxr8 
{
    unsigned sign:1;
    unsigned expo:8;
    unsigned mant_high:7;

    unsigned mant_low0:13;      	/*    13	*/   
    unsigned mant_low1:3;      		/*     3	*/   
					/* word boundry */
    unsigned mant_low2:13;  		/*    13	*/ 
    unsigned mant_low3:3;  		/*     3	*/ 
    unsigned mant_low4:13;  		/*   +13 = 45   */ 
    unsigned mant_to_low:3;   
};

union uvaxr8 
{
    double vr8;
    struct vaxr8 vr8s;
    int i[ 2 ];
    char b[ 8 ];
};

struct ieeer8
{
    unsigned sign:1;
    unsigned expo:11;
    unsigned mant_high:7;
    unsigned mant_low0:13;      	/*    13	*/   
					/* word boundry */
    unsigned mant_low1:3;		/*     3 	*/
    unsigned mant_low2:13;  		/*    13	*/ 
    unsigned mant_low3:3;  		/*     3	*/ 
    unsigned mant_low4:13;  		/*   +13 = 45   */ 
};

union uieeer8
{
    double ir8;
    struct ieeer8 ir8s;
    int i[ 2 ];
    char b[ 8 ];
};

struct expstr
{
    unsigned to_high:8;
    unsigned exp8:8;
};

union uexp
{
    short iexp;
    struct expstr sexp;
};

union uid
{
    int i[ 2 ];
    double d;
    char b[ 8 ];
};

double sun2vaxr8_( d )
double *d;
{
/***   Declaration of local variables   ***/

    union uvaxr8 uv;
    union uieeer8 ui;
    union uid u1;
    union uexp ue;
    int i;
    double value;

/***   start of code   ***/

    ui.ir8 = *d;

    if (ui.ir8 != 0.0) {
        uv.vr8s.mant_high = ui.ir8s.mant_high;
        uv.vr8s.mant_low0 = ui.ir8s.mant_low0;
        uv.vr8s.mant_low1 = ui.ir8s.mant_low1; 
        uv.vr8s.mant_low2 = ui.ir8s.mant_low2;
        uv.vr8s.mant_low3 = ui.ir8s.mant_low3; 
        uv.vr8s.mant_low4 = ui.ir8s.mant_low4;
        uv.vr8s.sign      = ui.ir8s.sign;
        ue.iexp = ui.ir8s.expo;
        ue.iexp += EXP_BIAS;
        uv.vr8s.expo = ue.sexp.exp8;
    }
    else
	uv.vr8 = 0.0;

/***   Do Byteswaping   ***/

    u1.b[ 1 ] = uv.b[ 0 ];
    u1.b[ 0 ] = uv.b[ 1 ];
    u1.b[ 3 ] = uv.b[ 2 ];
    u1.b[ 2 ] = uv.b[ 3 ];
    u1.b[ 5 ] = uv.b[ 4 ];
    u1.b[ 4 ] = uv.b[ 5 ];
    u1.b[ 7 ] = uv.b[ 6 ];
    u1.b[ 6 ] = uv.b[ 7 ];


    value = u1.d; 
  
    return( value );
}
