
C$Procedure DAFAH ( DAF, assign handles )

      SUBROUTINE DAFAH ( FNAME,
     .                   ND,
     .                   NI,
     .                   IFNAME,
     .                   RESV,
     .                   HANDLE,
     .                   UNIT    )

C$ Abstract
C
C     Assign handles to DAFs as they are opened.
C
C$ Required_Reading
C
C     DAF
C
C$ Keywords
C
C     FILES
C
C$ Declarations

      CHARACTER*(*)         FNAME
      INTEGER               ND
      INTEGER               NI
      CHARACTER*(*)         IFNAME
      INTEGER               RESV
      INTEGER               HANDLE
      INTEGER               UNIT

C
C     The record length should be big enough to hold 128 double
C     precision numbers.
C
C     For VAX environments, record length is measured in longwords,
C     since our records our unformatted, with two longwords per double
C     precision number. (Source: Programming in VAX Fortran.)
C
C     INTEGER               RECL
C     PARAMETER           ( RECL   = 256 )

C
C     For Sun environments, record length is measured in characters
C     (bytes) with eight characters per double precision number.
C     (Source: Sun Fortran Programmer's Guide.)
C
       INTEGER               RECL
       PARAMETER           ( RECL  = 1024 )
C
C     For IBM PCs, or any other machine running Microsoft FORTRAN,
C     record length is also measured in bytes. (Source: Microsoft
C     Fortran Optimizing Compiler User's Guide.)
C
C      INTEGER               RECL
C      PARAMETER           ( RECL  = 1024 )
C

      INTEGER               FTSIZE
      PARAMETER           ( FTSIZE =   4 )

C$ Brief_I/O
C
C     Variable  I/O  Entry points
C     --------  ---  --------------------------------------------------
C     FNAME     I,O  OPR, OPW, OPN, HFN, FNH
C     ND        I,O  OPN, HSF
C     NI        I,O  OPN, HSF
C     IFNAME     I   OPN
C     RESV       I   OPN
C     HANDLE    I,O  OPR, OPW, OPN, CLS, HLU, LUH, HFN, FNH
C     UNIT      I,O  HLU, LUH
C     RECL       P   OPR, OPW, OPN
C     FTSIZE     P   OPR, OPW, OPN, CLS, HLU, LUH, HFN, FNH
C
C$ Detailed_Input
C
C     FNAME       on input is the name of a DAF to be opened, or
C                 the name of a DAF about which some information
C                 (handle, logical unit) is requested.
C
C     ND          on input is the number of double precision components
C                 in array summary of a new file.
C
C     NI          on input is the number of integer components in each
C                 array summary in a new file.
C
C     IFNAME      is the internal file name for a DAF to be created.
C
C     RESV        is the number of records to be reserved in a DAF
C                 to be created.
C
C     HANDLE      on input is the handle of a DAF about which some
C                 information (file name, logical unit) is requested,
C                 or the handle of a DAF to be closed.
C
C     UNIT        on input is the logical unit connected to a DAF
C                 about which some information (file name, handle) is
C                 requested.
C
C$ Detailed_Output
C
C     FNAME       on output is the name of a DAF for which
C                 the corresponding handle or logical unit has been
C                 supplied.
C
C     ND          on output is the number of double precision
C                 components in each array summary of an existing file.
C
C     NI          on output is the number of integer components in
C                 each array summary in an existing file.
C
C     HANDLE      on output is the handle of a DAF for which
C                 the corresponding file name or logical unit has been
C                 supplied.
C
C     UNIT        on output is the logical unit connected to a DAF
C                 for which the corresponding file name or handle has
C                 been supplied.
C
C$ Parameters
C
C     RECL        is the record length of a DAF. Each record
C                 must be large enough to hold 128 double
C                 precision numbers or 1000 characters, whichever
C                 is greater. The units in which the record length
C                 must be specified vary from environment to
C                 environment. For example, VAX Fortran requires
C                 record lengths to be specified in longwords,
C                 where two longwords equal one double precision
C                 number.
C
C     FTSIZE      is the size of the file table maintained internally
C                 by DAFAH. In effect, FTSIZE is tha maximum number
C                 of DAFs that can be open simultaneously.
C
C$ Files
C
C     All DAFs opened by this routine are specified by name.
C
C$ Exceptions
C
C     1) If DAFAH is called directly, the error SPICE(BOGUSENTRY)
C        is signalled.
C
C     2) See entry points DAFOPR, DAFOPW, DAFOPN, DAFCLS, DAFHSF,
C        DAFHLU, DAFLUH, DAFHFN, and DAFNFH for exceptions specific
C        to those entry points.
C
C$ Particulars
C
C     DAFAH serves as an umbrella, allowing data to be shared by its
C     entry points:
C
C        DAFOPR         Open for read.
C        DAFOPW         Open for write.
C        DAFOPN         Open new.
C
C        DAFCLS         Close.
C
C        DAFHSF         Handle to summary format.
C
C        DAFHLU         Handle to logical unit.
C        DAFLUH         Logical to handle.
C
C        DAFHFN         Handle to name.
C        DAFFNH         File name to handle.
C
C     Before a DAF can be used, it must be opened. Entry points
C     DAFOPR and DAFOPW provide the only means for opening an
C     existing DAF.
C
C     Several files may be opened for use simultaneously. (This makes
C     it possible to use data from several files to construct a single
C     result.) As each DAF is opened, it is assigned a file handle,
C     which is used to keep track of the file internally, and which
C     is used by the calling program to refer to the file in all
C     subsequent calls to DAF routines.
C
C     DAFs may be opened for two kinds of access: read, and write.
C     Files opened for read access may not be changed in any way. Files
C     opened for write access may be both read and written. Only one
C     DAF may be open for write access at any one time.
C
C     Entry point DAFOPN provides the only means for creating a new
C     DAF. Since the only reason for creating a new file is to
C     write something in it, all new files are opened for write access.
C     Since only one file can be open for write access at any one time,
C     you cannot create a new file when another file is open for write
C     access.
C
C     Entry point DAFCLS provides the only official means of closing
C     a DAF that is currently open. Closing a DAF any other
C     way (for example, by determining its logical unit and using the
C     Fortran CLOSE statement directly) may affect your calling program
C     in mysterious ways.
C
C     Entry point DAFHSF allows you to determine the summary format
C     of any DAF that is currently open, without re-reading the
C     file record.
C
C     The remaining entry points exist mainly to translate between
C     alternative representation of DAFs. There are three ways to
C     identify any open DAF: by name, by handle, and by logical
C     unit. Given any one of these, you may use these entry points to
C     find the other two.
C
C$ Examples
C
C     See entry points DAFOPR, DAFOPW, DAFOPN, DAFCLS, DAFHSF,
C     DAFHLU, DAFLUH, DAFHFN, and DAFNFH for examples specific
C     to those entry points.
C
C$ Restrictions
C
C     1) The value of parameter RECL may need to be changed when DAFAH
C        and its entry points are ported to a new environment (CPU and
C        compiler).
C
C     2) An integer overflow may occur if the number of files opened
C        by a single program exceeds the maximum number that can be
C        stored in an integer variable.
C
C$ Literature_References
C
C     NAIF Document 167.0, "Double Precision Array Files (DAF)
C     Specification and User's Guide"
C
C$ Author_and_Institution
C
C     I.M. Underwood  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 22-MAR-1990 (HAN)
C
C        Literature references added to the header.
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (IMU)
C
C-&


C
C     SPICELIB functions
C
      INTEGER               ISRCHI
      LOGICAL               RETURN

C
C     Local variables
C

C
C     As each file is opened, it is assigned a handle, and the
C     internal file name is stored for comparison with other files.
C     All names in the file table begin with FT.
C
C        HAN      Handle
C        LUN      Logical unit
C        LNK      Number of links
C        ND,
C        NI       Summary format
C
C     The columns are stored in no particular order. New files are
C     added to the end of the list; the list is repacked whenever a
C     file is removed from the list.
C
C     NFT is the number of files currently opened: this may not be
C     greater than FTSIZE. FINDEX refers to a file of interest within
C     the table.
C
C     NEXT is incremented each time a file is opened to become the
C     next file handle assigned.
C
      INTEGER               NFT
      INTEGER               FTHAN    ( FTSIZE )
      INTEGER               FTLUN    ( FTSIZE )
      INTEGER               FTLNK    ( FTSIZE )
      INTEGER               FTND     ( FTSIZE )
      INTEGER               FTNI     ( FTSIZE )
      INTEGER               FINDEX
      INTEGER               NEXT

      LOGICAL               OPENED
      INTEGER               NUMBER

      CHARACTER*8           DAFWRD
      INTEGER               FND
      INTEGER               FNI
      CHARACTER*60          IFN
      INTEGER               FWARD
      INTEGER               BWARD
      INTEGER               FREE
      DOUBLE PRECISION      DREC     ( 128 )
      CHARACTER*1000        CREC

      INTEGER               MINHAN
      INTEGER               LOC
      INTEGER               IOSTAT
      INTEGER               I

C
C     Saved variables
C
      SAVE                  NFT
      SAVE                  FTHAN
      SAVE                  FTLUN
      SAVE                  FTLNK
      SAVE                  FTND
      SAVE                  FTNI

C
C     Initial values
C
      DATA                  NFT      / 0 /
      DATA                  NEXT     / 0 /


C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN  ( 'DAFAH' )
         CALL SIGERR ( 'SPICE(BOGUSENTRY)' )
         CALL CHKOUT ( 'DAFAH' )
      END IF

      RETURN




C$Procedure DAFOPR ( DAF, open for read )

      ENTRY DAFOPR ( FNAME, HANDLE )

C$ Abstract
C
C     Open a DAF for subsequent read requests.
C
C$ Required_Reading
C
C     DAF
C
C$ Keywords
C
C     FILES
C
C$ Declarations
C
C     CHARACTER*(*)         FNAME
C     INTEGER               HANDLE
C
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     FNAME      I   Name of DAF to be opened.
C     HANDLE     O   Handle assigned to DAF.
C
C$ Detailed_Input
C
C     FNAME       is the name of a DAF to be opened for read
C                 access.
C
C$ Detailed_Output
C
C     HANDLE      is the file handle associated with the file. This
C                 handle is used to identify the file in subsequent
C                 calls to other DAF routines.
C
C$ Parameters
C
C      None.
C
C$ Files
C
C     See argument FNAME.
C
C$ Exceptions
C
C     1) If the specified file has already been opened for read
C        access, the handle already associated with the file is
C        returned.
C
C     2) If the specified file has already been opened for write
C        access, the error SPICE(DAFRWCONFLICT) is signalled.
C
C     3) If the specified file has already been opened by a non-DAF
C        routine, the error SPICE(DAFIMPROPOPEN) is signalled.
C
C     4) If the specified file cannot be opened without exceeding
C        the maximum number of files, the error SPICE(DAFFTFULL)
C        is signalled.
C
C     5) If (for some reason) the file cannot be opened properly,
C        the error SPICE(DAFOPENFAIL) is signalled.
C
C     6) If the specified file is not a DAF (does not contain
C        the proper standard keyword), the error SPICE(DAFNOIDWORD)
C        is signalled.
C
C$ Particulars
C
C     Most DAFs require only read access. If you do not need to
C     change the contents of a file, you should open it with DAFOPR.
C
C$ Examples
C
C     In the following code fragment, DAFOPR is used to open a file,
C     which is then searched for DAFs containing data for a particular
C     object.
C
C        CALL DAFOPR ( FNAME, HANDLE )
C        CALL DAFBFS ( HANDLE )
C        CALL DAFFNA ( FOUND  )
C
C        DO WHILE ( FOUND )
C           CALL DAFGS ( SUM )
C           CALL DAFUS ( SUM, ND, NI, DC, IC )
C
C           IF ( IC(1) .EQ. TARGET_OBJECT ) THEN
C            .
C            .
C
C           END IF
C
C           CALL DAFFNA ( FOUND )
C        END DO
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     NAIF Document 167.0, "Double Precision Array Files (DAF)
C     Specification and User's Guide"
C
C$ Author_and_Institution
C
C     I.M. Underwood  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 22-MAR-1990 (HAN)
C
C        Literature references added to the header.
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (IMU)
C
C-&


C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'DAFOPR' )
      END IF

C
C     The file may or may not be open already. If so, it should have
C     not been opened for writing (handle < 0). If opened for reading,
C     just increment the number of links and return the handle.
C     If opened elsewhere, panic.
C
      INQUIRE ( FILE   = FNAME,
     .          OPENED = OPENED,
     .          NUMBER = NUMBER  )

      IF ( OPENED ) THEN

         FINDEX = ISRCHI ( NUMBER, NFT, FTLUN )

         IF ( FINDEX .GT. 0 ) THEN

            IF ( FTHAN(FINDEX) .LT. 0 ) THEN
               CALL SETMSG ( 'File already opened for write access.' )
               CALL SIGERR ( 'SPICE(DAFRWCONFLICT)' )
            ELSE
               FTLNK(FINDEX) = FTLNK(FINDEX) + 1
               HANDLE        = FTHAN(FINDEX)
            END IF

         ELSE
            CALL SETMSG ( 'File already connected to unit #.' )
            CALL ERRINT ( '#', NUMBER )
            CALL SIGERR ( 'SPICE(DAFIMPROPOPEN)' )
         END IF

C
C     If it hasn't been opened, it needs to be, but only if there
C     is room for another file.
C
      ELSE IF ( NFT .EQ. FTSIZE ) THEN

         CALL SETMSG ( 'The file table is full, with # entries.' )
         CALL ERRINT ( '#', FTSIZE )
         CALL SIGERR ( 'SPICE(DAFFTFULL)' )

C
C     To open for reading: get a free unit, open the file, get the
C     internal file name, and set the number of links to one.
C
C     Look out for:
C
C        -- No free logical units.
C
C        -- Error opening the file.
C
C        -- No NAIF/DAF ID word in the first record.
C
      ELSE

         CALL GETLUN ( NUMBER )

         OPEN ( UNIT   = NUMBER,
     .          FILE   = FNAME,
     .          ACCESS = 'DIRECT',
     .          RECL   = RECL,
     .          STATUS = 'OLD',
     .          IOSTAT = IOSTAT    )

         IF ( IOSTAT .NE. 0 ) THEN
            CALL SETMSG ( 'Attempt to open file # failed. Value of ' //
     .                    'IOSTAT was #.' )
            CALL ERRCH  ( '#', FNAME  )
            CALL ERRINT ( '#', IOSTAT )
            CALL SIGERR ( 'SPICE(DAFOPENFAIL)' )

         ELSE
            READ (NUMBER,
     .            REC=1,
     .            IOSTAT=IOSTAT) DAFWRD, FND, FNI

            IF (        DAFWRD .NE. 'NAIF/DAF'
     .           .AND.  DAFWRD .NE. 'NAIF/NIP' ) THEN

               CALL SIGERR ( 'SPICE(DAFNOIDWORD)' )

            ELSE
               NEXT       = NEXT + 1
               NFT        = NFT + 1
               FTHAN(NFT) = NEXT
               FTLUN(NFT) = NUMBER
               FTND(NFT)  = FND
               FTNI(NFT)  = FNI
               FTLNK(NFT) =  1
               HANDLE     = FTHAN(NFT)
            END IF
         END IF

      END IF

      CALL CHKOUT ( 'DAFOPR' )
      RETURN



C$Procedure DAFOPW ( DAF, open for write )

      ENTRY DAFOPW ( FNAME, HANDLE )

C$ Abstract
C
C     Open a DAF for subsequent write requests.
C
C$ Required_Reading
C
C     DAF
C
C$ Keywords
C
C     FILES
C
C$ Declarations
C
C     CHARACTER*(*)         FNAME
C     INTEGER               HANDLE
C
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     FNAME      I   Name of DAF to be opened.
C     HANDLE     O   Handle assigned to DAF.
C
C$ Detailed_Input
C
C     FNAME       is the name of a DAF to be opened for write
C                 access.
C
C$ Detailed_Output
C
C     HANDLE      is the file handle associated with the file. This
C                 handle is used to identify the file in subsequent
C                 calls to other DAF routines.
C
C$ Parameters
C
C      None.
C
C$ Files
C
C     See argument FNAME.
C
C$ Exceptions
C
C     1) If another file has already been opened for write access,
C        the error SPICE(DAFWCONFLICT) is signalled.
C
C     2) If the specified file has already been opened for read
C        access, the error SPICE(DAFRWCONFLICT) is signalled.
C
C     3) If the specified file cannot be opened without exceeding
C        the maximum number of files, the error SPICE(DAFFTFULL)
C        is signalled.
C
C     4) If (for some reason) the file cannot be opened properly,
C        the error SPICE(DAFOPENFAIL) is signalled.
C
C     5) If the specified file is not a DAF (does not contain
C        the proper standard keyword), the error SPICE(DAFNOIDWORD)'
C        is signalled.
C
C$ Particulars
C
C     Most DAFs require only read access. If you do not need to
C     change the contents of a file, you should open it with DAFOPR.
C     Use DAFOPW when you need to
C
C        -- change (update) one or more summaries, names, or
C           arrays within a file; or
C
C        -- add new arrays to a file.
C
C$ Examples
C
C     In the following code fragment, DAFOPW is used to open a
C     file, which is then searched for arrays containing data for
C     a particular object. The code for the object is then changed
C     (perhaps to reflect some new convention).
C
C        CALL DAFOPW ( FNAME, HANDLE )
C        CALL DAFBFS ( HANDLE )
C        CALL DAFFNA ( FOUND  )
C
C        DO WHILE ( FOUND )
C           CALL DAFGS ( SUM )
C           CALL DAFUS ( SUM, ND, NI, DC, IC )
C
C           IF ( IC(1) .EQ. OLD_CODE ) THEN
C              IC(1) = NEW_CODE
C
C              CALL DAFPS ( ND, NI, DC, IC, SUM )
C              CALL DAFRS ( SUM )
C           END IF
C
C           CALL DAFFNA ( FOUND )
C        END DO
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     NAIF Document 167.0, "Double Precision Array Files (DAF)
C     Specification and User's Guide"
C
C$ Author_and_Institution
C
C     I.M. Underwood  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 22-MAR-1990 (HAN)
C
C        Literature references added to the header.
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (IMU)
C
C-&


C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'DAFOPW' )
      END IF

C
C     Only one file can be written at a time: if any files are open
C     for writing already, this request cannot be honored.
C
      CALL MINAI ( FTHAN, NFT, MINHAN, LOC )

      IF ( MINHAN .LT. 0 ) THEN
         CALL SETMSG ( 'There are other files currently open for '    //
     .                 'writing.' )
         CALL SIGERR ( 'SPICE(DAFWCONFLICT)' )

         CALL CHKOUT ( 'DAFOPW' )
         RETURN
      END IF

C
C     A file may be opened for writing only once: otherwise, conflicts
C     are likely to occur when attempting to write from two different
C     places in one program. Nor can a file be opened for writing after
C     it has been opened for reading: otherwise, the same file would
C     be associated with two handles.
C
      INQUIRE ( FILE   = FNAME,
     .          OPENED = OPENED,
     .          NUMBER = NUMBER  )

      IF ( OPENED ) THEN

         CALL SETMSG ( 'File # already open.' )
         CALL ERRCH  ( '#', FNAME             )
         CALL SIGERR ( 'SPICE(DAFRWCONFLICT)' )

C
C     If it hasn't been opened, it needs to be, but only if there
C     is room for another file.
C
      ELSE IF ( NFT .EQ. FTSIZE ) THEN

         CALL SETMSG ( 'The file table is already full, with # '      //
     .                 'files open for read or write.' )
         CALL ERRINT ( '#', FTSIZE )
         CALL SIGERR ( 'SPICE(DAFFTFULL)' )

C
C     To open for writing: get a free unit, open the file, get the
C     internal file name, and set the number of links to one.
C
C     Look out for:
C
C        -- No free logical units.
C
C        -- Error opening the file.
C
      ELSE

         CALL GETLUN ( NUMBER )

         OPEN ( UNIT   = NUMBER,
     .          FILE   = FNAME,
     .          ACCESS = 'DIRECT',
     .          RECL   = RECL,
     .          STATUS = 'OLD',
     .          IOSTAT = IOSTAT    )

         IF ( IOSTAT .NE. 0 ) THEN
            CALL SETMSG ( 'Attempt to open file # failed. Value of ' //
     .                    'IOSTAT was #.' )
            CALL ERRCH  ( '#', FNAME  )
            CALL ERRINT ( '#', IOSTAT )
            CALL SIGERR ( 'SPICE(DAFOPENFAIL)' )

         ELSE
            READ (NUMBER,
     .            REC=1,
     .            IOSTAT=IOSTAT) DAFWRD, FND, FNI

            IF ( DAFWRD .NE. 'NAIF/DAF' ) THEN
               CALL SIGERR ( 'SPICE(DAFNOIDWORD)' )

            ELSE
               NEXT       =  NEXT + 1
               NFT        =  NFT + 1
               FTHAN(NFT) = -NEXT
               FTLUN(NFT) =  NUMBER
               FTND(NFT)  =  FND
               FTNI(NFT)  =  FNI
               FTLNK(NFT) =  1
               HANDLE     =  FTHAN(NFT)
            END IF
         END IF

      END IF

      CALL CHKOUT ( 'DAFOPW' )
      RETURN




C$Procedure DAFOPN ( DAF, open new )

      ENTRY DAFOPN ( FNAME, ND, NI, IFNAME, RESV, HANDLE )

C$ Abstract
C
C     Open a new DAF for subsequent write requests.
C
C$ Required_Reading
C
C     DAF
C
C$ Keywords
C
C     FILES
C
C$ Declarations
C
C     CHARACTER*(*)         FNAME
C     INTEGER               ND
C     INTEGER               NI
C     CHARACTER*(*)         IFNAME
C     INTEGER               RESV
C     INTEGER               HANDLE
C
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     FNAME      I   Name of DAF to be opened.
C     ND         I   Number of double precision components in sumaries.
C     NI         I   Number of integer components in summaries.
C     IFNAME     I   Internal file name.
C     RESV       I   Number of records to reserve.
C     HANDLE     O   Handle assigned to DAF.
C
C$ Detailed_Input
C
C     FNAME       is the name of a new DAF to be created (and
C                 consequently opened for write access).
C
C     ND          is the number of double precision components
C                 in each array summary of the new file.
C
C     NI          is the number of integer components in each
C                 array summary in the new file.
C
C     IFNAME      is the internal file name (containing as many as 60
C                 characters) for the new file. This should uniquely
C                 identify the file.
C
C     RESV        is the number of records in the new file to be
C                 reserved for non-DAF use. The user may reserve
C                 records 2 through (2 + RESV - 1) in the file.
C                 These records are not used to store DAF data,
C                 and are in fact invisible to all DAF routines.
C
C$ Detailed_Output
C
C     HANDLE      is the file handle associated with the file. This
C                 handle is used to identify the file in subsequent
C                 calls to other DAF routines.
C
C$ Parameters
C
C      None.
C
C$ Files
C
C     See argument FNAME.
C
C$ Exceptions
C
C     1) If another file has already been opened for write access,
C        the error SPICE(DAFWCONFLICT) is signalled.
C
C     2) If the specified file cannot be opened without exceeding
C        the maximum number of files, the error SPICE(DAFFTFULL)
C        is signalled.
C
C     3) If the number of records to be reserved is not zero or
C        postitive, the error SPICE(DAFNORESV) is signalled.
C
C     4) If (for some reason) the file cannot be opened properly,
C        the error SPICE(DAFOPENFAIL) is signalled.
C
C     5) If (for some reason) the initial records in the file cannot
C        be written, the error SPICE(DAFWRITEFAIL) is signalled.
C
C$ Particulars
C
C     The DAFs created by DAFOPN are just like other DAFs,
C     except they contain no arrays.
C
C$ Examples
C
C     In the following code fragment, DAFOPN is used to open a file,
C     to which a new array is then added.
C
C        CALL DAFOPN ( FNAME, ND, NI, IFNAME, 0, HANDLE )
C
C        CALL DAFBNA ( HANDLE, SUM, NAME )
C        CALL GET_DATA ( N, DATA, FOUND )
C
C        DO WHILE ( FOUND )
C           CALL DAFADA ( N, DATA )
C           CALL GET_DATA ( N, DATA, FOUND )
C        END DO
C
C        CALL DAFENA
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     NAIF Document 167.0, "Double Precision Array Files (DAF)
C     Specification and User's Guide"
C
C$ Author_and_Institution
C
C     I.M. Underwood  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 22-MAR-1990 (HAN)
C
C        Literature references added to the header.
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (IMU)
C
C-&


C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'DAFOPN' )
      END IF

C
C     Only one file can be written at a time: if any files are open
C     for writing already, this request cannot be honored.
C
      CALL MINAI ( FTHAN, NFT, MINHAN, LOC )

      IF ( MINHAN .LT. 0 ) THEN

         CALL SETMSG ( 'There are other files open for writing.' )
         CALL SIGERR ( 'SPICE(DAFWCONFLICT)' )

C
C     The file can be opened only if there is room for another file.
C
      ELSE IF ( NFT .EQ. FTSIZE ) THEN

         CALL SETMSG ( 'The file table is already full, with # '      //
     .                 'files open for read or write.' )
         CALL ERRINT ( '#', FTSIZE )
         CALL SIGERR ( 'SPICE(DAFFTFULL)' )

C
C     The user must reserve some non-negative number of records.
C
      ELSE IF ( RESV .LT. 0 ) THEN

         CALL SETMSG ( 'An attempt was made to reserve a negative '   //
     .                 'number (#) of records.' )
         CALL ERRINT ( '#', RESV )
         CALL SIGERR ( 'SPICE(DAFNORESV)' )

C
C     To open a new file: get a free unit, open the file, write
C     the file record, write an empty pair of summary/name records,
C     and set the number of links to one.
C
C     Look out for:
C
C        -- No free logical units.
C
C        -- Error opening the file.
C
C        -- Error writing to the file.
C
C     If anything goes wrong after the file has been opened, delete
C     the file.
C

      ELSE

         CALL GETLUN ( NUMBER )

         OPEN ( UNIT   = NUMBER,
     .          FILE   = FNAME,
     .          ACCESS = 'DIRECT',
     .          RECL   = RECL,
     .          STATUS = 'NEW',
     .          IOSTAT = IOSTAT    )

         IF ( IOSTAT .NE. 0 ) THEN
            CALL SETMSG ( 'Value of IOSTAT was: #' )
            CALL SETMSG ( 'Attempt to open file # failed. Value ' //
     .                    'of IOSTAT was #.' )
            CALL ERRCH  ( '#', FNAME  )
            CALL ERRINT ( '#', IOSTAT )
            CALL SIGERR ( 'SPICE(DAFOPENFAIL)' )

         ELSE
            IFN    = IFNAME
            FND    = ND
            FNI    = NI
            FWARD  = RESV + 2
            BWARD  = FWARD
            CREC   = ' '
            CALL CLEARD ( 128, DREC )
            CALL DAFRWA ( FWARD+2, 1, FREE )

            WRITE (NUMBER,REC=1,IOSTAT=IOSTAT) 'NAIF/DAF',
     .                                          FND,
     .                                          FNI,
     .                                          IFN,
     .                                          FWARD,
     .                                          BWARD,
     .                                          FREE

            IF ( IOSTAT .EQ. 0 ) THEN
               WRITE (NUMBER,REC=FWARD,IOSTAT=IOSTAT) DREC

               IF ( IOSTAT .EQ. 0 ) THEN
                  WRITE (NUMBER,REC=FWARD+1,IOSTAT=IOSTAT) CREC
               END IF
            END IF

            IF ( IOSTAT .NE. 0 ) THEN
               CALL SETMSG ( 'Attempt to open file # failed. ' //
     .                       'Value of IOSTAT was #.' )
               CALL ERRCH  ( '#', FNAME  )
               CALL ERRINT ( '#', IOSTAT )
               CALL SIGERR ( 'SPICE(DAFWRITEFAIL)' )

               CLOSE ( UNIT   = NUMBER,
     .                 STATUS = 'DELETE' )

            ELSE
               NEXT       =  NEXT + 1
               NFT        =  NFT + 1
               FTHAN(NFT) = -NEXT
               FTLUN(NFT) =  NUMBER
               FTND(NFT)  =  FND
               FTNI(NFT)  =  FNI
               FTLNK(NFT) =  1
               HANDLE     =  FTHAN(NFT)
            END IF
         END IF

      END IF

      CALL CHKOUT ( 'DAFOPN' )
      RETURN



C$Procedure DAFCLS ( DAF, close )

      ENTRY DAFCLS ( HANDLE )

C$ Abstract
C
C     Close the DAF associated with a given handle.
C
C$ Required_Reading
C
C     DAF
C
C$ Keywords
C
C     FILES
C
C$ Declarations
C
C     INTEGER               HANDLE
C
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     HANDLE     I   Handle of DAF to be closed.
C
C$ Detailed_Input
C
C     HANDLE      is the handle assigned to a DAF by a previous
C                 call to DAFOPR, DAFOPW, or DAFOPN.
C
C$ Detailed_Output
C
C     None.
C
C$ Parameters
C
C      None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C     1) If the specified handle does not belong to a DAF
C        that is currently open, nothing happens.
C
C$ Particulars
C
C     Because DAFAH and its entry points must keep track of what
C     files are open at any given time, it is important that DAF
C     files be closed only with DAFCLS, to prevent the remaining
C     DAF routines from failing, sometimes mysteriously.
C
C     Note that when a file is opened more than once for read access,
C     DAFOPR returns the same handle each time it is re-opened. Each
C     time the file is closed, DAFCLS checks to see if any other
C     claims on the file are still active before physically closing
C     the file.
C
C$ Examples
C
C     In the following code fragment, the arrays in a file are
C     examined in order to determine whether the file contains
C     any arrays whose names begin with the word TEST.
C     The complete names for these arrays are printed to
C     the screen. The file is closed at the end of the search.
C
C        CALL DAFOPR ( FNAME, HANDLE )
C        CALL DAFBFS ( HANDLE )
C        CALL DAFFNA ( FOUND  )
C
C        DO WHILE ( FOUND )
C           CALL DAFGN ( NAME )
C
C           IF ( NAME(1:5) .EQ. 'TEST ' ) THEN
C              WRITE (*,*) NAME
C           END IF
C
C           CALL DAFFNA ( FOUND )
C        END DO
C
C        CALL DAFCLS ( HANDLE )
C
C     Note that if the file has been opened already at some other
C     place in the calling program, it remains open. This makes it
C     possible to examine files that have been opened for use by
C     other modules without interfering with the operation of those
C     routines.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     NAIF Document 167.0, "Double Precision Array Files (DAF)
C     Specification and User's Guide"
C
C$ Author_and_Institution
C
C     I.M. Underwood  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 22-MAR-1990 (HAN)
C
C        Literature references added to the header.
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (IMU)
C
C-&


C
C     Is this file even open? If so, decrement the number of links
C     to the file. If the number of links drops to zero, physically
C     close the file and remove it from the file buffer.
C
C     If the file is not open: no harm, no foul.
C
      FINDEX = ISRCHI ( HANDLE, NFT, FTHAN )

      IF ( FINDEX .GT. 0 ) THEN
         FTLNK(FINDEX) = FTLNK(FINDEX) - 1

         IF ( FTLNK(FINDEX) .EQ. 0 ) THEN
            CLOSE ( FTLUN(FINDEX) )

            DO 50001
     .         I = FINDEX, NFT - 1
               FTHAN(I) = FTHAN(I+1)
               FTLUN(I) = FTLUN(I+1)
               FTLNK(I) = FTLNK(I+1)
               FTND(I)  = FTND(I+1)
               FTNI(I)  = FTNI(I+1)
50001       CONTINUE

            NFT = NFT - 1
         END IF
      END IF

      RETURN



C$Procedure DAFHSF ( DAF, handle to summary format )

      ENTRY DAFHSF ( HANDLE, ND, NI )

C$ Abstract
C
C     Return the summary format associated with a handle.
C
C$ Required_Reading
C
C     DAF
C
C$ Keywords
C
C     CONVERSION
C     FILES
C
C$ Declarations
C
C     INTEGER               HANDLE
C     INTEGER               ND
C     INTEGER               NI
C
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     HANDLE     I   Handle of a DAF.
C     ND         O   Number of double precision components in summaries.
C     NI         O   Number of integer components in summaries.
C
C$ Detailed_Input
C
C     HANDLE      is the handle associated with a DAF previously
C                 opened by a call to DAFOPR, DAFOPW, or DAFOPN.
C
C$ Detailed_Output
C
C     ND,
C     NI          are the numbers of double precision and integer
C                 components, respectively, in each array summary
C                 in the specified file.
C
C$ Parameters
C
C      None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     1) If the specified handle does not belong to any file that is
C        currently known to be open, the error SPICE(DAFNOSUCHHANDLE)
C        is signalled.
C
C$ Particulars
C
C     The summary format must be known in order to pack or unpack
C     an array summary.
C
C$ Examples
C
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     NAIF Document 167.0, "Double Precision Array Files (DAF)
C     Specification and User's Guide"
C
C$ Author_and_Institution
C
C     I.M. Underwood  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 22-MAR-1990 (HAN)
C
C        Literature references added to the header.
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (IMU)
C
C-&


C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'DAFHSF' )
      END IF

      FINDEX = ISRCHI ( HANDLE, NFT, FTHAN )

      IF ( FINDEX .GT. 0 ) THEN
         ND = FTND(FINDEX)
         NI = FTNI(FINDEX)

      ELSE
         CALL SETMSG ( 'There is no file open with handle = #' )
         CALL ERRINT ( '#', HANDLE )
         CALL SIGERR ( 'SPICE(DAFNOSUCHHANDLE)' )
      END IF

      CALL CHKOUT ( 'DAFHSF' )
      RETURN




C$Procedure DAFHLU ( DAF, handle to logical unit )

      ENTRY DAFHLU ( HANDLE, UNIT )

C$ Abstract
C
C     Return the logical unit associated with a handle.
C
C$ Required_Reading
C
C     DAF
C
C$ Keywords
C
C     CONVERSION
C     FILES
C
C$ Declarations
C
C     INTEGER               HANDLE
C     INTEGER               UNIT
C
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     HANDLE     I   Handle of a DAF.
C     UNIT       O   Corresponding logical unit.
C
C$ Detailed_Input
C
C     HANDLE      is the handle associated with a DAF previously
C                 opened by a call to DAFOPR, DAFOPW, or DAFOPN.
C
C$ Detailed_Output
C
C     UNIT        is the Fortran logical unit to which the file is
C                 connected.
C
C$ Parameters
C
C      None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     1) If the specified handle does not belong to any file that is
C        currently known to be open, the error SPICE(DAFNOSUCHHANDLE)
C        is signalled.
C
C$ Particulars
C
C     The best reason for knowing the logical unit to which a DAF
C     is connected is to read or write from the records reserved in a
C     file. Since these records are by definition invisible to the DAF
C     routines, you must read and write them directly.
C
C$ Examples
C
C     In the following code fragment, the first reserved record in
C     a newly created DAF is used to store the name and address
C     of the person who created it.
C
C        CALL DAFOPN ( FNAME, 3, 6, IFNAME, 5, HANDLE )
C        CALL DAFHLU ( HANDLE, UNIT )
C
C        WRITE (UNIT,REC=2) 'Ellis Wyatt, JPL ',
C       .                   '4800 Oak Grove Drive ',
C       .                   'Room 301-125A ',
C       .                   'Pasadena, CA 91109'
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     NAIF Document 167.0, "Double Precision Array Files (DAF)
C     Specification and User's Guide"
C
C$ Author_and_Institution
C
C     R.E. Thurman    (JPL)
C     I.M. Underwood  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 22-MAR-1990 (HAN)
C
C        Literature references added to the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (IMU)
C
C-&

C$ Revisions
C
C-     Beta Version 1.1.0, 1-NOV-1989 (RET)
C
C        DAFHLU now only checks in and checks out if the one exception
C        occurs. The purpose of this change was to help speed up a
C        routine that gets called constantly by higher level DAF
C        routines.
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      END IF

      FINDEX = ISRCHI ( HANDLE, NFT, FTHAN )

      IF ( FINDEX .GT. 0 ) THEN
         UNIT = FTLUN(FINDEX)

      ELSE
         CALL CHKIN  ( 'DAFHLU' )
         CALL SETMSG ( 'There is no file open with handle = #' )
         CALL ERRINT ( '#', HANDLE )
         CALL SIGERR ( 'SPICE(DAFNOSUCHHANDLE)' )
         CALL CHKOUT ( 'DAFHLU' )
      END IF

      RETURN





C$Procedure DAFLUH ( DAF, logical unit to handle )

      ENTRY DAFLUH ( UNIT, HANDLE )

C$ Abstract
C
C     Return the handle associated with a logical unit.
C
C$ Required_Reading
C
C     DAF
C
C$ Keywords
C
C     CONVERSION
C     FILES
C
C$ Declarations
C
C     INTEGER               UNIT
C     INTEGER               HANDLE
C
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     UNIT       I   Logical unit connected to a DAF.
C     HANDLE     O   Corresponding handle.
C
C$ Detailed_Input
C
C     UNIT        is the logical unit to which a DAF has been
C                 connected by a previous call to DAFOPR, DAFOPW, or
C                 DAFOPN.
C
C$ Detailed_Output
C
C     HANDLE      is the handle associated with the file.
C
C$ Parameters
C
C      None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     1) If the specified unit is not connected to any file that is
C        currently known to be open, the error SPICE(DAFNOSUCHUNIT)
C        is signalled.
C
C$ Particulars
C
C     It is unlikely, but possible, that a calling program would know
C     the logical unit to which a file is connected without knowing the
C     handle associated with the file. DAFLUH is provided mostly for
C     completeness.
C
C$ Examples
C
C     In the following code fragment, the handle associated with
C     a DAF is retrieved using the logical unit to which the
C     file is connected. The handle is then used to determine the
C     name of the file.
C
C        CALL DAFLUH ( UNIT,   HANDLE )
C        CALL DAFHFN ( HANDLE, FNAME )
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     NAIF Document 167.0, "Double Precision Array Files (DAF)
C     Specification and User's Guide"
C
C$ Author_and_Institution
C
C     I.M. Underwood  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 22-MAR-1990 (HAN)
C
C        Literature references added to the header.
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (IMU)
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'DAFLUH' )
      END IF

      FINDEX = ISRCHI ( UNIT, NFT, FTLUN )

      IF ( FINDEX .GT. 0 ) THEN
         HANDLE = FTHAN(FINDEX)

      ELSE
         CALL SETMSG ( 'There is no file open with unit = #' )
         CALL ERRINT ( '#', UNIT )
         CALL SIGERR ( 'SPICE(DAFNOSUCHUNIT)' )
      END IF

      CALL CHKOUT ( 'DAFLUH' )
      RETURN



C$Procedure DAFHFN ( DAF, handle to file name )

      ENTRY DAFHFN ( HANDLE, FNAME )

C$ Abstract
C
C     Return the name of the file associated with a handle.
C
C$ Required_Reading
C
C     DAF
C
C$ Keywords
C
C     CONVERSION
C     FILES
C
C$ Declarations
C
C     INTEGER               HANDLE
C     CHARACTER*(*)         FNAME
C
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     HANDLE     I   Handle of a DAF.
C     FNAME      O   Corresponding file name.
C
C$ Detailed_Input
C
C     HANDLE      is the handle associated with a DAF previously
C                 opened by a call to DAFOPR, DAFOPW, or DAFOPN.
C
C$ Detailed_Output
C
C     UNIT        is the name of the file.
C
C$ Parameters
C
C      None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     1) If the specified handle does not belong to any file that is
C        currently known to be open, the error SPICE(DAFNOSUCHHANDLE)
C        is signalled.
C
C$ Particulars
C
C     It may be desirable to recover the names of one or more DAF
C     files in a different part of the program from the one in which
C     they were opened. Note that the names returned by DAFHFN may
C     not be identical to the names used to open the files. Under
C     most operating systems, a particular file can be accessed using
C     many different names. DAFHFN returns one of them.
C
C$ Examples
C
C     In the following code fragment, the name of a DAF is
C     recovered using the handle associated with the file.
C
C        CALL DAFOPR ( 'sample.DAF', HANDLE )
C         .
C         .
C
C        CALL DAFHFN ( HANDLE, FNAME )
C
C     Depending on the circumstances (operating system, compiler,
C     default directory) the value of FNAME might resemble any of
C     the following:
C
C        'USER$DISK:[WYATT.IMAGES]SAMPLE.DAF;4'
C
C        '/wyatt/images/sample.DAF'
C
C        'A:\IMAGES\SAMPLE.DAF'
C
C     On the other hand, it might not.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     NAIF Document 167.0, "Double Precision Array Files (DAF)
C     Specification and User's Guide"
C
C$ Author_and_Institution
C
C     I.M. Underwood  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 22-MAR-1990 (HAN)
C
C        Literature references added to the header.
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (IMU)
C
C-&



C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'DAFHFN' )
      END IF

      FINDEX = ISRCHI ( HANDLE, NFT, FTHAN )

      IF ( FINDEX .GT. 0 ) THEN
         INQUIRE ( UNIT = FTLUN(FINDEX),
     .             NAME = FNAME          )

      ELSE
         CALL SETMSG ( 'There is no file open with handle = #' )
         CALL ERRINT ( '#', HANDLE )
         CALL SIGERR ( 'SPICE(DAFNOSUCHHANDLE)' )
      END IF

      CALL CHKOUT ( 'DAFHFN' )
      RETURN



C$Procedure DAFFNH ( DAF, file name to handle )

      ENTRY DAFFNH ( FNAME, HANDLE )

C$ Abstract
C
C     Return handle associated with a file name.
C
C$ Required_Reading
C
C     DAF
C
C$ Keywords
C
C     CONVERSION
C     FILES
C
C$ Declarations
C
C     CHARACTER*(*)         FNAME
C     INTEGER               HANDLE
C
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     FNAME      I   Name of a DAF.
C     HANDLE     O   Corresponding handle.
C
C$ Detailed_Input
C
C     FNAME       is the name of a DAF previously opened by a
C                 call to DAFOPR, DAFOPW, or DAFOPN.
C
C$ Detailed_Output
C
C     HANDLE      is the handle associated with the file.
C
C$ Parameters
C
C      None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     1) If the specified name does not specify any file currently known
C        to be open, the error SPICE(DAFNOSUCHFILE) is signalled.
C
C$ Particulars
C
C     It is sometimes easier to work with file names (which are
C     meaningful, and often predictable) than with file handles
C     (which are neither), especially in interactive situations.
C     However, nearly every DAF routines requires that you use file
C     handles to refer to files. DAFFNH is provided to bridge the gap
C     between the two representations.
C
C$ Examples
C
C     In the following code fragment, the handle associated with a
C     DAF is recovered using the name of the file.
C
C        CALL DAFOPR ( 'sample.DAF', HANDLE )
C         .
C         .
C
C        CALL DAFFNH ( 'sample.DAF', HANDLE )
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     NAIF Document 167.0, "Double Precision Array Files (DAF)
C     Specification and User's Guide"
C
C$ Author_and_Institution
C
C     I.M. Underwood  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 22-MAR-1990 (HAN)
C
C        Literature references added to the header.
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (IMU)
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'DAFFHN' )
      END IF

      INQUIRE ( FILE   = FNAME,
     .          OPENED = OPENED,
     .          NUMBER = NUMBER  )

      FINDEX = ISRCHI ( NUMBER, NFT, FTLUN )

      IF ( OPENED  .AND.  FINDEX .GT. 0 ) THEN
         HANDLE = FTHAN(FINDEX)

      ELSE
         CALL SETMSG ( 'There is no file in the table with file '  //
     .                 'name = #' )
         CALL ERRCH  ( '#', FNAME )
         CALL SIGERR ( 'SPICE(DAFNOSUCHFILE)' )
      END IF

      CALL CHKOUT ( 'DAFFNH' )
      RETURN

      END

