C$Procedure     INTSTR  ( Integer to character )

      SUBROUTINE INTSTR ( INT, CH )

C$ Abstract
C
C      Convert an integer to a character string.
C
C$ Required_Reading
C
C      None.
C
C$ Keywords
C
C      ALPHANUMERIC,  CHARACTER,  CONVERSION
C
C$ Declarations

      INTEGER          INT
      CHARACTER*(*)    CH

C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      INT        I   Integer to be converted.
C      CH         O   Equivalent character string, left justified.
C
C$ Detailed_Input
C
C      INT       is the integer to be converted.
C
C$ Detailed_Output
C
C      CH        is the resulting character string. See Examples, below.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C      None.
C
C$ Particulars
C
C      The digits in the integer are found by repeated applications
C      of the modulus division operators.
C
C$ Examples
C
C      The following argument values illustrate the use of INT2CH.
C
C          INT      CH
C          -------  ---------------------
C           -1      '-1                 '
C           -1      '-1                 '
C          223      '223                '
C            0      '0                  '
C
C$ Restrictions
C
C      None.
C
C$ Author_and_Institution
C
C      W.L. Taber      (JPL)
C      I.M. Underwood  (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (IMU) (WLT)
C
C-&



C
C     Local variables
C
      INTEGER          TEN
      PARAMETER      ( TEN = 10 )

      CHARACTER*20     TEMP

      CHARACTER*1      DIGIT(0:9)
      SAVE             DIGIT

      CHARACTER*1      LETTER

      INTEGER          COPY
      INTEGER          START

      INTEGER          I
      INTEGER          J

      DATA             DIGIT / '0', '1', '2', '3', '4',
     .                         '5', '6', '7', '8', '9'  /


C
C     Make a copy of the input so that the input will be returned
C     cherry. Also, pad the character buffer with blanks (to avoid
C     problems with justification arising from a bunch of nulls at
C     the end of the buffer.)
C
      COPY         = INT
      TEMP         = ' '

C
C     Determine whether the output string should have a minus sign
C     and where to begin writing the numeric character string.
C
      START = 1

      IF ( COPY .LT. 0 ) THEN

         TEMP(1:1) =  '-'
         COPY      = - COPY
         START     =   2

      END IF

      I    = START

C
C     Determine the first digit of the output string.
C
      J             = MOD ( COPY, TEN )
      TEMP (I:I)    = DIGIT(J)
      COPY          = COPY / TEN

C
C     Now collect all of the remaining digits.
C
50001 IF       ( COPY .GT. 0 )
     .THEN

         I          = I + 1
         J          = MOD ( COPY, TEN )
         TEMP (I:I) = DIGIT(J)
         COPY       = COPY / TEN

         GO TO 50001
      END IF

C
C     The numeric characters are determined but are stored in
C     reverse order.  Now we reverse the order the digits have been
C     stored.
C
50002 IF       ( START .LT. I )
     .THEN
         LETTER            = TEMP(START:START)
         TEMP(START:START) = TEMP(I:I)
         TEMP(I    :I    ) = LETTER

         I                 = I     - 1
         START             = START + 1
         GO TO 50002
      END IF

      CH = TEMP


      RETURN
      END
