C$Procedure             LASTNB ( Last non-blank character )

      INTEGER FUNCTION  LASTNB ( STRING )

C$ Abstract
C
C      Return the index of the last non-blank character in
C      a character string.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      ASCII,  CHARACTER,  SEARCH
C
C$ Declarations

      CHARACTER*(*)    STRING

C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      STRING     I   Input character string.
C      LASTNB     O   Index of the last non-blank character in STRING.
C
C$ Detailed_Input
C
C      STRING      is the input character string.
C
C$ Detailed_Output
C
C      LASTNB      is the index if the first non-blank character
C                  in the input string. If there are no non-blank
C                  characters in the string, LASTNB is zero.
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C      If the string is blank, return zero. Otherwise, step through
C      the string one character at a time until something other than
C      a blank is found. Return the index of that something within
C      the string.
C
C$ Examples
C
C      The following examples illustrate the use of LASTNB.
C
C            LASTNB ( 'ABCDE'              )   = 5
C            LASTNB ( 'AN EXAMPLE'         )   = 10
C            LASTNB ( 'AN EXAMPLE        ' )   = 10
C            LASTNB ( '                  ' )   = 0
C
C$ Restrictions
C
C      None.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      I.M. Underwood  (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (IMU)
C
C-&



C
C     Local variables
C
      INTEGER          I



C
C     Just like it says in the header.
C
      IF ( STRING .EQ. ' ' ) THEN
         LASTNB = 0

      ELSE
         DO 50001
     .      I = LEN (STRING), 1, -1

            IF ( STRING(I:I) .NE. ' ' ) THEN
               LASTNB = I
               RETURN
            END IF

50001    CONTINUE
      END IF

      RETURN
      END
