C$Procedure      LATREC ( Latitudinal to rectangular coordinates )

      SUBROUTINE LATREC ( RADIUS, LONG, LAT,  RECTAN )

C$ Abstract
C
C     Convert from latitudinal coordinates to rectangular coordinates.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      CONVERSION,  COORDINATES
C
C$ Declarations

      DOUBLE PRECISION   RADIUS
      DOUBLE PRECISION   LONG
      DOUBLE PRECISION   LAT
      DOUBLE PRECISION   RECTAN ( 3 )

C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      RADIUS     I   Distance of a point from the origin.
C      LONG       I   Angle of the point from the XZ plane in radians.
C      LAT        I   Angle of the point from the XY plane in radians.
C      RECTAN     O   Rectangular coordinates of the point.
C
C$ Detailed_Input
C
C      RADIUS     Distance of a point from the origin.
C
C      LONG       Angle of the point from the XZ plane in radians.
C
C      LAT        Angle of the point from the XY plane in radians.
C
C$ Detailed_Output
C
C      RECTAN     The rectangular coordinates of the input point.
C
C$ Parameters
C
C      None.
C
C$ Particulars
C
C      This routine returns the rectangular coordinates of a point
C      whose position is input in latitudinal coordinates.
C
C      Latitudinal coordinates are defined by a distance from a central
C      reference point, an angle from a reference meridian, and an angle
C      above the equator of a sphere centered at the central reference
C      point.
C
C$ Examples
C
C     Below are two tables.
C
C     Listed in the first table (under R, LONG and LAT ) are
C     latitudinal coordinate triples that approximately represent
C     points whose rectangular coordinates are taken from the set
C     {-1, 0, 1}.  (Angular quantities are given in degrees.)
C
C     The result of the code fragment
C
C          Use the SPICELIB routine CONVRT to convert the angular
C          quantities to radians
C
C          CALL CONVRT ( LAT,  'DEGREES', 'RADIANS', LAT  )
C          CALL CONVRT ( LONG, 'DEGREES', 'RADIANS', LONG )
C
C          CALL LATREC ( R, LONG, LAT, X )
C
C
C     are listed in the second parallel table under X(1), X(2) and X(3).
C
C
C       R         LONG       LAT           X(1)       X(2)     X(3)
C       --------------------------         --------------------------
C       0.0000    0.0000    0.0000         0.0000     0.0000   0.0000
C       1.0000    0.0000    0.0000         1.0000     0.0000   0.0000
C       1.0000   90.0000    0.0000         0.0000     1.0000   0.0000
C       1.0000    0.0000   90.0000         0.0000     0.0000   1.0000
C       1.0000  180.0000    0.0000        -1.0000     0.0000   0.0000
C       1.0000  -90.0000    0.0000         0.0000    -1.0000   0.0000
C       1.0000    0.0000  -90.0000         0.0000     0.0000  -1.0000
C       1.4142   45.0000    0.0000         1.0000     1.0000   0.0000
C       1.4142    0.0000   45.0000         1.0000     0.0000   1.0000
C       1.4142   90.0000   45.0000         0.0000     1.0000   1.0000
C       1.7320   45.0000   35.2643         1.0000     1.0000   1.0000
C
C$ Restrictions
C
C      None.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      W.L. Taber      (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (WLT)
C
C-&
C$ Revisions
C
C-     Beta Version 1.0.1, 1-Feb-1989 (WLT)
C
C      Example section of header upgraded.
C
C-&

      DOUBLE PRECISION X
      DOUBLE PRECISION Y
      DOUBLE PRECISION Z

C
C     Convert to rectangular coordinates, storing the results in
C     temporary variables.
C
      X = RADIUS * DCOS(LONG) * DCOS(LAT)
      Y = RADIUS * DSIN(LONG) * DCOS(LAT)
      Z = RADIUS * DSIN(LAT)

C
C  Move the results to the output variables.
C
      RECTAN(1) = X
      RECTAN(2) = Y
      RECTAN(3) = Z
C
      RETURN
      END
