C$Procedure      MEQUG  ( Matrix equal to another, general dimension )

      SUBROUTINE MEQUG ( M1, NR, NC, MOUT )

C$ Abstract
C
C      Set one double precision matrix of arbitrary size equal to
C      another.
C
C$ Required_Reading
C
C      None.
C
C$ Keywords
C
C      ASSIGNMENT,  MATRIX
C
C$ Declarations

      INTEGER            NR
      INTEGER            NC
      DOUBLE PRECISION   M1   ( NR,NC )
      DOUBLE PRECISION   MOUT ( NR,NC )

C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C       M1        I     Input matrix.
C       NR        I     Row dimension of M1 (and also MOUT).
C       NC        I     Column dimension of M1 (and also MOUT).
C       MOUT      O     Output matrix equal to M1.
C
C$ Detailed_Input
C
C      M1      is an arbitrary-sized double precision matrix.
C              There are no restrictions on what it may contain.
C
C      NR      is the number of rows in the input matrix.
C
C      NC      is the number of columns in the input matrix.
C
C$ Detailed_Output
C
C      MOUT    This matrix is set to be equal to M1.
C
C$ Parameters
C
C      None.
C
C$ Particulars
C
C      None.
C
C$ Examples
C
C      If  M1 = | 1.0D0   2.0D0 |
C               |               |
C               | 2.0D0   4.0D0 |
C               |               |
C               | 4.0D0   6.0D0 |
C
C      the call
C
C      CALL MEQUG ( M1, 3, 2, MOUT )
C
C      produces the matrix
C
C        MOUT = | 1.0D0   2.0D0 |
C               |               |
C               | 2.0D0   4.0D0 |
C               |               |
C               | 4.0D0   6.0D0 |
C
C$ Restrictions
C
C      None.
C
C$ Exceptions
C
C     Error free.
C
C     1) If NR < 1 or NC < 1, the elements of the matrix MOUT are not
C        assigned any values.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      W.M. Owen       (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (WMO)
C
C-&


      CALL MOVED (M1, NR*NC, MOUT)
C
      RETURN
      END
