C$Procedure      OUTMSG ( Output Error Messages )

      SUBROUTINE OUTMSG ( LIST )

C$ Abstract
C
C     Output those messages specified in a list which
C     have also been selected for output.  DO NOT CALL THIS ROUTINE.
C
C$ Required_Reading
C
C     ERROR
C
C$ Keywords
C
C     ERROR
C
C$ Declarations

      CHARACTER*(*)         LIST

      INTEGER               FILEN
      PARAMETER           ( FILEN  = 128 )

      INTEGER               NAMLEN
      PARAMETER           ( NAMLEN = 128 )

C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      LIST       I   A list of error message types.
C      FILEN      P   Maximum length of file name.
C      NAMLEN     P   Maximum length of module name.
C
C$ Detailed_Input
C
C      LIST    is a list of error message types.  A list is a
C              character string containing one or more words
C              separated by commas.  Possible words are:
C
C              SHORT
C              EXPLAIN
C              LONG
C              TRACEBACK
C              DEFAULT
C
C              Each type of error message specified in LIST will
C              be output when an error is detected, if it has
C              been selected for output.  Note that DEFAULT does
C              NOT refer to the "default message selection,"
C              but rather to a special message that is output
C              when the error action is 'DEFAULT'.  This message
C              is a statement referring the user to the error
C              handling documentation.
C
C              Messages are never duplicated in the output; for
C              instance, supplying a value of LIST such as
C
C              'SHORT, SHORT'
C
C              does NOT result in the output of two short messages.
C
C
C
C              The words in LIST may appear in mixed case;
C              for example, the call
C
C              CALL OUTMSG ( 'ShOrT' )
C
C              will work.
C
C
C$ Detailed_Output
C
C      None.
C
C$ Parameters
C
C      FILEN   is the maximum device name length that can be
C              accommodated by this routine.
C
C      NAMELN  is the maximum module name length that can be
C              accommodated in the traceback message.
C
C$ Exceptions
C
C      This routine detects invalid message types in the argument,
C      LIST.
C
C      The short error message in this case is  'SPICE(INVALIDLISTITEM)'
C
C
C$ Files
C
C      None.
C
C$ Particulars
C
C      DO NOT CALL THIS ROUTINE.
C
C      This routine is part of the SPICELIB error handling
C      mechanism.
C
C      This routine outputs those of the error messages specified
C      in LIST that have been enabled for output.  A border is
C      written out preceding and following the messages.
C      Output is directed to the current error output device.
C
C
C$ Examples
C
C      DO NOT CALL THIS ROUTINE.
C
C      1.  Here's an example in which the short and long messages
C          are to be output:
C
C      C
C      C     Output short and long messages:
C      C
C
C            CALL OUTMSG ( 'SHORT, LONG' )
C
C
C$ Restrictions
C
C      DO NOT CALL THIS ROUTINE.
C
C$ Literature_References
C
C      None.
C
C$ Author_and_Institution
C
C      N.J. Bachman    (JPL)
C
C$ Version
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (NJB)
C
C-&



C$ Revisions
C
C-     Beta Version 1.3.0, 19-JUL-1989 (NJB)
C
C         Calls to REMSUB removed; blanking and left-justifying used
C         instead.  This was done because REMSUB handles substring
C         bounds differently than in previous versions, and no longer
C         handles all possible inputs as required by this routine.
C         LJUST, which is used now, is error free.
C
C         Also, an instance of .LT. was changed to .LE.   The old code
C         caused a line break one character too soon.  A minor bug, but
C         a bug nonetheless.
C
C         Also, two substring bounds were changed to ensure that they
C         remain greater than zero.
C
C-     Beta Version 1.2.0, 16-FEB-1989 (NJB)
C
C         Warnings added to discourage use of this routine in
C         non-error-handling code.  Parameters section updated to
C         describe FILEN and NAMLEN.
C
C         Declaration of unused function FAILED removed.
C
C-     Beta Version 1.1.0, 06-OCT-1988 (NJB)
C
C         Test added to ensure substring upper bound is greater than 0.
C         REMAIN must be greater than 0 when used as the upper bound
C         for a substring of NAME.  Also, substring upper bound in
C         WRLINE call is now forced to be greater than 0.
C
C-&


C
C     SPICELIB functions
C
      INTEGER               LASTNB
      LOGICAL               MSGSEL
C
C     Local Variables:
C


      INTEGER               MAXWRD
      PARAMETER           ( MAXWRD = 5 )

      INTEGER               WORDLN
      PARAMETER           ( WORDLN = 9)
      CHARACTER*(WORDLN)    WORDS ( MAXWRD )
      CHARACTER*(WORDLN)    UPWORD

      INTEGER               NUMWRD

      CHARACTER*(FILEN)     DEVICE

      LOGICAL               SHORT
      LOGICAL               EXPL
      LOGICAL               LONG
      LOGICAL               TRACE
      LOGICAL               DFAULT

      INTEGER               DEPTH

      INTEGER               INDEX

      CHARACTER*(NAMLEN)    NAME

      INTEGER               SLEN
      PARAMETER           ( SLEN = 25  )
      CHARACTER*(SLEN)      SMSG

      INTEGER               LLEN
      PARAMETER           ( LLEN = 320 )
      CHARACTER*(LLEN)      LMSG

      INTEGER               XLEN
      PARAMETER           ( XLEN = 80 )
      CHARACTER*(XLEN)      XMSG

      INTEGER               LINLEN
      PARAMETER           ( LINLEN = 80 )
      CHARACTER*(LINLEN)    LINE

      INTEGER               LSTLEN
      PARAMETER           ( LSTLEN = 80 )
      CHARACTER*(LSTLEN)    TMPLST

      INTEGER               REMAIN

      INTEGER               I

      INTEGER               STRLEN
      PARAMETER           ( STRLEN = 3 )

      INTEGER               ENDLEN
      PARAMETER           ( ENDLEN = 1 )

      CHARACTER*(LINLEN)    STRBOR ( STRLEN )
      CHARACTER*(LINLEN)    ENDBOR ( ENDLEN )


      INTEGER               DEFLEN
      PARAMETER           ( DEFLEN = 6 )
      CHARACTER*(LINLEN)    DEFMSG( DEFLEN )

      SAVE                  DEFMSG
      SAVE                  STRBOR
      SAVE                  ENDBOR

C
C     Initial Values:
C

      DATA   DEFMSG  /

     .'Oh, by the way:  The SPICELIB error handling actions are',
     .'USER - TAILORABLE.  You can choose whether the toolkit aborts',
     .'or continues when errors occur, which error messages to out-',
     .'put, and where to send the output.  Please read the "required',
     .'reading" file ERROR.REQ, or see the routines, ERRACT, ERRDEV',
     .'and ERRPRT.' /


      DATA   STRBOR(1)  /  ' '  /

      DATA   STRBOR(2) (1:40)   /
     .'****************************************' /

      DATA   STRBOR(2) (41:80)  /
     .'****************************************' /

      DATA   STRBOR(3)  /  ' '  /



      DATA   ENDBOR(1) (1:40)   /
     .'****************************************' /

      DATA   ENDBOR(1) (41:80)  /
     .'****************************************' /






C
C     Executable Code:
C

C
C     No messages are to be output which are not specified
C     in LIST:
C

      SHORT  = .FALSE.
      EXPL   = .FALSE.
      LONG   = .FALSE.
      TRACE  = .FALSE.
      DFAULT = .FALSE.



C
C     We parse the list of message types, and set local flags
C     indicating which ones are to be output.  If we find
C     a word we don't recognize in the list, we signal an error
C     and continue parsing the list.
C

      TMPLST = LIST

      CALL LPARSE ( TMPLST,  ',' ,  MAXWRD,  NUMWRD, WORDS )

      DO 50001
     .   I = 1, NUMWRD

         CALL UCASE ( WORDS(I), UPWORD )

         IF  ( UPWORD  .EQ. 'SHORT' )  THEN

            SHORT  =  .TRUE.

         ELSE IF   ( UPWORD  .EQ. 'EXPLAIN' )   THEN

            EXPL   =  .TRUE.

         ELSE IF   ( UPWORD  .EQ. 'LONG' )   THEN

            LONG   =  .TRUE.

         ELSE IF   ( UPWORD  .EQ. 'TRACEBACK' )  THEN

            TRACE  =  .TRUE.

         ELSE IF   ( UPWORD  .EQ. 'DEFAULT' )   THEN

            DFAULT =  .TRUE.

         ELSE

C
C           Unrecognized word!  This is an error...
C


C
C           We have a special case on our hands; this routine
C           is itself called by SIGERR, so a recursion error will
C           result if this routine calls SIGERR.  So we output
C           the error message directly:
C

             CALL GETDEV ( DEVICE )

             CALL WRLINE ( DEVICE,  'SPICE(INVALIDLISTITEM)' )

             CALL WRLINE ( DEVICE, ' ' )

             CALL WRLINE ( DEVICE,

     .       'OUTMSG:  An invalid message type was specified in the'  //
     .       ' type list.  The type was  ' // WORDS(I)

     .              )



         END IF

50001 CONTINUE

C
C     LIST has been parsed.
C

C
C     Now, we output those error messages which were specified
C     by LIST and which belong to the set of messages
C     selected for output.
C

C
C     We get the default error output device:
C

      CALL GETDEV ( DEVICE )


      IF ( DEVICE .NE. 'NULL' ) THEN

C
C        We go ahead and output those messages which
C        have been specified in the list and also
C        are enabled for output.   Note that the order of
C        the cases below IS significant; the order in which
C        the messages appear in the output depends on it.
C


         IF    (   (  SHORT   .AND. MSGSEL ( 'SHORT'     )  )    .OR.
     .             (  EXPL    .AND. MSGSEL ( 'EXPLAIN'   )  )    .OR.
     .             (  LONG    .AND. MSGSEL ( 'LONG'      )  )    .OR.
     .             (  TRACE   .AND. MSGSEL ( 'TRACEBACK' )  )    .OR.
     .             (  DFAULT  .AND. MSGSEL ( 'DEFAULT'   )  )
     .   )THEN


C
C           If anything is actually going to be output, write the
C           starting border out:
C
            DO 50002
     .         I = 1, STRLEN

               CALL WRLINE ( DEVICE, STRBOR(I) )

50002       CONTINUE

C
C           Next, we output the messages specified in the list
C           that have been enabled.
C
C           We start with the short message and its accompanying
C           explanation.  If both are to be output, they are
C           concatenated into a single message.
C
C
            IF  (   (  SHORT .AND. MSGSEL ( 'SHORT'   )  )  .AND.
     .              (  EXPL  .AND. MSGSEL ( 'EXPLAIN' )  )        ) THEN

C
C              Extract the short message from global storage; then
C              get the corresponding explanation:
C
               CALL GETSMS ( SMSG )

               CALL EXPLN  ( SMSG, XMSG )

               CALL WRLINE ( DEVICE, SMSG( :MAX(1,LASTNB(SMSG)) )   //
     .                       ' -- '//XMSG( :MAX(1,LASTNB(XMSG)) )  )

               CALL WRLINE  ( DEVICE, ' '  )

            ELSE IF  (  SHORT .AND. MSGSEL ( 'SHORT'   )  )  THEN

               CALL GETSMS ( SMSG )

               CALL WRLINE  ( DEVICE, SMSG  )

               CALL WRLINE  ( DEVICE, ' '  )

            ELSE IF    (  EXPL  .AND. MSGSEL ( 'EXPLAIN' )  )    THEN
C
C              Obtain the explanatory text for the short error
C              message and output it:
C
               CALL GETSMS ( SMSG )

               CALL EXPLN  ( SMSG, XMSG )

               CALL WRLINE  ( DEVICE, XMSG )

               CALL WRLINE  ( DEVICE, ' '  )

            END IF



            IF    (  LONG .AND. MSGSEL ( 'LONG' )  )    THEN

C              Extract the long message from global storage and
C              output it:
C
               CALL GETLMS  (  LMSG  )

               CALL WRLINE  (  DEVICE, LMSG (: MAX(1, LASTNB(LMSG)) )  )

               CALL WRLINE  (  DEVICE, ' '  )


            END IF




            IF    (  TRACE .AND. MSGSEL ( 'TRACEBACK' )  )    THEN
C
C              Extract the traceback from global storage and
C              output it:
C
               CALL TRCDEP ( DEPTH )

               IF ( DEPTH .GT. 0 ) THEN

C
C                 We know we'll be outputting some trace information.
C                 So, write a line telling the reader what's coming.
C
                  CALL WRLINE ( DEVICE,

     .            'A traceback follows.  The name of the highest'     //
     .            ' level module is first.'
     .
     .                        )



C
C                 While there are more names in the traceback
C                 representation, we stuff them into output
C                 lines and write the lines out when they are
C                 full.
C
                  INDEX   =   1
                  LINE    =   ' '
                  REMAIN  =   LINLEN

50003             IF       ( INDEX .LE. DEPTH )
     .            THEN
C
C                    While there are more module names in the traceback
C                    representation, retrieve module names and
C                    stuff them into lines of characters.
C

C
C                    Get a name and add the call order sign.  We
C                    indicate calling order by a ' --> ' delimiter; e.g.
C                    "A calls B" is indicated by 'A --> B'.
C
C                    Note that if NAME has over NAMLEN - 4
C                    significant characters, the "greater than"
C                    sign will be lost.  That's life.
C

                     CALL TRCNAM ( INDEX, NAME )

C
C                    If it's not the last name, add the call order sign:
C
                     IF ( INDEX .LT. DEPTH ) THEN

                        CALL SUFFIX ( ' -->',   0,  NAME )

                     END IF


                     INDEX = INDEX + 1

C
C                    We have to stuff the name into one or more lines of
C                    text.  Our approach is as follows:
C
C                    1.  If the name fits in the current line,
C                        ram it in there.  (Urmmph!)
C                        If it's the first name on the line, we
C                        don't want a preceding blank; otherwise
C                        we do.
C
C                    2.  If the name doesn't fit, and the length
C                        of the name is <= the line length, write
C                        the current line, and stick the name in
C                        a new line.
C
C                    3.  If the name is longer than a line, we have
C                        no choice but to break it.  We stuff as
C                        much of it as will fit into the current
C                        line, and keep filling up new lines with
C                        chunks of the name, until there's none
C                        left.  As each line is filled, we write
C                        it out.
C

                     IF (   LASTNB( NAME ) .LE. REMAIN   ) THEN

                        IF ( REMAIN .EQ. LINLEN ) THEN

                           CALL SUFFIX ( NAME, 0, LINE )

                        ELSE

                           CALL SUFFIX ( NAME, 1, LINE )

                        END IF

                        REMAIN = REMAIN - LASTNB( NAME ) - 1

                     ELSE IF ( LASTNB( NAME ) .LT. LINLEN ) THEN

                        CALL WRLINE ( DEVICE, LINE )

                        LINE = NAME

                        REMAIN = LINLEN - LASTNB( NAME ) - 1

                     ELSE

                        IF ( REMAIN .EQ. LINLEN ) THEN

                           CALL SUFFIX (  NAME(:REMAIN), 0, LINE  )

                        ELSE IF ( REMAIN .GT. 0 ) THEN

                           CALL SUFFIX (  NAME(:REMAIN), 1, LINE  )

                        END IF

                        CALL WRLINE ( DEVICE, LINE )

                        IF ( REMAIN .GT. 0 ) THEN

                           NAME ( :REMAIN )  = ' '

                           CALL LJUST ( NAME, NAME )

                        END IF


50004                   IF       (  LASTNB( NAME ) .GT. LINLEN  )
     .                  THEN

                           CALL WRLINE (  DEVICE, NAME(:LINLEN)  )

                           NAME ( :LINLEN ) = ' '

                           CALL LJUST ( NAME, NAME )

                           GO TO 50004
                        END IF


                        IF ( NAME .NE. ' ' ) THEN

                           LINE = NAME

                           REMAIN = LINLEN  -  LASTNB( NAME )  -  1

                        ELSE

                           REMAIN = LINLEN

                        END IF

                     END IF

C
C                    At this point, a name has been inserted into
C                    one or more lines.  If multiple lines have
C                    been used, all lines but the last one have
C                    been written out.
C
                     GO TO 50003
                  END IF

C
C                 At this point, no more names are left in the
C                 trace representation.  LINE may still contain
C                 names, or part of a long name.  If it does,
C                 we now write it out.
C

                  IF ( LINE .NE. ' ' ) THEN

                     CALL WRLINE ( DEVICE, LINE )

                  END IF

                  CALL WRLINE  ( DEVICE, ' '  )

               END IF
C
C              At this point, either we have output the trace
C              representation, or the trace representation was
C              empty.
C

            END IF


            IF    (  DFAULT  .AND. MSGSEL ( 'DEFAULT' )  )    THEN
C
C              Output the default message:
C

               DO 50005
     .            I = 1, DEFLEN

                  CALL WRLINE  ( DEVICE, DEFMSG (I) )

50005          CONTINUE

               CALL WRLINE  ( DEVICE, ' '  )


            END IF


C
C           At this point, we've output all of the enabled messages
C           that were specified in LIST.  At least one message that
C           was specified was enabled.
C



C
C           Write the ending border out:
C

            DO 50006
     .         I = 1, ENDLEN

               CALL WRLINE ( DEVICE, ENDBOR(I) )

50006       CONTINUE



         END IF

C
C        At this point, we've output all of the enabled messages
C        that were specified in LIST.
C

      END IF

C
C     At this point, either we've output all of the enabled messages
C     that were specified in LIST, or the device was 'NULL', in
C     which case no output was required.
C

      END


