C$Procedure      PUTACT ( Store Error Response Action )

      SUBROUTINE PUTACT ( ACTION )

C$ Abstract
C
C     PUTACT is a low-level data structure access routine which
C     stores the error response action.  DO NOT CALL THIS ROUTINE.
C     USE ERRACT, NOT PUTACT, TO SET THE CURRENT ERROR RESPONSE ACTION.
C
C$ Required_Reading
C
C     ERROR
C
C$ Keywords
C
C     ERROR
C
C$ Declarations

      CHARACTER*(*)          ACTION

C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      ACTION     I   The error response action.
C
C$ Detailed_Input
C
C      ACTION    The new value of the error response action.  This
C                value will be saved.
C
C$ Detailed_Output
C
C      None.
C
C$ Parameters
C
C      None.
C
C$ Exceptions
C
C      None.
C
C$ Files
C
C      None.
C
C$ Particulars
C
C      DO NOT CALL THIS ROUTINE.
C
C      This is a data structure access routine for the SPICELIB
C      error response action.  This routine should be used for
C      no other purpose. In particular, it should not be used
C      by non-SPICELIB routines to set up an error response;
C      use ERRACT for that.
C
C$ Examples
C
C      None.
C
C$ Restrictions
C
C      DO NOT CALL THIS ROUTINE.
C
C      Calls to this routine by routines other than the
C      SPICELIB error handling routines may interfere
C      with error processing.
C
C$ Literature_References
C
C      None.
C
C$ Author_and_Institution
C
C      N.J. Bachman    (JPL)
C
C$ Version
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (NJB)
C
C-&

C$ Revisions
C
C-     Beta Version 1.0.1, 08-FEB-1989 (NJB)
C
C         Warnings added to discourage use of this routine in
C         non-error-handling code.
C
C-&




C
C     Local Variables:
C

C
C     The current error response action:
C

      INTEGER               ACTLEN
      PARAMETER           ( ACTLEN = 7 )

      CHARACTER*(ACTLEN)    SAVACT

      SAVE                  SAVACT

C
C     Initial values:
C

      DATA    SAVACT      / 'DEFAULT' /



C
C     Executable Code:
C


      SAVACT = ACTION

      RETURN




C$Procedure      GETACT ( Get Error Response Action )

       ENTRY GETACT ( ACTION )

C$ Abstract
C
C      Return the value of the current error response action.
C
C$ Required_Reading
C
C      ERROR
C
C$ Keywords
C
C      ERROR
C
C$ Declarations
C
C      CHARACTER*(*)          ACTION
C
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C
C      ACTION     O   The current error response action.
C
C$ Detailed_Input
C
C      None.
C
C$ Detailed_Output
C
C      ACTION    is the current error response action.  See the
C                "required reading" file for a detailed discussion
C                of error response actions.
C
C$ Parameters
C
C      None.
C
C$ Exceptions
C
C      None.
C
C      However, this routine is part of the SPICELIB error
C      handling mechanism.
C
C$ Files
C
C      None.
C
C$ Particulars
C
C      None.
C
C$ Examples
C
C      None.
C
C$ Restrictions
C
C      None.
C
C$ Literature_References
C
C      None.
C
C$ Author_and_Institution
C
C      N.J. Bachman    (JPL)
C
C$ Version
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (NJB)
C
C-&




C
C     Executable Code:
C

C
C     Grab saved error response action:
C

      ACTION = SAVACT

      END

