
C$Procedure      RECRAD ( Rectangular coordinates to RA and DEC )

      SUBROUTINE RECRAD ( RECTAN, RANGE, RA, DEC )

C$ Abstract
C
C      Accepts as input rectangular coordinates and returns the range,
C      right ascension, and declination.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      CONVERSION,  COORDINATES
C
C$ Declarations

      DOUBLE PRECISION   RECTAN ( 3 )
      DOUBLE PRECISION   RANGE
      DOUBLE PRECISION   RA
      DOUBLE PRECISION   DEC

C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      RECTAN     I   Rectangular coordinates of a point.
C      RANGE      O   Distance of the point from the origin.
C      RA         O   Right ascension in radians.
C      DEC        O   Declination in radians.
C
C$ Detailed_Input
C
C      RECTAN     contains the rectangular coordinates of a point.
C
C$ Detailed_Output
C
C      RANGE      is the distance of the point from the origin.
C
C      RA         is the right ascension, the angular distance
C                 measured toward the east from the XZ plane to the
C                 point.  RA ranges from 0 to ( 2 * pi ) radians.
C
C      DEC        is the angle from the XY plane to the point.
C                 DEC ranges from - ( pi/2 ) to ( pi/2 ) radians.
C
C$ Parameters
C
C      None.
C
C$ Particulars
C
C      This routine returns the range, right ascension, and declination
C      of a point whose position is input in rectangular coordinates.
C
C      The output is defined by a distance from a central reference
C      point, an angle from a reference meridian, and an angle above
C      the equator of a sphere centered at the central reference
C      point.
C
C      This subroutine calls RECLAT which returns range, latitude, and
C      longitude. The longitude ranges from - pi to pi radians.  The
C      right ascension however, ranges from zero to two pi radians.
C      If the longitude returned by RECLAT is negative, this subroutine
C      adds two pi to it so that it then falls within the range of the
C      right ascension.
C
C$ Examples
C
C     The following code fragment demonstrates the use of RECRAD.
C
C
C     Determine the intersection of a line-of-sight vector with the
C     surface of an ellipsoid.
C
C      CALL SURFPT ( POSITN, U, A, B, C, POINT, FOUND )
C
C
C     Convert to range, right ascension, and declination.
C
C      CALL RECRAD ( POINT, RANGE, RA, DEC )
C
C
C$ Restrictions
C
C      None.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      H.A. Neilan     (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (HAN)
C
C-&


C
C     SPICELIB functions
C
      DOUBLE PRECISION      TWOPI

C
C     Call the subroutine RECLAT to convert the rectangular coordinates
C     into latitudinal coordinates.  In RECLAT, the longitude ( which
C     is returned to this subroutine as RA ) ranges from - pi to pi
C     radians.   Because the right ascension ranges from zero to
C     two pi radians, whenever RA is negative two pi must be added to
C     it.
C
C

      CALL RECLAT ( RECTAN, RANGE, RA, DEC )


      IF ( RA .LT. 0 ) THEN
         RA = RA + TWOPI()
      END IF


      RETURN
      END
