C$Procedure      SHELLC ( Shell sort a character array )

      SUBROUTINE SHELLC ( NDIM, ARRAY )

C$ Abstract
C
C      Sort an array of character strings according to the ASCII
C      collating sequence using the Shell Sort algorithm.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      ARRAY,  SORT
C
C$ Declarations

      INTEGER          NDIM
      CHARACTER*(*)    ARRAY ( * )

C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      NDIM       I   Dimension of the array.
C      ARRAY     I/O  The array.
C
C$ Detailed_Input
C
C      NDIM        is the number of elements in the array to be sorted.
C
C      ARRAY       on input, is the array to be sorted.
C
C$ Detailed_Output
C
C      ARRAY       on output, contains the same elements, sorted
C                  according to the ASCII collating sequence.
C                  The actual sorting is done in place in ARRAY.
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C      The Shell Sort Algorithm is well known.
C
C$ Examples
C
C      Let ARRAY contain the following elements:
C
C            'FEYNMAN'
C            'NEWTON'
C            'EINSTEIN'
C            'GALILEO'
C            'EUCLID'
C            'Galileo'
C
C      Then after a call to SHELLC, the array would be ordered as
C      follows:
C
C            'EINSTEIN'
C            'EUCLID'
C            'FEYNMAN'
C            'GALILEO'
C            'Galileo'
C            'NEWTON'
C
C$ Restrictions
C
C      None.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      I.M. Underwood  (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (IMU)
C
C-&



C
C     Local variables
C
      INTEGER          GAP
      INTEGER          I
      INTEGER          J
      INTEGER          JG



C
C     This is a straightforward implementation of the Shell Sort
C     algorithm.
C
      GAP = NDIM / 2

50001 IF       ( GAP .GT. 0 )
     .THEN

         DO 50002
     .      I = GAP+1, NDIM

            J = I - GAP
50003       IF       ( J .GT. 0 )
     .      THEN
               JG = J + GAP

               IF ( LLE (ARRAY(J), ARRAY(JG)) ) THEN
                  J = 0
               ELSE
                  CALL SWAPC ( ARRAY(J), ARRAY(JG) )
               END IF

               J = J - GAP
               GO TO 50003
            END IF

50002    CONTINUE

         GAP = GAP / 2

         GO TO 50001
      END IF

      RETURN
      END
