C$Procedure            SIZEI ( Size of an integer cell )

      INTEGER FUNCTION SIZEI ( CELL )

C$ Abstract
C
C     Return the size (maximum cardinality) of an integer cell.
C
C$ Required_Reading
C
C     CELLS
C
C$ Keywords
C
C     CELLS
C
C$ Declarations

      INTEGER               LBCELL
      PARAMETER           ( LBCELL = -5 )

      INTEGER               CELL  ( LBCELL: * )

C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     CELL       I   Input cell.
C
C     The function returns the size of the input cell.
C
C$ Detailed_Input
C
C
C      CELL        is a cell.
C
C
C$ Detailed_Output
C
C     The function returns the size of (maximum number of elements in)
C     the input cell.
C
C$ Parameters
C
C      None.
C
C$ Particulars
C
C     None.
C
C$ Examples
C
C     The size (SIZE) functions are typically used in conjunction
C     with the cardinality functions to predict (and subsequently
C     avoid) overflows when manipulating cells. In the following
C     example, SIZEI is used to determine whether the integer cell
C     ORIGINAL can be safely copied into the integer cell SAVE before
C     actually attempting the operation. (If ORIGINAL contains more
C     elements than SAVE is capable of holding, then the operation
C     will fail.)
C
C           IF ( CARDI ( ORIGINAL ) .LE. SIZEI ( SAVE ) ) THEN
C              CALL COPYI ( ORIGINAL, SAVE, ERROR )
C
C           ELSE
C            .
C            .
C           END DO
C
C$ Restrictions
C
C     None.
C
C$ Exceptions
C
C     1)  If the input array has invalid cardinality, the error
C         SPICE(INVALIDCARDINALITY) is signalled.  SIZEI returns
C         an unspecified value in this case.
C
C     2)  If the input array has invalid size, the error
C         SPICE(INVALIDSIZE) is signalled.  SIZEI returns
C         an unspecified value in this case.
C
C$ Files
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     N.J. Bachman    (JPL)
C     C.A. Curzon     (JPL)
C     W.L. Taber      (JPL)
C     I.M. Underwood  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (CAC) (WLT) (IMU)
C
C-&

C$ Revisions
C
C-    Beta Version 2.0.0, 13-MAR-1989 (NJB)
C
C        Check for valid input cell added.  The input cell must
C        have valid size and cardinality values.
C-&


C
C     SPICELIB functions
C
      LOGICAL               RETURN



      IF ( RETURN() ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'SIZEI' )
      END IF

C
C     Set return value, regardless of validity.
C
      SIZEI = CELL(-1)

C
C     Squeal if something is awry.
C

      IF (  CELL(-1) .LT. 0  )  THEN

         CALL SETMSG ( 'Invalid cell size.  The size was #.')
         CALL ERRINT ( '#', CELL(-1)  )
         CALL SIGERR ( 'SPICE(INVALIDSIZE)' )
         CALL CHKOUT ( 'SIZEI' )
         RETURN

      ELSE IF ( CELL(0) .LT. 0  ) THEN

         CALL SETMSG ( 'Invalid cell cardinality.  The cardinality '  //
     .                 'was #.'      )
         CALL ERRINT ( '#', CELL(0)  )
         CALL SIGERR ( 'SPICE(INVALIDCARDINALITY)' )
         CALL CHKOUT ( 'SIZEI' )
         RETURN

      ELSE IF ( CELL(0) .GT. CELL(-1)  ) THEN

         CALL SETMSG ( 'Invalid cell cardinality; cardinality exceeds'//
     .                 ' cell size.  The cardinality was #.  The size'//
     .                 ' was #.'  )
         CALL ERRINT ( '#', CELL( 0)  )
         CALL ERRINT ( '#', CELL(-1)  )
         CALL SIGERR ( 'SPICE(INVALIDCARDINALITY)' )
         CALL CHKOUT ( 'SIZEI' )
         RETURN

      END IF


      CALL CHKOUT ( 'SIZEI' )
      RETURN
      END
