C$Procedure      TRCPKG ( Declare Arguments for Trace Routines )

      SUBROUTINE TRCPKG ( DEPTH, INDEX, MODULE, TRACE, NAME )

C$ Abstract
C
C      Declare the arguments for the trace entry points.  This routine
C      should never be called.
C
C$ Required_Reading
C
C      ERROR
C
C$ Keywords
C
C      ERROR
C
C$ Declarations

      INTEGER               DEPTH
      INTEGER               INDEX
      CHARACTER*(*)         MODULE
      CHARACTER*(*)         TRACE
      CHARACTER*(*)         NAME

      INTEGER               FILEN
      PARAMETER           ( FILEN  = 128 )

      INTEGER               NAMLEN
      PARAMETER           ( NAMLEN = 128 )

C$ Brief_I/O
C
C      VARIABLE  I/O  ENTRY
C      --------  ---  --------------------------------------------------
C
C      DEPTH      O   TRCDEP
C      INDEX      I   TRCNAM
C      NAME       O   TRCNAM
C      MODULE     I   CHKIN, CHKOUT
C      TRACE      O   QCKTRC
C      FILEN      P   CHKIN,  CHKOUT, TRCNAM, QCKTRC
C      NAMLEN     P   CHKOUT, QCKTRC
C
C$ Detailed_Input
C
C      See the ENTRY points for discussions of their arguments.
C
C$ Detailed_Output
C
C      See the ENTRY points for discussions of their arguments.
C
C$ Parameters
C
C      See the ENTRY points for discussions of their parameters.
C
C$ Exceptions
C
C      1.  SPICE(BOGUSENTRY)  -- It is an error to call this routine.
C
C
C      Note:   All entry points in this routine write out error messages
C              rather than signalling errors, so as to avoid recursion.
C
C$ Files
C
C      None.
C
C$ Particulars
C
C      The entry points declared in this routine are:
C
C      CHKIN
C      CHKOUT
C      TRCDEP
C      TRCNAM
C      QCKTRC
C      FREEZE
C
C      There is no reason to call this subroutine.
C      The purpose of this subroutine is to provide a place to
C      declare the arguments for the various entry points.  This
C      routine has no run-time function whatsoever.
C
C$ Examples
C
C      Don't even think about calling this routine.  If this routine is
C      called, it will signal the error SPICE(BOGUSENTRY); then your
C      program will probably stop.
C
C$ Restrictions
C
C      Don't even think about calling this routine.
C
C$ Literature_References
C
C      None.
C
C$ Author_and_Institution
C
C      N.J. Bachman    (JPL)
C
C$ Version
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (NJB)
C
C-&


C$ Revisions
C
C-     Beta Version 1.0.1, 08-FEB-1989 (NJB)
C
C         Warnings added to discourage use of this routine.
C
C-&




C
C     NAIF toolkit functions:
C

      INTEGER               LASTNB
      INTEGER               FRSTNB
      LOGICAL               FAILED

C
C     Local Variables:
C

      INTEGER               MODLEN
      INTEGER               LOC
      INTEGER               BEG
      INTEGER               END
      CHARACTER*(11)        STRING
      INTEGER               POS
      CHARACTER*(NAMLEN)    MODNAM
      CHARACTER*(NAMLEN)    CALLER
      CHARACTER*(FILEN)     DEVICE
      CHARACTER*(10)        ACTION
      INTEGER               FIRST
      INTEGER               LAST
      INTEGER               COUNT

C
C     Saved variables:
C



      INTEGER               TRCLEN
      PARAMETER           ( TRCLEN = 512 )

      CHARACTER*(TRCLEN)    TRCSTR
      CHARACTER*(TRCLEN)    FRZSTR
      INTEGER               STKPTR
      INTEGER               MODCNT
      INTEGER               PSHCNT
      INTEGER               FRZCNT

      SAVE                  TRCSTR
      SAVE                  FRZSTR
      SAVE                  STKPTR
      SAVE                  MODCNT
      SAVE                  PSHCNT
      SAVE                  FRZCNT


C
C     Initial values:
C

      DATA    TRCSTR   / ' '   /
      DATA    FRZSTR   / ' '   /
      DATA    STKPTR   /  1    /
      DATA    MODCNT   /  0    /
      DATA    PSHCNT   /  0    /
      DATA    FRZCNT   /  0    /



C
C     Executable Code:
C

      CALL WRLINE ( 'SCREEN', 'SPICE(BOGUSENTRY)' )

      CALL WRLINE ( 'SCREEN',
     .
     .              'TRCPKG: You have called an entry which '//
     .              ' performs no run-time function.  This'  //
     .              ' may indicate a bug.  Please check the' //
     .              ' TRCPKG documentation.' )



      RETURN




C$Procedure      CHKIN ( Module Check In )

       ENTRY  CHKIN  ( MODULE )

C$ Abstract
C
C      Inform the SPICELIB error handling mechanism of entry into a
C      routine.
C
C$ Required_Reading
C
C      ERROR
C
C$ Keywords
C
C      ERROR
C
C$ Declarations
C
C      CHARACTER*(*)          MODULE
C
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      MODULE     I   The name of the calling routine.
C      FILEN      P   Maximum length of file name.
C
C$ Detailed_Input
C
C      MODULE  is the name of the routine calling CHKIN.  The
C              named routine is supposed to be "checking in"
C              when it calls CHKIN; that is, the call should
C              be the first executable statement following
C              the reference to the function RETURN (which
C              should be the first executable statement).
C
C
C$ Detailed_Output
C
C      None.
C
C$ Parameters
C
C      FILEN   is the maximum file name length that can be
C              accommodated by this routine.
C
C$ Exceptions
C
C
C        CHKIN does not signal errors; rather it writes error messages,
C        so as to avoid recursion.
C
C  1.    This routine detects overflow of the traceback
C        storage area.
C
C        The short error message in that case is:
C        SPICE(TRACEBACKOVERFLOW).
C
C
C  2.    Checking in with a blank module name is also an error.
C
C        The short message is to
C        SPICE(BLANKMODULENAME).
C
C
C  3.    Checking in with a module name containing embedded blanks is
C        an error.
C
C        The short error message is  SPICE(EMBEDDEDBLANK).
C
C
C
C      Note:  This routine is part of the NAIF toolkit error
C      handling mechanism.
C
C$ Files
C
C      None.
C
C$ Particulars
C
C
C      Please read the required reading!
C
C      Conceptually, the effect of this routine is to
C      "push" the supplied module name onto a stack.  The
C      routine, CHKOUT, performs the inverse, or "pop,"
C      operation.
C
C      Every routine that participates in the traceback scheme
C      should have a call to CHKIN as the second executable
C      statement.  The first executable statements should
C      be:
C
C           IF ( RETURN() ) THEN
C              RETURN
C           ELSE
C              CALL CHKIN ( module )
C           END IF
C
C
C      Here module is the name of the routine in which this
C      code appears.
C
C      The line of code preceding the END or any RETURN statement
C      should be
C
C           CALL CHKOUT ( module )
C
C      Note:  All SPICELIB routines should call CHKIN and CHKOUT,
C      except for those that do not detect any errors AND do not
C      have external references.  Applications linked with SPICELIB
C      may also use CHKIN and CHKOUT; again, all routines in the
C      application should call CHKIN and CHKOUT, except for those that
C      do not detect any errors AND do not have external references.
C
C      Routines which don't call CHKIN and CHKOUT won't appear in the
C      traceback.
C
C      It is especially important that every routine which calls
C      CHKIN also call CHKOUT.  Otherwise, the trace mechanism
C      will become very confused.
C
C
C$ Examples
C
C      See "Particulars" for an example of how to call this
C      routine.
C
C$ Restrictions
C
C      Routines which call this routine must call CHKOUT
C      immediately prior to any RETURN or END statement.
C
C      Module names are assumed to have no embedded blanks.
C
C
C$ Literature_References
C
C      None.
C
C$ Author_and_Institution
C
C      N.J. Bachman    (JPL)
C
C$ Version
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990  (NJB)
C
C-&

C$ Revisions
C
C-     Beta Version 1.1.1, 10-FEB-1988  (NJB)
C
C         Parameter declarations documented.  Parameters section added,
C         and parameter declarations listed in "Brief I/O."
C
C-     Beta Version 1.1.0, 27-OCT-1988  (NJB)
C
C         Cosmetic improvement to code.  Condensed a continued
C         statement into one line.
C
C-&


C
C     Executable Code:
C


C
C     Although conceptually the trace representation may be thought
C     of as a stack, we implement it as a single character string,
C     to which we append, or from which we remove, module names.
C     The contents of the string are module names, separated by
C     single blanks.  The last module name in the string is
C     the name of the LAST module which "checked in."  This name
C     can be thought of as being at the "top of the stack."
C
C     In this implementation, a "push" operation consists of
C     suffixing the current string with a new
C     module name.  A "pop" operation consists of blanking out the
C     last module name in the string, so that the second-to-last
C     name in the string becomes the last name.
C
C     Note:  the push count is maintained so that the
C     traceback representation will not be corrupted in the
C     event of overflow.  The idea is that the number of pushes
C     may exceed the number of module names saved in the
C     traceback representation, but "pops" only remove module
C     names from the representation when the pop is "undoing"
C     a push that actually succeeded in placing a new name into
C     the representation.
C
C     With this procedure, in the event of overflow, the modules in the
C     representation will still be a correct representation
C     of the top portion of the call chain.
C


C
C     Perform a "push", if there's more room in the string.
C     This means suffixing the string on the right with the new
C     name, updating the stack pointer and updating the module count.
C


      FIRST  =  FRSTNB ( MODULE )
      LAST   =  LASTNB ( MODULE )

      MODLEN =  LAST - FIRST  +  1



      IF ( LAST .EQ. 0  ) THEN

         CALL GETDEV (  DEVICE  )

         CALL WRLINE (  DEVICE,   'SPICE(BLANKMODULENAME)' )

         CALL WRLINE (  DEVICE,
     .
     .                 'CHKIN:  An attempt to check in was made '     //
     .                 'without supplying a module name'
     .               )


      ELSE
C
C        Check for embedded blanks:
C
         DO 50001
     .      POS = FIRST, LAST

            IF  ( MODULE(POS:POS) .EQ. ' ' ) THEN

               CALLER = MODULE

               CALL GETDEV (  DEVICE  )

               CALL WRLINE (  DEVICE,   'SPICE(EMBEDDEDBLANK)' )

               CALL WRLINE (  DEVICE,
     .
     .                       'CHKIN:  An attempt to check in was '    //
     .                       'made with a module name containing '    //
     .                       'at least  one embedded blank.  The '    //
     .                       'name was:  ' // CALLER(FIRST:LAST)
     .                     )

            END IF

50001    CONTINUE

      END IF



      IF (    MODLEN    .LE.   TRCLEN - STKPTR + 1  )   THEN

         MODCNT  =   MODCNT + 1
         PSHCNT  =   PSHCNT + 1

         TRCSTR ( STKPTR : STKPTR + MODLEN - 1 )  =  MODULE ( FIRST : )

         STKPTR = STKPTR + MODLEN + 1

      ELSE

         CALL GETDEV ( DEVICE )

         CALL WRLINE ( DEVICE,  'SPICE(TRACEBACKOVERFLOW)' )

         CALL WRLINE ( DEVICE,
     .
     .                 'CHKIN:  The trace storage is completely'//
     .                 ' full.  No further module' //
     .                 ' names can be   added.'  )
C                                     ^
C        NOTE:  The extra spaces right here are SUPPOSED to be there.
C        They cause a line break in the right place.
C



C
C        Even though we can't store another name, we bump the
C        push counter so that checking out won't corrupt the
C        existing traceback information.
C
         PSHCNT =  PSHCNT + 1

      END IF



      RETURN





C$Procedure      CHKOUT ( Module Check Out )

       ENTRY  CHKOUT ( MODULE )

C$ Abstract
C
C      Inform the SPICELIB error handling mechanism of exit from a
C      routine.
C
C$ Required_Reading
C
C      ERROR
C
C$ Keywords
C
C      ERROR
C
C$ Declarations
C
C      CHARACTER*(*)        MODULE
C
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      MODULE     I   The name of the calling routine.
C      NAMLEN     P   Maximum module name length.
C      FILEN      P   Maximum file name length.
C
C$ Detailed_Input
C
C      MODULE  is the name of the routine calling CHKOUT.  The
C              named routine is supposed to be "checking out"
C              when it calls CHKOUT; that is, the call should
C              be the last executable statement preceding any exit
C              from the routine.
C
C
C$ Detailed_Output
C
C      None.
C
C$ Parameters
C
C      FILEN   is the maximum file name length that can be
C              accommodated by this routine.
C
C      NAMLEN  is the maximum module name length that can be
C              accommodated by this routine.
C
C$ Exceptions
C
C      CHKOUT does not signal errors; rather it writes error messages,
C      so as to avoid recursion.
C
C  1.  SPICE(INVALIDCHECKOUT) --
C
C      Either:
C
C      The module name supplied as input didn't match the name popped
C      from the trace representation, or
C
C      the trace stack was empty, or
C
C      an error occurred trying to pop a name from the trace
C      representation.
C
C
C
C      This routine is part of the NAIF toolkit error
C      handling mechanism.
C
C$ Files
C
C      None.
C
C$ Particulars
C
C
C      Please read the required reading!
C
C      Conceptually, the effect of this routine is to
C      "pop" a module name from a stack.  The
C      routine CHKIN performs the inverse, or "push"
C      operation.
C
C      Every routine that participates in the traceback scheme
C      should have a call to CHKIN as the second executable
C      statement.  The first executable statements should
C      be:
C
C           IF ( RETURN() ) THEN
C              RETURN
C           ELSE
C              CALL CHKIN ( module )
C           END IF
C
C
C      Here module is the name of the routine in which this
C      code appears.
C
C      The line of code preceding the END or any RETURN statement
C      should be
C
C           CALL CHKOUT  ( module )
C
C      Note:  All SPICELIB routines should call CHKIN and CHKOUT,
C      except for those that do not detect any errors AND do not
C      have external references.  Applications linked with SPICELIB
C      may also use CHKIN and CHKOUT; again, all routines in the
C      application should call CHKIN and CHKOUT, except for those that
C      do not detect any errors AND do not have external references.
C
C      Routines which don't call CHKIN and CHKOUT won't appear in the
C      traceback.
C
C      It is especially important that every routine which calls
C      CHKIN also call CHKOUT.  Otherwise, the trace mechanism
C      will become very confused.
C
C
C$ Examples
C
C
C      1.  Call CHKOUT before a RETURN statement:
C
C
C          IF ( FAILED() ) THEN
C             CALL CHKOUT ( module )
C             RETURN
C          END IF
C
C
C      2.  Call CHKOUT before an END statement:
C
C
C          CALL CHKOUT ( module )
C          END
C
C
C      3.  Only ONE call to CHKOUT is needed here:
C
C          CALL CHKOUT ( module )
C          RETURN
C          END
C
C
C$ Restrictions
C
C      Routines which call this routine must call CHKIN
C      as the second executable statement. (The first is
C      a call to RETURN).
C
C$ Literature_References
C
C      None.
C
C$ Author_and_Institution
C
C      N.J. Bachman    (JPL)
C
C$ Version
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990  (NJB)
C
C-&

C$ Revisions
C
C-     Beta Version 1.1.1, 10-FEB-1988  (NJB)
C
C         Parameter declarations documented.  Parameters section added,
C         and parameter declarations listed in "Brief I/O."
C
C-     Beta Version 1.1.0, 27-OCT-1988  (NJB)
C
C         Cosmetic improvement to code.  Removed a blank line
C         separating the first line of a statement from the next
C         continuation line, and condensed and re-organized
C         the statement.  Note:  the precompiler failed to properly
C         convert the orginal statement into standard Fortran.
C
C-&



C
C     Executable Code:
C

C
C     Note:  See the comments at the beginning of the code of
C     CHKIN for a discussion of the implementation ideas used
C     in these routines.
C

      IF ( PSHCNT .GT. 0 ) THEN

         IF ( PSHCNT .EQ. MODCNT ) THEN
C
C           We're not in an overflow case, so let's remove the module
C           name at the "top of the stack" and adjust our counters.
C


C
C           We need to find the beginning of the module name at
C           the top of the stack.  If the module is the only one
C           in the stack, it begins at position 1.  Otherwise, the
C           module name is preceded by a blank.
C


            IF ( MODCNT .LE. 1 ) THEN

               BEG = 1

            ELSE

C
C              Search for beginning of name...
C

               BEG = STKPTR - 2


50002          IF       (       (  TRCSTR ( BEG : BEG ) .NE. ' '  )
     .                    .AND. (  BEG                  .GT.   1  )   )
     .         THEN

                  BEG = BEG - 1

                  GO TO 50002
               END IF

               BEG = BEG + 1

            END IF

C
C           At this point, BEG has been set.  END is easy to get;
C           it's just 2 spaces before the stack pointer.
C

            END = STKPTR - 2


            IF  (  ( BEG .GT. 0 ) .AND. ( END .GE. BEG )  )   THEN

               PSHCNT               =   PSHCNT - 1
               MODCNT               =   MODCNT - 1
               STKPTR               =   BEG
               MODNAM               =   TRCSTR ( BEG : END )
               TRCSTR ( BEG : END ) =   ' '


               IF ( MODNAM .NE. MODULE ) THEN

                  CALLER = MODULE

                  CALL GETDEV ( DEVICE )

                  CALL WRLINE ( DEVICE, 'SPICE(INVALIDCHECKOUT)' )

                  CALL WRLINE ( DEVICE,
     .
     .                          'CHKOUT:  Error popping module name; '//
     .                          'name of caller doesn''t match popped'//
     .                          ' name.   Caller is:  '               //
     .                          CALLER(: MAX ( 1,LASTNB(CALLER) ) )   //
     .                          ';  popped name is:  '                //
     .                          MODNAM(: MAX ( 1,LASTNB(MODNAM) ) )   //
     .                          '.'
     .                         )

               END IF


            ELSE

               CALL GETDEV ( DEVICE )

               CALL WRLINE ( DEVICE, 'SPICE(INVALIDCHECKOUT)' )

               CALL WRLINE ( DEVICE,
     .
     .                       'CHKOUT:  Error popping module name; '   //
     .                       'name not found in trace.'
     .                     )

            END IF


         ELSE
C
C           Overflow case:  just decrement the push count:
C

            PSHCNT  =  PSHCNT - 1
C
C           We don't get any more space, since we didn't remove
C           any names from TRCSTR.
C

         END IF

      ELSE

         CALL GETDEV ( DEVICE )

         CALL WRLINE ( DEVICE, 'SPICE(INVALIDCHECKOUT)' )

         CALL WRLINE ( DEVICE,
     .
     .                 'CHKOUT: An attempt to check out was made' //
     .                 ' when no modules were checked in.'
     .               )


      END IF


      RETURN




C$Procedure      TRCDEP ( Get Depth of Traceback )

       ENTRY  TRCDEP ( DEPTH )

C$ Abstract
C
C      Return the number of modules in the traceback representation.
C
C$ Required_Reading
C
C      ERROR
C
C$ Keywords
C
C      ERROR
C
C$ Declarations
C
C      INTEGER               DEPTH
C
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C
C      DEPTH      O   The number of modules in the traceback.
C
C
C$ Detailed_Input
C
C      None.
C
C$ Detailed_Output
C
C      DEPTH  Indicates the number of module names in the
C             traceback representation.
C
C             The module names represent modules in a call chain,
C             with the first name being the top-level module,
C             and the name with index DEPTH being the lowest level
C             module.
C
C             The meaning of the traceback depends on the state of the
C             error handling mechanism.  There are two cases:
C
C             1.  In 'RETURN' mode, when an error is signalled, the
C                 traceback at that point is saved.  TRCDEP, TRCNAM,
C                 and QCKTRC will return values pertaining to the
C                 saved traceback.
C
C             2.  In all other cases, the traceback represents
C                 the CURRENT call chain.  TRCDEP, TRCNAM,
C                 and QCKTRC will return values pertaining to the
C                 current trace representation.
C
C
C$ Parameters
C
C      None.
C
C$ Exceptions
C
C      This routine does not detect any errors.
C
C      This routine is part of the NAIF toolkit error
C      handling mechanism.
C
C$ Files
C
C      None.
C
C$ Particulars
C
C
C      Please read the required reading!
C
C
C$ Examples
C
C      1.  Here's an example of how to use this routine, together
C          with TRCNAM, to create a traceback report.
C          We might wish to create such a report when we have detected
C          an error condition (see FAILED).
C
C          In this example, we assume that the error has already
C          been detected, and that we wish to create a traceback
C          report.  We assume the existence of two user-written
C          routines:
C
C          USER_TRACE_FORMAT   -- this one creates a traceback
C                                 report in the format preferred
C                                 by the user
C
C          USER_TRACE_INIT     -- this one indicates that a
C                                 traceback report is to be created;
C                                 it also indicates how many module
C                                 names will be in the report
C
C
C          Here's the example:
C
C
C          C
C          C      Get the trace depth, and retrieve that number of
C          C      module names from the traceback representation.
C          C      Call USER_TRACE_INIT to indicate that a traceback
C          C      report is to be created containing "DEPTH"
C          C      number of module names.
C          C      Input each of these names, as they are retrieved,
C          C      to USER_TRACE_FORMAT.
C          C
C
C
C                 CALL TRCDEP           ( DEPTH )
C
C                 CALL USER_TRACE_INIT  ( DEPTH )
C
C
C                 DO INDEX = 1, DEPTH
C
C                    CALL TRCNAM     ( INDEX, MODULE )
C
C                    CALL USER_TRACE_FORMAT ( MODULE )
C
C                 END DO
C
C
C
C$ Restrictions
C
C      None.
C
C$ Literature_References
C
C      None.
C
C$ Author_and_Institution
C
C      N.J. Bachman    (JPL)
C
C$ Version
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990  (NJB)
C
C-&


C
C     Executable Code:
C


      CALL GETACT ( ACTION )


C
C     If we're in 'RETURN' mode, and an error has occurred, we want to
C     use the frozen version of the traceback.  Otherwise, we want to
C     get the module name from the current traceback.
C



      IF  (   ( ACTION .EQ. 'RETURN' )  .AND.   FAILED()   )   THEN

         DEPTH = FRZCNT

      ELSE

         DEPTH = MODCNT

      END IF


      RETURN




C$Procedure      TRCNAM ( Get Module Name from Traceback )

      ENTRY  TRCNAM ( INDEX, NAME )

C$ Abstract
C
C     Return the name of the module having the specified position in
C     the trace representation.  The first module to check in is at
C     position 1.
C
C$ Required_Reading
C
C     ERROR
C
C$ Keywords
C
C     ERROR
C
C$ Declarations
C
C     INTEGER               INDEX
C     CHARACTER*(*)         NAME
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C
C     INDEX      I   The position of the requested module name.
C     NAME       O   The name in the #INDEX position in the traceback.
C     FILEN      P   Maximum file name length.
C
C
C$ Detailed_Input
C
C     INDEX    is the position in the traceback of the requested
C              module name.  The first module to check in is in
C              the first position; the last to check in in the
C              the position indicated by the argument, DEPTH,
C              returned by TRCDEP.  Note that the first module to check
C              in is at the top of the traced call chain.
C
C$ Detailed_Output
C
C     NAME    is the name of the module in the position within
C             the traceback indicated by INDEX.
C
C
C             The meaning of the traceback depends on the state of the
C             error handling mechanism.  There are two cases:
C
C             1.  In 'RETURN' mode, when an error is signalled, the
C                 traceback at that point is saved.  TRCDEP, TRCNAM,
C                 and QCKTRC will return values pertaining to the
C                 saved traceback.
C
C             2.  In all other cases, the traceback represents
C                 the CURRENT call chain.  TRCDEP, TRCNAM,
C                 and QCKTRC will return values pertaining to the
C                 current trace representation.
C
C$ Parameters
C
C      FILEN   is the maximum file name length that can be
C              accommodated by this routine.
C
C$ Exceptions
C
C     1)  This routine detects the condition of INDEX being out of
C         range.  The short error message set in that case is
C        'SPICE(INVALIDINDEX)'.
C
C     2)  If INDEX is in range, but no module name is found at the
C         indicated location in the trace representation, the error
C         message 'SPICE(INVALIDINDEX)' is set.
C
C     Because this routine is below SIGERR in the calling
C     hierarchy, this routine can not call SIGERR in the
C     event of an error.  Therefore, this routine outputs
C     error messages, rather than signalling errors.
C
C     This routine is part of the NAIF toolkit error
C     handling mechanism.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C
C     Please read the required reading!
C
C
C$ Examples
C
C      1.  Here's an example of how to use this routine, together
C          with TRCDEP, to create a traceback report.
C          We might wish to create such a report when we have detected
C          an error condition (see FAILED).
C
C          In this example, we assume that the error has already
C          been detected, and that we wish to create a traceback
C          report.  We assume the existence of two user-written
C          routines:
C
C          USER_TRACE_FORMAT   -- this one creates a traceback
C                                 report in the format preferred
C                                 by the user
C
C          USER_TRACE_INIT     -- this one indicates that a
C                                 traceback report is to be created;
C                                 it also indicates how many module
C                                 names will be in the report
C
C
C          Here's the example:
C
C
C          C
C          C      Get the trace depth, and retrieve that number of
C          C      module names from the traceback representation.
C          C      Call USER_TRACE_INIT to indicate that a traceback
C          C      report is to be created containing "DEPTH"
C          C      number of module names.
C          C      Input each of these names, as they are retrieved,
C          C      to USER_TRACE_FORMAT.
C          C
C
C
C                 CALL TRCDEP           ( DEPTH )
C
C                 CALL USER_TRACE_INIT  ( DEPTH )
C
C
C                 DO INDEX = 1, DEPTH
C
C                    CALL TRCNAM      ( INDEX, MODULE )
C
C                    CALL USER_TRACE_FORMAT  ( MODULE )
C
C                 END DO
C
C
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     N.J. Bachman    (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990  (NJB)
C
C-&

C$ Revisions
C
C
C-    Beta Version 1.1.1, 10-FEB-1988  (NJB)
C
C        Parameter declarations documented.  Parameters section added,
C        and parameter declarations listed in "Brief I/O."
C
C-    Beta Version 1.1.0, 27-OCT-1988  (NJB)
C
C        Added test for failure to remove name from trace
C        representation.  If LOC equals 0 on return from
C        NTHWD, the error SPICE(INVALIDINDEX) is reported.
C        SIGERR is not called; that would be overly recursive.
C
C        Cosmetic changes to header and code were made.  Indentation
C        of some header items was changed, and some blank lines
C        were removed from the code.
C-&

C
C     Executable Code:
C



      CALL GETACT ( ACTION )


C
C     If we're in 'RETURN' mode, and an error has occurred, we want to
C     use the frozen version of the traceback.  Otherwise, we want to
C     get the module name from the current traceback.
C


      IF  (   ( ACTION .EQ. 'RETURN' )  .AND.   FAILED()   )   THEN

         IF (   ( INDEX .GE. 1 )  .AND.  ( INDEX .LE. FRZCNT )   )  THEN

C
C           We've got a valid index..
C

            CALL NTHWD ( FRZSTR,  INDEX,  NAME,  LOC )

         ELSE

C
C           Invalid index...we output the error messages directly
C           in this case:
C
            CALL  GETDEV ( DEVICE )

            CALL  WRLINE ( DEVICE,  'SPICE(INVALIDINDEX)' )

            CALL  INTSTR ( INDEX, STRING )

            CALL  WRLINE ( DEVICE,
     .      'TRCNAM: An invalid index was input.  The value was:  '   //
     .      STRING  )


         END IF


      ELSE

C
C        Otherwise, use current traceback:
C

         IF (   ( INDEX .GE. 1 )  .AND.  ( INDEX .LE. MODCNT )   )  THEN

C
C           We've got a valid index..
C

            CALL NTHWD ( TRCSTR,  INDEX,  NAME,  LOC )

         ELSE

C
C           Invalid index...we output the error messages directly
C           in this case:
C
            CALL  GETDEV ( DEVICE )

            CALL  WRLINE ( DEVICE,  'SPICE(INVALIDINDEX)' )

            CALL  INTSTR ( INDEX, STRING )

            CALL  WRLINE ( DEVICE,
     .      'TRCNAM: An invalid index was input.  The value was:  '   //
     .      STRING  )


         END IF


      END IF

      IF ( LOC .EQ. 0 ) THEN

         CALL GETDEV ( DEVICE )

         CALL WRLINE ( DEVICE,
     .   '****************************************'                //
     .   '****************************************'         )

         CALL WRLINE ( DEVICE, ' ' )

         CALL WRLINE ( DEVICE,  'SPICE(INVALIDINDEX)' )

         CALL INTSTR ( INDEX, STRING )

         CALL WRLINE ( DEVICE,

     .   'QCKTRC:  No module was found in the traceback string '   //
     .   'in the position specified  by the following index:  '    //
     .   STRING  )

         CALL WRLINE ( DEVICE, ' ' )

         CALL WRLINE ( DEVICE,
     .   '****************************************'                //
     .   '****************************************'         )

         RETURN

      END IF

      RETURN




C$Procedure      QCKTRC ( Get Quick Traceback )

       ENTRY QCKTRC ( TRACE )

C$ Abstract
C
C      Return a string containing a traceback.
C
C$ Required_Reading
C
C      ERROR
C
C$ Keywords
C
C      ERROR
C
C$ Declarations
C
C      CHARACTER*(*)         TRACE
C
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  -------------------------------------------------
C
C      TRACE      O   A traceback report.
C      NAMLEN     P   Maximum module name length.
C      FILEN      P   Maximum file name length.
C
C$ Detailed_Input
C
C      None.
C
C$ Detailed_Output
C
C      TRACE  is a list of module names, delimited by the
C             string, ' -->'.  An example would be
C             'SPUD -->SPAM -->FOOBAR'.
C
C             In general, the meaning of the trace is as
C             follows:
C
C             The first name in the list is the name of the first
C             module to check in (that hasn't yet checked out).
C             The last name is the name of the module at
C             the end of the call chain; this is the last
C             module that checked in.
C
C
C             The meaning of the traceback depends on the state of the
C             error handling mechanism.  There are two cases:
C
C             1.  In 'RETURN' mode, when an error is signalled, the
C                 traceback at that point is saved.  TRCDEP, TRCNAM,
C                 and QCKTRC will return values pertaining to the
C                 saved traceback.
C
C             2.  In all other cases, the traceback represents
C                 the CURRENT call chain.  TRCDEP, TRCNAM,
C                 and QCKTRC will return values pertaining to the
C                 current trace representation.
C
C
C             Any module names exceeding NAMLEN characters in
C             length are truncated on the right.
C
C$ Parameters
C
C
C      FILEN   is the maximum file name length that can be
C              accommodated by this routine.
C
C      NAMLEN  is the maximum module name length that can be
C              accommodated by this routine.
C
C$ Exceptions
C
C      This routine does not detect any errors.
C
C      This routine is part of the NAIF toolkit error
C      handling mechanism.
C
C$ Files
C
C      None.
C
C$ Particulars
C
C
C      Please read the required reading!
C
C
C$ Examples
C
C
C      1.  Here's an example of how to use this routine:
C
C      C
C      C    We call RDTEXT and test for an error condition.
C      C    If an error occurred, we get the traceback and
C      C    long error message and output them using the
C      C    user-defined routine, USER_ERROR.
C      C
C
C           CALL RDTEXT ( FILE, LINE, EOF )
C
C           IF ( FAILED() ) THEN
C
C              CALL QCKTRC     ( TRACE )
C              CALL USER_ERROR ( TRACE )
C
C              CALL GETMSG     ( 'LONG', MSG )
C              CALL USER_ERROR (         MSG )
C
C           END IF
C
C
C$ Restrictions
C
C      It is assumed no module names exceed NAMLEN characters in length.
C
C$ Literature_References
C
C      None.
C
C$ Author_and_Institution
C
C      N.J. Bachman    (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990  (NJB)
C
C-&

C$ Revisions
C
C-    Beta Version 1.1.1, 10-FEB-1988  (NJB)
C
C        Parameter declarations documented.  Parameters section added,
C        and parameter declarations listed in "Brief I/O."
C
C-    Beta Version 1.1.0, 06-OCT-1988  (NJB)
C
C        Added test for failure to remove name from trace
C        representation.  If LOC equals 0 on return from
C        NTHWD, the error SPICE(INVALIDINDEX) is reported.
C        SIGERR is not called; that would be overly recursive.
C
C        Also, some cosmetic changes to code were made.  Some
C        unnecessary continuation lines were removed.
C-&


C
C     Executable Code:
C



      CALL GETACT ( ACTION )


C
C     If we're in 'RETURN' mode, and an error has occurred, we want to
C     use the frozen version of the traceback.  Otherwise, we want to
C     use the current traceback.
C


      IF  (   ( ACTION .EQ. 'RETURN' )  .AND.   FAILED()   )   THEN

         COUNT = FRZCNT

      ELSE

         COUNT = MODCNT

      END IF




C
C     The names are delimited by ' --> '; e.g.,
C
C     "SPUD --> SPAM --> FOOBAR".
C

      TRACE = ' '

      DO 50003
     .   POS = 1, COUNT


         IF  (   ( ACTION .EQ. 'RETURN' )  .AND.   FAILED()   )   THEN

            CALL NTHWD  (  FRZSTR, POS, MODNAM, LOC  )

         ELSE

            CALL NTHWD  (  TRCSTR, POS, MODNAM, LOC  )

         END IF

         IF ( LOC .EQ. 0 ) THEN

            CALL GETDEV ( DEVICE )

            CALL WRLINE ( DEVICE,
     .      '****************************************'                //
     .      '****************************************'         )

            CALL WRLINE ( DEVICE, ' ' )

            CALL WRLINE ( DEVICE,  'SPICE(INVALIDINDEX)' )

            CALL INTSTR ( INDEX, STRING )

            CALL WRLINE ( DEVICE,

     .      'QCKTRC:  No module was found in the traceback string '   //
     .      'in the position specified  by the following index:  '    //
     .      STRING  )

            CALL WRLINE ( DEVICE, ' ' )

            CALL WRLINE ( DEVICE,
     .      '****************************************'                //
     .      '****************************************'         )

            RETURN

         END IF


         IF ( COUNT  .GT. 1 ) THEN


            IF ( POS .EQ. 1 ) THEN

               CALL SUFFIX (   MODNAM(:LASTNB(MODNAM)) // ' -->'    ,
     .                         0,
     .                         TRACE  )

            ELSEIF (    ( POS .GT.   1    )  .AND.
     .                  ( POS .LT. COUNT  )            )  THEN


               CALL SUFFIX (   MODNAM(:LASTNB(MODNAM)) // ' -->'    ,
     .                         1,
     .                         TRACE  )

            ELSE

               CALL SUFFIX (   MODNAM(:LASTNB(MODNAM)) ,
     .                         1,
     .                         TRACE  )

            END IF

         ELSE IF ( COUNT  .EQ. 1 ) THEN

            TRACE = MODNAM(:LASTNB(MODNAM))

         ELSE

            TRACE = ' '

         END IF

50003 CONTINUE


      RETURN




C$Procedure   FREEZE   ( Get frozen copy of traceback )

      ENTRY  FREEZE

C$ Abstract
C
C     Make a copy of the current traceback.  This copy is
C     frozen, i.e. unchanged, until the next call to FREEZE.
C     DO NOT CALL THIS ROUTINE.
C
C$ Required_Reading
C
C     ERROR
C
C$ Keywords
C
C     ERROR
C
C$ Declarations
C
C     None.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C
C     None.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     None.
C
C$ Parameters
C
C      None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     None.
C
C$ Particulars
C
C     DO NOT CALL THIS ROUTINE.
C
C     When the error response action is 'RETURN', and an error is
C     signalled, a copy of the traceback is saved for later
C     retrieval by the application program.  This is called the
C     "frozen" version of the traceback.  FREEZE is used to create
C     this frozen version.
C
C     This routine is called by the SPICELIB routines SIGERR and RESET.
C     It is unlikely that there should be a need to call it from any
C     other routine.
C
C$ Examples
C
C     DO NOT CALL THIS ROUTINE.
C
C                    C
C                    C     Create a frozen traceback:
C                    C
C
C                          CALL FREEZE
C
C
C$ Restrictions
C
C     DO NOT CALL THIS ROUTINE.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     N.J. Bachman    (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990  (NJB)
C
C-&

C$ Revisions
C
C-    Beta Version 1.0.1, 08-FEB-1989 (NJB)
C
C        Warnings added to discourage use of this routine in
C        non-error-handling code.
C
C-&





C
C     Executable Code:
C


C
C     Create a frozen version of the traceback:
C

      FRZCNT = MODCNT
      FRZSTR = TRCSTR

      RETURN
      END


