C$Procedure            WNELMD ( Element of a DP window )

      LOGICAL FUNCTION WNELMD ( POINT, WINDOW )

C$ Abstract
C
C     Determine whether a point is an element of a double precision
C     window.
C
C$ Required_Reading
C
C     WINDOWS
C
C$ Keywords
C
C     WINDOWS
C
C$ Declarations

      INTEGER               LBCELL
      PARAMETER           ( LBCELL = -5 )

      DOUBLE PRECISION      POINT
      DOUBLE PRECISION      WINDOW      ( LBCELL:* )

C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      POINT      I   Input point.
C      WINDOW     I   Input window.
C
C      The function returns TRUE if POINT is an element of WINDOW.
C
C$ Detailed_Input
C
C      POINT       is a point, which may or may not be contained in
C                  one of the intervals in WINDOW.
C
C      WINDOW      is a window containing zero or more intervals.
C
C$ Detailed_Output
C
C      The function returns TRUE if the input point is an element of
C      the input window---that is, if
C
C            a(i)  <  POINT  <  b(i)
C                  -         -
C
C      for some interval [ a(i), b(i) ] in WINDOW---and returns FALSE
C      otherwise.
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C      None.
C
C$ Examples
C
C      Let A contain the intervals
C
C            [ 1, 3 ]  [ 7, 11 ]  [ 23, 27 ]
C
C      Then the following expressions are true
C
C            WNELMD ( 1, WINDOW )
C            WNELMD ( 9, WINDOW )
C
C      and the following expressions are false.
C
C            WNELMD (  0, WINDOW )
C            WNELMD ( 13, WINDOW )
C            WNELMD ( 29, WINDOW )
C
C$ Exceptions
C
C     None.
C
C$ Files
C
C      None.
C
C$ Restrictions
C
C      None.
C
C$ Literature_References
C
C      None.
C
C$ Author_and_Institution
C
C      H.A. Neilan     (JPL)
C      W.L. Taber      (JPL)
C      I.M. Underwood  (JPL)
C
C$ Version
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (WLT) (IMU)
C
C-&


C$ Revisions
C
C-     Beta Version 1.2.0, 24-FEB-1989  (HAN)
C
C         Added calls to CHKIN and CHKOUT.
C
C-&






C
C     SPICELIB functions
C
      INTEGER               CARDD
      LOGICAL               RETURN

C
C     Local variables
C
      INTEGER               CARD
      INTEGER               I



C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'WNELMD' )
      END IF


C
C     How many endpoints in the window?
C
      CARD = CARDD ( WINDOW )

C
C     Check the point against every interval in the window. Quit if
C     we find an interval that contains it. Inefficient, but it works.
C
      DO 50001
     .   I = 1, CARD, 2

         IF ( POINT .GE. WINDOW(I)  .AND. POINT .LE. WINDOW(I+1) ) THEN
            WNELMD = .TRUE.
            CALL CHKOUT ( 'WNELMD' )
            RETURN
         END IF

50001 CONTINUE

      WNELMD = .FALSE.


      CALL CHKOUT ( 'WNELMD' )
      RETURN
      END
