C========================================================================
C c12_of_geos.f
C------------------------------------------------------------------------
	subroutine C12_of_Geos(x_m,del_g,Dlta_Fc,Dlta_Fa,lon0,c1_g,c2_g,
     1	alpha1,alpha2,ipj,burst_num)
C
C Abstract:
C	Determines the projection coordinates c1_g(.,.), and c2_g(.,.)
C	for the geometric reference points. 
C
	implicit none

C Declarations:
C	Passing Parameters: 

	real x_m(3), del_g, Dlta_Fc, Dlta_Fa, lon0
	real c1_g(3,3), c2_g(3,3), alpha1, alpha2
	integer ipj, burst_num

C	Constant Parameters: None.
C	Include files: None.
C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	x_m		I		position of MRP
C	del_g		I		sample spacing
C	Dlta_Fc		I		framelet size in cross-track dimension
C	Dlta_Fa		I		framelet size in along-track dimensio
C	lon0		I		longitude of oblique sin. origin
C	c1_g, c2_g	O		projection coord. of geometric ref. pts.
C	alpha1, alpha2	I		angles for rotation
C	ipj		I		projection flag
C	burst_num	I		burst counter
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	None.
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	None.
C
C Author and Institution:
C	Michael Jin (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

	real r, lat, lon
	real c1_m, c2_m
	integer i, j

	if(ipj .eq. 1 .or. ipj .eq. 3) then
	call VBF_to_sph(x_m(1),x_m(2),x_m(3),r,lat,lon) !get MRP lat-lon for
c							 sinusoidal projection 
	else

	call VBF_to_qsph(x_m(1),x_m(2),x_m(3),alpha1,alpha2,r,lat,lon)
c		get MRP pseudo lat-lon for oblique sinusoidal projection
	end if

	call sph_to_c12(lat,lon,lon0,c1_m,c2_m,ipj)    !get the projection 
c							coordinates for MRP

d	type *, 'c1_m, c2_m= ', c1_m, c2_m

	c1_g(2,2)=del_g*nint(c1_m/del_g)   !get c1 for the center geo-ref pt
	c2_g(2,2)=del_g*nint(c2_m/del_g)   !get c2 for the center geo-ref pt

	do i=1,3
	do j=1,3

	c1_g(i,j)=c1_g(2,2)+(i-2)*del_g*int((Dlta_Fa/3.)/del_g)   !c1s for all
	c2_g(i,j)=c2_g(2,2)+(j-2)*del_g*int((Dlta_Fc/3.)/del_g)   !c2s for all

	end do
	end do

	return
	end
