C========================================================================
C c12_of_rdiop.f
C------------------------------------------------------------------------
	subroutine c12_of_Rdiop(ipj,irl,rref,fdref,r_rg,fd_rg,mu_g,mu_a,
     1	c1_rg,c2_rg,c1ref,c2ref,burst_num)
C
C Abstract:
C	Computes the projection coordinates c1_rg(.,.) and
C	c2_rg(.,.) for the radiometric reference points based on the
C	range and azimuth resampling coefficients mu_g and mu_a.
C
	implicit none

C Declarations:
C	Passing Parameters: 

	integer ipj, irl, burst_num
	real rref, fdref, r_rg(3,3), fd_rg(3,3), mu_g(3,3), mu_a(3,3)
	real c1_rg(3,3), c2_rg(3,3), c1ref, c2ref

C	Constant Parameters: None.
C	Include files: None.
C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	ipj		I		projection flag
C	irl		I		left- or right- looking
C	burst_num	I		burst counter
C	rref, fdref	I		range & doppler freq. of reference point
C	r_rg, fd_rg	I		range & doppler freq. of radiometric
C					reference points
C	mu_g, mu_a	I		range & azimuth resampling coefficients
C	c1_rg, c2_rg	O		projection coordinates of radiometric
C					reference points
C	c1ref, c2ref	I		projection coordinates of reference pt.
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	None.
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	None.
C
C Author and Institution:
C	Michael Jin (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

	real dr_rg(3,3),dfd_rg(3,3),dc1_rg(3,3),dc2_rg(3,3)
	integer i, j

	do i=1,3
	do j=1,3
	dr_rg(i,j)=r_rg(i,j)-rref
	dfd_rg(i,j)=fd_rg(i,j)-fdref

	call drf_to_dc12(dr_rg(i,j),dfd_rg(i,j),ipj,irl,mu_g,mu_a,
     1	dc1_rg(i,j),dc2_rg(i,j),burst_num)   ! input dr_rg and dfd_rg
c					       output dc1_rg and dc2_rg

 	c1_rg(i,j)=dc1_rg(i,j)+c1ref      ! c1ref is the reference point
 	c2_rg(i,j)=dc2_rg(i,j)+c2ref      ! c2ref is the reference point

	end do
	end do

	return
	end
