C========================================================================
C c12_to_sph.f
C------------------------------------------------------------------------
	subroutine c12_to_sph(c1IN,c2IN,lat,lon,lon0,alpha1,alpha2,ipj)
C
C Abstract:
C	Converts the projection coordinates into the
C	latitude and longitude values. Two projection are available
C	namely the sinusoidal and oblique sinusoidal projections.
C
	implicit none

C Declarations:
C	Passing Parameters: 

	real c1in, c2in, lat, lon, lon0, alpha1, alpha2
	integer ipj

C	Constant Parameters: None.
C	Include files: None.
C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	c1in, c2in	I		c1, c2 coordinates
C	lat, lon	O		latitude & longitude 
C	lon0		I		longitude of oblique sinusoidal origin
C	alpha1
C	alpha2
C	ipj		I		flag for option of projection
C					values of 1 and 3 for sinusoidal proj.
C					values of 2 and 4 for obique sin. proj.
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	None.
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	None.
C
C Author and Institution:
C	Michael Jin (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

	real rv, temp, pi, x, y, z, r
	real c1, c2

	Rv=6051000.

	C1=C1IN		!save the original c1 in c1in
	C2=C2IN		!save the original c2 in c2in

	if(ipj.eq.2 .or. ipj .eq. 4) then  !if oblique sinusoidal then
	temp=c1
	c1=c2
	c2=temp		!swap c1 and c2
	else
	end if

	pi=atan(1.)*4.
	lat=180./pi*c1/Rv
	if(ipj.eq.1 .or. ipj .eq.3) then
	lon=lon0+180./pi*c2/(Rv*cosd(lat))
	if(lon.gt.180) lon=lon-360
	if(lon.lt.-180) lon=lon+360
	else
	lon= 180./pi * ( c2 / (Rv*cosd(lat)) )
	if(lon.gt.180) lon=lon-360
	if(lon.lt.-180) lon=lon+360
	end if

	if (ipj.eq.1 .or. ipj .eq.3) then
	return
	else		!else get real lat-lon for oblique projection case

	call sph_to_VBF(Rv,lat,lon,x,y,z)	!back to rectangular first
	call rotate_y(x,y,z,alpha2,-1.)		!rotate around y by -alpha2
	call rotate_z(x,y,z,alpha1,-1.)		!rotate around z by -alpha1
	call VBF_to_sph(x,y,z,r,lat,lon)	!then get latitude and longitude
	end if

	return
	end
