C========================================================================
C c_85deg.f
C------------------------------------------------------------------------
	SUBROUTINE c_85deg( t_85deg )
C
C Abstract:
C	Finds the time of the burst closest to 85 degrees latitude,
C	and puts the burst number and time into the Per-Orbit file.
C
	implicit none

C Declarations:
C	Passing Parameters: 

	REAL*8		t_85deg

C	Constant Parameters: None.
C	Include files: 

	include '../../../inc/pmc'
	include '../../../inc/po'
	include '../../../inc/pp_time'
	include '../../../inc/pp_bip'

C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	t_85deg		O		time of burst closest to 85deg latitude
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	see include file listing
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	None.
C
C Author and Institution:
C	Cynthia L. Wong (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

	INTEGER*4	i
	LOGICAL*4	done
	REAL*4		delta_before, delta_after


C Start:

D	TYPE *, 'C_85DEG:'


C Do this only if oblique sinusoidal is present:

	IF ( PO_DATA_PROJC_OBL_ST .NE. 0 ) THEN

D	TYPE *, '   Begin DO loop...'
D	TYPE *, '   PO_DATA_PROJC_OBL_ST = ', PO_DATA_PROJC_OBL_ST
D	TYPE *, '   PO_DATA_PROJC_OBL_END = ', PO_DATA_PROJC_OBL_END
D	TYPE *, '   grid_fix_lat = ', grid_fix_lat

		done = .FALSE.
		I = PO_DATA_PROJC_OBL_ST
		DO WHILE ( I .LE. PO_DATA_PROJC_OBL_END
	2		   .AND. .NOT. done )

D	TYPE *, '   DO:  i = ', i
D	TYPE *, '   Done = ', done
D	TYPE *, '   bip_lat = ', pp_bip_bip_lat( i )
D	TYPE *, '   burst_ref = ', pp_time_burst_ref( i )

		IF ( pp_bip_bip_lat( i ) .le. grid_fix_lat ) then

			IF ( I .GT. PO_DATA_PROJC_OBL_ST ) THEN

C	Is this burst or previous burst closer to "grid_fix_lat"?

				delta_before =
	2	ABS( pp_bip_bip_lat( i-1 ) - grid_fix_lat )
				delta_after =
	2	ABS( pp_bip_bip_lat( i ) - grid_fix_lat )

D		TYPE *, '   delta_before = ', delta_before
D		TYPE *, '   delta_after = ', delta_after

				IF ( delta_before
	2				.LE.
	3				delta_after ) THEN

C		Previous burst is closer:

		PO_DATA_PROJP_GRID_FIX_BURST = i - 1
		PO_DATA_PROJP_GRID_FIX_TIME = pp_time_burst_ref( i-1 )

		t_85deg = pp_time_burst_ref( i-1 ) 
	1    		- PO_DATA_ORB_PERIAPSIS_J2000

			ELSE

C		Current burst is closer:

		PO_DATA_PROJP_GRID_FIX_BURST = i
		PO_DATA_PROJP_GRID_FIX_TIME = pp_time_burst_ref( i )
		t_85deg = pp_time_burst_ref( i )
	1    		- PO_DATA_ORB_PERIAPSIS_J2000

			END IF

		ELSE

C		First burst in obl. sin. projection -- use it:


     		PO_DATA_PROJP_GRID_FIX_BURST = i
     		PO_DATA_PROJP_GRID_FIX_TIME = pp_time_burst_ref( i )
		t_85deg = pp_time_burst_ref( i )
	1    		- PO_DATA_ORB_PERIAPSIS_J2000

		END IF

			done = .TRUE.
		END IF

			i = i + 1
	END DO

C	By the way, if we're still NORTH of "grid_fix_lat", use the last
C	obl. sin. burst:

D	TYPE *, '   i = ', i
D	TYPE *, '   Done = ', done

		IF ( I .GT. PO_DATA_PROJC_OBL_END ) THEN

		PO_DATA_PROJP_GRID_FIX_BURST = i - 1
		PO_DATA_PROJP_GRID_FIX_TIME = pp_time_burst_ref( i-1 )
		t_85deg = pp_time_burst_ref( i-1 )
	2   		- PO_DATA_ORB_PERIAPSIS_J2000

		END IF
	END IF


C Done:

D	TYPE *, '   GRID_FIX_BURST = ', PO_DATA_PROJP_GRID_FIX_BURST
D	TYPE *, '   GRID_FIX_TIME = ', PO_DATA_PROJP_GRID_FIX_TIME
D	TYPE *, '   t_85deg = ', t_85deg

D	TYPE *, 'End of C_85DEG.'

	RETURN
	END
