C========================================================================
C c_detproj.f
C------------------------------------------------------------------------
	SUBROUTINE c_detproj( south_pole )
C
C Abstract:
C	Determines the projection of each burst, and
C	saves the starting/ending burst information in the
C	Per-Orbit file.
C
	implicit none

C Declarations:
C	Passing Parameters: 

        integer south_pole	! -1: No OS; 0: North; 1: South

C	Constant Parameters: None.
C	Include files: None.

	include '../../../inc/pmc'
	include '../../../inc/pp_time'
	include '../../../inc/pp_bip'
	include '../../../inc/po'
        include '../../../inc/pc'
	include '../../../inc/sar_stat'

C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	south_pole	I		flag to indicate north,south,or no pole
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	None.
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	None.
C
C Author and Institution:
C	Cynthia L. Wong (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

	INTEGER*4	cur_burst
        integer start_burst, end_burst
        integer num_burst
        integer os_st, os_end

        write (*,*) 'C_DETPROJ:'

C Start:

	IF ( PC_FLAG_START_BURST .LT. 1 .OR.
     .     PC_FLAG_START_BURST .GT. PO_DATA_GEN_N_EDR_BURSTS ) THEN
         start_burst = 1
      else
	START_BURST = PC_FLAG_START_BURST
      endif
	IF ( PC_FLAG_END_BURST .LT. 1 .OR.
     .     PC_FLAG_END_BURST .GT. PO_DATA_GEN_N_EDR_BURSTS ) THEN
	END_BURST = PO_DATA_GEN_N_EDR_BURSTS
      else
	END_BURST = PC_FLAG_END_BURST
      endif

	IF ( PC_FLAG_COLD_SKY .NE. 0 ) THEN
	END_BURST = MIN ( END_BURST, PC_FLAG_START_COLD - 1 )
      endif

C	Find starting sinusoidal burst:

        cur_burst = max( 100, start_burst )

D       write (*,*) 'pp_bip_bip_lat( cur_burst ) = ',
D    .               pp_bip_bip_lat( cur_burst ) 

        DO WHILE ( cur_burst .gt. start_burst .and.
     .            (pp_bip_bip_lat( cur_burst ) .le. 89.0 
     .         .or. sar_stat_anomaly( cur_burst ) .eq. 1 .or.
     .             sar_stat_error( cur_burst ) .eq. 1 ) )
	      cur_burst = cur_burst - 1
        END DO
	if ( pp_bip_bip_lat( cur_burst ) .le. 89.0 ) then
	PO_DATA_PROJC_SIN_ST = CUR_BURST
	else
	PO_DATA_PROJC_SIN_ST = CUR_BURST + 1
	endif

C	Find ending sinusoidal burst:

	CUR_BURST = MAX( END_BURST-100, PO_DATA_PROJC_SIN_ST )
        DO WHILE ( cur_burst .lt. end_burst .and.
     .            (pp_bip_bip_lat( cur_burst ) .ge. -89.0 
     .         .or. sar_stat_anomaly( cur_burst ) .eq. 1 .or.
     .             sar_stat_error( cur_burst ) .eq. 1 ) )
	      cur_burst = cur_burst + 1
        END DO
	if ( pp_bip_bip_lat( cur_burst ) .ge. -89.0 ) then
	PO_DATA_PROJC_SIN_END = CUR_BURST
	else
	PO_DATA_PROJC_SIN_END = CUR_BURST - 1
	endif

	NUM_BURST = PO_DATA_PROJC_SIN_END - PO_DATA_PROJC_SIN_ST
        if ( num_burst .gt. max_nimages_file15 ) then
            write (*,*) 'C_DETPROJ: SIN proj. ends at burst ',
     .                   PO_DATA_PROJC_SIN_END,
     .                   ' (will be cut off)'
	PO_DATA_PROJC_SIN_END = PO_DATA_PROJC_SIN_END -
     .                              num_burst + max_nimages_file15
        endif

        write (*,*) 'Sinusoidal interval (burst):',
     .                   PO_DATA_PROJC_SIN_ST,
     .                   PO_DATA_PROJC_SIN_END

        south_pole = -1

C	Find starting oblique sinusoidal burst (North Pole):

	cur_burst = start_burst

	do while ( cur_burst .LE. end_burst .and.
     .             sar_stat_anomaly( cur_burst ) .eq. 1 .or.
     .             sar_stat_error( cur_burst ) .eq. 1 ) 
            cur_burst = cur_burst + 1
        enddo
        if ( cur_burst .gt. end_burst ) then
            write (*,*) 'All bursts are bad !!!!'
            call exit
        endif

	IF ( pp_bip_bip_lat( cur_burst ) .gt. 80.0 ) then
	PO_DATA_PROJC_OBL_ST = CUR_BURST
	ELSE
	PO_DATA_PROJC_OBL_ST = 0
	END IF


C	Find ending oblique sinusoidal burst:

	IF ( PO_DATA_PROJC_OBL_ST .GT. 0 ) THEN

	DO WHILE ( cur_burst .lt. end_burst .and.
     .            (pp_bip_bip_lat( cur_burst ) .gt. 80.0 
     .         .or. sar_stat_anomaly( cur_burst ) .eq. 1 .or.
     .             sar_stat_error( cur_burst ) .eq. 1 ) )
	      cur_burst = cur_burst + 1
	END DO
	if ( pp_bip_bip_lat( cur_burst ) .gt. 80.0 ) then
	PO_DATA_PROJC_OBL_END = CUR_BURST
	else
	PO_DATA_PROJC_OBL_END = CUR_BURST - 1
	endif

	NUM_BURST = PO_DATA_PROJC_OBL_END - PO_DATA_PROJC_OBL_ST + 1
        if ( num_burst .gt. max_nimages_file13 ) then
            write (*,*) 'C_DETPROJ: OS proj. ends at burst ',
     .                   PO_DATA_PROJC_OBL_END,
     .                   ' (will be cut off)'
	PO_DATA_PROJC_OBL_END = PO_DATA_PROJC_OBL_END -
     .                              num_burst + max_nimages_file13
        endif
        south_pole = 0

        endif

C	Find starting/end oblique sinusoidal burst (South Pole):

	IF ( PO_DATA_PROJC_OBL_ST .LE. 0 ) THEN
         cur_burst = max( end_burst-max_nimages_file13, start_burst )
         DO WHILE ( cur_burst .lt. end_burst .and.
     .            (pp_bip_bip_lat( cur_burst ) .ge. -80.0
     .         .or. sar_stat_anomaly( cur_burst ) .eq. 1 .or.
     .             sar_stat_error( cur_burst ) .eq. 1 ) )
            cur_burst = cur_burst + 1
         END DO
	 if ( pp_bip_bip_lat( cur_burst ) .lt. -80.0 ) then
	PO_DATA_PROJC_OBL_ST = CUR_BURST
	PO_DATA_PROJC_OBL_END = END_BURST

	NUM_BURST = PO_DATA_PROJC_OBL_END - PO_DATA_PROJC_OBL_ST + 1
            if ( num_burst .gt. max_nimages_file13 ) then
                write (*,*) 'C_DETPROJ: OS proj. starts at burst ',
     .                    PO_DATA_PROJC_OBL_ST,
     .                     ' (will be cut off)'
	PO_DATA_PROJC_OBL_ST = PO_DATA_PROJC_OBL_ST +
     .                                 num_burst - max_nimages_file13
            endif
            south_pole = 1
	 else
	PO_DATA_PROJC_OBL_ST = 0
	PO_DATA_PROJC_OBL_END = 0
	 endif

      endif

      write (*,*) 'Oblique sinusoidal interval (burst):',
     .                   PO_DATA_PROJC_OBL_ST,
     .                   PO_DATA_PROJC_OBL_END

C>>  Save the start and end time of oblique sinusoidal bursts

	IF ( PO_DATA_PROJC_OBL_ST .NE. 0 ) THEN

	OS_ST  = PO_DATA_PROJC_OBL_ST
	OS_END = PO_DATA_PROJC_OBL_END

	PO_DATA_PROJP_OBL_ST_TIME = pp_time_burst_start( os_st )
	PO_DATA_PROJP_OBL_END_TIME = pp_time_burst_start( os_end )

      endif

      write (*,*) 'End of C_DETPROJ.'

      RETURN
      END
