C========================================================================
C c_ephemeris.f 
C------------------------------------------------------------------------
	subroutine c_ephemeris( ephem_file, ephem_ascii_file, 
     .				nav_unique_id )
C
C Abstract:
C	Extracts ephemeris data from EDR ephemeris file which contains both 
C	SFDU and ASCII data. Keeps the ASCII ephemeris data for NAV READER.
C	Returns navigation unique ID.
C
	implicit none

C Declarations:
C	Passing Parameters: 

	character*(*) ephem_file, ephem_ascii_file
	character*(*) nav_unique_id

C	Constant Parameters: None.
C	Include files: None.
C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	ephem_file	I		name of EDR ephemeris ascii file
C	ephem_ascii_file  I		name of ephemeris data file 
C					without SFDU in ascii
C	nav_unique_id	O		navigation unique id
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	None.
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	Reads in ephem_file and outputs ephem_ascii_file.
C
C Author and Institution:
C	Cynthia L. Wong (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

	INTEGER*4	in_lun, out_lun
	CHARACTER*8192	cbuf
	INTEGER*4	i, status
	integer itrunc

C Start:

	WRITE (*,*) 'C_EPHEMERIS:'

	CALL get_lun ( in_lun )
	write (*,*) 'Reading ', ephem_file
	OPEN (	unit = in_lun,
	2  		FILE = ephem_file,
	3		status = 'old',
	4		form='formatted',
	5		access = 'sequential',
	8		readonly )

D	type *, 'Starting to search for NAIF...'

	read( in_lun, 100, err=9200, iostat=status ) i, cbuf
100	format ( q, a )

C  search for start of data (skip SFDU header)

	if ( cbuf(i:i) .eq. char( '0D'x  )) then
	   write (*,*) 'CR-LF type'
	   itrunc = 1
	else
	   write (*,*) 'NOT CR-LF type, but found: ', cbuf(i:i)
	   itrunc = 0
	endif

	do while( cbuf(1:10).ne.'''NAIF/DAF''' )
	    read( in_lun, 100, err=9200, iostat=status ) i, cbuf
            if ( index ( cbuf, 'NAV_UNIQUE_ID=' ) ) then
		nav_unique_id( :32) = cbuf(16:)
		WRITE (*,*) nav_unique_id(:32)
            endif
	end do

D	type *, 'Found NAIF info, copying...'

C  Found NAIF/DAF, copy until trailing SFDU

	CALL get_lun ( out_lun )
	write (*,*) 'Writing ', ephem_ascii_file
	OPEN (	unit = out_lun, organization='stream', 
	2	file = ephem_ascii_file,
	3	status = 'unknown', 
	5	access = 'sequential',
	6	form = 'formatted', recordtype='variable',
	7	err = 9000,
	8	iostat = status )

	do while( cbuf(1:4).ne.'CCSD' )
	    write( out_lun, *, err=9300, iostat=status ) cbuf( :i-itrunc )
	    read( in_lun, 100, err=9200, end=8000, iostat=status ) i, cbuf
	end do
8000	continue
	if ( cbuf(1:4) .ne.'CCSD' ) then
	   write (*,*) 'EMARKER not found in ephemeris file'
	endif
	close( unit=in_lun )
	close( unit=out_lun )

        call free_lun ( in_lun )
        call free_lun ( out_lun )

        RETURN

9000	continue
	type *, '   Error creating NAIF ASCII file:', status
	stop

9200	continue
	type *, '   Error reading temporary NAIF file:', status
	TYPE *, '   byte count = ', i
	stop

9300	continue
	type *, '   Error writing to NAIF ASCII file:', status
	stop

	END
