C========================================================================
C c_get_pp_2.f
C------------------------------------------------------------------------
      subroutine c_get_pp_2 ( nb )
C
C Abstract:
C	Reloads data to the local variables
C
	implicit none

C Declarations:
C	Constant Parameters: 

      integer max_rec
      parameter ( max_rec = 8600 ) 

C	Passing Parameters: 

	integer nb
	integer*2 nb2

	byte threshold (24,max_rec)
	common /threshold/ threshold

C	Include files: 

      include '../../../inc/ppp'
      include '../../../inc/temp_pp'
      include '../../../inc/sar_stat'
      include '../../../inc/var_local'

C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	nb		I		burst counter
C
C Constant Parameters:
C	maxrec	- maximum number of burst per orbit
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	see include file listing
C	threshod	I		thresholds for all bursts
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	None.
C
C Author and Institution:
C	Cynthia L. Wong (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

      real pbw_old /0./
      integer last_chk /0/, curr_chk /0/            ! 40% prf
      real dca
      integer i

d     write (*,*) 'C_GET_PP_2: nb = ', nb

	nb2 = nb

C>>  Restore the temp variables

      x_m(1) = temp_pp_x_m(1,nb)
      x_m(2) = temp_pp_x_m(2,nb)
      x_m(3) = temp_pp_x_m(3,nb)

      e(1) = temp_pp_e(1,nb)
      e(2) = temp_pp_e(2,nb)
      e(3) = temp_pp_e(3,nb)

      h(1) = temp_pp_h(1,nb)
      h(2) = temp_pp_h(2,nb)
      h(3) = temp_pp_h(3,nb)

C>>  Set the local variables 

      prf = fs / sar_stat_prf_code(nb)
      np = sar_stat_n_echos(nb)
      ns = 2 * sar_stat_range_gate(nb)
      dca = sar_stat_sar_gain(nb)
      gs_raw = jzext( sar_stat_sar_gain(nb) )

C>>  Restore times

      t_b = pp_time_burst_ref( nb )        ! for pp file and pp computation
      t_d = pp_time_echo_delay( nb )       ! only for pp file
      t_m = pp_time_burst_center( nb )     ! only for pp file

c      t_d = t_m - t_b - ( ns-nrs ) / ( 2.*fs ) 
d      write (*,*) nb, ' t_d = ', t_d,
d    .            pp_time_echo_delay( nb )

C>>  Get data from PBW

      tb_tp = t_b - t_p
d     write (*,*) ' prf=',prf, ' pbw_old=',pbw_old
      call pbw_select ( tb_tp, t_pbw, pbw_in, prf_in, 
     .                  maxcmnd, prf, pbw_old,0 )
d     write (*,*) ' prf=',prf, ' pbw_old=',pbw_old
      pbw = pbw_old * percen
      curr_chk = 0
      if ( pbw .lt. prf*.4 ) then
         pbw = .4 * prf 
         curr_chk = 1
      endif

      if ( last_chk .xor. curr_chk ) then
         if ( .not. last_chk ) then
            write (*,*) 'set pbw to be 40% of prf START burst #', nb
            last_chk = 1 
         elseif ( .not. curr_chk ) then
            write (*,*) 'set pbw to be 40% of prf END burst #', nb-1
            last_chk = 0
         endif
      endif
d     write (*,*) 'percen=',percen, ' pbw=', pbw

C>>  Get data from Telemetry

      th_m = 0.
      do i = 1, 24
         thresh (i) = izext( threshold(i,nb) )
         th_m = max( thresh(i), th_m )
      enddo

C>>  Determine some local variables based on the input parameters

      if ( np .lt. 175 ) then
         na = 1024
      elseif ( np .lt. 350 ) then
         na = 2048 
      elseif ( np .lt. 699 ) then
         na = 4096 
      else
         na = 8192
      endif

      df = prf / na
      s3 = int ( 31*log(th_M+1) / log(127.) ) + 1
      s2 = exp( -s3*log(127.) / 31. )
      gbaq = ( s2*127.) / 1.73

c	This is telemetry code.  See also C_PREPROCESS.

      call get_temps ( t_b )
      call save_to_radiom ( nb2 )

C>>  reload from partial processing parameters

      burst_num = nb 

      x_s(1) = pp_ssp_sc_x_vbf( nb )
      x_s(2) = pp_ssp_sc_y_vbf( nb ) 
      x_s(3) = pp_ssp_sc_z_vbf( nb ) 

      v_s(1) = pp_ssp_sc_vx_vbf( nb )
      v_s(2) = pp_ssp_sc_vy_vbf( nb ) 
      v_s(3) = pp_ssp_sc_vz_vbf( nb ) 

      p(1) = pp_ssp_ubor_x_vbf( nb ) 
      p(2) = pp_ssp_ubor_y_vbf( nb ) 
      p(3) = pp_ssp_ubor_z_vbf( nb ) 

      x_b(1) = pp_bip_bip_x_vbf( nb )
      x_b(2) = pp_bip_bip_y_vbf( nb )
      x_b(3) = pp_bip_bip_z_vbf( nb )
      rapp = pp_bip_bip_app_rg( nb )
      fd_b = pp_bip_bip_fd( nb )
      i_b = pp_bip_bip_inc_ang( nb )

      fd_m = pp_mrp_mrp_fd( nb )
      fr_m = pp_mrp_mrp_fr( nb )
      r_m = pp_mrp_mrp_app_rg( nb )
      i_m = pp_mrp_mrp_incang( nb )

d     write (*,*) 't_b, t_m, t_d = ', t_b, t_m, t_d
d     write (*,*) 'prf,np,na,df,ns,pbw,th_m,gbaq'
d     write (*,*) prf,np,na,df,ns,pbw,th_m,gbaq
d     write (*,*) 'x_m(*)=',x_m
d     write (*,*) 'e(*)=',e
d     write (*,*) 'h(*)=',h
d     write (*,*) 'ipj=',ipj
d     write (*,*) 'x_s(*)=',x_s
d     write (*,*) 'v_s(*)=',v_s
d     write (*,*) 'p(*)=',p
d     write (*,*) 'fd_m=',fd_m,' fr_m=',fr_m, 
d    .            ' r_m=',r_m, ' i_m=',i_m

d     write (*,*) 'End of C_GET_PP_2.'

      return
      end
