C=============================================================================
C c_preprocess.f 
C------------------------------------------------------------------------
	subroutine c_preprocess
C
C Abstract:
C	This is a top level routine of the preprocessing software.
C
	implicit none

C Declarations:
C	Passing Parameters: None.
C	Constant Parameters:

	integer maxburst, os_maxburst, pp_recsiz
	parameter ( maxburst = 8600, os_maxburst = 400 )
	parameter ( pp_recsiz = 1315 )

	byte os_ppbuf( os_maxburst*pp_recsiz )
	byte s_ppbuf( maxburst*pp_recsiz )

	common / os_ppbuf / os_ppbuf
	common / s_ppbuf / s_ppbuf

C	Include files:

	include '../../../inc/b_head_init'
	include '../../../inc/navi3'
	include '../../../inc/pc'
	include '../../../inc/po_init'
	include '../../../inc/rec_count'
	include '../../../inc/sar_stat'
	include '../../../inc/sdmr_init'
	include '../../../inc/sdps_dir_init'
	include '../../../inc/var_local'

C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	None.
C
C Constant Parameters:
C	os_maxburst	-	Maximum number of os bursts per orbit	
C	maxburst	-	Maximum number of sin. bursts per orbit	
C	pp_recsiz	-	length of pp record
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	os_ppbuf	O		pp buffer for oblique sinusoidal proj.
C	s_ppbuf		O		pp buffer for sinusoidal proj.
C	See other include file listing.
C
C Files:
C	None.
C
C Author and Institution:
C	Cynthia L. Wong (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

      integer*4 error
      integer*4 handle
      integer*4 start_burst, end_burst
      integer*4 last_alarm/0/, curr_alarm/0/
      character*80 clock_file, telem_file 
      integer lun, nb, i
      integer south_pole
      integer offset
      real*8  vax2sunr8

	common / pole / south_pole

	include '../../../inc/constant'

      write (*,*) 'C_PREPROCESS:'
      call c_read_recount ( pc_file_temp_rec_count )
D	type *,'finish c_read_recount -----------------'
      call c_wr_bidr_01
D	type *,'finish c_wr_bidr_01 -----------------'

	PO_SFDU_PRIME_TYPE = B_HEAD_BIDR_TYPE
	READ ( B_HEAD_ORBIT, '(I5)') PO_SFDU_ORBIT_NUM
	READ ( B_HEAD_ORBIT, '(I5)') PO_DATA_GEN_ORBIT
	PO_DATA_GEN_PRODUCT_ID = B_HEAD_TYPE // B_HEAD_ORBIT //
     .                         B_HEAD_PERIOD1 // B_HEAD_VERSION
	PO_DATA_GEN_VOL_ID = B_HEAD_TYPE // B_HEAD_EDR_LABEL(2:6)
	PO_DATA_GEN_LOCAL_TIME = B_HEAD_YEAR // B_HEAD_SLASH //
     .                         B_HEAD_DAY // B_HEAD_DASH //
     .                         B_HEAD_HOUR // B_HEAD_COLON1 //
     .                         B_HEAD_MIN // B_HEAD_COLON2 //
     .                         B_HEAD_SEC  // B_HEAD_PERIOD2 //
     .                         B_HEAD_MSEC
	PO_DATA_GEN_NLOOKS = PC_FLAG_SPECIAL_NLOOKS

C>>  Determine some local variable by usign processor configuration file

      ksp = ksp / 2.041737           ! decrease 3.1 db /9/10/90

      write (*,*) 'KSP=', ksp

	I_PROCESS = PC_FLAG_COLD_SKY
      IR_pass = 0
      percen = 1.

	IF ( PC_FLAG_SPECIAL_PROD )
     .   write (*,'(/,a,/)') ' SPECIAL PROCESSING OPTION'

      nav_source = 1
	IF ( PC_FLAG_SPECIAL_PROD ) THEN

	IF ( PC_FLAG_SPECIAL_KEPLERIAN .EQ. 1 ) THEN
            write (*,*) 'SPECIAL PROCESSING (keplerian)'
            nav_source = 2
	ELSEIF ( PC_FLAG_SPECIAL_TV_KEPLERIAN .EQ. 1 ) THEN
            nav_source = 3
         endif

      endif
      write (*,*) 'NAV_SOURCE = ', nav_source

	IF ( PC_FLAG_SPECIAL_PROD .EQ. 1 ) THEN

	IF ( PC_FLAG_SPECIAL_RAD_BYPASS .EQ. 1 ) THEN
	IR_PASS = PC_FLAG_SPECIAL_RAD_BYPASS
            write (*,*) 'By pass radiometric correction', IR_pass
         endif

	IF ( PC_FLAG_SPECIAL_A_PAT .EQ. 1 ) THEN
	READ ( PC_FLAG_SPECIAL_A_PAT_X_SKEW, * ) D_ANGLK
            write (*,*) 'Delta look angle=', d_anglk
         endif

	IF ( PC_FLAG_SPECIAL_PBW .EQ. 1 ) THEN
	READ ( PC_FLAG_SPECIAL_BANDWIDTH_PC, * ) PERCEN
            percen = percen / 100.
            write (*,*) 'Special pbw factor = ', percen
         endif

	IF ( PC_FLAG_SPECIAL_NLOOKS .GT. 0 ) THEN
	MAX_LK = PC_FLAG_SPECIAL_NLOOKS - 1
	MIN_LK = PC_FLAG_SPECIAL_NLOOKS - 1
            write (*,*) 'Nlooks = ', min_lk, max_lk
         endif

	IF ( PC_FLAG_MIN_SWATH .GT. 0 ) THEN
	WRITE (*,*) 'MINIMUM SWATH (KM) = ', PC_FLAG_MIN_SWATH
         endif

      endif

C>>  Extract Orbit Header Information

      if ( pc_flag_special_prod .and. 
     .	   pc_flag_special_edr_clock ) then
          clock_file = pc_file_special_clock 
      else
          clock_file = pc_file_edr_clock 
      endif

      if ( pc_flag_special_prod .and. 
     .     pc_flag_special_edr_orb_head ) then
           call c_orbit_hdr( pc_file_special_orb_head, clock_file )
      else
	   call c_orbit_hdr( pc_file_edr_orb_head, clock_file )
      endif
      T_P = PO_DATA_ORB_PERIAPSIS_J2000
      write (*,*) 'Time periapsis (TDB(ET)): ', t_p
      WRITE (*,*) 'TOTAL OF EDR BURSTS: ', PO_DATA_GEN_N_EDR_BURSTS

C>>  Limit total # of edr bursts to be the maximum

	IF ( PO_DATA_GEN_N_EDR_BURSTS .GT. MAXBURST )
     .       PO_DATA_GEN_N_EDR_BURSTS = MAXBURST

C>>  Extract SAB Header Information

      if ( pc_flag_special_prod .and. 
     .	   pc_flag_special_edr_sar_head ) then
           call c_sab_hdr( error, pc_file_special_sar_head )
      else
	   call c_sab_hdr( error, pc_file_edr_sar_head )
      endif

C>>  Map Out the bursts selected by user

      call get_lun( lun )
      write (*,*) 'Opening ', pc_file_param_skip_burst
      open ( unit=lun, file=pc_file_param_skip_burst, form='formatted',
     .       readonly, err=599, status='old' )
600   read ( lun,*,err=599,end=599 ) nb
      write (*,*) 'User selects to skip burst #', nb
	IF ( NB. GT. 0 .AND. NB .LE. PO_DATA_GEN_N_EDR_BURSTS )
     .       sar_stat_error( nb ) = 1
      goto 600
599   close ( lun )
      call free_lun( lun )

C>>  Compute Times

      call c_times
      write (*,*) 'Pass SAB_header & Times Computation...'

C>>  Read Model Files

      call read_models
      write (*,*) 'Pass loading the model files...'

      if ( nav_source .eq. 3 ) then
	T_P = NAVI3_TP
         write (*,*) 'Time periapsis (NAV3): ', t_p
      endif

C>>  Initialize NAV1

      if ( pc_flag_special_prod .and.
     .	   pc_flag_special_edr_ephemeris ) then
         call c_ephemeris( pc_file_special_ephemeris, 
     .		 	   pc_file_temp_ephem_ascii, 
     .			   po_data_gen_ephemeris_id )
      else
         call c_ephemeris( pc_file_edr_ephemeris, 
     .			   pc_file_temp_ephem_ascii, 
     .			   po_data_gen_ephemeris_id )
      endif
      CALL NAV1_INIT( pc_file_temp_ephem_ascii, 
     .		      pc_file_temp_ephem_bin, 
     .		      pc_file_param_leapsecondsker, t_p, handle )
      write (*,*) 'Pass Ephemeris Computation..handle=', handle

C>>  Get PBW and MQPC files

	IF ( PC_FLAG_SPECIAL_PROD .AND.
     .       PC_FLAG_SPECIAL_EDR_PBW ) THEN 
	CALL PBWDAT( PC_FILE_SPECIAL_PBW )
      else
	CALL PBWDAT( PC_FILE_EDR_PBW )
      endif
      write (*,*) 'Pass PBWDAT...'

	IF ( PC_FLAG_SPECIAL_PROD .AND.
     .       PC_FLAG_SPECIAL_EDR_POINTING ) THEN 
	CALL MQPCDAT( PC_FILE_SPECIAL_POINTING )
      else
	CALL MQPCDAT( PC_FILE_EDR_POINTING )
      endif
      if ( irl .eq. 1 ) then
         write (*,*) 'RIGHT LOOKING ORBIT'
      else
         write (*,*) 'LEFT LOOKING ORBIT'
      endif
      write (*,*) 'Pass MQPCDAT...'

C>>  Compute Reference Meridians

      call meridian(nav_source,lon0,t_p,handle)
      call Tp_search(handle)
      write (*,*) 'Pass REF_MERIDIAN..'

C>>  Interpolate Telemetry 

      if ( pc_flag_special_prod .and.
     .	   pc_flag_special_edr_telemetry ) then
	 telem_file = pc_file_special_telemetry
      else
	 telem_file = pc_file_edr_telemetry 
      endif
      if ( pc_flag_special_prod .and.
     .	   pc_flag_special_edr_decom_cal ) then
         call tlmf ( pc_file_special_decom_cal,
     .               telem_file )
      else
         call tlmf ( pc_file_edr_decom_cal,
     .               telem_file )
      endif
      write (*,*) 'Pass TLMF..'

      if ( pc_flag_quat_usage .eq. 0 ) then
         call get_dqs  ! get delta quaternion
         write (*,*) 'Pass GET_DQS..'
      end if

C>>  Compute Start/End burst      !clw/07-01-90/

	IF ( PC_FLAG_START_BURST .LT. 1 .OR.
     .     PC_FLAG_START_BURST .GT. PO_DATA_GEN_N_EDR_BURSTS ) THEN
         start_burst = 1
      else
	START_BURST = PC_FLAG_START_BURST
      endif
	IF ( PC_FLAG_END_BURST .LT. 1 .OR.
     .     PC_FLAG_END_BURST .GT. PO_DATA_GEN_N_EDR_BURSTS ) THEN
	END_BURST = PO_DATA_GEN_N_EDR_BURSTS
      else
	END_BURST = PC_FLAG_END_BURST
      endif

	IF ( PC_FLAG_COLD_SKY .NE. 0 ) THEN
	END_BURST = MIN ( END_BURST, PC_FLAG_START_COLD - 1 )
      endif

      write (*,*) 'Starting Preprocessing Computation Part 1 '
      write (*,*) '   from burst ', start_burst, ' to ', end_burst

      do i = start_burst, end_burst

         if ( mod(i,1000) .eq. 0 ) then
            write (*,*) i, ' bursts processed.'
         endif

         if ( sar_stat_anomaly( i ) .eq. 1 .or.
     .        sar_stat_error( i ) .eq. 1 ) goto 100

         call c_get_pp (i)

C>>  Compute S/C state

         call sc_state( handle )

C>>  Compute Pointing Parameters

         call pointing_vectors

C>>  Compute BIP Parameters

         call BIP_parameters ( error )
         if ( error .eq. 1 ) then
            type *, 'Look angle too large (burst,angle)=', i, ang_lk
            sar_stat_error( i ) = 1
            goto 100
         endif

C>>  Check Radar Echo Window Position

         call check_1 (Rapp,tm_tb,Dt_v_1way,cspeed,
     .                 fs,r_off_bound,alarm)
         curr_alarm = int (alarm)
         if ( last_alarm .xor. curr_alarm ) then
            if ( .not. last_alarm ) then
               write (*,*) 'Alarm (MRP-BIP) starts at burst ', i
               last_alarm = 1
            elseif ( .not. curr_alarm ) then
               write (*,*) 'Alarm (MRP-BIP) ends   at burst ', i
               last_alarm = 0
            endif
         endif

         call MRP_parameters

100      call c_dmp_pp (i)

      enddo

      write (*,*) 'Pass Preprocessing Computation Part 1'

      i = start_burst
      do while ( i .le. end_burst .and.
     .           ( sar_stat_anomaly( i ) .eq. 1 .or.
     .             sar_stat_error( i ) .eq. 1 ) )
    	 i = i + 1
      enddo
      if ( i .ne. start_burst ) then
	PC_FLAG_START_BURST = I
	PC_FLAG_END_BURST = END_BURST
	WRITE (*,*) 'REVISE BURST RANGE FROM ', PC_FLAG_START_BURST,
     .               ' TO ', PC_FLAG_END_BURST
      endif

C>>  Determine Projections

      call c_detproj( south_pole )

	IF ( PO_DATA_PROJC_OBL_ST .NE. 0 ) THEN

C	Find burst nearest 85 degrees latitude:

		CALL c_85deg( t_85deg )
		write (*,*) 'Pass C_85DEG...'

C	Get angles for the oblique sinusoidal coordinates:

		CALL alpha12( handle )
		write (*,*) 'Pass ALPHA12...'

		if ( south_pole .eq. 1 ) then
		   ipj = 4
		   offset = 1
		   call c_pp_2( po_data_projc_obl_st,
	1			po_data_projc_sin_end, 
	2			os_ppbuf(offset) )
		   if ( po_data_projc_obl_end .gt. 
	1		po_data_projc_sin_end ) then
		      ipj = 2
		      offset = (po_data_projc_sin_end -
	1			po_data_projc_obl_st + 1) * pp_recsiz
	2			+ 1
		      call c_pp_2( po_data_projc_sin_end+1,
	1	   	   	   po_data_projc_obl_end, 
	2			   os_ppbuf(offset) )
		   endif
		else
		   offset = 1
		   if ( po_data_projc_obl_st .lt. 
	1		po_data_projc_sin_st ) then
		      ipj = 2
		      call c_pp_2( po_data_projc_obl_st,
	1			   po_data_projc_sin_st-1,
	2			   os_ppbuf(offset) )
		      offset = (po_data_projc_sin_st -
	1			po_data_projc_obl_st) * pp_recsiz + 1 
		   endif
		   ipj = 4
		   call c_pp_2( po_data_projc_sin_st,
	1			po_data_projc_obl_end,
	2			os_ppbuf(offset) )
		endif
	END IF

      call c_po

      offset = 1
      if ( south_pole .lt. 0 ) then
	 ipj = 1
      	 call c_pp_2( po_data_projc_sin_st, po_data_projc_sin_end,
	1	      s_ppbuf(offset) )
      elseif ( south_pole .eq. 0 ) then
   	 ipj = 3
   	 call c_pp_2( po_data_projc_sin_st, po_data_projc_obl_end,
	1		s_ppbuf(offset) )
	 ipj = 1
	 offset = (po_data_projc_obl_end - po_data_projc_sin_st + 1)
	1	  * pp_recsiz + 1
	 call c_pp_2( po_data_projc_obl_end+1, po_data_projc_sin_end,
	1		s_ppbuf(offset) )
      else
   	 ipj = 1
   	 call c_pp_2( po_data_projc_sin_st, po_data_projc_obl_st-1,
	1		s_ppbuf(offset) )
	 ipj = 3
	 offset = (po_data_projc_obl_st - po_data_projc_sin_st) 
	1	  * pp_recsiz + 1
	 call c_pp_2( po_data_projc_obl_st, po_data_projc_sin_end,
	1		s_ppbuf(offset) )
      endif

      call c_data_gap
      call c_gen_sdmr
      call c_sdps_dir

      call c_set_cs_telem
      call c_gen_radiom( handle )

      write (*,*) 'End of C_PREPROCESS.'
      return
      end
