C========================================================================
C c_sclk_scet.f
C	contains subroutines c_sclk_scet & c_get_clock.
C------------------------------------------------------------------------
      subroutine c_sclk_scet( filename )
C
C Abstract:
C	Computes parameters in TIMEC common block
C
	implicit none

C Declarations:
C	Passing Parameters: 

	character*(*) filename

      character*19 s_time             ! First SAB SCET
      character*82 clock              ! SCLK/SCET coefficients record
      common /get_clock/ s_time, clock

C	Constant Parameters: 

      real*8 J2000
      parameter ( j2000=2451545.d0 )

      byte   CUTOFF
      parameter ( cutoff=80 )

C	Include files: 

      include '../../../inc/po'                     ! per orbit
      include '../../../inc/timec'                  ! time conversion

C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	filename	I		filename of SCLK/SCET file
C
C Constant Parameters:
C	j2000 - seconds in year 2000 ET.
C	CUTOFF - last 2 digits of cutoff year
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	see include file listing
C	get_clock	I		clock parameters returned 
C					from c_get_clock routine
C	
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	see above
C
C Files:
C	None.
C
C Author and Institution:
C	Cynthia L. Wong (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:


      integer*4 rim, mod91, mod10, mod8
      integer*4 year, doy, days
      integer*4 hour, min
      real*4 sec, delta
      real*4 a0_fracsec, a0_days

C>>  Variables for BUFHANDLER

      integer*4 filesiz /0/                   ! used to OPENQIO
      integer*4 channel                       ! channel linked to file
      integer*4 lun                           ! logical unit of file
      integer*4 clockrec /300/                ! sclk/scet max records
      integer*4 reclng /82/                   ! sclk/scet record length
      integer*4 rec_os /0/                    ! records to skip
      integer*4 sfdu_len                      ! length of sfdu of EDR file
      common /sfdu_len/ sfdu_len
      external c_get_clock
      external c_get_sfdu_len
      integer initdk

      integer*4 error

      write (*,*) 'C_SCLK_SCET:'

C>>  Extract SCLK/SCET coefficients

      call get_lun( lun )
      WRITE (*,*) 'Reading (EZIO) ', filename
      CHANNEL = INITDK ( LUN, filename )
      if ( channel.le.0 ) then
         write (*,*) 'C_SCLK_SCET: OPEN error'
         return
      endif
      call bufhandler (1, 20, channel, 0, 0, 0, c_get_sfdu_len, error)
      call bufhandler ( clockrec, reclng, channel, 0,
     .                  sfdu_len, rec_os, c_get_clock, error )
      if ( error.eq.1 ) then
         write (*,*) 'C_SCLK_SCET: BUFHANDLER error'
         return
      endif
      call closedk( lun, channel)
      call free_lun ( lun )

C>>  Start Computation

D     write (*,*) clock (1:80)

	PO_DATA_TIME_SCLK0 = CLOCK(2:14)
	PO_DATA_TIME_A1 = CLOCK(43:54)
	PO_DATA_TIME_A0 = CLOCK(16:34)
	PO_DATA_TIME_DUT = CLOCK(36:41)

D	WRITE (*,*) PO_DATA_TIME_SCLK0, PO_DATA_TIME_A1,
D	.            PO_DATA_TIME_A0, PO_DATA_TIME_DUT

	READ ( PO_DATA_TIME_DUT, '(F6.3)' ) TIMEC_DUT
	READ ( PO_DATA_TIME_A1, '(F12.9)' ) TIMEC_A1

D	WRITE (*,*) TIMEC_DUT, TIMEC_A1

	READ ( PO_DATA_TIME_SCLK0(1:8), '(I8)' ) RIM
	READ ( PO_DATA_TIME_SCLK0(10:11), '(I2)' ) MOD91
	READ ( PO_DATA_TIME_SCLK0(13:13), '(I1)' ) MOD10
	TIMEC_RIM_SCLK0 = RIM + MOD91 / 91.0D0 + MOD10 / 910.0D0

D     write (*,*) rim, mod91, mod10
D	WRITE (*,*) TIMEC_RIM_SCLK0

	READ ( PO_DATA_TIME_A0(1:2), '(I2)' ) YEAR
	READ ( PO_DATA_TIME_A0(4:6), '(I3)' ) DOY
	READ ( PO_DATA_TIME_A0(8:9), '(I2)' ) HOUR
	READ ( PO_DATA_TIME_A0(11:12), '(I2)' ) MIN
	READ ( PO_DATA_TIME_A0(14:19), '(F6.3)') SEC

D     write (*,*) year, doy, hour, min, sec

      if ( year.gt.CUTOFF ) then
         year = year + 1900
      else
         year = year + 2000
      endif
      days = int( (year+4712) * 365.25 + 0.75 ) - 13 + doy - 1
      if ( hour.ge.12 ) then
         hour = hour - 12
      else
         hour = hour + 12
         days = days - 1
      endif

D     write (*,*) year, days, hour

	A0_FRACSEC = HOUR*3600 + MIN*60 + SEC + TIMEC_DUT
      a0_days = days - J2000
	TIMEC_A0_SECONDS = A0_DAYS * 86400.0D0 + A0_FRACSEC

D     write (*,*) a0_fracsec, a0_days
D	WRITE (*,*) TIMEC_A0_SECONDS

      write (*,*) 'End of C_SCLK_SCET:'

      return
      end

C=============================================================================
C>>  C_GET_CLOCK - CONTROL subroutine to extract sclk/scet coefficients info.
C>>
C>>  ** /clw/7-7-89/ **
C=============================================================================
C>>
      subroutine c_get_clock ( buf, nrec )

      implicit none

C>>  Passing parameter

      byte buf(1)
      integer*4 nrec

C>>  Input/output from common block

      character*19 s_time
      character*82 clock
      common /get_clock/ s_time, clock

C>>  Variables

      integer reclng /82/            ! record length
      integer buf_ptr
      integer status

D     write (*,*) 'C_GET_CLOCK: start time: ', s_time
D     write (*,*) 'nrec=', nrec

      buf_ptr = 1
      clock( 1:reclng ) = '$$$$$'

D     write (*,*) 'beginning of the search for $$EOH..'

      do while ( clock(1:5) .ne. '$$EOH' )
         decode (82,'(a82)',buf(buf_ptr),iostat=status) clock
         buf_ptr = buf_ptr + reclng
      enddo

D     write (*,*) 'beginning of the search for time..'

      do while ( clock(1:5).ne.'$$EOF' .and.
     .           s_time .ge. clock(16:34) )
         decode (82,'(a82)',buf(buf_ptr),iostat=status) clock
         buf_ptr = buf_ptr + reclng
      enddo

C      if ( clock(1:5) .eq. '$$EOF' ) then
         buf_ptr = buf_ptr - 2*reclng
         decode (82,'(a82)',buf(buf_ptr),iostat=status) clock
C      endif

      write (*,*) 'End of C_GET_CLOCK.'

      return
      end
