C========================================================================
C c_times.f
C------------------------------------------------------------------------
      subroutine c_times
C
C Abstract:
C	Uses the 52-bit time tags to compute time parameters.
C
	implicit none

C Declarations:
C	Passing Parameters: None.
C	Constant Parameters: 

      integer*4 maxrec
      integer*4 cr_cs_offset 
      integer*4 cs_dur       
      integer*4 prf_arpo_offset 
      integer*4 pw              
      real*8 zrcf            
      real*8 stalo           
      real*8 res_clk         
      parameter (maxrec = 8600)
      parameter (cr_cs_offset = 7)
      parameter (cs_dur = 453 )
      parameter (prf_arpo_offset = 10)
      parameter (pw = 60)
      parameter (zrcf = 1.9918D-6)             ! 9/7/90
      parameter (stalo = 72.272727D6)
      parameter (res_clk=32./stalo)

C	Include files: 

      include '../../../inc/pp_time'
      include '../../../inc/po'
      include '../../../inc/sar_stat'
      include '../../../inc/timec'
      include '../../../inc/radiom'

C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	None.
C
C Constant Parameters:
C      maxrec - maximum number of bursts
C      cr_cs_offset - offset between Cycle Reset and Cycle start
C      cs_dur       - Cycle Start duration
C      prf_arpo_offset - offset between PRF rising edge and Actual
C      pw              - pulse width
C      zrcf            - Zero-range correction factor
C      stalo           - stalo frequency in Hz
C      res_clk         - MGN fine resolution clock interval
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	see include file listing
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	None.
C
C Author and Institution:
C	Cynthia L. Wong (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

      integer i                  ! scratch index
      integer*4 RIM              ! RIM count
      integer*4 NA               !
      real*8 CR_rim              ! cycle reset RIM
      real*8 CR_tdb              ! cycle reset in tdb
      real*8 t0                  ! cycle reset to arpo
      real*8 TD_sec              ! transmission duration in seconds
      real*8 RD_sec              ! receive duration in seconds
      real*8 drad                ! delta rad

      write (*,*) 'C_TIMES:'
	WRITE (*,*) '# OF BURSTS=',PO_DATA_GEN_N_EDR_BURSTS

	DO I = 1, PO_DATA_GEN_N_EDR_BURSTS

D        write (*,*)
D        write (*,*) 'Burst # ', i

C>>  compute Cycle Reset in TDB seconds since J2000 (double precision)

         RIM = jishft(
     .            jzext( sar_stat_time_tag_rim(1,i) ), 16 )
     .        .or. jishft (
     .            jzext( sar_stat_time_tag_rim(2,i) ), 8  )
     .        .or.jzext( sar_stat_time_tag_rim(3,i) )

D        write (*,*) 'RIM=',rim

c ---------------------------------
c Lawrence Chen 12/21/93
c Since the current Sun's Fortran Complier can not
c automatically change byte data to real in arithmetic
c operation.  We need to modify the statement

c         CR_rim = RIM + sar_stat_time_tag_Mod91(i) / 91.0D0
c     . 		      + sar_stat_time_tag_Mod10(i) / 910.0D0
c     . 		      + sar_stat_time_tag_Mod210(i) / 191100.0D0

	 CR_rim = RIM + real(sar_stat_time_tag_Mod91(i)) / 91.0D0
     .                + real(sar_stat_time_tag_Mod10(i)) / 910.0D0
     .                + real(sar_stat_time_tag_Mod210(i)) / 191100.0D0

c ^ --- End of Modification

D        write (*,*) 'CR_rim=',cr_rim

	CR_TDB = (CR_RIM - TIMEC_RIM_SCLK0) * TIMEC_A1
     .                + TIMEC_A0_SECONDS

D        write (*,*) 'CR_tdb=',cr_tdb

C>>  compute t0 (Cycle Reset to ARPO)

         t0 = (- cr_cs_offset + cs_dur + sar_stat_PRF_code(i) - 1
     .             + prf_arpo_offset) * res_clk

D        write (*,*) 't0', t0

C>>  compute burst start time in TDB seconds

  	 pp_time_burst_start( i ) = CR_tdb +
     .                                        t0 + (zrcf / 2.d0)

C>>  compute transmission duration in seconds

         TD_sec = ( float(sar_stat_n_echos(i) - 1)
     .              * sar_stat_PRF_code(i) ) * res_clk

D        write (*,*) 'TD_sec=',TD_sec

C>>  compute burst reference time in TDB seconds since J2000

         pp_time_burst_ref( i ) =
     .       pp_time_burst_start( i ) + (TD_sec / 2.d0)

C>>  compute receive duration in seconds

         RD_sec = ( float(sar_stat_n_echos(i) - 1)
     .                   * sar_stat_PRF_code(i)
     .              + ( 2.d0 * sar_stat_range_gate(i) ) - pw )
     .		    * res_clk

D        write (*,*) 'RD_sec=', rd_sec

C>>  compute echo delay time in seconds

 	 pp_time_echo_delay( i ) =
     .       ( float( sar_stat_coarse_res(i) ) * sar_stat_PRF_code(i)
     .       + sar_stat_fine_res(i) - 9 )
     .       * res_clk - zrcf

C>>  compute burst center time in TDB seconds since J2000

         pp_time_burst_center( i ) =
     .       pp_time_burst_start( i ) +
     .       pp_time_echo_delay( i ) + (RD_sec / 2.d0)

C>>  compute radiometer time

        NA = int ( ( 1 + sar_stat_PRF_code(i) *
     .               ( jzext( sar_stat_n_echos(i) ) +
     .                 sar_stat_coarse_res(i) ) ) / 151. ) + 1

D       write (*,*) 'NA = ', NA

        drad = 151 * ( NA + 62 + sar_stat_alt_coarse_res(i) )

D       write (*,*) 'delta rad = ', drad

        radiom_rad_time(i) = CR_tdb + res_clk *
     .                       ( -cr_cs_offset + cs_dur + drad )

      enddo

      write (*,*) 'End of C_TIMES.'

      return
      end
