C========================================================================
C c_wr_bidr_01.f
C------------------------------------------------------------------------
      subroutine c_wr_bidr_01
C
C Abstract:
C	Writes the BIDR header record onto disk
C
	implicit none

C Declarations:
C	Passing Parameters:

      character*8 date
      common / proc_date / date

C	Constant Parameters: 

      integer*4 bidr_reclen  
      integer edr_reclen
      parameter ( bidr_reclen = 32500 )
      parameter ( edr_reclen=32500 )

C	Include files: 

      include '../../../inc/pc'
      include '../../../inc/b_head'

C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C
C Constant Parameters:
C	bidr_reclen - record length of bidr file
C	edr_reclen  - record length of edr file
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	pc		I		names and flags of processor config.
C	bidr		O		stores bider header parameters.
C	proc_date	O		processing date
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	Write BIDR header record file.
C
C Author and Institution:
C	Cynthia L. Wong (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

      character*23 date_time
      integer*4 c_to_doy, doy      ! external routine to convert
      external c_to_doy            ! calender date to day of year

      character*3 month (12)
     .       /'JAN','FEB','MAR','APR','MAY','JUN',
     .        'JUL','AUG','SEP','OCT','NOV','DEC'/

      byte edr_head(edr_reclen)
      character*32500 edr_head_str
      equivalence ( edr_head(1), edr_head_str )

      character*30 ver_str

      integer i, j, k      ! scratch indices
      integer lun, chan, status

c ---------------------------------
c Lawrence Chen 12/21/93
c subroutine which passed by reference does not need
c declase routine's type in Sun Fortran
c      integer*4 initdk, closedk    ! external routine to open or close
      integer*4 initdk		   ! L. Chen
      external initdk, closedk     ! a file ( EZIO )

      write (*,*) 'C_WR_BIDR_01:'

      write (*,*) 'Reading( EZIO ) ', pc_file_edr_vol_head
      call get_lun( lun )
      CHAN = INITDK( LUN, PC_FILE_EDR_VOL_HEAD )
      call dkread( chan, edr_head(1), edr_reclen, 1 )
      call closedk( lun, chan )
      call free_lun( lun )

C>>  Create BIDR header
C>>  Assign minor data product ID

	B_HEAD_TYPE = ' '
      i = index( edr_head_str, 'DATA_OBJECT_TYPE=' )

	IF ( PC_FLAG_TEST .OR. PC_FLAG_CHECK ) THEN
	B_HEAD_TYPE = 'U'
	ELSEIF ( PC_FLAG_SPECIAL_PROD ) THEN
	B_HEAD_TYPE = 'S'
      elseif ( index( edr_head_str(i+17:), 'SAR_XEDR') ) then
	B_HEAD_TYPE = 'X'
      elseif ( index( edr_head_str(i+17:), 'SAR_TEDR') ) then
	B_HEAD_TYPE = 'T'
      else
	B_HEAD_TYPE = 'F'
      endif

C>>  Assign source EDR

      if ( index( edr_head_str(i+17:),'SAR_EDR') ) then
	B_HEAD_EDR_LABEL(1:1) = 'S'
      elseif ( index( edr_head_str(i+17:),'SAR_UEDR') ) then
	B_HEAD_EDR_LABEL(1:1) = 'U'
      elseif ( index( edr_head_str(i+17:), 'SAR_XEDR') ) then
	B_HEAD_EDR_LABEL(1:1) = 'X'
      elseif ( index( edr_head_str(i+17:), 'SAR_TEDR') ) then
	B_HEAD_EDR_LABEL(1:1) = 'T'
      endif

      i = index( edr_head_str, 'ORBIT_NUMBER=' )
	B_HEAD_ORBIT = EDR_HEAD_STR( I+13:I+17)

	WRITE ( B_HEAD_VERSION, '(I2.2)') PC_FLAG_RELEASE_NUM

C>>  Assign tape write time

                                                !  123456789 123456789 123
      call get_date_time ( date_time )          ! "dd-mmm-yyyy hh:mm:ss.ss"
	B_HEAD_YEAR = DATE_TIME(10:11)

      i = 0
      do while ( i .lt. 12 .and.
     .           date_time(4:6) .ne. month (i+1) )
         i = i + 1
      enddo
      write ( date (1:2), '(i2.2)' ) i+1

      if ( date_time (1:1) .eq. ' ' ) then
         date (3:5) = '/0' // date_time (2:2)
      else
         date (3:5) = '/' // date_time (1:2)
      endif
      date (6:8) = '/' // date_time(10:11)

      doy = c_to_doy ( date )
	WRITE ( B_HEAD_DAY, '(I3.3)' ) DOY

	B_HEAD_HOUR = DATE_TIME(13:14)
	B_HEAD_MIN  = DATE_TIME(16:17)
	B_HEAD_SEC  = DATE_TIME(19:20)
	B_HEAD_MSEC = DATE_TIME (22:23) // '0'

C>>  Assign tape creator version codes

      call get_lun( lun )
      write (*,*) 'Reading ', pc_file_param_version 
      open(	unit=lun,
     .          file = pc_file_param_version,
     .          access = 'sequential',
     .          form = 'formatted',
     .          recordtype = 'variable',
     .          status = 'old' )

      read ( lun,'(a)' ) ver_str      ! hardware version
	B_HEAD_HVER = VER_STR(27:30)
      read ( lun, '(a)' ) ver_str      ! sofeware version
	B_HEAD_SVER = VER_STR(27:30)

      close (lun)
      call free_lun ( lun )

C>>  Assign tape creator method

	IF ( B_HEAD_TYPE .EQ. 'F' .OR.
     .     B_HEAD_TYPE .EQ. 'T' .OR.
     .     B_HEAD_TYPE .EQ. 'X' .OR.
     .     B_HEAD_TYPE .EQ. 'S' ) THEN
	B_HEAD_CMETHOD = 'OFFLINE'
      else
	B_HEAD_CMETHOD = 'TEST   '
      endif

	READ ( B_HEAD_ORBIT, '(I5)' ) I
	WRITE ( B_HEAD_EDR_LABEL(2:5), '(Z4.4)' ) I

      i = index( edr_head_str, 'VERSION_ID=')
      read ( edr_head_str(i+11:i+12), '(i2)' ) j
	WRITE ( B_HEAD_EDR_LABEL(6:6), '(Z1.1)') J

C>>  Assign product name

	IF ( B_HEAD_TYPE .EQ. 'F' ) THEN
	B_HEAD_BIDR_NAME = 'F-BIDR '
      else
	B_HEAD_BIDR_NAME = 'F-' // B_HEAD_TYPE // 'BIDR'
      endif

C>>  Assign product type

	IF ( B_HEAD_TYPE .EQ. 'F' ) THEN
	B_HEAD_BIDR_TYPE = '104'
	ELSEIF ( B_HEAD_TYPE .EQ. 'T' ) THEN
	B_HEAD_BIDR_TYPE = '105'
	ELSEIF ( B_HEAD_TYPE .EQ. 'S' ) THEN
	B_HEAD_BIDR_TYPE = '106'
	ELSEIF ( B_HEAD_TYPE .EQ. 'X' ) THEN
	B_HEAD_BIDR_TYPE = '107'
	ELSEIF ( B_HEAD_TYPE .EQ. 'U' ) THEN
	B_HEAD_BIDR_TYPE = '108'
      endif

C>>  Write BIDR

      write (*,*) 'Writing (EZIO) ', pc_file_bidr_header
      call get_lun ( lun )
      CHAN = INITDK ( LUN, PC_FILE_BIDR_HEADER )
      call dkwrit ( chan, b_head, bidr_reclen, 1 )
      call closedk( lun, chan )
      call free_lun ( lun )

      return
      end
