C========================================================================
C c_write_rad.f
C------------------------------------------------------------------------
	SUBROUTINE c_write_rad( buf, nbytes, channel, block )
C
C Abstract:
C	Writes out the radiometer or the cold sky files.
C
	implicit none

C Declarations:
C	Passing Parameters: 

	BYTE		buf( * )
	INTEGER*4	nbytes, channel, block

C	Constant Parameters: None.
C	Include files: 

	include '../../../inc/pmc'

C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	buf		I		data buffer
C	nbytes		I		# of bytes to write
C	channel		I		channel link to output file
C	block		I		block address
C
C Constant Parameters:
C	pmc - see include file pmc
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	None.
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	Writes to file with the given channel number
C
C Author and Institution:
C	Cynthia L. Wong (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

	INTEGER*4	write_size
	INTEGER*4	nwrites
	INTEGER*4	bytes_rem

	INTEGER*4	i
	INTEGER*4	lun

	INTEGER*4	ptr

c Start:

d	TYPE *, 'C_WRITE_RAD:'


c	How many full writes of 64 blocks each?

	write_size = 64 * 512
	nwrites = nbytes / write_size
	bytes_rem = nbytes - (nwrites * write_size)

d	TYPE *, 'nbytes = ', nbytes
d	TYPE *, 'write_size = ', write_size
d	TYPE *, 'nwrites = ', nwrites
d	TYPE *, 'bytes_rem = ', bytes_rem


c	Write the data:

	ptr = 1
	DO i = 1, nwrites

            call dkwrit( channel, buf(ptr), write_size, block )
      	    ptr = ptr + write_size
	    block = block + 64
	END DO


c Last write:

        call dkwrit( channel, buf(ptr), bytes_rem, block )

c Done:

d	TYPE *, 'End of C_WRITE_RAD.'


	RETURN
	END
