C========================================================================
C drf_to_dc12.f
C------------------------------------------------------------------------
	subroutine drf_to_dc12(dr, df, ipj, irl, mu_g, mu_a, dc1, 
     c	dc2, burst_num)
C
C Abstract:
c	Computes the delta projection coordinates of a target
c	on the ground based on its delta range and delat Doppler. Delta
c	is with respect to those of the center geometric reference point
c	see Appendix J in PP document.
C
	implicit none

C Declarations:
C	Passing Parameters: 

	real dr, df, mu_g(3,3), mu_a(3,3), dc1, dc2
	integer ipj, irl, burst_num

C	Constant Parameters: None.
C	Include files: None.
C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	dr, df		I		range, doppler
C	mu_g		I		range resampling coefficients
C	mu_a		I		azimuth resampling coefficients
C	dc1, dc2	O		projection coordinates of the target
C	ipj		I		flag for option of projection
C	irl		I		flag for option of left or right looking
C	burst_num	I		burst counter
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	None.
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	None.
C
C Author and Institution:
C	Michael Jin (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:
	
	real a, b, c, val

	a=mu_g(3,1)+df* (mu_g(3,2)+mu_g(3,3)*df)
	b=mu_g(2,1)+df* (mu_g(2,2)+mu_g(2,3)*df)
	c=mu_g(1,1)+df* (mu_g(1,2)+mu_g(1,3)*df) -dr
	val=b*b-4*a*c
	if(val.lt.0) then
	type*, 'WARNING: square root of negative # @burst ', burst_num
C	type *, 'negative number to be square rooted', val,a,b,c
	dc2=(-b-sqrt(-1*val))/(2*a)	
C	type *, 'dc2= (when val=-val)', dc2
	dc2=-b/(2*a)
C	type *, 'dc2= (when val=0)', dc2

	else
	if(irl.eq.1) then		!right is 1
	dc2=(-b-sqrt(val))/(2*a)	
	else
	dc2=(-b+sqrt(val))/(2*a)
	end if
	end if

	a=mu_a(1,3)+dc2*(mu_a(2,3)+mu_a(3,3)*dc2)
	b=mu_a(1,2)+dc2*(mu_a(2,2)+mu_a(3,2)*dc2)
	c=mu_a(1,1)+dc2*(mu_a(2,1)+mu_a(3,1)*dc2) -df

	val=b*b-4*a*c
	if(val.lt.0) then
	type*, 'WARNING: square root of negative # @burst ', burst_num
C	type *, 'negative number to be square rooted', val,a,b,c
	dc1=(-b-sqrt(-1*val))/(2*a)	
C	type *, 'dc1= (when val=-val)', dc1
	dc1=-b/(2*a)
C	type *, 'dc1= (when val=0)', dc1

	else
	if(ipj.eq.1 .or. ipj.eq. 3) then
	dc1=(-b-sqrt(val))/(2*a)	
	else
	dc1=(-b+sqrt(val))/(2*a)	
	end if
	end if

	return
	end
