C========================================================================
C far_pointing.f
C------------------------------------------------------------------------
	subroutine far_pointing(x_mgn,z_mgn,theta_d,p)
C
C Abstract:
C	Computes the pointing vector corresponding to 
C	the boresight plus theta_d in the plan of x_mgn and z_mgn
C
	implicit none

C Declarations:
C	Passing Parameters: 

	real x_mgn(3), z_mgn(3), theta_d, p(3)

C	Constant Parameters: None.
C	Include files: None.
C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	x_mgn, z_mgn	I		spacecraft X & Z axes	
C	theta_d		I		delta look angle for far BIP
C	p		O		pointing vector to far BIP
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	None.
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	None.
C
C Author and Institution:
C	Michael Jin (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

	real smag

	p(1)=cosd(theta_d)*z_mgn(1)-sind(theta_d)*x_mgn(1)
	p(2)=cosd(theta_d)*z_mgn(2)-sind(theta_d)*x_mgn(2)
	p(3)=cosd(theta_d)*z_mgn(3)-sind(theta_d)*x_mgn(3)

	smag=sqrt(p(1)**2+p(2)**2+p(3)**2)
	p(1)=p(1)/smag
	p(2)=p(2)/smag
	p(3)=p(3)/smag

	return
	end
