C========================================================================
C frm_size_c.f
C------------------------------------------------------------------------
	subroutine frm_size_c(Ns,Nrs,Nw,Nintp,I_m,Dr,Dlta_r,Dlta_Fc)
C
C Abstract:
C	Computes the cross-track size of a framelet.
C
	implicit none

C Declarations:
C	Passing Parameters: 

	integer Ns, Nrs, Nintp
	real Nw, I_m, Dr, Dlta_r, Dlta_Fc

C	Constant Parameters: None.
C	Include files: 

        include '../../../inc/pc'

C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	Ns		I		# of range samples in each echo pulse
C	Nrs		I		# of samples in range reference func.
C	Nintp		I		# of pixels to be truncated due to 
C					degradation from interpolation
C	Nw		I		# of range walk samples
C	I_m		I		incidence angle of MRP
C	Dr		I		Slant range sample spacing
C	Dlta_r		O		apparent range ralative to central 
C					radiometric grid point
C	Dlta_Fc		O		framelet size in the cross-track dimen.
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	pc		I		include file pc
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	pc_flag_special_prod I		special processing flag
C	pc_flag_min_swath    I		minimum swath (Km)
C
C Files:
C	None.
C
C Author and Institution:
C	Michael Jin (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

        real min_swath

	Dlta_r=Dr*(Ns-Nrs-Nw-Nintp)	!slant range swath
	Dlta_Fc=Dlta_r/sind(I_m)	!cross-track size of a framelet

	if(Dlta_Fc .gt. 35000.) then	!Max swath bound is set to 35.0 km
	Dlta_Fc = 35000.
	Dlta_r = Dlta_Fc * sind(I_m)	!corresponding slant range swath
	end if

	if(Dlta_Fc .lt. 23000.) then	!Min swath bound is set to 23.0 km
	Dlta_Fc = 23000.
	Dlta_r = Dlta_Fc * sind(I_m)	!corresponding slant range swath
	end if

C use variable plot_id for minimum swath bound

	IF ( PC_FLAG_SPECIAL_PROD .EQ. 1 ) THEN
	IF ( PC_FLAG_MIN_SWATH .GT. 0 ) THEN
	MIN_SWATH = FLOAT( PC_FLAG_MIN_SWATH ) * 1000.
C             type *, 'min_swath=',min_swath
              if ( Dlta_Fc .lt. min_swath ) then
  	         Dlta_Fc = min_swath
  	         Dlta_r = Dlta_Fc * sind(I_m)	!corresponding slant range swath
	      end if
           endif
        endif

	return
	end
