C========================================================================
C get_dqs.f
C------------------------------------------------------------------------
      SUBROUTINE GET_DQS
C
C Abstract:
C	Calculates Q4 from Q1, Q2, and Q3 and then interpolate all 
C	four delta quaternions to the burst reference times.
C
	implicit none

C Declarations:
C	Passing Parameters: None.
C	Constant Parameters: None.
C	Include files: 

      include	 '../../../inc/pmc'
      include	'../../../inc/telem'
      include	 '../../../inc/pp_time'
      include	 '../../../inc/pp_ssp'
      include	'../../../inc/po'

C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	see include file listing
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	None.
C
C Author and Institution:
C	Cynthia L. Wong (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

      INTEGER*4	I,J,K,L,M,N		! General purpose
      INTEGER*4	IA,IB			! Position of points A and B
      INTEGER*4	IT / 1 /, IP / 1 /	! Starting position in TLM & PP dataset
      INTEGER*4	NSGNCH / 0 /		! # of DQ( 4 ) sign changes
      INTEGER*4	IMAX			! Loop count
      INTEGER*4	ECOUNT			! Error count
      REAL*8	T1_TLM			! Time of first telemetry data point
      REAL*8	T1_PP			! First burst reference time
      REAL*8	T			! Local burst reference time
      REAL*8	TMAX			! Local max burst reference time
      REAL*8	TMIN			! Local min burst reference time
      REAL*8	TA,TB			! Local SCLK times below & above T
      REAL*8	DQA( 3 ),DQB( 3 )	! Local quaternions below & above T
      REAL*8	DQ( 4 )			! Local quaternions at T
      REAL*8	SUM			! Sumation of DQ^2
      REAL*8	FRACA,FRACB		! Fractional portion of samples A and B
      REAL*8	SCLK2T			! Function to convert sclk into secends
      REAL*8	D1 / 1.0 /		! Double precition 1
      CHARACTER*4 SUB / 'SA  ' /	! Substructure name

***   Check for no data   ***

      IF ( TD_NSA .LE. 0 ) THEN
        TYPE *
        TYPE *,
     &  '  Warning from GET_DQS no delta quaternions for this orbit '
        TYPE *
        RETURN
      END IF

***   Report some values   ***

C      TYPE *
C      TYPE *,'  Subroutine GET_DQS Reporting'
C      TYPE *
C      TYPE *,'  The first 10 delta Qs'
C      TYPE *
C      DO I = 1,10
C        TYPE *,'  DQ1: ',TD_SA_Q( 1, I )
C        TYPE *,'  DQ2: ',TD_SA_Q( 2, I )
C        TYPE *,'  DQ3: ',TD_SA_Q( 3, I )
C      END DO

***   Handel case where burst ref. time starts above telem. times   ***

      T      = pp_time_burst_ref( 1 )
      T1_TLM = SCLK2T( TD_NSA, SUB )
      IF ( T .GE. T1_TLM ) THEN
	DO I = 1,PO_DATA_GEN_N_EDR_BURSTS - IP
      	  IF ( DABS( DQ(1) ) .LT. .001 .AND. DABS( DQ(2) ) .LT. .001
     &         .AND. DABS( DQ(3) ) .LT. .001 ) THEN
	    DQB( 1 ) = TD_SA_Q( 1, TD_NSA )
	    DQB( 2 ) = TD_SA_Q( 2, TD_NSA )
	    DQB( 3 ) = TD_SA_Q( 3, TD_NSA ) 
	    DQ( 4 ) = DSQRT( 1.0 - DQ(1)**2 - DQ(2)**2 - DQ(3)**2 )
	    PP_SSP_DELTA_Q1( I ) = DQ( 1 )
	    PP_SSP_DELTA_Q2( I ) = DQ( 2 )
	    PP_SSP_DELTA_Q3( I ) = DQ( 3 )
	    PP_SSP_DELTA_Q4( I ) = DQ( 4 )
      	  ELSE
      	    ECOUNT = ECOUNT + 1
      	  END IF
        END DO
      END IF

***   Handel case where burst ref. time starts befor telem. times   ***

      I = 1
      T1_TLM = SCLK2T( 1, SUB )
      T1_PP = PP_TIME_BURST_REF( 1 )
	DO WHILE(T1_PP .LT. T1_TLM .AND. I .LE. PO_DATA_GEN_N_EDR_BURSTS)
      	I = I + 1
        T1_PP = pp_time_burst_ref( i )
      	IF ( DABS( DQ(1) ) .LT. .001 .AND. DABS( DQ(2) ) .LT. .001
     &       .AND. DABS( DQ(3) ) .LT. .001 ) THEN
	  DQB( 1 ) = TD_SA_Q( 1,1 )
	  DQB( 2 ) = TD_SA_Q( 2,1 )
	  DQB( 3 ) = TD_SA_Q( 3,1 )
	  DQ( 4 ) = DSQRT( 1.0 - DQ(1)**2 - DQ(2)**2 - DQ(3)**2 )
	  PP_SSP_DELTA_Q1( I ) = DQ( 1 )
	  PP_SSP_DELTA_Q2( I ) = DQ( 2 )
	  PP_SSP_DELTA_Q3( I ) = DQ( 3 )
	  PP_SSP_DELTA_Q4( I ) = DQ( 4 )
      	ELSE
      	  ECOUNT = ECOUNT + 1
        END IF
      END DO
      IP = I - 1

***   Interpolate delta quaternions to the burst reference times   ***

      IT = 2
      TB = SCLK2T( IT, SUB )
	DO I = 1,PO_DATA_GEN_N_EDR_BURSTS - IP
	T = pp_time_burst_ref( ip+i )
	DO WHILE ( TB .LT. T .AND. IT .LE. TD_NSA )
      	  IT = IT + 1
          TB = SCLK2T( IT, SUB )
	END DO
	IF ( IT .GT. TD_NSA ) THEN			! Above telem time range
      	  IF ( DABS( DQ(1) ) .LT. .001 .AND. DABS( DQ(2) ) .LT. .001
     &         .AND. DABS( DQ(3) ) .LT. .001 ) THEN
	    PP_SSP_DELTA_Q1( IP+i ) = DQ( 1 )
	    PP_SSP_DELTA_Q2( IP+i ) = DQ( 2 )
	    PP_SSP_DELTA_Q3( IP+i ) = DQ( 3 )
	    PP_SSP_DELTA_Q4( IP+i ) = DQ( 4 )
      	  ELSE
      	    ECOUNT = ECOUNT + 1
          END IF
      	ELSE
	  TA       = SCLK2T( IT - 1, SUB )
	  DQA( 1 ) = TD_SA_Q( 1,IT - 1 )
	  DQA( 2 ) = TD_SA_Q( 2,IT - 1 )
	  DQA( 3 ) = TD_SA_Q( 3,IT - 1 )
	  DQB( 1 ) = TD_SA_Q( 1,IT )
	  DQB( 2 ) = TD_SA_Q( 2,IT )
	  DQB( 3 ) = TD_SA_Q( 3,IT )
      	  DO J = 1, 3 					    ! All this error
      	    IF ( DQA( J ) .LT. 1.0E-10 ) DQA( J ) = 0.0	    ! trapping is to
      	    IF ( DQB( J ) .LT. 1.0E-10 ) DQB( J ) = 0.0	    ! avoid floating
      	  END DO					    ! point underflow
      	  IF ( TB - T .LT. 1.0E-10 ) THEN
      	    FRACA = 0.0
      	  ELSE
      	    FRACA = (( TB - T )/( TB - TA ))
      	  END IF
      	  IF ( T - TA .LT. 1.0E-10 ) THEN
      	    FRACB = 0.0
      	  ELSE
      	    FRACB = (( T - TA )/( TB - TA ))
      	  END IF
	  DO J = 1,3
	    DQ( J ) = FRACA * DQA( J )
     &              + FRACB * DQB( J )
	  END DO


Ccccccccccccccc  JG  10/19/90:

      	  IF ( DABS( DQ(1) ) .LT. 0.001 .AND. DABS( DQ(2) ) .LT. 0.001
     &      .AND. DABS( DQ(3) ) .LT. 0.001 ) THEN
      	    SUM = DQ(1)**2 + DQ(2)**2 + DQ(3)**2
    	  ELSE
      	    ECOUNT = ECOUNT + 1
      	    SUM = 0.0
	    dq( 1 ) = 0.0 D0
	    dq( 2 ) = 0.0 D0
	    dq( 3 ) = 0.0 D0
      	  END IF

Ccccccccccccccc End of change.


	  DQ( 4 ) = DSQRT( 1.0 - SUM )
	  PP_SSP_DELTA_Q1( IP+i ) = DQ( 1 )
	  PP_SSP_DELTA_Q2( IP+i ) = DQ( 2 )
	  PP_SSP_DELTA_Q3( IP+i ) = DQ( 3 )
	  PP_SSP_DELTA_Q4( IP+i ) = DQ( 4 )
	END IF
      END DO

***   Report telemetry and burst ref time spans   ***

      TMIN = pp_time_burst_ref( 1 )
	TMAX = pp_time_burst_ref( PO_DATA_GEN_N_EDR_BURSTS )
      TYPE *,'  GET_DQS Reporting '
      TYPE *,'  The burst reference time span is from: '
      TYPE *,TMIN,'  to:: ',TMAX
      TYPE *
      TMIN = SCLK2T(      1, SUB )
      TMAX = SCLK2T( TD_NSA, SUB )
      TYPE *,'  The telemetry time span is from: '
      TYPE *,TMIN,'  to:: ',TMAX
      TYPE *
      IF ( ECOUNT .GT. 0 ) THEN
        TYPE *
        TYPE '( A13, I4, A30 )',
     &  '  There were ',ECOUNT,' DQS > 0.001 and reset to 0.0'
      END IF
      RETURN
      END

****************   End of program code and source file   ****************

