C========================================================================
C get_fr_m.f
C------------------------------------------------------------------------
	subroutine get_fr_m(x_s,v_s,a_s,x_m,wavl,gmass,fr_m)
C
C Abstract:
C	Computes the Doppler frequency rate of the mid-
C	range point according to Eq. (9) of PP Doc.
C
	implicit none

C Declarations:
C	Passing Parameters: 
	
	real x_s(3), v_s(3), a_s(3), x_m(3), wavl, gmass, fr_m

C	Constant Parameters: None.
C	Include files: None.
C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	x_s, v_s, a_s	I		sensor status
C	x_m		I		MRP position
C	wavl		I		radar wavelength
C	gmass		I		mass of Venus
C	fr_m		O		doppler freq. rate of MRP
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	None.
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	None.
C
C Author and Institution:
C	Michael Jin (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

	real x_sm(3), xs_mag, vs_mag, xsm_mag, xsm_dot_as, vs_dot_xsm

	xs_mag=sqrt(x_s(1)**2+x_s(2)**2+x_s(3)**2)

	a_s(1) = -1*gmass*x_s(1)/xs_mag**3
	a_s(2) = -1*gmass*x_s(2)/xs_mag**3
	a_s(3) = -1*gmass*x_s(3)/xs_mag**3
	
	x_sm(1)=x_s(1)-x_m(1)
	x_sm(2)=x_s(2)-x_m(2)
	x_sm(3)=x_s(3)-x_m(3)

	xsm_mag= sqrt(x_sm(1)**2+x_sm(2)**2+x_sm(3)**2)
	vs_mag= sqrt(v_s(1)**2+v_s(2)**2+v_s(3)**2)

	xsm_dot_as=x_sm(1)*a_s(1)+x_sm(2)*a_s(2)+x_sm(3)*a_s(3)

	vs_dot_xsm=v_s(1)*x_sm(1)+v_s(2)*x_sm(2)+v_s(3)*x_sm(3)
c	type *, 'here'
c	type *, 'xsm_mag, wavl', xsm_mag, wavl
     	fr_m=-2*(xsm_dot_as+vs_mag**2)/(wavl*xsm_mag)+
     1        2*vs_dot_xsm**2/(wavl*xsm_mag**3)

	return
	end

