C========================================================================
C get_temps.f
C	contains subroutines get_temps and get_tempsa
C------------------------------------------------------------------------
      SUBROUTINE GET_TEMPS( T_SAMP )
C
C Abstract:
C	Interpolates the telemetry data cable and radar temperatures to 
C	the input time T_SAMP.
C
	implicit none

C Declarations:
C	Passing Parameters: 

	real*8 t_samp

C	Constant Parameters: None.
C	Include files: 

      include	'../../../inc/var_local'
C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	t_samp		I		burst reference time
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	None.
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	None.
C
C Author and Institution:
C	Cynthia L. Wong (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

***   Pass variables from VAR_LOCAL to GET_TEMPSA   ***

      CALL GET_TEMPSA( T_SAMP, T_cable1, T_cable2, T_cable3,
     &                 T_cable4, T_cable5, TXU_A_state,
     &                 RXU_A_state, ONU_A_state, T_T1_A,
     &                 T_T1_B, T_RX_A, T_RX_B, T_os_A, T_os_B )

      RETURN
      END

*************************************************************************
*                                                                       *
*  This code was split into two subroutines because PI is DECLARED in   *
*  both VAR_LOCAL and PMC                                               *
*                                                                       *
*************************************************************************

      SUBROUTINE GET_TEMPSA( T_SAMP, T_cable1, T_cable2,
     &                 T_cable3, T_cable4, T_cable5, TXU_A_state,
     &                 RXU_A_state, ONU_A_state, T_T1_A,
     &                 T_T1_B, T_RX_A, T_RX_B, T_os_A, T_os_B )

***   Declaration of variables   ***

      IMPLICIT NONE

***   Include files   ***

      include	'../../../inc/pmc'
      include	'../../../inc/telem'
      include	'../../../inc/po'

***   Declaration of functions   ***

      REAL*8	SCLK2T

***   Local variables   ***

      INTEGER*4	I,J,K,L,M,N		! General purpose
      INTEGER*4	IT / 1 /		! Starting position in TLM dataset
      REAL*8	T1_TLM			! Time of first telemetry data point
      REAL*8	T_SAMP			! Time to sample to
      REAL*8	TA,TB			! Local SCLK times below & above T
      REAL*8	CTA,CTB			! Cable temps below & above T
      REAL*8	RTA,RTB			! Radar temps below & above T

      REAL   T_cable1, T_cable2, T_cable3, T_cable4, T_cable5,
     &       TXU_A_state, RXU_A_state, ONU_A_state, T_T1_A, T_T1_B,
     &       T_RX_A, T_RX_B, T_os_A, T_os_B

      INTEGER*4	 NSB( 5 )
      CHARACTER*4 SB( 5 ) / 'SB1 ','SB2 ','SB3 ','SB4 ','SB5 '  /

***   Set number of cable temperature data points   ***

      NSB( 1 ) = TD_NSB1
      NSB( 2 ) = TD_NSB2
      NSB( 3 ) = TD_NSB3
      NSB( 4 ) = TD_NSB4
      NSB( 5 ) = TD_NSB5

***   Interpolate the 5 cable temperatures   ***

      DO I = 1,5
	J  = 1
      	IT = 1
    	IF ( NSB( I ) .LE. 0 ) GO TO 10
	TB     = SCLK2T( 2, SB( I ) )
	T1_TLM = SCLK2T( 1, SB( I ) )
      	IF ( I .EQ. 1 ) THEN
	  IF ( T1_TLM .LE. T_SAMP ) THEN
	    DO WHILE ( TB .LT. T_SAMP .AND. J .LE. NSB( I ) )
	      J = J + 1
	      TB = SCLK2T( J, SB( I ) )
	    END DO
	    IT = J
      	    IF ( IT .EQ. 1 ) IT = 2
	    IF ( J .GE. NSB( I ) ) THEN			! Above TLM time range
      	      IF ( NSB( I ) .EQ. 0 ) NSB( I ) = 1
              T_cable1 = TD_SB1_TEMP( NSB( I ) )
      	      GO TO 10
	    END IF
	  ELSE						! Below TLM time range
            T_cable1 = TD_SB1_TEMP( 1 )
      	    GO TO 10
	  END IF
          TA  = SCLK2T( IT - 1, SB( I ) )
          CTA = TD_SB1_TEMP( IT - 1 )
          CTB = TD_SB1_TEMP( IT     )
	  T_cable1 = (( TB - T_SAMP )/( TB - TA )) * CTA
     &             + (( T_SAMP - TA )/( TB - TA )) * CTB

      	ELSE IF ( I .EQ. 2 ) THEN

	  IF ( T1_TLM .LE. T_SAMP ) THEN
	    DO WHILE ( TB .LT. T_SAMP .AND. J .LE. NSB( I ) )
	      J = J + 1
	      TB = SCLK2T( J, SB( I ) )
	    END DO
	    IT = J
      	    IF ( IT .EQ. 1 ) IT = 2
	    IF ( J .GE. NSB( I ) ) THEN			! Above TLM time range
      	      IF ( NSB( I ) .EQ. 0 ) NSB( I ) = 1
              T_cable2 = TD_SB2_TEMP( NSB( I ) )
      	      GO TO 10
	    END IF
	  ELSE						! Below TLM time range
            T_cable2 = TD_SB2_TEMP( 1 )
      	    GO TO 10
	  END IF
          TA  = SCLK2T( IT - 1, SB( I ) )
          CTA = TD_SB2_TEMP( IT - 1 )
          CTB = TD_SB2_TEMP( IT     )
	  T_cable2 = (( TB - T_SAMP )/( TB - TA )) * CTA
     &             + (( T_SAMP - TA )/( TB - TA )) * CTB

      	ELSE IF ( I .EQ. 3 ) THEN

	  IF ( T1_TLM .LE. T_SAMP ) THEN
	    DO WHILE ( TB .LT. T_SAMP .AND. J .LE. NSB( I ) )
	      J = J + 1
	      TB = SCLK2T( J, SB( I ) )
	    END DO
	    IT = J
      	    IF ( IT .EQ. 1 ) IT = 2
	    IF ( J .GE. NSB( I ) ) THEN			! Above TLM time range
      	      IF ( NSB( I ) .EQ. 0 ) NSB( I ) = 1
              T_cable3 = TD_SB3_TEMP( NSB( I ) )
      	      GO TO 10
	    END IF
	  ELSE						! Below TLM time range
            T_cable3 = TD_SB3_TEMP( 1 )
      	    GO TO 10
	  END IF
          TA  = SCLK2T( IT - 1, SB( I ) )
          CTA = TD_SB3_TEMP( IT - 1 )
          CTB = TD_SB3_TEMP( IT     )
	  T_cable3 = (( TB - T_SAMP )/( TB - TA )) * CTA
     &             + (( T_SAMP - TA )/( TB - TA )) * CTB

      	ELSE IF ( I .EQ. 4 ) THEN

	  IF ( T1_TLM .LE. T_SAMP ) THEN
	    DO WHILE ( TB .LT. T_SAMP .AND. J .LE. NSB( I ) )
	      J = J + 1
	      TB = SCLK2T( J, SB( I ) )
	    END DO
	    IT = J
      	    IF ( IT .EQ. 1 ) IT = 2
	    IF ( J .GE. NSB( I ) ) THEN			! Above TLM time range
      	      IF ( NSB( I ) .EQ. 0 ) NSB( I ) = 1
              T_cable4 = TD_SB4_TEMP( NSB( I ) )
      	      GO TO 10
	    END IF
	  ELSE						! Below TLM time range
            T_cable4 = TD_SB4_TEMP( 1 )
      	    GO TO 10
	  END IF
          TA  = SCLK2T( IT - 1, SB( I ) )
          CTA = TD_SB4_TEMP( IT - 1 )
          CTB = TD_SB4_TEMP( IT     )
	  T_cable4 = (( TB - T_SAMP )/( TB - TA )) * CTA
     &             + (( T_SAMP - TA )/( TB - TA )) * CTB

      	ELSE IF ( I .EQ. 5 ) THEN

	  IF ( T1_TLM .LE. T_SAMP ) THEN
	    DO WHILE ( TB .LT. T_SAMP .AND. J .LE. NSB( I ) )
	      J = J + 1
	      TB = SCLK2T( J, SB( I ) )
	    END DO
	    IT = J
      	    IF ( IT .EQ. 1 ) IT = 2
	    IF ( J .GE. NSB( I ) ) THEN			! Above TLM time range
      	      IF ( NSB( I ) .EQ. 0 ) NSB( I ) = 1
              T_cable5 = TD_SB5_TEMP( NSB( I ) )
      	      GO TO 10
	    END IF
	  ELSE						! Below TLM time range
            T_cable5 = TD_SB5_TEMP( 1 )
      	    GO TO 10
	  END IF
          TA  = SCLK2T( IT - 1, SB( I ) )
          CTA = TD_SB5_TEMP( IT - 1 )
          CTB = TD_SB5_TEMP( IT     )
	  T_cable5 = (( TB - T_SAMP )/( TB - TA )) * CTA
     &             + (( T_SAMP - TA )/( TB - TA )) * CTB

      	END IF
 10     CONTINUE
      END DO

***   Get transmitter state and temperatures   ***

      IF ( TD_XMTR_A_STATE .EQ. 1 ) THEN		! 1 = A ( on )
      	TXU_A_state = 1
	J = 1
    	IF ( TD_NRBXA .LE. 0 ) GO TO 11
	TB     = SCLK2T( 2, 'RBXA' )
	T1_TLM = SCLK2T( 1, 'RBXA' )
	IF ( T1_TLM .LE. T_SAMP ) THEN
	  DO WHILE ( TB .LT. T_SAMP .AND. J .LE. TD_NRBXA )  ! Find offset into
	    J = J + 1					     ! the telemetry
	    TB = SCLK2T( J, 'RBXA' )			     ! datasets
	  END DO
	  IT = J
      	  IF ( IT .EQ. 1 ) IT = 2
	  IF ( J .GE. TD_NRBXA ) THEN			! Above TLM time range
            T_T1_A = TD_RBXA_TEMP( TD_NRBXA )
      	    GO TO 11
	  END IF
	ELSE						! Below TLM time range
          T_T1_A = TD_RBXA_TEMP( 1 )
      	  GO TO 11
	END IF
        TA  =  SCLK2T( IT - 1, 'RBXA' )
        RTA = TD_RBXA_TEMP( IT - 1 )
        RTB = TD_RBXA_TEMP( IT     )
      	T_T1_A = (( TB - T_SAMP )/( TB - TA )) * RTA
     &         + (( T_SAMP - TA )/( TB - TA )) * RTB
      ELSE
      	TXU_A_state = 0
	J  = 1
    	IF ( TD_NRBXB .LE. 0 ) GO TO 11
	TB     = SCLK2T( 2, 'RBXB' )
	T1_TLM = SCLK2T( 1, 'RBXB' )
	IF ( T1_TLM .LE. T_SAMP ) THEN
	  DO WHILE ( TB .LT. T_SAMP .AND. J .LE. TD_NRBXB )  ! Find offset into
	    J = J + 1					    ! the telemetry
	    TB = SCLK2T( J, 'RBXB' )			    ! datasets
	  END DO
	  IT = J
      	  IF ( IT .EQ. 1 ) IT = 2
	  IF ( J .GE. TD_NRBXB ) THEN			! Above TLM time range
            T_T1_B = TD_RBXB_TEMP( TD_NRBXB )
      	    GO TO 11
	  END IF
	ELSE						! Below TLM time range
          T_T1_B = TD_RBXB_TEMP( 1 )
      	  GO TO 11
	END IF
        TA  =  SCLK2T( IT - 1, 'RBXB' )
        RTA = TD_RBXB_TEMP( IT - 1 )
        RTB = TD_RBXB_TEMP( IT     )
      	T_T1_B = (( TB - T_SAMP )/( TB - TA )) * RTA
     &         + (( T_SAMP - TA )/( TB - TA )) * RTB
      END IF
 11   CONTINUE

***   Get receiver state and temperatures   ***

      IF ( TD_RXU_A_STATE .EQ. 1 ) THEN
      	RXU_A_state = 1
	J  = 1
    	IF ( TD_NRBRA .LE. 0 ) GO TO 12
	TB     = SCLK2T( 2, 'RBRA' )
	T1_TLM = SCLK2T( 1, 'RBRA' )
	IF ( T1_TLM .LE. T_SAMP ) THEN
	  DO WHILE ( TB .LT. T_SAMP .AND. J .LE. TD_NRBRA )  ! Find offset into
	    J = J + 1					     ! the telemetry
	    TB = SCLK2T( J, 'RBRA' )			     ! datasets
	  END DO
	  IT = J
      	  IF ( IT .EQ. 1 ) IT = 2
	  IF ( J .GE. TD_NRBRA ) THEN	! Above TLM time range
            T_RX_A = TD_RBRA_TEMP( TD_NRBRA )
      	    GO TO 12
	  END IF
	ELSE						! Below TLM time range
          T_RX_A = TD_RBRA_TEMP( 1 )
      	  GO TO 12
	END IF
        TA  =  SCLK2T( IT - 1, 'RBRA' )
        RTA = TD_RBRA_TEMP( IT - 1 )
        RTB = TD_RBRA_TEMP( IT     )
      	T_RX_A = (( TB - T_SAMP )/( TB - TA )) * RTA
     &         + (( T_SAMP - TA )/( TB - TA )) * RTB
      ELSE
      	RXU_A_state = 0
	J  = 1
    	IF ( TD_NRBRB .LE. 0 ) GO TO 12
	TB     = SCLK2T( 2, 'RBRB' )
	T1_TLM = SCLK2T( J, 'RBRB' )
	IF ( T1_TLM .LE. T_SAMP ) THEN
	  DO WHILE ( TB .LT. T_SAMP .AND. J .LE. TD_NRBRB )  ! Find offset into
	    J = J + 1					    ! the telemetry
	    TB = SCLK2T( J, 'RBRB' )			    ! datasets
	  END DO
	  IT = J
      	  IF ( IT .EQ. 1 ) IT = 2
	  IF ( J .GE. TD_NRBRB ) THEN			! Above TLM time range
            T_RX_B = TD_RBRB_TEMP( TD_NRBRB )
      	    GO TO 12
	  END IF
	ELSE						! Below TLM time range
          T_RX_B = TD_RBRB_TEMP( 1 )
      	  GO TO 12
	END IF
        TA  =  SCLK2T( IT - 1, 'RBRB' )
        RTA = TD_RBRB_TEMP( IT - 1 )
        RTB = TD_RBRB_TEMP( IT     )
      	T_RX_B = (( TB - T_SAMP )/( TB - TA )) * RTA
     &         + (( T_SAMP - TA )/( TB - TA )) * RTB
      END IF
 12   CONTINUE

***   Get ONU state and temperatures   ***

      IF ( TD_RXU_A_STATE .EQ. 1 ) THEN
      	ONU_A_state = 1
	J  = 1
    	IF ( TD_NRBOA .LE. 0 ) GO TO 13
	TB     = SCLK2T( 2, 'RBOA' )
	T1_TLM = SCLK2T( J, 'RBOA' )
	IF ( T1_TLM .LE. T_SAMP ) THEN
	  DO WHILE ( TB .LT. T_SAMP .AND. J .LE. TD_NRBOA )  ! Find offset into
	    J = J + 1					    ! the telemetry
	    TB = SCLK2T( J, 'RBOA' )			    ! datasets
	  END DO
	  IT = J
      	  IF ( IT .EQ. 1 ) IT = 2
	  IF ( J .GE. TD_NRBOA ) THEN			! Above TLM time range
            T_os_A = TD_RBOA_TEMP( TD_NRBOA )
      	    GO TO 13
	  END IF
	ELSE						! Below TLM time range
          T_os_A = TD_RBOA_TEMP( 1 )
      	  GO TO 13
	END IF
        TA  =  SCLK2T( IT - 1, 'RBOA' )
        RTA = TD_RBOA_TEMP( IT - 1 )
        RTB = TD_RBOA_TEMP( IT     )
      	T_os_A = (( TB - T_SAMP )/( TB - TA )) * RTA
     &         + (( T_SAMP - TA )/( TB - TA )) * RTB
      ELSE
      	ONU_A_state = 0
	J  = 1
    	IF ( TD_NRBOB .LE. 0 ) GO TO 13
	TB     = SCLK2T( 2, 'RBOB' )
	T1_TLM = SCLK2T( J, 'RBOB' )
	IF ( T1_TLM .LE. T_SAMP ) THEN
	  DO WHILE ( TB .LT. T_SAMP .AND. J .LE. TD_NRBOB )  ! Find offset into
	    J = J + 1					    ! the telemetry
	    TB = SCLK2T( J, 'RBOB' )			    ! datasets
	  END DO
	  IT = J
      	  IF ( IT .EQ. 1 ) IT = 2
	  IF ( J .GE. TD_NRBOB ) THEN			! Above TLM time range
            T_os_B = TD_RBOB_TEMP( TD_NRBOB )
      	    GO TO 13
	  END IF
	ELSE						! Below TLM time range
          T_os_B = TD_RBOB_TEMP( 1 )
      	  GO TO 13
	END IF
        TA  =  SCLK2T( IT - 1, 'RBOB' )
        RTA = TD_RBOB_TEMP( IT - 1 )
        RTB = TD_RBOB_TEMP( IT     )
      	T_os_B = (( TB - T_SAMP )/( TB - TA )) * RTA
     &         + (( T_SAMP - TA )/( TB - TA )) * RTB
      END IF
 13   CONTINUE

C      TYPE *,'  TD CABLE TEMP 1: ', TD_SB1_TEMP( 1 )
C      TYPE *,'  TD CABLE TEMP 2: ', TD_SB2_TEMP( 1 )
C      TYPE *,'  TD CABLE TEMP 3: ', TD_SB3_TEMP( 1 )
C      TYPE *,'  TD CABLE TEMP 4: ', TD_SB4_TEMP( 1 )
C      TYPE *,'  TD CABLE TEMP 5: ', TD_SB5_TEMP( 1 )
C      TYPE *
C      TYPE *,' CABEL TEMP 1 = ',T_cable1
C      TYPE *,' CABEL TEMP 2 = ',T_cable2
C      TYPE *,' CABEL TEMP 3 = ',T_cable3
C      TYPE *,' CABEL TEMP 4 = ',T_cable4
C      TYPE *,' CABEL TEMP 5 = ',T_cable5
C      TYPE *,' TXU_A_state = ',TXU_A_state
C      TYPE *,' RXU_A_state = ',RXU_A_state
C      TYPE *,' ONU_A_state = ',ONU_A_state
C      TYPE *,' T_T1_A = ',T_T1_A
C      TYPE *,' T_T1_B = ',T_T1_B
C      TYPE *,' T_RX_A = ',T_RX_A
C      TYPE *,' T_RX_B = ',T_RX_B
C      TYPE *,' T_OS_A = ',T_OS_A
C      TYPE *,' T_OS_B = ',T_OS_B

      RETURN
      END

****************   End of program code and source file   ****************

