C========================================================================
C getegrec.f
C------------------------------------------------------------------------
      SUBROUTINE GETEGREC
C
C Abstract:
C	Extracts records from the EDR file 10 "1-ENG_DATA.;1".
C
	implicit none

C Declarations:
C	Passing Parameters: 

      INTEGER*4		IRETURN			! Return value
      COMMON / RSTAT / IRETURN

      BYTE		OUT_BUF( 512 )
      CHARACTER*512	COUT_BUF
      EQUIVALENCE( COUT_BUF, OUT_BUF )
      COMMON / BUF / COUT_BUF

      CHARACTER*80	FILE_09			! Decom/decal file name
      CHARACTER*80	FILE_10			! Engineerind data file name
      COMMON / FNBLK / FILE_09, FILE_10

C	Constant Parameters: None.
C	Include files: 

      include '../../../inc/rec_count'

C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	rec_count	I		file size of file 10.
C	rstat		O		return value
C	buf		O		extracted data
C	fnblk		I		filename of file 10
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	see above.
C
C Files:
C	Reads file 10 (engineering file from EDR)
C
C Author and Institution:
C	Cynthia L. Wong (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

      CHARACTER*32768	CIN_BUF
      BYTE		IN_BUF( 32768 )
      EQUIVALENCE( CIN_BUF, IN_BUF )
      CHARACTER*512	NULLS			! Blanks to clear OUT_BUF
      LOGICAL		EOD			! End of data
      LOGICAL		EOH			! End of header
      LOGICAL		NEWFILE			! Beginning a new file
      LOGICAL		FIRST			! First record
      LOGICAL		REPEAT / .FALSE. /	! Not the first call
      INTEGER*4		I,J,K,L,M,N		! Indexes
      INTEGER*4		LUN			! Logical unit # of output file
      INTEGER*4		INCHN			! I/O channel number
      INTEGER*4		INITDK			! Function to get channel #
      INTEGER*4		DEND			! End of data block in CIN_BUF
      INTEGER*4		DBGN			! Start of data block in CIN_BUF
      INTEGER*4		DPTR			! Data Pointer
      INTEGER*4		IBPT			! Input file block pointer
      INTEGER*4		NFILE			! File number

      LOGICAL		EOF			! End of file
      INTEGER*4		NBYTES			! # of bytes to read
      INTEGER*4		NBYTESF			! # of bytes in file

      SAVE CIN_BUF, EOD, EOH, NEWFILE, FIRST, REPEAT, LUN,
     &       INCHN, DEND, DBGN,	DPTR, IBPT, NFILE, EOF, NBYTES, NBYTESF

***   Initialize ENG file if first time arround   ***

      IF ( .NOT. REPEAT ) THEN
        CALL GET_LUN( LUN )
        INCHN = INITDK( LUN, FILE_10 )
C        INCHN = INITDK( LUN, 'FILE_10.' )
  	TYPE *
      	TYPE '(A41,A80)',
     &  '  Subroutine GETEGREC reading from file: ', FILE_10
  	TYPE *
      	REPEAT  = .TRUE.
      	NEWFILE = .TRUE.
        IBPT = 1
	NBYTESF = REC_COUNT_FILE_10 * 32500
	write (*,*) 'File size = ', rec_count_file_10, ' records'
C      	NBYTESF = 27 * 32500
      END IF
      COUT_BUF = NULLS
      IF ( IRETURN .EQ. 0 ) IRETURN = 1.0

***   Choose the right file and transfer a record   ***

      IF ( NEWFILE ) THEN
	NEWFILE = .FALSE.
	EOH     = .FALSE.
	EOD     = .FALSE.
	I       = 1
	CALL DKREAD( INCHN, IN_BUF, 12288, IBPT )
	IBPT = IBPT + 20
	DO WHILE ( .NOT. EOH )
	  I = I + 1
	  IF ( ( IN_BUF( I ) .EQ. '0A'X .OR. IN_BUF( I ) .EQ. '0D'X )
     &      .AND. CIN_BUF( I + 1 : I + 6 ) .EQ. 'NJPL1I' ) THEN
	    EOH = .TRUE.
	    DBGN = I + 1
	  END IF
	END DO
	DPTR = DBGN
      END IF
      IF ( CIN_BUF( DPTR + 274 : DPTR + 279 ) .NE. 'NJPL1I' .AND.
     &     CIN_BUF( DPTR + 174 : DPTR + 179 ) .NE. 'NJPL1I' ) THEN
	EOD     = .TRUE.
	DEND    = DPTR - 1
	NFILE   = NFILE + 1
	COUT_BUF( 1 : 274 ) = CIN_BUF( DPTR : DPTR + 274 )
        CALL CLOSEDK( LUN, INCHN )
        CALL FREE_LUN( LUN )
	IRETURN = 0
      END IF

      IF ( DPTR .GE. 10240 .AND. IRETURN .NE. 0 ) THEN
      	IF ( NBYTESF - ( IBPT - 1 ) * 512 .GT. 12288 ) THEN
      	  NBYTES = 12288
	  CALL DKREAD( INCHN, IN_BUF, NBYTES, IBPT )
	  IBPT = IBPT + 20
	  DPTR = DPTR - 10240
        ELSE
      	  NBYTES = NBYTESF - ( IBPT - 1 ) * 512
          DO I = DPTR, 12288
      	    IF ( CIN_BUF( I - 3:I ) .EQ. 'NAME' ) EOF = .TRUE.
      	  END DO
      	  IF ( .NOT. EOF ) THEN
	    CALL DKREAD( INCHN, IN_BUF, NBYTES, IBPT )
	    DPTR = DPTR - 10240
	    IBPT = IBPT + 20
      	  END IF
      	END IF
      END IF

      IF ( CIN_BUF( DPTR + 274 : DPTR + 279 ) .EQ. 'NJPL1I' ) THEN
	COUT_BUF( 1 : 274 ) = CIN_BUF( DPTR : DPTR + 274 )
	DPTR = DPTR + 274
      ELSE IF ( CIN_BUF( DPTR + 174 : DPTR + 179 ) .EQ. 'NJPL1I' ) THEN
	COUT_BUF( 1 : 174 ) = CIN_BUF( DPTR : DPTR + 174 )
	DPTR = DPTR + 174
      END IF
      RETURN
      END

****************   End of program code and source file   ****************


