C========================================================================
C getta.f
C------------------------------------------------------------------------
	subroutine getta(period,ecc,pi,t,ta)
C
C Abstract:
C	Computes the true anomaly angle based on
C	given in-orbit parameters period and ecc, and time info 't'.
C
	implicit none

C Declarations:
C	Passing Parameters: 

	real*8 period, ecc
	real pi, t, ta

C	Constant Parameters: None.
C	Include files: None.
C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	period		I		period
C	ecc		I		eccentricity
C	pi		I		pi
C	t		I		time
C	ta		O		true anomaly angle
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	None.
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	None.
C
C Author and Institution:
C	Michael Jin (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

	real*8 A
	real fn, e, elast, fm, fac
	integer icnt

	fn=2.*pi/period 
	e=0.0				! eccentric anomaly
	icnt=0				! iteration counter
 1	continue
	icnt=icnt+1
	elast=e
	fm=fn*t				! mean anomaly
	e=fm+ecc*sin(e)
	if(abs(elast-e).gt.1.e-20) go to 1
	fac=sqrt((1.+ecc)/(1.-ecc))*tan(e/2.)
	ta=2.*atand(fac)		! true anomaly
cc	type *,'ta=',ta

	return
	end	
