C========================================================================
C gtsnr.f
C------------------------------------------------------------------------
	subroutine gtsnr(rv,ta0,aincl,omg,tax,alt,vt,vr,x,y,z,vx,vy,vz)
C
C Abstract:
C	Computes the sensor status based on the true
C	anomaly angle, the orbit angles, and the altitude of the
C	sensor
C
	implicit none

C Declarations:
C	Passing Parameters: 

	real rv, ta0, aincl, omg, tax, alt, vt, vr, x, y, z, vx, vy, vz

C	Constant Parameters: None.
C	Include files: None.
C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	rv		I		radius of venus
C	ta0		I		argument of periapsis (deg)
C	aincl		I		inclination (deg)
C	omg		I		longitude of ascending node (deg)
C	tax 		I		true anomally angle (deg)
C	alt		I		altitude of the sensor
C	vt, vr		I		tangential & radial velocity
C	x, y, z		O		sensor position
C	vx, vy, vz	O		sensor velocity
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	None.
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	None.
C
C Author and Institution:
C	Michael Jin (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

	x=(rv+alt)*cosd(tax)
	y=(rv+alt)*sind(tax)
	z=0.
	vx=vr*cosd(tax)-vt*sind(tax)
	vy=vr*sind(tax)+vt*cosd(tax)
	vz=0.
	call rotate_jin(x,y,z,vx,vy,vz,ta0,aincl,omg)
	
	return
	end
