C========================================================================
C meridian.f
C------------------------------------------------------------------------
	subroutine meridian(nav_source,lon0,t_p,handle)
C
C Abstract:
c	Computes the reference meridian for the orbit.
C
	implicit none

C Declarations:
C	Passing Parameters:

	integer nav_source, handle
	real lon0
	real*8 t_p
	
C	Constant Parameters: None.
C	Include files: None.
C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	nav_source	I		navigation flag
C	lon0		O		reference meridian
C	t_p		I		time since periapsis
C	handle		I		hanle of S/P kernel file (NAV s/w)
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	None.
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	None.
C
C Author and Institution:
C	Michael Jin (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

	real*8 t, day
	real x_s_j2000(3), v_s_j2000(3), a_s_j2000(3), lat, lon, rs
	real x_s_vme(3),v_s_vme(3),x_s_vbf(3),v_s_vbf(3)
	real pi, rv, dt_10deg

	pi=4.*atan(1.)

	rv=6051000.

	day = t_p / (24*3600.)
	dt_10deg = 130.6658
	t = t_p + dt_10deg
1	continue
d	type *, 't= ', t
	call navs(nav_source,t,t_p,x_s_j2000,v_s_j2000,
     c	a_s_j2000, handle)
	call j2000_to_VME(x_s_j2000,x_s_vme)
	call j2000_to_VME(v_s_j2000,v_s_vme)
d	type *, 'z= ', x_s_vme(3), v_s_vme(3)
	if(abs(x_s_vme(3)).lt.3.) go to 2
	t=t-x_s_vme(3)/(v_s_vme(3)*sind(86.))     !"-" is for descending


	go to 1
2	call VME_to_VBF(day,x_s_vme,x_s_vbf)
	call VBF_to_sph(x_s_vbf(1),x_s_vbf(2),x_s_vbf(3),rs,lat,lon0)
	lon0=Nint(lon0*pi/180.*Rv/75.)*75./Rv*180./pi

	return
	end

