C========================================================================
C mgn_axs.f
C------------------------------------------------------------------------
	subroutine mgn_axs(day, q, x_mgn, y_mgn, z_mgn)
C
C Abstract:
C	Computes the pointing vectors of the three axes
C	of the spacecraft based on the pointing quaternion q and the
C	time (day). Eq.s are from the planetary constant and model
C	document.
C
	implicit none

C Declarations:
C	Passing Parameters: 

	real*8 day	
	real q(4,4), x_mgn(3), y_mgn(3), z_mgn(3)
	
C	Constant Parameters: None.
C	Include files: None.
C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	day		I		# of days since 2000 ET
C	q		I		poiting quaternion
C	x_, y_, z_mgn	O		pointing vectors of three axes of s/c
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	None.
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	None.
C
C Author and Institution:
C	Michael Jin (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

	x_mgn(1)=q(1,1)-q(2,2)-q(3,3)+q(4,4)
	x_mgn(2)=q(1,2)+q(3,4)
	x_mgn(3)=q(1,3)-q(2,4)

	y_mgn(1)=q(1,2)-q(3,4)
	y_mgn(2)=-q(1,1)+q(2,2)-q(3,3)+q(4,4)
	y_mgn(3)=q(2,3)+q(1,4)

	z_mgn(1)=q(1,3)+q(2,4)
	z_mgn(2)=q(2,3)-q(1,4)
	z_mgn(3)=-q(1,1)-q(2,2)+q(3,3)+q(4,4)

	return
	end
