C========================================================================
C nav1.f
C------------------------------------------------------------------------
      SUBROUTINE NAV1(T,T_P,XS,VS,AS,HANDLE)
C
C Abstract:
C	Calls NAV software to obtain sensor status
C
	implicit none

C Declarations:
C	Passing Parameters: 

      DOUBLE PRECISION T, T_P
      REAL XS(3), VS(3), AS(3)
      INTEGER 		HANDLE

C	Constant Parameters: None.
C	Include files: None.
C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	t		I		burst reference time
C	t_p		I		time at periapsis
C	x_s		O		sensor position in j2000 coordinates
C	v_s		O		sensor velocity
C	a_s		O		sensor acceleration
C	handle		O		S/P kernel file handler (NAV s/w)
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	None.
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	None.
C
C Author and Institution:
C	Michael Jin  (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

      INTEGER           MGN
      INTEGER           CENTER

      CHARACTER*(40)    IDENT
 
      DOUBLE PRECISION  DESCR  (   5 )
      DOUBLE PRECISION  ET
      DOUBLE PRECISION  STATE  (   6 )
 
      LOGICAL           FOUND
 

	ET = T
d	TYPE *, 'HANDLE ===', HANDLE

	MGN=-18 
	CALL SPKSFS(MGN,ET,HANDLE,DESCR,IDENT,FOUND)

	IF(.NOT. FOUND) THEN
	WRITE(*,*) 'SEGMENT NOT FOUND FOR MGN AT ET EPOCH', ET
	STOP
	END IF

	CENTER = 0

d	type *, 'ET= ', et
d	type *, 'DESCR= ', DESCR(1)
d	type *, 'DESCR= ', DESCR(2)
d	type *, 'DESCR= ', DESCR(3)
d	type *, 'DESCR= ', DESCR(4)
d	type *, 'DESCR= ', DESCR(5)

         CALL SPKPV  ( HANDLE, DESCR, ET, 'J2000', STATE, CENTER )
C     
C        The cartesian position vector is returned as the first three 
C        components of STATE, the velocity is the final three.
C      
d         WRITE (*,*)
d         WRITE (*,*) 'Spacecraft position (km):   ', STATE( 1 )
d         WRITE (*,*) '                            ', STATE( 2 )
d         WRITE (*,*) '                            ', STATE( 3 )
d         WRITE (*,*)
d         WRITE (*,*) 'Spacecraft velocity (km/s): ', STATE( 4 )
d         WRITE (*,*) '                            ', STATE( 5 )
d         WRITE (*,*) '                            ', STATE( 6 )

	XS( 1 ) = STATE( 1 )*1000.
	XS( 2 ) = STATE( 2 )*1000.
	XS( 3 ) = STATE( 3 )*1000.
	VS( 1 ) = STATE( 4 )*1000.
	VS( 2 ) = STATE( 5 )*1000.
	VS( 3 ) = STATE( 6 )*1000.

      RETURN 	
      END
