C========================================================================
C nav3.f
C------------------------------------------------------------------------
	subroutine NAV3(t,t_p,x_s_j2000,v_s_j2000,a_s_j2000)
C
C Abstract:
C	This routine is for science special processing use. It gets the
C	spacecraft status at a given time based on the time varying
C	Keplerians.
C
	implicit none

C Declarations:
C	Passing Parameters: 

	real*8 t, t_p
	real x_s_j2000(3), v_s_j2000(3), a_s_j2000(3)

C	Constant Parameters: None.
C	Include files: 

	include '../../../inc/navi3'

C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	t		I		burst reference time
C	t_p		I		time at periapsis
C	x_s_j2000	O		sensor position in j2000 coordinates
C	v_s_j2000	O		sensor velocity
C	a_s_j2000	O		sensor acceleration
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	navi3		I		contains time-varying kelperian data	
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	None.
C
C Author and Institution:
C	Michael Jin (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

	real*8 period, ecc, A
	real aincl, omg, ta0, rv, pi, gmass
	real tax, altp, alt, ar, vr, va
	real x_s_vme(3), v_s_vme(3), a_s_vme(3)
        real p1, p2, p3

        p1 = t - t_p
        p2 = p1 ** 2
        p3 = p1 ** 3

D       write (*,*) p1, p2, p3

C>>	Calculate the parameters

	!Semi_major

	A = NAVI3_A(1) + NAVI3_A(2) * P1 +
     .     NAVI3_A(3) * P2 + NAVI3_A(4) * P3

	!Eccentricity

	ECC = NAVI3_ECC(1) + NAVI3_ECC(2) * P1 +
     .       NAVI3_ECC(3) * P2 + NAVI3_ECC(4) * P3

	!Inclination

	AINCL = NAVI3_INCL(1) + NAVI3_INCL(2) * P1 +
     .         NAVI3_INCL(3) * P2 + NAVI3_INCL(4) * P3

	!Node_lon

	OMG = NAVI3_OMG(1) + NAVI3_OMG(2) * P1 +
     .       NAVI3_OMG(3) * P2 + NAVI3_OMG(4) * P3


	!Arg_periapsis

	TA0 = NAVI3_TA0(1) + NAVI3_TA0(2) * P1 +
     .       NAVI3_TA0(3) * P2 + NAVI3_TA0(4) * P3

C>>	Main code

D       write (*,*) a, ecc, aincl, omg, ta0, t_p

	pi=4*atan(1.)
	rv = 6051000.
	GMASS=3.24858765616871651*10**14.
	period=2.d0*pi*sqrt(A**3/gmass)

	call getta(period,ecc,pi,p1,tax)

	altp = A * (1 - ECC) - rv
	call snrstt(gmass,rv,altp,ecc,tax,alt,va,vr,ar)

	call gtsnr(rv,ta0,aincl,omg,tax,alt,va,vr,
     .             x_s_j2000(1),x_s_j2000(2),x_s_j2000(3),
     .             v_s_j2000(1),v_s_j2000(2),v_s_j2000(3))

	return
	end
C============== end of nav3.for ===============================
