C========================================================================
C pbw_select.f
C------------------------------------------------------------------------
        subroutine pbw_select(t_b,t_pbw,pbw_in,prf_in,maxcmnd,prf,
     .                        pbw,overlap)
C
C Abstract:
C	Selects pbw and prf according to burst time from pbw data block.
C
	implicit none

C Declarations:
C	Passing Parameters: 

	real t_b, t_pbw(950), pbw_in(950), prf_in(950)
	integer maxcmnd, overlap
	real prf, pbw

C	Constant Parameters: None.
C	Include files: None.
C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	t_b		I		burst time (sec)
C	t_pbw		I		prf command times from pbw data (sec)
C	pbw_in		I		pbw data (Hz)
C	prf_in		I		prf data (Hz)
C	maxcmnd		I		number of prf commands
C	prf		O		prf of current burst (Hz)
C	pbw		O		pbw of current burst (Hz)
C	overlap		I		1=backup 0=normal
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	None.
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	None.
C
C Author and Institution:
C	Michael Jin (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

        real stalo		! Stalo frequency of radar (hz)
        integer ipbw_set       	! Position in pbw file
        integer prf_old     	! Prf of last burst selected (hz)
        logical lpstop		! Loop flag
        logical cmnd_ok		! Selection status
	integer	istat

        save ipbw_set
        save cmnd_ok
        save prf_old

c
c   Initialization

        data ipbw_set/1/
        data prf_old/9999.0/
        data cmnd_ok/.false./
        data stalo/72.272727e6/
c
c   Selection algorithm

	istat = 0

        if (prf .eq. 0.) then
           type *,'Error in PBW_SELECT  prf=0.0'
           stop 'Stop in PBW_SELECT'
        endif

        if (t_pbw(ipbw_set) .gt. t_b .or.
     .      overlap .eq. 1      )  then         	! Reset ipbw_set to 1 
           ipbw_set = 1                              	!  if t_pbw(ipbw_set)
           cmnd_ok  = .false.                     	!  is greater than t_b  

	   istat = istat + 16

        endif

        lpstop = .false.
        do while ( lpstop .eq. .false. )   	 	! Loop to move pointer
           if ( ipbw_set .lt. maxcmnd ) then      	!  forward in time until
              if (t_pbw(ipbw_set+1) .le. t_b) then    	!  t_pbw(ipbw_set+1)  
                 ipbw_set=ipbw_set+1              	!  is greater than t_b
                 cmnd_ok = .false.                   	!  or ipbw_set is equal

		 istat = istat + 32

              else                                  	!  to the number of 
                 lpstop = .true.                	!  commands
              endif                               	!  
           else                                    	!  
              lpstop = .true.
           endif
	end do


        IF (nint(stalo/(32*prf)) .ne.           	! If prf change then 
     &        nint(stalo/(32*prf_old))) THEN
		 cmnd_ok=.false.			!  new command
		 istat = istat + 1
	END IF

        prf_old=prf
        if (cmnd_ok .eq. .false. ) then              	! If new command then
           if (nint(stalo/(32*prf_in(ipbw_set))) .eq. 	!  use pbw(ipbw_set) if
     &             nint(stalo/(32*prf)) ) then       	!  prf equals prf_in
              pbw=pbw_in(ipbw_set)
              cmnd_ok = .true.

	      istat = istat + 2

           else                                     	! Else use pbw from 
              if (ipbw_set .lt. maxcmnd) then           		
                 if ( nint(stalo/(32*prf_in(ipbw_set+1))) .eq. !  next cmnd
     &                   nint(stalo/(32*prf)) ) then
                    pbw=pbw_in(ipbw_set+1)
                    cmnd_ok = .true.

		    istat = istat + 4

                 endif
              endif
              if (ipbw_set .gt. 1) then
                 if ( nint(stalo/(32*prf_in(ipbw_set-1))) .eq. !  previous cmnd
     &                   nint(stalo/(32*prf)) ) then
                    pbw=pbw_in(ipbw_set-1)
                    cmnd_ok = .true.

		    istat = istat + 8

                 endif
              endif
           endif
        endif
     
        if ( cmnd_ok .eq. .false. ) then

           type *, 'Error in PBW_SELECT ', t_b, prf, pbw, ipbw_set,
	2	   istat, t_pbw( ipbw_set ), pbw_in( ipbw_set ),
	3	   prf_in( ipbw_set ), overlap, maxcmnd,
	4	   pbw_in( ipbw_set+1 ), prf_in( ipbw_set+1 ),
	5	   t_pbw( ipbw_set+1 )

		pbw = .6 * prf
        endif

d      type *, 'prf,pbw,ipbw_set,t_b=',prf,pbw,ipbw_set,t_b


        return
        end

