C========================================================================
C quaternion.f
C------------------------------------------------------------------------
	subroutine quaternion(dmp,tb_tp,dqm,q,qm,tsup)
C
C Abstract:
C	Computes the pointing quaternions from the MQPC
C
	implicit none

C Declarations:
C	Passing Parameters: 

	real dmp(4,9), tb_tp, dqm(4), q(4,4), qm(4), tsup(9)

C	Constant Parameters: None.
C	Include files: 

	include '../../../inc/pc'

C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	dmp		I		quaternion from MQPC
C	tb_tp		I		burst time since periapsis
C	dqm		I		delta quaternion
C	q		O		computed quaternion in other form
C	qm		O		computed quaternion
C	tsup		O		TBD		
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	pc		I		processor configuration 
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C pc:
C	PC_FLAG_QUAT_USAGE  I		use quaternion or not
C
C Files:
C	None.
C
C Author and Institution:
C	Michael Jin (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

	real qmc(4), dqmc(4), qmc_mag
	integer i, j, l

	tsup(1)=1.
	do j=2,9
	if(abs(tsup(j-1)).lt.1.e-20) then
	tsup(j) = 0.
	else
	tsup(j)=tb_tp*tsup(j-1)
	end if

	end do

	do i=1,4
	qm(i)=0.
		do j=1,9
		qm(i)=qm(i)+dmp(i,j)*tsup(j)	!from MQPC to quaternion
		end do
D	type *, 'qm(',i,')=',qm(i)
	end do

	IF ( PC_FLAG_QUAT_USAGE .EQ. 0 ) THEN

	do i=1,3
	dqmc(i)=dqm(i)/2		!use delta quaternion
	end do
	dqmc(4)=sqrt(1-dqmc(1)**2-dqmc(2)**2-dqmc(3)**2)

C	The following combines the quaternions with the delta quaternions

	qmc(1)=qm(4)*dqmc(1)-qm(3)*dqmc(2)+qm(2)*dqmc(3)+qm(1)*dqmc(4)
	qmc(2)=qm(3)*dqmc(1)+qm(4)*dqmc(2)-qm(1)*dqmc(3)+qm(2)*dqmc(4)
	qmc(3)=-1*qm(2)*dqmc(1)+qm(1)*dqmc(2)+
     c	qm(4)*dqmc(3)+qm(3)*dqmc(4)
	qmc(4)=-1*qm(1)*dqmc(1)-qm(2)*dqmc(2)-
     c	qm(3)*dqmc(3)+qm(4)*dqmc(4)

	else
		do l=1,4
		qmc(i) = qm(i)
		end do

	end if


D	do l=1,4
D	type *, 'qmc(',l,')=',qmc(l)
D	end do

	qmc_mag=sqrt(qmc(1)**2+qmc(2)**2+qmc(3)**2+qmc(4)**2)

	do i=1,4
	qm(i)=qmc(i)/qmc_mag 	!Normalize the quaternions
	end do

	q(1,1)=qm(1)*qm(1)	!Quaternions in another form
	q(2,2)=qm(2)*qm(2)
	q(3,3)=qm(3)*qm(3)
	q(4,4)=qm(4)*qm(4)

	q(1,2)=2*qm(1)*qm(2)
	q(1,3)=2*qm(1)*qm(3)
	q(1,4)=2*qm(1)*qm(4)
	q(2,3)=2*qm(2)*qm(3)
	q(2,4)=2*qm(2)*qm(4)
	q(3,4)=2*qm(3)*qm(4)

	return
	end
