C========================================================================
C ra_alfa.f
C------------------------------------------------------------------------
	subroutine Ra_Alfa(hgt,theta_a,alpha1,R_ao)
C
C Abstract:
C	Computes:
C
C	1) The apparent range which is from the ray entry point (EP) at the 
C	top of the atmosphere to the surface intersept point (SIP).
C	2) Angle between SIP, EP, and center of Venus
C
C	based on elevation of the assumed sphere & incidence angle at top 
C	of the atmosphere (~80km above). The results are based upon two sets 
C	of polynomial coefficients r_coef and alfa_coef.
C
	implicit none

C Declarations:
C	Passing Parameters: 

	real hgt, theta_a, alpha1, R_ao

	real ang_order, elev_order
	real coef1(20),coef2(20)
	real*8 r_coef(10,10),alfa_coef(10,10)
	common /array4/ang_order,elev_order,r_coef,alfa_coef

C	Constant Parameters: None.
C	Include files: None.
C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	hgt		I		elevation of assumed sphere
C	theta_a		I		incidence angle at top of atmosphere
C					(~80km above)
C	alpha1		O		angle between SIP, EP & center of venus
C	R_ao		O		apparent range between BIP & BIP at top C					of atmosphere.
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	array4		I		range & alpha coefficients
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	see above
C
C Files:
C	None.
C
C Author and Institution:
C	Michael Jin (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

	integer n_ang, n_hgt
	integer i, j
	real temp1, temp2

	n_ang=ang_order+1
	n_hgt=elev_order+1

	temp1=theta_a
	temp2=hgt/1000.


	R_ao=0.
	alpha1=0.

     	     do i=n_ang,1,-1
	     coef1(i)=0.
	     coef2(i)=0.
		do j=n_hgt,1,-1
		coef1(i)=coef1(i)*temp2+r_coef(i,j)
		coef2(i)=coef2(i)*temp2+alfa_coef(i,j)
		end do
	     R_ao=R_ao*temp1+coef1(i)
	     alpha1=alpha1*temp1+coef2(i)
	     end do

	return
	end
