C========================================================================
C rcvr_gn_crr1.f
C------------------------------------------------------------------------
	subroutine rcvr_gn_crr1(Gs_raw,RXU_A_state,Gr,T_RX_A,T_RX_B)
C
C Abstract:
C	Computes receiver gain
C
	implicit none

C Declarations:
C	Passing Parameters: 

	integer Gs_raw
	real RXU_A_state, Gr, T_RX_A, T_RX_B

C	Constant Parameters: None.
C	Include files: None.
C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	Gs_raw		I		raw data of gain scale
C	RXU_A_state	I		determines if A or B state or RXU cable
C	T_RX_A, T_TX_B	I		temperature A and B of RXU cable
C	Gr		O		receiver gain
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	None.
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	None.
C
C Author and Institution:
C	Cynthia L. Wong (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

	real dca, dct, dc_rx
        real dCA_A(8), dCA_B(8), xmin_temp /285./, xmean_temp /292.5/

        data dCA_A /0.,3.97,8.2,12.17,16.22,20.19,24.42,28.39/
        data dCA_B /0.,3.94,8.08,12.02,16.07,20.01,24.15,28.09/

        if (RXU_A_state.eq.1) then
        dCA=dCA_A(Gs_raw+1)
        else
        dCA=dCA_B(Gs_raw+1)
        end if

        if (RXU_A_state.eq.1) then
           if ( T_RX_A .lt. xmin_temp) then
              write (*,*) 'T_RX_A < ', xmin_temp, T_RX_A
              dCT=-1.38624+0.05515*(xmean_temp-273.12)
           else
              dCT=-1.38624+0.05515*(T_RX_A-273.12)
           endif
        else
           if ( T_RX_B .lt. xmin_temp ) then
              write (*,*) 'T_RX_B < ', xmin_temp, T_RX_B
              dCT=-1.28207+0.05455*(xmin_temp-273.12)
           else
              dCT=-1.28207+0.05455*(T_RX_B-273.12)
           endif
        end if
        
        dC_RX=dCT+dCA
        dC_RX=10**(dC_RX/10.)
        Gr=1./dC_RX
        
	return
	end
