C========================================================================
C rfd_of_rdiop.f
C------------------------------------------------------------------------
	subroutine rfd_of_Rdiop(t_m,t_p,r_m,fd_m,dr,df,Dlta_r,PBW,r_rg,fd_rg)
C
C Abstract:
C	Computes the range and Doppler values for each 
C	radiometric reference point based on the slant range swath
C 	and the processing bandwidth
C
	implicit none

C Declarations:
C	Passing Parameters: 

	real*8 t_m, t_p
	real r_m, fd_m, dr, df, Dlta_r, pbw, r_rg(3,3),fd_rg(3,3)

C	Constant Parameters: None.
C	Include files: None.
C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	t_m		I		burst center time
C	t_p		I		time at periapsis
C	r_m, fd_m	I		range & doppler freq. of MRP
C	dr		I		slant range sample spacing
C	df		I		frequency sampling interval
C	Dlta_r		I		apparent range relative to central 
C					radiometric grid point
C	pbw		I		processing bandwidth
C	r_rg, fd_rg	O		range & doppler freq. of radiometric
C					reference points
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	None.
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	None.
C
C Author and Institution:
C	Michael Jin (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:
	
	real*8 ratio, r0, rc, fd0, fdc
	integer i, j

        ratio = 1.25d0 - abs(t_m - t_p) * .75d0/1250.d0

	r0 = int(r_m/dr)*dr
	rc = int(DltA_r/(3.d0*dr))*dr*ratio

	fd0 = int(fd_m/df)*df
	fdc = int(PBW/(3.d0*df))*df

	do i=1,3
	do j=1,3
	r_rg(i,j)= r0 + (i-2) * rc
	fd_rg(i,j)= fd0 + (j-2) * fdc
	end do
	end do

	return
	end
