C========================================================================
C sclk2t.f
C------------------------------------------------------------------------
      FUNCTION SCLK2T( INDEX, SUB )
C
C Abstract:
C	This subroutine was written to convert SCLK parameters from
C	rim counts to the burst start time.
C
	implicit none

C Declarations:
C	Passing Parameters: 

      INTEGER*4		INDEX		
      CHARACTER*4	SUB	

C	Constant Parameters: None.
C	Include files: 

      include	 '../../../inc/pmc'
      include	 '../../../inc/telem'
      include	 '../../../inc/timec'
      include	 '../../../inc/sar_stat'

C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	index 		I		Index into telemetry data common block
C	sub		I		name of desired substructure
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	see include file listing
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	None.
C
C Author and Institution:
C	Cynthia L. Wong (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

      REAL*8		RIM_CNT		! Rim count integer form
      INTEGER*4		MOD91_CNT	! Mod 91 count integer form
      INTEGER*4		MOD10_CNT	! Mod 10 count integer form
      INTEGER*4		MOD8_CNT	! Mod 8 count integer form
      INTEGER*4		I,J,K,L,M,N	! General purpose
      INTEGER*4		RIM1
      INTEGER*4		RIM2
      INTEGER*4		RIM3
      REAL*8		BS_TDB		! Burst start time
      REAL*8		SCLK2T		! Returned value = BS_TDB
      REAL*8		CR_RIM 		! Time of Cycle Reset in RIM counts
      REAL*8		CR_TDB		! Time of Cycle Reset in TBD seconds
      REAL*8		T0		! Time from Cycle Reset to the time
      					! of Actual RF Pulse Out
      REAL*8	CR_CS_OFFSET  / 7.0 /	! Offset between Cycle Reset and
      					! cycle start
      REAL*8	CS_DUR	    / 453.0 /	! Cycle start duration
      REAL*8 PRF_APRO_OFFSET / 10.0 /	! Offset between PRF rising and
      					! actual RF pulse out

***   Convert from byte to integer   ***

      IF ( INDEX .LE. 0 ) RETURN
      IF ( SUB .EQ. 'SA' .OR. SUB .EQ. 'sa' ) THEN

 	RIM1 = TD_SA_RIM( 1,INDEX )
 	RIM2 = TD_SA_RIM( 2,INDEX )
 	RIM3 = TD_SA_RIM( 3,INDEX )
 	MOD91_CNT = TD_SA_RIM( 4,INDEX )
 	MOD10_CNT = TD_SA_RIM( 5,INDEX )
 	MOD8_CNT  = TD_SA_RIM( 6,INDEX )

      ELSE IF ( SUB .EQ. 'SB1' .OR. SUB .EQ. 'sb1' ) THEN

 	RIM1 = TD_SB1_RIM( 1,INDEX )
 	RIM2 = TD_SB1_RIM( 2,INDEX )
 	RIM3 = TD_SB1_RIM( 3,INDEX )
 	MOD91_CNT = TD_SB1_RIM( 4,INDEX )
 	MOD10_CNT = TD_SB1_RIM( 5,INDEX )
 	MOD8_CNT  = TD_SB1_RIM( 6,INDEX )

      ELSE IF ( SUB .EQ. 'SB2' .OR. SUB .EQ. 'sb2' ) THEN

 	RIM1 = TD_SB2_RIM( 1,INDEX )
 	RIM2 = TD_SB2_RIM( 2,INDEX )
 	RIM3 = TD_SB2_RIM( 3,INDEX )
 	MOD91_CNT = TD_SB2_RIM( 4,INDEX )
 	MOD10_CNT = TD_SB2_RIM( 5,INDEX )
 	MOD8_CNT  = TD_SB2_RIM( 6,INDEX )

      ELSE IF ( SUB .EQ. 'SB3' .OR. SUB .EQ. 'sb3' ) THEN

 	RIM1 = TD_SB3_RIM( 1,INDEX )
 	RIM2 = TD_SB3_RIM( 2,INDEX )
 	RIM3 = TD_SB3_RIM( 3,INDEX )
 	MOD91_CNT = TD_SB3_RIM( 4,INDEX )
 	MOD10_CNT = TD_SB3_RIM( 5,INDEX )
 	MOD8_CNT  = TD_SB3_RIM( 6,INDEX )

      ELSE IF ( SUB .EQ. 'SB4' .OR. SUB .EQ. 'sb4' ) THEN

 	RIM1 = TD_SB4_RIM( 1,INDEX )
 	RIM2 = TD_SB4_RIM( 2,INDEX )
 	RIM3 = TD_SB4_RIM( 3,INDEX )
 	MOD91_CNT = TD_SB4_RIM( 4,INDEX )
 	MOD10_CNT = TD_SB4_RIM( 5,INDEX )
 	MOD8_CNT  = TD_SB4_RIM( 6,INDEX )

      ELSE IF ( SUB .EQ. 'SB5' .OR. SUB .EQ. 'sb5' ) THEN

 	RIM1 = TD_SB5_RIM( 1,INDEX )
 	RIM2 = TD_SB5_RIM( 2,INDEX )
 	RIM3 = TD_SB5_RIM( 3,INDEX )
 	MOD91_CNT = TD_SB5_RIM( 4,INDEX )
 	MOD10_CNT = TD_SB5_RIM( 5,INDEX )
 	MOD8_CNT  = TD_SB5_RIM( 6,INDEX )

      ELSE IF ( SUB .EQ. 'RBRA' .OR. SUB .EQ. 'rbra' ) THEN

 	RIM1 = TD_RBRA_RIM( 1,INDEX )
 	RIM2 = TD_RBRA_RIM( 2,INDEX )
 	RIM3 = TD_RBRA_RIM( 3,INDEX )
 	MOD91_CNT = TD_RBRA_RIM( 4,INDEX )
 	MOD10_CNT = TD_RBRA_RIM( 5,INDEX )
 	MOD8_CNT  = TD_RBRA_RIM( 6,INDEX )

      ELSE IF ( SUB .EQ. 'RBRB' .OR. SUB .EQ. 'rbrb' ) THEN

 	RIM1 = TD_RBRB_RIM( 1,INDEX )
 	RIM2 = TD_RBRB_RIM( 2,INDEX )
 	RIM3 = TD_RBRB_RIM( 3,INDEX )
 	MOD91_CNT = TD_RBRB_RIM( 4,INDEX )
 	MOD10_CNT = TD_RBRB_RIM( 5,INDEX )
 	MOD8_CNT  = TD_RBRB_RIM( 6,INDEX )

      ELSE IF ( SUB .EQ. 'RBOA' .OR. SUB .EQ. 'rboa' ) THEN

 	RIM1 = TD_RBOA_RIM( 1,INDEX )
 	RIM2 = TD_RBOA_RIM( 2,INDEX )
 	RIM3 = TD_RBOA_RIM( 3,INDEX )
 	MOD91_CNT = TD_RBOA_RIM( 4,INDEX )
 	MOD10_CNT = TD_RBOA_RIM( 5,INDEX )
 	MOD8_CNT  = TD_RBOA_RIM( 6,INDEX )

      ELSE IF ( SUB .EQ. 'RBOB' .OR. SUB .EQ. 'rbob' ) THEN

 	RIM1 = TD_RBOB_RIM( 1,INDEX )
 	RIM2 = TD_RBOB_RIM( 2,INDEX )
 	RIM3 = TD_RBOB_RIM( 3,INDEX )
 	MOD91_CNT = TD_RBOB_RIM( 4,INDEX )
 	MOD10_CNT = TD_RBOB_RIM( 5,INDEX )
 	MOD8_CNT  = TD_RBOB_RIM( 6,INDEX )

      ELSE IF ( SUB .EQ. 'RBXA' .OR. SUB .EQ. 'rbxa' ) THEN

 	RIM1 = TD_RBXA_RIM( 1,INDEX )
 	RIM2 = TD_RBXA_RIM( 2,INDEX )
 	RIM3 = TD_RBXA_RIM( 3,INDEX )
 	MOD91_CNT = TD_RBXA_RIM( 4,INDEX )
 	MOD10_CNT = TD_RBXA_RIM( 5,INDEX )
 	MOD8_CNT  = TD_RBXA_RIM( 6,INDEX )

      ELSE IF ( SUB .EQ. 'RBXB' .OR. SUB .EQ. 'rbxb' ) THEN

 	RIM1 = TD_RBXB_RIM( 1,INDEX )
 	RIM2 = TD_RBXB_RIM( 2,INDEX )
 	RIM3 = TD_RBXB_RIM( 3,INDEX )
 	MOD91_CNT = TD_RBXB_RIM( 4,INDEX )
 	MOD10_CNT = TD_RBXB_RIM( 5,INDEX )
 	MOD8_CNT  = TD_RBXB_RIM( 6,INDEX )

      ELSE

      	TYPE *
      	TYPE *,'  ERROR! No substructure with this name ',SUB
      	TYPE *

      END IF

***   Calculate time of Cycle Reset in RIM counts   ***

        IF ( RIM1 .LT. 0 ) RIM1 = RIM1 + 256
        IF ( RIM2 .LT. 0 ) RIM2 = RIM2 + 256
        IF ( RIM3 .LT. 0 ) RIM3 = RIM3 + 256
 	RIM_CNT   = RIM1 * 256 ** 2
     &	    	  + RIM2 * 256
     &   	  + RIM3
        IF ( MOD91_CNT .LT. 0 ) MOD91_CNT = MOD91_CNT + 256
        IF ( MOD10_CNT .LT. 0 ) MOD10_CNT = MOD10_CNT + 256
        IF ( MOD8_CNT .LT. 0 ) MOD8_CNT = MOD8_CNT + 256

      CR_RIM = RIM_CNT + FLOAT( MOD91_CNT ) / 91.0
     &		       + FLOAT( MOD10_CNT ) / 910.0
     &		       + FLOAT(  MOD8_CNT ) / 7280.0

***   Calculate time of Cycle Reset in TDB seconds   ***

	CR_TDB = ( CR_RIM - TIMEC_RIM_SCLK0 ) * TIMEC_A1
     &        + TIMEC_A0_SECONDS

***   Calculate T0 the time in spacecraft seconds from    ***
***   Cycle Reset to the time of Actual RF Pulse Output   ***

      T0 = ( - CR_CS_OFFSET + CS_DUR + ( SAR_STAT_PRF_CODE(1) - 1 )
     &     + PRF_APRO_OFFSET ) * 0.4428E-6

***   Calculate the burst start time and assume TDB seconds   ***

      BS_TDB = CR_TDB + T0 + ( ZERO_RANGE_TIME / 2.0 )
      SCLK2T = BS_TDB
      END

****************   End of program code and source file   ****************

