C========================================================================
C tlmf.f
C------------------------------------------------------------------------
      SUBROUTINE TLMF( FIL_09, FIL_10 )
C
C Abstract:
C	Extracts MGN telemetry data
C
	implicit none

C Declarations:
C	Passing Parameters: 

      CHARACTER*(*)	FIL_09
      CHARACTER*(*)	FIL_10

      CHARACTER*80	FILE_09
      CHARACTER*80	FILE_10
      COMMON / FNBLK /  FILE_09, FILE_10

C	Constant Parameters: None.
C	Include files: 

      include '../../../inc/pmc'
      include '../../../inc/telem'

C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	file_09		I		name of dcomdcal file
C	file_10		I		name of engineering file
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	see include listing file.
C	FNBLK		O		stores filenames of file 09 & 10
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	Reads the dcomdcal and engineering file from EDR.
C
C Author and Institution:
C	Cynthia L. Wong (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

      REAL*8	RBUFA( MOD1_MAX )	! Real filtering buffer A
      REAL*8	RBUFB( MOD1_MAX )	! Real filtering buffer B
      integer n, i			! scratch indices

***   Call subroutine TLMC to load the data structure   ***

      FILE_09 = FIL_09
      FILE_10 = FIL_10
      CALL TLMC

***   Report the first 10 values   ***

      TYPE *
      TYPE *,'    Subroutine TLMF reporting befor filtering'
      TYPE *
C      DO I = 1,10
C    	TYPE *,'  Q1: ',TD_SA_Q(1,I)
C    	TYPE *,'  Q2: ',TD_SA_Q(2,I)
C    	TYPE *,'  Q3: ',TD_SA_Q(3,I
C    	TYPE *
C        TYPE *,'  Cable temp 1: ',TD_SB1_TEMP( I )
C        TYPE *,'  Cable temp 2: ',TD_SB2_TEMP( I )
C        TYPE *,'  Cable temp 3: ',TD_SB3_TEMP( I )
C        TYPE *,'  Cable temp 4: ',TD_SB4_TEMP( I )
C       TYPE *,'  Cable temp 5: ',TD_SB5_TEMP( I )
C   	TYPE *( I )
C    	TYPE *,'   RXU A TEMP: ',TD_RBRA_TEMP( I )
C    	TYPE *,'   RXU B TEMP: ',TD_RBRB_TEMP( I )
C    	TYPE *,'   ONU A TEMP: ',TD_RBOA_TEMP( I )
C    	TYPE *,'   ONU B TEMP: ',TD_RBOB_TEMP( I )
C    	TYPE *,'  XMTR A TEMP: ',TD_RBXA_TEMP( I )
C    	TYPE *,'  XMTR B TEMP: ',TD_RBXB_TEMP( I )
C      END DO
C      TYPE *
      TYPE *,'                        Sample counts  '
      TYPE *
      TYPE *,'  NSA: ',TD_NSA
      TYPE *,'  NSB1: ',TD_NSB1
      TYPE *,'  NSB2: ',TD_NSB2
      TYPE *,'  NSB3: ',TD_NSB3
      TYPE *,'  NSB4: ',TD_NSB4
      TYPE *,'  NSB5: ',TD_NSB5
      TYPE *,'  NRBRA: ',TD_NRBRA
      TYPE *,'  NRBRB: ',TD_NRBRB
      TYPE *,'  NRBOA: ',TD_NRBOA
      TYPE *,'  NRBOB: ',TD_NRBOB
      TYPE *,'  NRBXA: ',TD_NRBXA
      TYPE *,'  NRBXB: ',TD_NRBXB
      TYPE *
      TYPE *,'              SAR States '
      TYPE *
      TYPE *,'   RXU A State: ',TD_RXU_A_STATE
      TYPE *,'   RXU B State: ',TD_RXU_B_STATE
      TYPE *,'   ONU A State: ',TD_ONU_A_STATE
      TYPE *,'   ONU B State: ',TD_ONU_B_STATE
      TYPE *,'  XMTR A State: ',TD_XMTR_A_STATE
      TYPE *,'  XMTR B State: ',TD_XMTR_B_STATE
      TYPE *

***   Check the states   ***

      IF ( TD_RXU_A_STATE .EQ. TD_RXU_B_STATE ) THEN
      	TYPE *,'  WARNING ! Invalid RXU states'
      END IF
      IF ( TD_ONU_A_STATE .EQ. TD_ONU_B_STATE ) THEN
      	TYPE *,'  WARNING ! Invalid ONU states'
      END IF
      IF ( TD_XMTR_A_STATE .EQ. TD_XMTR_B_STATE ) THEN
      	TYPE *,'  WARNING ! Invalid XMTR states'
      END IF

***   Filter data with subroutine TLMFLTR   ***

      N = TD_NSB1
      DO I = 1,N				! Get cable temp 1
      	RBUFA( I ) = TD_SB1_TEMP( I )
      END DO
      CALL TLMFLTR( N,RBUFA,RBUFB )		! Filter data vector
      DO I = 1,N				! Put cable temp 1 back
      	 TD_SB1_TEMP( I ) = RBUFB( I )	! in the telemetry data
      END DO					! structure

      N = TD_NSB2
      DO I = 1,N				! Get cable temp 2
      	RBUFA( I ) = TD_SB2_TEMP( I )
      END DO
      CALL TLMFLTR( N,RBUFA,RBUFB )		! Filter data vector
      DO I = 1,N				! Put cable temp 2 back
      	 TD_SB2_TEMP( I ) = RBUFB( I )	! in the telemetry data
      END DO					! structure

      N = TD_NSB3
      DO I = 1,N				! Get cable temp 3
      	RBUFA( I ) = TD_SB3_TEMP( I )
      END DO
      CALL TLMFLTR( N,RBUFA,RBUFB )		! Filter data vector
      DO I = 1,N				! Put cable temp 3 back
      	 TD_SB3_TEMP( I ) = RBUFB( I )	! in the telemetry data
      END DO					! structure

      N = TD_NSB4
      DO I = 1,N				! Get cable temp 4
      	RBUFA( I ) = TD_SB4_TEMP( I )
      END DO
      CALL TLMFLTR( N,RBUFA,RBUFB )		! Filter data vector
      DO I = 1,N				! Put cable temp 4 back
      	 TD_SB4_TEMP( I ) = RBUFB( I )	! in the telemetry data
      END DO					! structure

      N = TD_NSB5
      DO I = 1,N				! Get cable temp 5
      	RBUFA( I ) = TD_SB5_TEMP( I )
      END DO
      CALL TLMFLTR( N,RBUFA,RBUFB )		! Filter data vector
      DO I = 1,N				! Put cable temp 5 back
      	 TD_SB5_TEMP( I ) = RBUFB( I )	! in the telemetry data
      END DO					! structure

      N = TD_NRBRA
      DO I = 1,N				! Get preamp. A temp
      	RBUFA( I ) = TD_RBRA_TEMP( I )
      END DO
      CALL TLMFLTR( N,RBUFA,RBUFB )		! Filter data vector
      DO I = 1,N				! Put preamp. A temp back
      	 TD_RBRA_TEMP( I ) = RBUFB( I )	! in the telemetry data
      END DO					! structure

      N = TD_NRBRB
      DO I = 1,N				! Get preamp. B temp
      	RBUFA( I ) = TD_RBRB_TEMP( I )
      END DO
      CALL TLMFLTR( N,RBUFA,RBUFB )		! Filter data vector
      DO I = 1,N				! Put preamp. B temp back
      	 TD_RBRB_TEMP( I ) = RBUFB( I )	! in the telemetry data
      END DO					! structure

      N = TD_NRBOA
      DO I = 1,N				! Get SAR temp. A
      	RBUFA( I ) = TD_RBOA_TEMP( I )
      END DO
      CALL TLMFLTR( N,RBUFA,RBUFB )		! Filter data vector
      DO I = 1,N				! Put SAR temp. A back
      	 TD_RBOA_TEMP( I ) = RBUFB( I )	! in the telemetry data
      END DO					! structure

      N = TD_NRBOB
      DO I = 1,N				! Get SAR temp. B
      	RBUFA( I ) = TD_RBOB_TEMP( I )
      END DO


Cccccccccc  JG  07/14/90:

      CALL TLMFLTR( N,RBUFA,RBUFB )		! Filter data vector

Cccccccccc End of change.


Ccc      CALL TLMFLTR( NRBOB,RBUFA,RBUFB )		! Filter data vector
      DO I = 1,N				! Put SAR temp. B back
      	 TD_RBOB_TEMP( I ) = RBUFB( I )	! in the telemetry data
      END DO					! structure

      N = TD_NRBXA
      DO I = 1,N				! Get stage 1 temp. A
      	RBUFA( I ) = TD_RBXA_TEMP( I )
      END DO
      CALL TLMFLTR( N,RBUFA,RBUFB )		! Filter data vector
      DO I = 1,N				! Put stage 1 temp. A back
      	 TD_RBXA_TEMP( I ) = RBUFB( I )	! in the telemetry data
      END DO					! structure

      N = TD_NRBXB
      DO I = 1,N				! Get stage 1 temp. B
      	RBUFA( I ) = TD_RBXB_TEMP( I )
      END DO
      CALL TLMFLTR( N,RBUFA,RBUFB )		! Filter data vector
      DO I = 1,N				! Put stage 1 temp. B back
      	 TD_RBXB_TEMP( I ) = RBUFB( I )	! in the telemetry data
      END DO					! structure

***   Report the first 10 values   ***

C      TYPE *
C      TYPE *,'    Subroutine TLMF reporting after filtering'
C      TYPE *
C      DO I = 1,10
C    	TYPE *,'  Q1: ',TD_SA_Q( 1,I )
C    	TYPE *,'  Q2: ',TD_SA_Q( 2,I )
C    	TYPE *,'  Q3: ',TD_SA_Q( 3,I )
C    	TYPE *
C        TYPE *,'  Cable temp 1: ',TD_SB1_TEMP( I )
C        TYPE *,'  Cable temp 2: ',TD_SB2_TEMP( I )
C        TYPE *,'  Cable temp 3: ',TD_SB3_TEMP( I )
C        TYPE *,'  Cable temp 4: ',TD_SB4_TEMP( I )
C        TYPE *,'  Cable temp 5: ',TD_SB5_TEMP( I )
C    	TYPE *
C    	TYPE *,'   RXU A TEMP: ',TD_RBRA_TEMP( I )
C    	TYPE *,'   RXU B TEMP: ',TD_RBRB_TEMP( I )
C    	TYPE *,'   ONU A TEMP: ',TD_RBOA_TEMP( I )
C    	TYPE *,'   ONU B TEMP: ',TD_RBOB_TEMP( I )
C    	TYPE *,'  XMTR A TEMP: ',TD_RBXA_TEMP( I )
C    	TYPE *,'  XMTR B TEMP: ',TD_RBXB_TEMP( I )
C    	TYPE *
C      END DO
      RETURN
      END
