C========================================================================
C tlmfltr.f
C------------------------------------------------------------------------
      SUBROUTINE TLMFLTR( NTEMPS, INTEMP, OUTEMP )
C
C Abstract:
C	This subroutine is called by TLMF to filter the decalibrated
C	Magellan telemetry data.
C
	implicit none

C Declarations:
C	Passing Parameters: 

	integer ntemps
	real*8 intemp(1), outemp(1)

C	Constant Parameters: None.
C	Include files: None.
C
C Brief I/O:
C	Variable	I/O		Description
C       --------	---		------------
C	ntemps		I		# of data elements
C	intemp		I		input unfiltered temperature values
C	outemp		O		output filtered temperature values
C
C Constant Parameters:
C	None.
C
C Common Blocks:
C	Name		I/O		Description
C       ----		---		------------
C	None.
C
C Detailed I/O through common blocks:
C
C	Variable	I/O		Description
C       --------	---		------------
C	TBD
C
C Files:
C	None.
C
C Author and Institution:
C	Cynthia L. Wong (JPL).
C
C References:
C	Source is obtainted from MGN/SDPS/PSP preprocessing software on VAX.
C
C Revised Information:
C	PPLIB 05-01-1992 (CLW) - To be compatible to Alliant FX/2800.
C
C========================================================================
C Local Variables:

      REAL*8 	D, D1, DMAX		! Deltas
      REAL*8 	SUM			! Sumation of temps.
      INTEGER*4 I, J, K, L, M, N	! Indexes

      integer ncount
      real*8  dt

***   Initializations   ***

      DMAX = 5.0
      SUM  = 0.0

***   Check the first value   ***

c      IF ( DABS( INTEMP( 2 ) - INTEMP( 1 ) ) .GT. DMAX ) THEN
c      	DO I = 1, 8
c      	  SUM = SUM + INTEMP( I )
c      	END DO
c      	OUTEMP( 1 ) = SUM / 8.0
c      	OUTEMP( 2 ) = OUTEMP( 1 )
c      ELSE
c      	OUTEMP( 1 ) = INTEMP( 1 )
c      END IF

C>>  Set the first value with another method (10/31/90 clw for MJ)

      ncount = 1            ! number of big delta
      i = 1

      do while ( ncount .le. 8 .and. i+1 .le. ntemps ) 

         dt = dabs( intemp(i) - intemp(i+1) ) 
         if ( dt .lt. 10. ) then
c            write (*,*) 'TLMFLTR: (start up) temp delta < 10. ',
c     .                  intemp(i), intemp(i+1), ' element', i
            sum = sum + intemp(i)
            ncount = ncount + 1
         endif
         i = i + 1

      enddo
      outemp(1) = sum / 8.

***   Now check the rest   ***


      ncount = ntemps - 1

      DO I = 2, ncount

      	OUTEMP( I ) = INTEMP( I )
      	IF ( DABS( INTEMP( I ) - INTEMP( I - 1 ) ) .GT. DMAX ) THEN
      	  OUTEMP( I ) = ( INTEMP( I + 1 ) + OUTEMP( I - 1 ) ) / 2.0
      	END IF

        dt = dabs( outemp(i) - outemp(i-1) )             ! clw for JC
        if ( dt .gt. dmax ) outemp(i) = outemp(i-1)

      END DO

      outemp(ntemps) = intemp(ntemps)
      dt = dabs( outemp(i) - outemp(i-1) )             
      if ( dt .gt. dmax ) outemp(i) = outemp(i-1)

      RETURN
      END

***************   End of program code and source file   ***************

