/*
	@(#)altedr.h   MgnAlt 1.2 (MIT/CSR) 11/21/89

	Function:	Define structure of ALT-EDR and SAR-EDR
	System:		Magellan Altimetry Data Reduction
	Program:	MgnAlt
	Module:		altedr.h
	Revision:	1.2
	Date:		11/21/89
	Author:		pgf@space.mit.edu
	Created:	Thu Apr 14 11:42:33 EDT 1988
	Checker:	
	Checked:	
	Control:	SCCS
*/

	/*
	**	Project Magellan ALT-EDR and SAR-EDR Data Structures
	*/

#include	"mgm.h"

	/*
	**	TIS Primary Header
	*/
					/* Begin tis_1.h */
typedef	struct	{			/* altedr.h 1.2 11/21/89 */
	chdo	t1_chdo;		/* CHDO type=31, length=8 */
	struct	recid	{
		uchar	t1_major,	/* SFDU Major Type */
			t1_minor,	/* SFDU Minor Type */
			t1_mission_id,	/* Mission ID Code */
			t1_format;	/* SFDU Format */
	}	t1_recid;		/* Record id */
} tis_1;
					/* End tis_1.h */
	/*
	**	Organization Codes
	*/

#define	ORG_DSN		48		/* Deep Space Network */
#define	ORG_FEP		66		/* Front End Processor (AMPTE/DACS) */
#define	ORG_CMD		100		/* Command Subsystem */
#define	ORG_DMD		101		/* Data Monitor and Display */
#define	ORG_CDA		102		/* Central Data Access */
#define	ORG_DPS		103		/* Data Products Subsystem */
#define	ORG_DTS		104		/* Data Transport Subsystem */
#define	ORG_DTV		105		/* Digital Television Subsystem */
#define	ORG_EAS		106		/* Engineering Analysis */
#define	ORG_EUA		107		/* External User Access */
#define	ORG_GIF		108		/* GCF Interface */
#define	ORG_MAS		109		/* Mission Planning and Analysis */
#define	ORG_MIPL	110		/* Multimission Image Processing Lab */
#define	ORG_NAV		111		/* Multimission Navigation Subsystem */
#define	ORG_SAS		112		/* Science Analysis Subsystem */
#define	ORG_SEQ		113		/* Sequence Generation Subsystem */
#define	ORG_SIM		114		/* Simulation System */
#define	ORG_SMC		115		/* SFOC Monitor and Control */
#define	ORG_TCA		116		/* Telecommunications Analysis */
#define	ORG_TIS		117		/* Telemetry Input System */
#define	ORG_TWS		118		/* Test Workstation */
#define	ORG_WSE		119		/* Workstation Environment */

	/*
	**	DSN Station Codes
	*/

#define	DSN_MIL_71_SPC	0x02
#define	DSN_MIL_71_LINK	0x03
#define	DSN_SIM		0x13
#define	DSN_INTERN	0x14
#define	DSN_MIL_71	0x26
#define	DSN_CTA_21	0x6b
#define	DSN_DSS_62	0x76
#define	DSN_NOCC	0x77
#define	DSN_DSS_12	0x81
#define	DSN_DSS_14	0x82
#define	DSN_DSS_15	0x83
#define	DSN_DSS_13	0x89
#define	DSN_DSS_17	0x8a
#define	DSN_DSS_18	0x8b
#define	DSN_DSS_42	0x92
#define	DSN_DSS_43	0x93
#define	DSN_DSS_45	0x94
#define	DSN_DSS_46	0x95
#define	DSN_DSS_47	0x97
#define	DSN_DSS_48	0x9a
#define	DSN_DSS_60	0xd3
#define	DSN_DSS_61	0xf3
#define	DSN_DSS_63	0xf4
#define	DSN_DSS_65	0xf5
#define	DSN_DSS_66	0xf6
#define	DSN_DSS_67	0xf7
#define	DSN_DSS_68	0xfa

	/*
	**	TIS Secondary Header
	*/
#define	T2O_NA		0	 	/* Not applicable */
#define	T2O_ROUTER_A	1 		/* Router A */
#define	T2O_ROUTER_B	2 		/* Router B */
#define	T2O_WIDEBAND	3 		/* Wideband Switch */
#define	T2O_IDR		4 		/* IDR Tape */

#define	T2C_REALTIME	0 		/* Realtime/NA */
#define	T2C_IDR		1 		/* IDR */
#define	T2C_ODR		2 		/* ODR */
#define	T2C_QL		3 		/* Quick Look */
#define	T2C_MERGED	4 		/* Merged */
#define	T2C_REPLAY	5 		/* SFDU Replay */
#define	T2C_APB		6 		/* Asynchronous Playback */

#define	T2M_PB_MODE	0x8000 		/* Playback Mode */
#define	T2M_DATA_MODE	0x4000		/* Data Simulated */
#define	T2M_TEST_MODE	0x2000		/* Generated by Flight MOS */
#define	T2M_REPLAY_MODE	0x1000		/* Replay mode */
#define	T2M_DATA_INVAL	0x0800		/* Data invalid */
#define	T2M_DSN_INVAL	0x0400		/* DSN invalid */
#define	T2M_ERT_INVAL	0x0100		/* ERT Known to be Bad */
#define	T2M_DSN_DODR	0x0080		/* Result of DSN Dodr Replay */
#define	T2M_CHKSUM_ERR	0x0040		/* Checksum error in FSS-DDR */
#define	T2M_GCF_ERR	0x0030		/* GIF Error Code */

#define	T2F_PHASE_FLG	0x80		/* Input Phase Complemented */
#define	T2F_SOFT_SYNC	0x40		/* No hardware frame sync */
#define	T2F_SCID_FORCE	0x20		/* Spacecraft ID value forced */
#define	T2F_SCLK_REF_FLG	0x10	/* SCLK ref not established */
#define	T2F_SCLK_COR_FLG	0x08	/* SCLK correction disabled */

#define	T2A_ANT_26	0x80		/* Using 26m DSS 16, 46, 66 */
#define	T2A_ANT_34_TR	0x40		/* Using 34m DSS 12, 42, 61 */
#define	T2A_ANT_34_HEF	0x20		/* Using 34m DSS 15, 45 */
#define	T2A_ANT_64	0x10		/* Using 64m DSS 14, 43, 63 */

#define	T2R_NONE	0 		/* No R-S Error */
#define	T2R_IGNORED	1		/* R-S error ignored */
#define	T2R_UNCORRECTED	2		/* R-S error found but uncorrected */
#define	T2R_CORRECTED	3		/* R-S error found & corrected */

#define	T2G_NONE	0 		/* No Golay Error */
#define	T2G_IGNORED	1		/* Golay error ignored */
#define	T2G_UNCORRECTED	2		/* Golay error found but uncorrected */
#define	T2G_CORRECTED	3		/* Golay error found & corrected */

#define	T2X_RECEIVER_1	0x80		/* Receiver #1 */
#define	T2X_RECEIVER_2	0x40		/* Receiver #2 */
#define	T2X_RECEIVER_3	0x20		/* Receiver #3 */
#define	T2X_RECEIVER_4	0x10		/* Receiver #4 */
#define	T2X_RECEIVER_5	0x08		/* Receiver #5 */
#define	T2X_RECEIVER_6	0x04		/* Receiver #6 */
#define	T2X_RECEIVER_7	0x02		/* Receiver #7 */
#define	T2X_RECEIVER_8	0x01		/* Receiver #8 */

#define	T2L_REC_LOCK     0xc000		/* Receiver out of lock */
#define	T2L_COMB_LOCK    0x3000		/* RT Combiner */
#define	T2L_DEMOD_LOCK   0x0c00		/* Subcarrier demod */
#define	T2L_SYMBOL_LOCK  0x0300		/* Symbol sync */
#define	T2L_MCD_LOCK     0x00c0		/* Convolutional decoder */
#define	T2L_FRAME_SYNC   0x0030		/* Frame sync */

#define	T2I_UPSTREAM	0x4000		/* Upstream anomaly */
#define	T2I_OTHER	0x2000		/* Data bad for unknown reason */
#define	T2I_FORMAT	0x0800		/* Frame format ID has changed */
#define	T2I_FORCED	0x0400		/* Operator forced loss of sync */
#define	T2I_PHASE	0x0200		/* Change in data phase */
#define	T2I_BREAK	0x0100		/* Data break - no sync */
#define	T2I_CLOCK	0x0080		/* New S/C clock */
#define	T2I_OFF		0x0040		/* Processor turned off */
#define	T2I_TIMEOUT	0x0020		/* Input timeout */
#define	T2I_SEQUENCE	0x0010		/* Break in input record req */
#define	T2I_OVERFLOW	0x0008		/* Real-time queue overflow */
#define	T2I_INTERFACE	0x0004		/* Error in I/O interface */

					/* Begin tis_2.h */
typedef	struct	{			/* altedr.h 1.2 11/21/89 */
	chdo	t2_chdo;		/* CHDO type=15, length=74 */
	uchar	t2_originator,		/* Origin Code=117 (ORG_TIS) */
		t2_last_modifier,	/* Last Modifier (ORG_) */
		t2_scft_id,		/* Spacecraft ID */
		t2_data_source;		/* Station ID (DSN_) */
	ushort	t2_mode;		/* Mode flags */
	scet	t2_ert;			/* Earth Received Time */
	char	t2_spare1;		/* unused */
	uchar	t2_extract_level;	/* Synchronous extraction count */
	ushort	t2_dsn_record_seq[2];	/* SFDU count (unaligned long) */
	uchar	t2_bet,			/* TIS bit error tolerance */
		t2_fly,			/* TIS flywheel factor */
		t2_reed_solomon,	/* Reed-Solomon error flag T2R_ */
		t2_golay,		/* Golay error flag T2G_ */
		t2_flag,		/* Flag fields */
		t2_pn_errors;		/* Number of parent frame sync errors */
	struct	recid
		t2_parent_frame;	/* Record ID of parent frame */
	uchar	t2_spare2,		/* spare */
		t2_frequency_band;	/* 'S', 'X', or 'C' */
	ushort	t2_bit_rate[2];		/* Data rate in bits/sec (unal) */
	uchar	t2_destination,		/* Destination code */
		t2_gdd,			/* spare */
		t2_snt[4],		/* System noise temperature (float) */
		t2_ssnr[4],		/* Symbol signal-to-noise ratio (f) */
		t2_signal_level[4],	/* Receiver signal level (float) */
		t2_ant,			/* Antenna type */
		t2_receiver,		/* Receiver type */
		t2_master_antenna,	/* 1-8 */
		t2_master_receiver,	/* 1-8 */
		t2_dtm_group,		/* 1-4 */
		t2_tlm_channel;		/* 1-2 */
	ushort	t2_lock;		/* Lock flags */
	uchar	t2_version,		/* Software version number */
		t2_build,		/* Software build number */
		t2_orig_source,		/* Origin of input T2O_ */
		t2_curr_source;		/* Current input T2C_ */
	scet	t2_rct;			/* Creation time */
	ushort	t2_anom;		/* Anomaly flags */
	short	t2_lock_count,		/* Synchronized frame lock count */
		t2_lrn;			/* Logical record number */
	char	t2_pub[6],		/* User-defined ASCII bytes */
		t2_spare3[2];		/* Spares */
} tis_2;
					/* End tis_2.h */
	/*
	**	MGN Tertiary Telemetry Header
	*/
#define	T3E_FRAME	0		/* Frame Synchronized */
#define	T3E_EXTRACT	1		/* Extracted from Frame Synchronized */
#define	T3E_EXTRACT2	2		/* Extracted from Extracted Data */

#define	M3C_RT_COR_FLG	0x8000		/* Real-time FID correction */
#define	M3C_MRO_COR_FLG	0x4000		/* Memory Readout correction */
#define	M3C_CMI_COR_FLG	0x2000		/* Comm Map Indic correction */
#define	M3C_MSN_COR_FLG	0x1000		/* Map Seq Number correction */
#define	M3C_REC_COR_FLG	0x0800		/* Recorded FID correction */
#define	M3C_RIM_COR_FLG	0x0080		/* SCLK rim count corrected */
#define	M3C_M91_COR_FLG	0x0040		/* SCLK mod-91 corrected */
#define	M3C_M10_COR_FLG	0x0020		/* SCLK mod-10 corrected */
#define	M3C_M8_COR_FLG	0x0010		/* SCLK mod-8 corrected */

#define	M3F_RT_FORCED	0x80		/* Real-time FID forced */
#define	M3F_MRO_FORCED	0x40		/* MRO FID forced */
#define	M3F_CMI_FORCED	0x20		/* Comm map FID forced */
#define	M3F_MSN_FORCED	0x10		/* Map seq FID forced */
#define	M3F_REC_FORCED	0x08		/* Recorded FID forced */
#define	M3F_ORBIT_DIR	0x04		/* =1 for southward orbit */
#define	M3F_SCET_VALID	0x02		/* =1 SCET is valid */
#define	M3F_SCET_INT	0x01		/* =1 SCET is predicted */

#define	M3I_RT_FID	0xf800		/* Real-time format ID */
#define	M3I_MRO_FLG	0x0400		/* MRO flag */
#define	M3I_CMI_ID	0x0300		/* Commutation map ID */
#define	M3I_MS_NUM	0x00e0		/* Map sequence number */
#define	M3I_PB_FID	0x001f		/* Playback format ID */

					/* Begin mgn_3.h */
typedef	struct	{			/* altedr.h 1.2 11/21/89 */
	chdo	m3_chdo;		/* CHDO type=19, length=20 */
	ushort	m3_corr;		/* Correction flags M3C */
	uchar	m3_fid,			/* More flags M3F */
		m3_extr_level;		/* Extract level T3E */
	ushort	m3_id;			/* ID fields M3I */
	sclk	m3_sclk;		/* Spacecraft clock */
	scet	m3_scet;		/* Spacecraft event time UTC */
	short	m3_orbit_number;	/* Inserted by MGN MHR */
} mgn_3;
					/* End mgn_3.h */
	/*
	**	SAB Header
	*/

typedef	struct	{
	bit			: 1,	/* Spare */
		sb_sar_fine	: 8,	/* SAR fine gate delay */
		sb_prf		: 7,	/* SAR prf */
		sb_sar_coarse	: 8,	/* SAR coarse gate delay */
		sb_gate_length	: 8,	/* SAR range gate length */
		sb_pulse_count	: 11,	/* SAT transmit pulses */
		sb_alt_coarse1	: 5,	/* ALT coarse gate delay (MSB) */
		sb_alt_coarse2	: 4,	/* ALT coarse gate delay (LSB) */
		sb_burst_time_1	: 15,	/* Length of burst period */
		sb_alt_rg	: 3,	/* ALT receiver gain */
		sb_sar_rg	: 3,	/* SAR receiver gain */
		sb_rad_rg	: 3,	/* Radiometer receiver gain */
		sb_alt_skip	: 2,	/* ALT skip factor */
		sb_rad_source	: 1,	/* Radiometer switch flag */
		sb_alt_set	: 1;	/* ALT data present flag */
} sab_b;
					/* Begin sab_hdr.h */
typedef	struct	{			/* altedr.h 1.2 11/21/89 */
	uchar	sb_sync[4],		/* JPL Sync code 0x03915ed3 */
		sb_thresh[24],		/* BFQ threshold values */
		sb_rad[4],		/* Radiometer reading */
		sb_update;		/* Clock update count */
	sclk	sb_sclk;		/* Spacecraft clock */
	ushort	sb_spare1,		/* Spare */
		sb_sab_b[5];		/* Bit fields mapped by sab_b */
	uchar	sb_bmc_flag[2];		/* Buffer memory checkout */
} sab_hdr;
					/* End  sab_hdr.h */ 
	/*
	**	ALT-EDR type 1: Volume header
	*/

/* No binary structure */

	/*
	**	ALT-EDR Type 2: Orbit Header
	*/
					/* Begin edr_oh_rec.h */
typedef	struct	{			/* altedr.h 1.2 11/21/89 */
	char	oh_orbit[5],		/* orbit number */
		oh_map_start_sclk[15],	/* commanded mapping start SCLK */
		oh_map_stop_sclk[15],	/* commanded mapping stop SCLK */
		oh_sab_start_sclk[15],	/* SCLK of first SAB */
		oh_sab_stop_sclk[15],	/* SCLK of last SAB */
		oh_sab_start_scet[23],	/* SCET of first SAB */
		oh_sab_stop_scet[23],	/* SCET of last SAB */
		oh_start_ert[23],	/* ERT of data start */
		oh_stop_ert[23],	/* ERT of data stop */
		oh_nrec[4],		/* Number of alt records */
		oh_nsab[4],		/* Number of SAB headers */
		oh_data_time[5],	/* Data period "mm:ss" */
		oh_gap_time[5],		/* Total gap time "mm:ss" */
		oh_per_sclk[15],	/* predicted SCLK of periapsis */
		oh_sma[23],		/* periapsis semi major axis */
		oh_ecc[23],		/* periapsis eccentricity */
		oh_inc[23],		/* periapsis inclination */
		oh_lan[23],		/* periapsis long of asc node */
		oh_arg[23],		/* periapsis argument */
		oh_pad[1];		/* padding */
} edr_oh_rec;
					/* End edr_oh_rec.h */
	/*
	**	ALT-EDR Type 3: Data Quality
	*/
					/* Begin edr_dq_rec.h */
typedef	struct	{			/* altedr.h 1.2 11/21/89 */
	char	dq_frames[4],		/* valid frames since last gap */
		dq_last_scet[23],	/* SCET of first missing SAB */
		dq_last_ert[15],	/* SCLK of first missing SAB */
		dq_first_scet[23],	/* SCET of first SAB after gap */
		dq_first_ert[15];	/* SCLK of first SAB after gap */
} edr_dq_rec;
					/* End edr_dq_rec.h */
	/*
	**	ALT-EDR Type 4: Spacecraft Ephemeris (S-Kernels)
	*/

/* No binary structure */

	/*
	**	ALT-EDR Type 5: SCLK/SCET Clock Coefficients
	*/
					/* Begin edr_sc_rec.h */
#define	EDR_SC_SCANF \
	" %8d:%2d:%1d %2d-%3d/%2d:%2d:%6f %6f %12lf %2d-%3d/%2d:%2d:%2d  %8d"
					/* End edr_sc_rec.h */

	/*
	**	ALT-EDR Type 6: DSN Monitor
	*/

#define	MO_MST_EXT	0x80		/* Extension flag */
#define	MO_MST_TIME_ID	0x70		/* Time code ID */
#define	MO_MST_EP	0x08		/* Epoch ID */
#define	MO_MST_LD	0x04		/* Length of day segment */
#define	MO_MST_RESOL	0x03		/* Time resolution */
					/* Begin edr_mo_rec.h */
typedef	struct	{			/* altedr.h 1.2 11/21/89 */
	sfdu	mo_hdr;			/* NJPL1I00C115 data header */
	chdo	mo_chdo1;		/* CHDO type=1 length=4 */
	tis_1	mo_tis1;		/* TIS Primary Header */
	chdo	mo_chdo2;		/* CHDO type=121 length=28 */
	uchar	mo_originator,		/* Origin Code=48 (ORG_DSN) */
		mo_last_modifier,	/* Last Modifier = 108 (ORG_GIF) */
		mo_scft_id,		/* Spacecraft ID */
		mo_data_source,		/* Station ID (DSN_) */
		mo_spare1,		/* Spare */
		mo_mst_flg;		/* Sample time flags (MO_MST) */
	scet	mo_mst;			/* Monitor sample time */
	short	mo_spare2;		/* Spare */
	scet	mo_rct;			/* Record creation time */
	ushort	mo_spare3,		/* Spare */
		mo_flags;		/* Flag fields (T2I) */
	short	mo_nlock,		/* Lock count */
		mo_lrn;			/* Logical record number */
	chdo	mo_chdo3;		/* CHDO type=10 length=518 */
	char	mo_data[518];		/* Monitor 5-12 logical record */
} edr_mo_rec;
					/* End edr_mo_rec.h */
	/*
	**	ALT-EDR Type 7: Quaternion coefficients
	*/

/* No binary structure */

	/*
	**	ALT-EDR Type 8: Engineering DECOM/DECAL
	*/

/* No binary structure */

	/*
	**	ALT-EDR Type 9: Engineering Frames
	*/

#define	EN_ID_REF	0x80		/* Ref FID not established */
#define	EN_ID_CORR	0x40		/* Frame ID corrected */
#define	EN_TRICKLE_REF	0x20		/* Trickle channel id established */
#define	EN_OVERLAP	0x08		/* Recorder overlap is present */
#define	EN_RECORDER	0x04		/* New recorder */
#define	EN_SNR_QUALITY	0x02		/* Bad SNR */
#define	EN_OVERLAP_REM	0x01		/* Overlap removed */

					/* Begin edr_en_rec.h */
typedef	struct	{			/* altedr.h 1.2 11/21/89 */
	sfdu	en_hdr;			/* NJPL2I000131 header */
	chdo	en_chdo1;		/* CHDO type=1 length=146 */
	tis_1	en_tis1;		/* TIS Primary Header */
	tis_2	en_tis2;		/* TIS Secondary Header */
	mgn_3	en_mgn3;		/* MGN Tertiary Header */
	chdo	en_chdo2;		/* CHDO type=21, length=30 */
	short	en_vector_size;		/* Number of filler bytes */
	uchar	en_filler_flags[20],	/* RCD frame fill flags */
		en_frame_id,		/* Minor frame index 0-23 */
		en_flags,		/* Flag fields (EN) */
		en_mro_address,		/* Trickle channel number */
		en_spare1;		/* Spare */
	chdo	en_chdo3;		/* CHDO type=21, length=10 */
	uchar	en_frame[100];		/* Engineering minor frame */
} edr_en_rec;
					/* End edr_en_rec.h */
	/*
	**	ALT-EDR Type 10: SAB Headers
	*/

#define	SA_DECODE	0x80		/* SAB header not decoded */
#define	SA_GOLAY_UCD	0x40		/* Golay decoder disabled */
#define	SA_SRC_CHANGE	0x20		/* Source station changed */
#define	SA_OVERLAP	0x10		/* Tape recorder overlap */
#define	SA_RECORDER	0x08		/* If overlap, new recdr ok */

					/* Begin edr_sa_rec.h */
typedef	struct	{			/* altedr.h 1.2 11/21/89 */
	sfdu	sa_hdr;			/* NJPL2I000131 data header */
	chdo	sa_chdo1;		/* CHDO type=1, length=256 */
	tis_1	sa_tis1;		/* TIS Primary Header */
	tis_2	sa_tis2;		/* TIS Secondary Header */
	mgn_3	sa_mgn3;		/* MGN Tertiary Header */
	chdo	sa_chdo2;		/* CHDO type=24, length=136 */
	short	sa_vector_size;		/* Number of filler bytes */
	uchar	sa_filler_bytes[117],	/* RCD frame fill flags (111 bits) */
		sa_spare1;		/* Spare */
	ushort	sa_sab_length[2];	/* SAB frame length in bytes (unal) */
	short	sa_extract_count,	/* Bytes extracted from first RCD */
		sa_golay_error_count;	/* Number of bit errors */
	uchar	sa_rcd_count,		/* Number of contributing RCD frames */
		sa_rcd_missing,		/* Number of missing RCD frames */
		sa_sab_bet,		/* Bit error tolerance */
		sa_sab_pn_error,	/* Number of sync code bit errors */
		sa_last_source,		/* Last DSN source station */
		sa_flags,		/* Flag fields (SA) */
		sa_total_parts,		/* Number of SAB SFDU's in set */
		sa_part_number;		/* SAB frame Sequence Number */
	chdo	sa_chdo3;		/* Data CHDO */
	sab_hdr	sa_frame;		/* Golay-decoded SAB header frame */
} edr_sa_rec;
					/* End edr_sa_rec.h */
	/*
	**	ALT-EDR Type 11: Altimeter data
	*/
					/* Begin edr_al_rec.h */
typedef	struct	{			/* altedr.h 1.2 11/21/89 */
	sfdu	al_hdr;			/* NJPL2I000131 frame header */
	chdo	al_chdo1;		/* CHDO type=1, length=136 */
	tis_1	al_tis1;		/* TIS Primary Header */
	tis_2	al_tis2;		/* TIS Secondary Header */
	mgn_3	al_mgn3;		/* MGN Tertiary Header */
	chdo	al_chdo2;		/* CHDO type=26, length=16 */
	short	al_vector_size;		/* Number of filler bytes */
	uchar	al_filler_bytes[4];	/* RCD frame fill flags (4 bits) */
	short	al_extract_count,	/* Bytes extracted from first RCD */
		al_golay_error_count;	/* Number of bit errors */
	uchar	al_rcd_count,		/* Number of contributing RCD frames */
		al_rcd_missing,		/* Number of missing RCD frames */
		al_sab_bet,		/* Bit error tolerance */
		al_sab_pn_error,	/* Number of sync code bit errors */
		al_last_source,		/* Last DSN source station */
		al_flags;		/* Flag fields (SA) */
	chdo	al_chdo3;		/* Data CHDO */
	sab_hdr	sa_frame;		/* Golay-decoded SAB header frame */
	uchar	al_frame[2266];		/* Altimetry frame */
} edr_al_rec;	
					/* End edr_al_rec.h */
	/*
	**	ALT-EDT Type 12: Volume Trailer
	*/

/* No binary structure */

