/*
	@(#)mgm.h   MgnAlt 1.10 (MIT/CSR) 11/21/89

	Function:	General Magellan A&R Definitions
	System:		Magellan Altimetry Data Reduction
	Phase:		All
	Module:		mgm.h
	Revision:	1.10
	Date:		11/21/89
	Author:		pgf@space.mit.edu
	Created:	Tue Sep  6 17:23:23 EDT 1988
	Checker:	
	Checked:	
	Control:	SCCS
*/

#ifndef FILE
#include	<stdio.h>
#endif

#ifndef INPUT_HEADER_FILE

	/*
	**	Intermediate files
	*/

#define	INPUT_HEADER_FILE	"%s/hdr"
#define	INPUT_DQSUMMARY_FILE	"%s/dqs"
#define	INPUT_EPHEMERIS_FILE	"%s/eph"
#define	INPUT_CLOCK_FILE	"%s/clk"
#define	INPUT_MONITOR_FILE_1	"%s/mo1"
#define	INPUT_MONITOR_FILE_2	"%s/mo2"
#define	INPUT_QUATERNION_FILE	"%s/qtn"
#define	INPUT_BANDWIDTH_FILE	"%s/pbw"
#define	INPUT_DECOM_FILE	"%s/dcm"
#define	INPUT_DECAL_NAME_FILE	"%s/dc0"
#define	INPUT_DECAL_POLY_FILE	"%s/dc1"
#define	INPUT_DECAL_INTERP_FILE	"%s/dc2"
#define	INPUT_DECAL_FLAG_FILE	"%s/dc3"
#define	INPUT_ENGINEERING_FILE	"%s/eng"
#define	INPUT_SAB_HEADER_FILE	"%s/sab"
#define	INPUT_ORBIT_PARM_FILE	"%s/opf"
#define	INPUT_PROC_CONST_FILE	"%s/prc"

	/*
	**	ARCDR data type flags
	*/

#define	ALT_LON		1	/* Footprint Longitude (deg, VBF85) */
#define	ALT_LAT		2	/* Footprint Latitude (deg, VBF85) */
#define	ALT_XFOOT	3	/* Along-track Footprint Size (km) */
#define	ALT_YFOOT	4	/* Cross-track Footprint Size (km) */
#define	ALT_RCAL	5	/* Receiver Noise Calibration (km-sq) */
#define	ALT_RANGE	6	/* Uncorrected range to nadir (km) */
#define	ALT_ATMOS	7	/* Atmospheric corrn to range (km) */
#define	ALT_RADIUS	8	/* Derived Planetary Radius (km) */
#define	ALT_SLOPE	9	/* Derived RMS Surface Slope (deg) */
#define	ALT_RHO		10	/* Derived Fresnel Reflectivity */
#define	ALT_RHOCOR	11	/* Rho Diffuse Scatt Corrn Factor */
#define	ALT_RADERR	12	/* Formal errs in Radius, Slope, Rho */
#define	ALT_SLOERR	13	/* Formal errs in Radius, Slope, Rho */
#define	ALT_RHOERR	14	/* Formal errs in Radius, Slope, Rho */
#define	ALT_RADSLO	15	/* Formal correlations in same */
#define	ALT_SLORHO	16	/* Formal correlations in same */
#define	ALT_RHORAD	17	/* Formal correlations in same */
#define	ALT_SLORAD	18	/* Formal correlations in same */
#define	ALT_RHOSLO	19	/* Formal correlations in same */
#define	ALT_RADRHO	20	/* Formal correlations in same */
#define	ALT_DRAD	21	/* Ephemeris Radius Correction (km) */
#define	ALT_DLON	22	/* Ephemeris Long Corrn. (deg, VBF85) */
#define	ALT_DLAT	23	/* Ephemeris Lat Corrn. (deg, VBF85) */
#define	ALT_FIT		24	/* Non-range-sharp goodness of fit */
#define	ALT_RSFIT	25	/* Range-sharpened goodness-of-fit */

#define	RAD_LON		-1	/* Footprint Longitude (deg, VBF85) */
#define	RAD_LAT		-2	/* Footprint Latitude (deg, VBF85) */
#define	RAD_XFOOT	-3	/* Along Track Footprint Size (km) */
#define	RAD_YFOOT	-4	/* Cross Track Footprint Size (km) */
#define	RAD_SFOOT0	-5	/* SAR Footprint Radii (km) */
#define	RAD_SFOOT1	-6	/* SAR Footprint Radii (km) */
#define	RAD_SAR0	-7	/* SAR Average Backscatter Val (dB) */
#define	RAD_SAR1	-8	/* SAR Average Backscatter Val (dB) */
#define	RAD_ANGLE	-9	/* Incidence Angle (deg) */
#define	RAD_BRIGHT	-10	/* Brightness Temperature (K) */
#define	RAD_RADIUS	-11	/* Average Planetary Radius (km) */
#define	RAD_PLANET	-12	/* System Temperature of Planet (K) */
#define	RAD_SKY		-13	/* Assumed Cold Sky Temperature (K) */
#define	RAD_LOAD	-14	/* System Temperature of Load (K) */
#define	RAD_SURF	-15	/* Physical Surface Temperature (K) */
#define	RAD_EMISS	-16	/* Surface Emissivity */

	/*
	**	General MgM Stuff
	*/

#define	uchar	unsigned char
#define	ushort	unsigned short
#define	ulong	unsigned long
#define	bit	unsigned

typedef	struct	{
	char	*flag_name;		/* argument flag character */
	char	*flag_oper;		/* argument format and title */
	char	*flag_ptr;		/* pointer to argument value */
} flag_entry;

extern	int	flags();		/* Parse calling argument list */
extern	void	init_decal();		/* Read Decalibration files */
extern	int	get_decom_data();	/* Return decal'd channel */
extern	int	get_decal_data();	/* Return decal'd channel */
extern	char	*alloc();		/* Storage allocation */
extern	void	mgmerror();		/* General error handler */

#define	MGM_TITLE(x,y,z)	"x (y z)"
#ifndef	MGM_ETAG
#define	MGM_ETAG	MGM_TITLE(XXX,mgm.h,1.10)	/* Processing phase tag */
#endif
#define	MGM_ERR		01		/* Mgm error with message text */
#define	MGM_PERR	02		/* UNIX library error */
/*
#define	MGMERROR(a, b, c)	mgmerror(MGM_ERR,MGM_ETAG,(a),(b),(c))
#define	MGMPERROR(a, b)		mgmerror(MGM_PERR,MGM_ETAG,(a),(b),(char *)0)
*/
	/*
	**	SFDU Header (Generic SFDO Header)
	*/
					/* Begin sfdu.h */
#define	SFDU_CCSD	"CCSD"		/* CCSDS Control Authority Header */
#define	SFDU_NJPL	"NJPL"		/* JPL Control Authority Header */
#define	SFDU_ASCII	'1'		/* ASCII length field */
#define	SFDU_BINARY	'2'		/* Binary length field */
#define	SFDU_VOLSTOP	'A'		/* Volume terminator */
#define	SFDU_START	'B'		/* Logical collection Start */
#define	SFDU_CATALOG	'C'		/* Catalog/index tables */
#define	SFDU_DDREC	'D'		/* Data definition */
#define	SFDU_DICT	'E'		/* Element/Parameters Dictionary */
#define	SFDU_DATA	'I'		/* Information/Data Object */
#define	SFDU_KEYWORD	'K'		/* Keyword (Secondary Header) */
#define	SFDU_PROGRAM	'P'		/* Programming Data Object */
#define	SFDU_SUP	'S'		/* Supplementary Object */
#define	SFDU_TEXT	'T'		/* Text Data (and/or Fill) Object */
#define	SFDU_VOLSTART	'V'		/* Volume Label (Aggregation Start) */
#define	SFDU_STOP	'X'		/* Logical Collection Stop */
#define	SFDU_AGGREGATE	'Z'		/* Non-Classified Aggregation */
	
typedef	struct	{			/* mgm.h 1.10 11/21/89 */
	char	sf_ctrl[4],		/* Control authority */
		sf_vers,		/* 1/2=ASCII/binary */
		sf_class,		/* SFDU type */
		sf_spare[2],		/* Spares: 00 */
		sf_ddid[4];		/* Data definition ID */
	union	{
		ushort	sf_qlen[4];	/* Quad integer aggregate length */
		char	sf_clen[8];	/* ASCII aggregate length */
	} sf_length;
} sfdu;
					/* End sfdu.h */

	/*
	**	MIT DDID Values
	*/

#define	MGM_ALL_DDID	"0177"		/* Collection of MIT data */
#define	MGM_OHF_DDID	"0178"		/* Orbit header record */
#define	MGM_ADF_DDID	"0179"		/* Altimetry data record */
#define	MGM_RDF_DDID	"0180"		/* Radiometry data record */

#define	SFDU_SCET_FMT	"%04d-%02d-%02dT%02d:%02d:%06.3f"

#define	sfduend(s)	((strlen(s) & 01) ? " \r\n" : "\r\n")
#define	sfdulen(s)	(*(s) ? (strlen(s)+strlen(sfduend(s))) : 0)

extern	char	*mgm_ptime();		/* return current date/time */
extern	char	*mgm_scet();		/* return SCET date/time */

	/*
	**	Project Magellan Binary CHDU Header labels
	*/
					/* Begin chdo.h */
#define	CHDO_TIS_1	31		/* TIS Primary Label */
#define	CHDO_TIS_2	15		/* TIS Secondary Label */
#define	CHDO_ANC_2	14		/* Ancillary Secondary Label */
#define	CHDO_ANC	10		/* Orbit Header or Quaternion Data */
#define	CHDO_MGN_3	19		/* MGN Tertiary Label */
#define	CHDO_MGN_ENG_4	21		/* MGN Engineering Quaternary Label */
#define	CHDO_MGN_SAB_4	24		/* MGN SAB Header Quaternary Label */
#define	CHDO_MGN_ALT_4	26		/* MGN Altimetry Quaternary Label */
#define	CHDO_MON_2	200		/* DSN Monitor Secondary Label */
#define	CHDO_MON	201		/* DSN Monitor Data */

typedef	struct	{			/* mgm.h 1.10 11/21/89 */
	short	ch_type;		/* Data type code */
	short	ch_length;		/* Length of following data */
} chdo;
					/* End chdo.h */
	/*
	**	Project Magellan Binary Ephemeris time format
	*/
					/* Begin scet.h */
typedef	struct	{			/* mgm.h 1.10 11/21/89 */
	ushort	et_days,		/* days since 1 January 1958, TDB */
		et_msec[2];		/* milliseconds of day */
} scet;
					/* End scet.h */

#define	ETIME_TO_SECONDS(e)	\
	(86400.0*(e).et_days+0.001*((e).et_msec[1]+((ulong)((e).et_msec[0])<<16)))

#define	ET_FORMAT	"%04d-%02d-%02dT%02d:%02d:%06.3f"

	/*
	**	Project Magellan Binary Spacecraft Clock format
	*/
				/* Begin sclk.h */
typedef	struct	{		/* mgm.h 1.10 11/21/89 */
	uchar	sc_rim[3],	/* one per 60 2/3 seconds (major frame) */
		sc_mod91,	/* one per 2/3 seconds (eng minor frame) */
		sc_mod10,	/* one per Real Time Interrupt (RTI) */
		sc_mod8;	/* one per 8.5 msec (RCD minor frame) */
} sclk;
				/* End sclk.h */

	/*
	**	Database flags and definitions
	*/

#define	DBM_CTL_STOP	1	/* Suspend the database manager */
#define	DBM_CTL_RESUME	2	/* Restart database manager */
#define	DBM_CTL_FLUSH	3	/* Flush all pending database updates */
#define	DBM_CTL_DEBUG	4	/* Start database manager debugging */
#define	DBM_CTL_UNDEBUG	5	/* Stop database manager debugging */
#define	DBM_CTL_RELOAD	6	/* Reload the configuration file */

#define	DBM_SLOT	1	/* Tape slot */
#define	DBM_VOLUME	2	/* Tape volume */
#define	DBM_ORBIT	3	/* Spacercraft orbit */

#define	DBM_ADD		1	/* ADD an entry */
#define	DBM_REPLACE	2	/* REPLACE an entry */
#define	DBM_DELETE	3	/* DELETE an entry */

#define	DBM_REP_GOOD	0	/* Database request honored */
#define	DBM_REP_BLOCKED	1	/* Database is stopped */
#define	DBM_REP_TIMEOUT	2	/* Database timeout */
#define	DBM_REP_ERROR	3	/* Database error */

#define	DBM_MAX_NAME	8	/* Maximum length of object name */
#define	DBM_MAX_ITEM	32	/* Maximum length of item name */
#define	DBM_MAX_TEXT	256	/* Maximum length of item value */

#define	DBM_DEBUG_FILE	"/usr/tmp/mgmdbm.debug"
#define	DBM_CONFIG_FILE	"/usr/local/tables/mgmdbm.conf"
#define	DBM_SERVER	"mgmdbmserver"	/* hostname of manager */
#define	DBM_RETRY	5	/* Retry count */
#define	DBM_TIMEOUT	5	/* Timeout seconds */

#ifdef lint

	/*
	**	Definitions for Lint checker
	*/

	/*LINTLIBRARY*/
	/*VARARGS*/
int	flags(n,a,t) int n; char **a; flag_entry *t; { return flags(n,a,t); }
char	*alloc(n,m) { return alloc(n,m); }
char	*mgm_ptime() { return mgm_ptime(); }
char	*mgm_scet(d) double d; { return mgm_ptime(d); }
void	mgmerror(n,s,t,u,v) char *s, *t, *u, *v; { mgmerror(n,s,t,u,v); }

#endif	lint

#endif	INPUT_HEADER_FILE
