



/************************************************************************
*									*
*  JPL Radar Science   Section 334 	Magellan Telemetry Software	*
*  Last Revised on:    6-FEB-1990  	By D. Swantek			*
*  Source File:        JPLMAD::[SWANTEK.MGN.TLM]TELEM.H         	*
*									*
*************************************************************************

  This header file is the C equivalent to J. Gilbert's FORTRAN 
  include file TELEM.INC. It gives the structure used to store 
  the raw and filtered telemetry, files which contain all the 
  values extracted from the engineering file via the Decom and
  Decal files.
      
*/

#define	Mod1_max  7000
#define	Mod13_max 538
#define	Mod24_max 291
#define	Mod91_max 153

struct	telemc
{					/*  Spacecraft telemetry:	*/
	struct	telem_sa_q
  	{
					/*  Delta quaternions:		*/
		double	q1,		/*  E-1028  <- Channels		*/
			q2,		/*  E-1029			*/
			q3;		/*  E-1030			*/

	} sa_q[ Mod1_max ];

						/*  Cable temperatures:	*/
	double	cable1_temp[ Mod91_max ];	/*  E-0041		*/
						/*  Cable temperatures:	*/
	double	cable2_temp[ Mod91_max ];	/*  E-0042		*/
						/*  Cable temperatures:	*/
	double	cable3_temp[ Mod91_max ];	/*  E-0043		*/
						/*  Cable temperatures:	*/
	double	cable4_temp[ Mod91_max ];	/*  E-0044		*/
						/*  Cable temperatures:	*/
	double	cable5_temp[ Mod91_max ];	/*  E-0045		*/
						/*  RXU preamp temperature:*/
	double	RXU_A_temp[ Mod24_max ];	/*  R-0670		*/
						/*  RXU preamp temperature:*/
	double	RXU_B_temp[ Mod24_max ];	/*  R-1670		*/
						/*  ONU SAR temperature:*/
	double	ONU_A_temp[ Mod24_max ];	/*  R-0570		*/
						/*  ONU SAR temperature:*/
	double	ONU_B_temp[ Mod24_max ];	/*  R-1570		*/
						/*  XMTR stage 1 temperature:*/
	double	XMTR_A_temp[ Mod24_max ];	/*  R-0472		*/
						/*  XMTR stage 1 temperature:*/
	double	XMTR_B_temp[ Mod24_max ];	/*  R-1472		*/

	int	nsa;
	int	nsb1;
	int	nsb2;
	int	nsb3;
	int	nsb4;
	int	nsb5;
	int	nrbra;
	int	nrbrb;
	int	nrboa;
	int	nrbob;
	int	nrbxa;
	int	nrbxb;

	struct	telem_ra 		/*  Radar telemetry:		*/
  	{
					/*  Radar hardware states:	*/
					/*  0 = B channel is on		*/
					/*  1 = A channel is on		*/

		short	RXU_B_state,	/*  R-2105			*/
			RXU_A_state,	/*  R-2106			*/
			ONU_B_state,	/*  R-2107			*/
			ONU_A_state,	/*  R-2108			*/
			XMTR_B_state,	/*  R-2109			*/
			XMTR_A_state;	/*  R-2110			*/
  	} ra;

	struct	telem_sa_time 
  	{
		unsigned 
		char	rim[ 3 ],	/*  Clock for this minor frame:	*/
      			mod91[ 1 ],
      			mod10[ 1 ],
      			mod8[ 1 ];

	} sa_time[ Mod1_max ];

	struct	telem_sb1
  	{
		unsigned 
		char	rim[ 3 ],	/*  Clock for this minor frame:	*/
      			mod91[ 1 ],
      			mod10[ 1 ],
      			mod8[ 1 ];

  	} sb1[ Mod91_max ];

	struct	telem_sb2
  	{
		unsigned 
		char	rim[ 3 ],	/*  Clock for this minor frame:	*/
      			mod91[ 1 ],
      			mod10[ 1 ],
      			mod8[ 1 ];

  	} sb2[ Mod91_max ];

	struct	telem_sb3
  	{
		unsigned 
		char	rim[ 3 ],	/*  Clock for this minor frame:	*/
      			mod91[ 1 ],
      			mod10[ 1 ],
      			mod8[ 1 ];

  	} sb3[ Mod91_max ];

	struct	telem_sb4
  	{
		unsigned 
		char	rim[ 3 ],	/*  Clock for this minor frame:	*/
      			mod91[ 1 ],
      			mod10[ 1 ],
      			mod8[ 1 ];

  	} sb4[ Mod91_max ];

	struct	telem_sb5
  	{
		unsigned 
		char	rim[ 3 ],	/*  Clock for this minor frame:	*/
      			mod91[ 1 ],
      			mod10[ 1 ],
      			mod8[ 1 ];

  	} sb5[ Mod91_max ];

	struct	telem_rbra
  	{
		unsigned 
		char	rim[ 3 ],	/*  Clock for this minor frame:	*/
      			mod91[ 1 ],
      			mod10[ 1 ],
      			mod8[ 1 ];

  	} rbra[ Mod24_max ];

	struct	telem_rbrb
  	{
		unsigned 
		char	rim[ 3 ],	/*  Clock for this minor frame:	*/
      			mod91[ 1 ],
      			mod10[ 1 ],
      			mod8[ 1 ];

  	} rbrb[ Mod24_max ];

	struct	telem_rboa
  	{
		unsigned 
		char	rim[ 3 ],	/*  Clock for this minor frame:	*/
      			mod91[ 1 ],
      			mod10[ 1 ],
      			mod8[ 1 ];

  	} rboa[ Mod24_max ];

	struct	telem_rbob
  	{
		unsigned 
		char	rim[ 3 ],	/*  Clock for this minor frame:	*/
      			mod91[ 1 ],
      			mod10[ 1 ],
      			mod8[ 1 ];

  	} rbob[ Mod24_max ];

	struct	telem_rbxa
  	{
		unsigned 
		char	rim[ 3 ],	/*  Clock for this minor frame:	*/
      			mod91[ 1 ],
      			mod10[ 1 ],
      			mod8[ 1 ];

  	} rbxa[ Mod24_max ];

	struct	telem_rbxb
  	{
		unsigned 
		char	rim[ 3 ],	/*  Clock for this minor frame:	*/
      			mod91[ 1 ],
      			mod10[ 1 ],
      			mod8[ 1 ];

  	} rbxb[ Mod24_max ];

};


